@@ -159,6 +159,8 @@ about_dlg_struct *AboutDlgNew(gpointer core_ptr)
 "Sobre"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Omtrent"
+#elif defined(PROG_LANGUAGE_POLISH)
+"O programie"
 #else
 "About"
 #endif
@@ -267,6 +269,8 @@ about_dlg_struct *AboutDlgNew(gpointer core_ptr)
 "Os Crditos"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Kreditter"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Autorzy"
 #else
 "Credits"
 #endif
@@ -343,6 +347,8 @@ about_dlg_struct *AboutDlgNew(gpointer core_ptr)
 "A Verso"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Versjon"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Wersja"
 #else
 "Version"
 #endif
@@ -462,6 +468,8 @@ about_dlg_struct *AboutDlgNew(gpointer core_ptr)
 "Os Direitos Autorais"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Copyright"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Prawa autorskie"
 #else
 "Copyright"
 #endif
@@ -618,6 +626,8 @@ about_dlg_struct *AboutDlgNew(gpointer core_ptr)
 "A Verso"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Versjon"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Wersja"
 #else
 "Version"
 #endif
@@ -663,6 +673,8 @@ about_dlg_struct *AboutDlgNew(gpointer core_ptr)
 "A Verso"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Versjon"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Wersja"
 #else
 "Version"
 #endif
@@ -694,6 +706,8 @@ about_dlg_struct *AboutDlgNew(gpointer core_ptr)
 "A Linguagem"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Sprk"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Jzyk"
 #else
 "Language"
 #endif
@@ -720,6 +734,8 @@ about_dlg_struct *AboutDlgNew(gpointer core_ptr)
 "O Portugus"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Norsk"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Polski"
 #else
 "English"
 #endif
@@ -742,6 +758,8 @@ about_dlg_struct *AboutDlgNew(gpointer core_ptr)
 "Compile Data"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Kompiler Date"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Data kompilacji"
 #else
 "Compile Date"
 #endif
@@ -784,6 +802,8 @@ about_dlg_struct *AboutDlgNew(gpointer core_ptr)
 "O Compilador"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Kompilator"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Kompilator"
 #else
 "Compiler"
 #endif
@@ -814,6 +834,8 @@ about_dlg_struct *AboutDlgNew(gpointer core_ptr)
 "Compilado Em"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Kompilert At"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Skompilowano na"
 #else
 "Compiled At"
 #endif
@@ -858,6 +880,8 @@ about_dlg_struct *AboutDlgNew(gpointer core_ptr)
 "A Verso"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Versjon"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Wersja"
 #else
 "Version"
 #endif
@@ -901,6 +925,8 @@ about_dlg_struct *AboutDlgNew(gpointer core_ptr)
 "A Verso"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Versjon"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Wersja"
 #else
 "Version"
 #endif
