@@ -273,6 +273,8 @@ static void EDVArchiveInfoSetCommentCB(GtkWidget *widget, gpointer data)
 "O erro de sistemas."
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Systemfeil."
+#elif defined(PROG_LANGUAGE_POLISH)
+"Bd systemu."
 #else
 "Systems error."
 #endif
@@ -294,6 +296,8 @@ static void EDVArchiveInfoSetCommentCB(GtkWidget *widget, gpointer data)
 "Este formato do arquivo nao apoia comentrios."
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Dette arkivs format sttter ikke kommentarer."
+#elif defined(PROG_LANGUAGE_POLISH)
+"Format tego archiwum nie obsuguje komentarzy."
 #else
 "This archive's format does not support comments."
 #endif
@@ -315,6 +319,8 @@ static void EDVArchiveInfoSetCommentCB(GtkWidget *widget, gpointer data)
 "Erro por o comentrio de arquivo."
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "En feil forekommet whiles etting arkivkommentaren."
+#elif defined(PROG_LANGUAGE_POLISH)
+"Bd przy ustawianiu komentarza archiwum."
 #else
 "Error setting archive comment."
 #endif
@@ -337,6 +343,8 @@ static void EDVArchiveInfoSetCommentCB(GtkWidget *widget, gpointer data)
 "Comentrio Fixo Fracassou"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Fast Comment Failed"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Bd ustawiania komentarza"
 #else
 "Set Comment Failed"
 #endif
@@ -498,14 +506,14 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 	EDVObjectSetPath(obj, d->arch_obj);
 	if(!lstat((const char *)arch_obj, &lstat_buf))
 	    EDVObjectSetStat(obj, &lstat_buf);
-	EDVObjectValidateLink(obj);
+	EDVObjectUpdateLinkFlags(obj);
 	/* Get medium pixmap and mask */
 	EDVMatchObjectIcon(
 	    c_ptr->device, c_ptr->total_devices,
 	    c_ptr->mimetype, c_ptr->total_mimetypes,
 	    obj->type,
 	    obj->full_path,
-	    obj->link_valid,
+	    EDV_OBJECT_IS_LINK_VALID(obj),
 	    obj->permissions,
 	    1,			/* Medium sized icons */
 	    &pixmap, &mask,
@@ -558,7 +566,7 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 		    this_obj_size = obj_ptr->size + (
 			(obj_ptr->full_path != NULL) ?
 			STRLEN(obj_ptr->full_path) : STRLEN(obj_ptr->name)
-		    ) + STRLEN(obj_ptr->linked_to);
+		    ) + STRLEN(obj_ptr->link_value);
 		    links_size += this_obj_size;
 		    uncompressed_size += this_obj_size;
 		    break;
@@ -608,6 +616,8 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 "O Comentrio & Estatstica"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Kommentar & Statistics"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Komentarz i statystyki archiwum"
 #else
 "Archive Comment & Statistics"
 #endif
@@ -693,10 +703,14 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 	}
 	/* Label */
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = STRDUP(
+	rcstyle->font_name = g_strdup(
+#if defined(PROG_LANGUAGE_POLISH)
+"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-2"
+#else
 "-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
+#endif
 	);
-	s = EDVCopyShortenPath(obj->name, 40);
+	s = EDVShortenPath(obj->name, 40);
 	d->name_label = w = gtk_label_new(s);
 	g_free(s);
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
@@ -712,8 +726,12 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 	parent4 = w;
 	/* Label */
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = STRDUP(
+	rcstyle->font_name = g_strdup(
+#if defined(PROG_LANGUAGE_POLISH)
+"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-2"
+#else
 "-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
+#endif
 	);
 	w = gtk_label_new(
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -730,6 +748,8 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 "Localidade"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Plassering"
+#elif defined(PROG_LANGUAGE_POLISH)
+"cieka"
 #else
 "Location"
 #endif
@@ -741,11 +761,15 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 	GTK_RC_STYLE_UNREF(rcstyle)
 	/* Location Label */
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = STRDUP(
+	rcstyle->font_name = g_strdup(
+#if defined(PROG_LANGUAGE_POLISH)
+"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-2"
+#else
 "-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
+#endif
 	);
 	s2 = g_dirname(obj->full_path);
-	s = EDVCopyShortenPath(s2, 45);
+	s = EDVShortenPath(s2, 45);
 	d->location_label = w = gtk_label_new(s);
 	g_free(s);
 	g_free(s2);
@@ -832,8 +856,12 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 }
 
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = STRDUP(
+	rcstyle->font_name = g_strdup(
+#if defined(PROG_LANGUAGE_POLISH)
+"-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-2"
+#else
 "-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
+#endif
 	);
 #if defined(PROG_LANGUAGE_SPANISH)
 	CREATE_LABEL(0, "Los Archivos:", file_objects, files_size);
@@ -870,6 +898,11 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 	CREATE_LABEL(1, "Kataloger:", directory_objects, directories_size);
 	CREATE_LABEL(2, "Ledd:", link_objects, links_size);
 	CREATE_LABEL(3, "Annen Object:", other_objects, others_size);
+#elif defined(PROG_LANGUAGE_POLISH)
+	CREATE_LABEL(0, "Pliki:", file_objects, files_size);
+	CREATE_LABEL(1, "Katalogi:", directory_objects, directories_size);
+	CREATE_LABEL(2, "Odnoniki:", link_objects, links_size);
+	CREATE_LABEL(3, "Inne obiekty:", other_objects, others_size);
 #else
 	CREATE_LABEL(0, "Files:", file_objects, files_size);
 	CREATE_LABEL(1, "Directories:", directory_objects, directories_size);
@@ -879,8 +912,12 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 	GTK_RC_STYLE_UNREF(rcstyle)
 
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = STRDUP(
+	rcstyle->font_name = g_strdup(
+#if defined(PROG_LANGUAGE_POLISH)
+"-adobe-helvetica-bold-r-normal-*-12-*-*-*-*-*-iso8859-2"
+#else
 "-adobe-helvetica-bold-r-normal-*-12-*-*-*-*-*-iso8859-1"
+#endif
 	);
 #if defined(PROG_LANGUAGE_SPANISH)
 	CREATE_LABEL(4, "El Suma:", total_objects, uncompressed_size);
@@ -896,6 +933,8 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 	CREATE_LABEL(4, "O Total:", total_objects, uncompressed_size);
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 	CREATE_LABEL(4, "Total:", total_objects, uncompressed_size);
+#elif defined(PROG_LANGUAGE_POLISH)
+	CREATE_LABEL(4, "Razem:", total_objects, uncompressed_size);
 #else
 	CREATE_LABEL(4, "Total:", total_objects, uncompressed_size);
 #endif
@@ -962,6 +1001,9 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 		"Strrelse", s2,
 		"Utvidet:", s
+#elif defined(PROG_LANGUAGE_POLISH)
+		"Rozmiar", s2,
+		"Niezkompresowany:", s
 #else
 		"Size", s2,		/* Header & Footer */
 		"Uncompressed:", s
@@ -1001,6 +1043,8 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 "Comprimido"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Komprimert"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Zkompresowany"
 #else
 "Compressed"
 #endif
@@ -1027,6 +1071,8 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 "O Comentrio"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Kommentar"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Komentarz"
 #else
 "Comment"
 #endif
@@ -1051,8 +1097,12 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 	parent3 = w;
 	/* Comments text box */
 	rcstyle = gtk_rc_style_new();
-	rcstyle->font_name = STRDUP(
+	rcstyle->font_name = g_strdup(
+#if defined(PROG_LANGUAGE_POLISH)
+"-adobe-courier-medium-r-normal-*-12-*-*-*-*-*-iso8859-2"
+#else
 "-adobe-courier-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
+#endif
 	);
 	d->comment_text = w = gtk_text_new(NULL, NULL);
 	editable = GTK_EDITABLE(w);
@@ -1135,6 +1185,8 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 "O Jogo"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Sett"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Ustaw"
 #else
 "Set"
 #endif
@@ -1185,6 +1237,8 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 "A Pasta"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Masse"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Wklej"
 #else
 "Paste"
 #endif
@@ -1214,6 +1268,8 @@ edv_archive_info_struct *EDVArchiveInfoNew(
 "Insira Arquivo"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Tilfy Arkiv"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Wstaw plik"
 #else
 "Insert File"
 #endif
