@@ -490,6 +490,8 @@ gboolean EDVArchAddOptsGetResponse(
 "Adicione A Opes de Arquivo"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Tilfy To Archive Options"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Opcje dodawania do archiwum"
 #else
 "Add To Archive Options"
 #endif
@@ -508,6 +510,8 @@ gboolean EDVArchAddOptsGetResponse(
 "Adicione"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Tilfy"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Dodaj"
 #else
 "Add"
 #endif
@@ -526,6 +530,8 @@ gboolean EDVArchAddOptsGetResponse(
 "Cancelamento"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Kanseller"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Anuluj"
 #else   
 "Cancel"
 #endif
@@ -617,8 +623,12 @@ gboolean EDVArchAddOptsGetResponse(
 		gtk_widget_show(w);
 
 		rcstyle = gtk_rc_style_new();
-		rcstyle->font_name = STRDUP(
+		rcstyle->font_name = g_strdup(
+#if defined(PROG_LANGUAGE_POLISH)
+"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-2"
+#else
 "-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
+#endif
 		);
 		w = gtk_label_new(EDVGetPathName(arch_obj));
 		gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
@@ -679,6 +689,8 @@ archive formats and therefore do not apply."
 "O Recurse Em Guias"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Dra In Directories"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Uwzgldnij podkatalogi"
 #else
 "Recurse Into Directories"
 #endif
@@ -708,6 +720,9 @@ archive formats and therefore do not apply."
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Sjekk dette inkludere tilfyingen av objekt som funnet i all\
  barnkataloger av den valgte ut stien(s)"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Zaznacz to pole by doda do archiwum wszystkie obiekty znajdujce\
+ si w podanej ciece (ciekach) i jej (ich) podkatalogach"
 #else
 "Check this to include the adding of objects found in all child\
  directories of the selected path(s)"
@@ -736,6 +751,8 @@ archive formats and therefore do not apply."
 "Compresso"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Kompresjon"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Kompresja"
 #else
 "Compression"
 #endif
@@ -779,6 +796,9 @@ archive formats and therefore do not apply."
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Sett mengden av kompresjon; 0% for ingen kompresjon, 50% for normal\
  kompresjon, og 100% for maksimum kompresjon"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Ustaw stopie kompresji. 0% - brak kompresji, 50%\
+ - normalna kompresja, 100% - maksymalna kompresja"
 #else
 "Set the amount of compression; 0% for no compression,\
  50% for standard compression, and 100% for maximum\
@@ -837,6 +857,13 @@ archive formats and therefore do not apply."
 	    glist = g_list_append(glist, "Standard");
 	    glist = g_list_append(glist, "Hy");
 	    glist = g_list_append(glist, "Maksimum");
+#elif defined(PROG_LANGUAGE_POLISH)
+	    glist = g_list_append(glist, "Brak");
+	    glist = g_list_append(glist, "Niska");
+	    glist = g_list_append(glist, "Normalna");
+	    glist = g_list_append(glist, "Wysoka");
+	    glist = g_list_append(glist, "Maksymalna");
+
 #else
 	    glist = g_list_append(glist, "None");
 	    glist = g_list_append(glist, "Low");
@@ -887,6 +914,8 @@ archive formats and therefore do not apply."
 "O Dereference Liga"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Dereference Ledds"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Obiekty docelowe odnonikw"
 #else
 "Dereference Links"
 #endif
@@ -916,6 +945,9 @@ archive formats and therefore do not apply."
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Sjekk dette tilfye destinasjonen av leddobjekt i stedet for\
  leddet protesterer seg"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Zaznacz to pole by do archwium zostay dodane obiekty wskazywane\
+ przez odnoniki zamiast ich samych"
 #else
 "Check this to add the destination of link objects instead of the\
  link objects themselves"
@@ -1038,6 +1070,8 @@ gboolean EDVArchExtractOptsGetResponse(
 "Extraia De Opes De Arquivo"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Trekk Ut From Archive Options"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Opcje rozpakowywania archiuwum"
 #else
 "Extract From Archive Options"
 #endif
@@ -1056,6 +1090,8 @@ gboolean EDVArchExtractOptsGetResponse(
 "Extraia"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Extrakt"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Rozpakuj"
 #else
 "Extract"
 #endif
@@ -1074,6 +1110,8 @@ gboolean EDVArchExtractOptsGetResponse(
 "Cancelamento"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Kanseller"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Anuluj"
 #else
 "Cancel"
 #endif
@@ -1162,8 +1200,12 @@ gboolean EDVArchExtractOptsGetResponse(
 		gtk_widget_show(w);
 
 		rcstyle = gtk_rc_style_new();
-		rcstyle->font_name = STRDUP(
+		rcstyle->font_name = g_strdup(
+#if defined(PROG_LANGUAGE_POLISH)
+"-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-2"
+#else
 "-adobe-helvetica-bold-r-normal-*-14-*-*-*-*-*-iso8859-1"
+#endif
 		);
 		w = gtk_label_new(EDVGetPathName(arch_obj));
 		gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
@@ -1224,6 +1266,8 @@ archive formats and therefore do not apply."
 "Conserve Guias"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Bevar Directories"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Zachowaj struktur katalogw"
 #else
 "Preserve Directories"
 #endif
@@ -1253,6 +1297,9 @@ archive formats and therefore do not apply."
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Sjekk dette vedlikeholde det originale stiprefikser av hver objekt\
  som trukket ut fra arkivet"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Zaznacz to pole by zachowa oryginalne cieki obiektw\
+ wypakowywanych archiwum"
 #else
 "Check this to maintain the original path prefixes of each object\
  extracted from the archive"
@@ -1282,6 +1329,8 @@ archive formats and therefore do not apply."
 "Conserve Selos De Tempo"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Bevar Time Stamps"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Zachowaj daty dostpu"
 #else
 "Preserve Time Stamps"
 #endif
@@ -1311,6 +1360,9 @@ archive formats and therefore do not apply."
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Sjekk dette vedlikeholde det originale tidsfrimerker av hver\
  objekt som trukket ut fra arkivet"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Zaznacz to pole by zachowa oryginalne daty utworzenia\
+ i modyfikacji obiektw rozpakowywanych z archiwum"
 #else
 "Check this to maintain the original time stamps of each object\
  extracted from the archive"
