@@ -6,13 +6,18 @@
 #define ARCHIVER_H
 
 #include <gtk/gtk.h>
+#include "cfg.h"
 #include "edvtypes.h"
-#include "edvstatusbar.h"
 #include "toolbar.h"
 #include "findbar.h"
+#include "statusbar.h"
 #include "archiveinfo.h"
 
 
+typedef struct _edv_archiver_struct		edv_archiver_struct;
+typedef struct _edv_archiver_opid_struct	edv_archiver_opid_struct;
+
+
 /*
  *	Archiver Contents List Column Types:
  */
@@ -103,15 +108,12 @@ typedef enum {
 /*
  *	Archiver Operation ID:
  */
-typedef struct {
+struct _edv_archiver_opid_struct {
 
-	gpointer	archiver;
 	edv_archiver_op	op;
-	gboolean	allow_multiple;		/* Allow multiple instances
-						 * of this operation in
-						 * lists */
-	toolbar_item_type tb_item_type;		/* Type of item when placed
-						 * on the tool bar */
+	edv_opid_flags	flags;
+	toolbar_item_type	tb_item_type;
+	edv_archiver_struct	*archiver;
 
 	/* Operation callback */
 	void	(*func_cb)(
@@ -142,24 +144,22 @@ typedef struct {
 	guint8	**button_icon_data,	/* Shared */
 		**menu_icon_data;	/* Shared */
 
-} edv_archiver_opid_struct;
+};
 #define EDV_ARCHIVER_OPID(p)	((edv_archiver_opid_struct *)(p))
 
 
 /*
  *	Archiver:
  */
-typedef struct {
+struct _edv_archiver_struct {
 
 	GtkWidget	*toplevel;
-	GtkAccelGroup	*accelgrp;
 	gboolean	processing;
 	gint		busy_count,
 			freeze_count;
 	gpointer	core_ptr;
 
-	edv_archiver_opid_struct	**opid;
-	gint				total_opids;
+	GList		*opid_list;
 
 	gboolean	tool_bar_map_state,
 			location_bar_map_state,
@@ -261,20 +261,27 @@ typedef struct {
 
 
 
-	/* Status bar */
-	edv_status_bar_struct	*status_bar;
+	/* Status Bar */
+	edv_statusbar_struct	*status_bar;
 
-	/* Archive info dialog */
+	/* Archive Info Dialog */
 	edv_archive_info_struct	*arch_info;
 
-} edv_archiver_struct;
+};
 #define EDV_ARCHIVER(p)	((edv_archiver_struct *)(p))
 
 
+/* Utilities */
+extern edv_archiver_opid_struct *EDVArchiverMatchOPID(
+	edv_archiver_struct *archiver, edv_archiver_op op
+);
+
+/* Title */
 extern void EDVArchiverSetTitle(
 	edv_archiver_struct *archiver, const gchar *path
 );
 
+/* Location */
 extern gchar *EDVArchiverCurrentLocation(edv_archiver_struct *archiver);
 extern void EDVArchiverSetLocation(
 	edv_archiver_struct *archiver,
@@ -283,29 +290,37 @@ extern void EDVArchiverSetLocation(
 extern void EDVArchiverUpdateLocationIcon(
 	edv_archiver_struct *archiver, const gchar *path
 );
+
+/* Password */
 extern gchar *EDVArchiverCurrentPassword(edv_archiver_struct *archiver);
 extern void EDVArchiverSetPassword(
 	edv_archiver_struct *archiver, const gchar *password
 );
 
-extern void EDVArchiverToolbarRegenerate(edv_archiver_struct *archiver);
+/* Regenerate Style, Menus, and Tool Bar */
+extern void EDVArchiverAccelkeysRegenerate(edv_archiver_struct *archiver);
+extern void EDVArchiverToolBarRegenerate(edv_archiver_struct *archiver);
 extern void EDVArchiverContentsMenuRegenerate(edv_archiver_struct *archiver);
 
+/* Sync Configuration */
 extern void EDVArchiverSyncConfiguration(edv_archiver_struct *archiver);
 
+/* Select Archive */
 extern void EDVArchiverSelectArchive(
 	edv_archiver_struct *archiver, const gchar *arch_obj,
 	const gchar *password
 );
 
-extern edv_archiver_opid_struct **EDVArchiverOPIDListNew(
-	edv_archiver_struct *archiver,	/* Can be NULL */
-	gint *total
-);
-extern void EDVArchiverOPIDListDelete(
-	edv_archiver_opid_struct **list, gint total
+/* Operation IDs */
+extern GList *EDVArchiverOPIDListNew(
+	edv_archiver_struct *archiver		/* Can be NULL */
 );
+extern void EDVArchiverOPIDListDelete(GList *glist);
 
+/* Accel Keys */
+extern cfg_accelkey_list_struct *EDVArchiverAccelkeysListNewDefault(void);
+
+/* Archiver */
 extern edv_archiver_struct *EDVArchiverNew(gpointer core_ptr);
 extern void EDVArchiverSyncData(edv_archiver_struct *archiver);
 extern void EDVArchiverUpdateMenus(edv_archiver_struct *archiver);
