@@ -14,7 +14,7 @@
 #include "cfg.h"
 #include "edvobj.h"
 #include "edvarchobj.h"
-#include "edvstatusbar.h"
+#include "statusbar.h"
 #include "archiver.h"
 #include "archivercb.h"
 #include "archiveropcb.h"
@@ -284,9 +284,11 @@ gint EDVArchiverKeyEventCB(
 )
 {
 	gint status = FALSE;
+	gboolean is_press;
 	gint etype;
 	guint keyval, state;
-	gboolean press;
+	GtkWidget *w, *focus_widget;
+	const cfg_item_struct *cfg_list;
 	edv_core_struct *core_ptr;
 	edv_archiver_struct *archiver = EDV_ARCHIVER(data);
 	if((widget == NULL) || (key == NULL) || (archiver == NULL))
@@ -299,11 +301,11 @@ gint EDVArchiverKeyEventCB(
 	if(core_ptr == NULL)
 	    return(status);
 
-	/* Get event type */
+	w = archiver->toplevel;
+	focus_widget = (w != NULL) ? GTK_WINDOW(w)->focus_widget : NULL;        
+	cfg_list = core_ptr->cfg_list;
 	etype = key->type;
-
-	/* Get other key event values */
-	press = (etype == GDK_KEY_PRESS) ? TRUE : FALSE;
+	is_press = (etype == GDK_KEY_PRESS) ? TRUE : FALSE;
 	keyval = key->keyval;
 	state = key->state;
 
@@ -311,81 +313,58 @@ gint EDVArchiverKeyEventCB(
 #define DO_STOP_KEY_SIGNAL_EMIT	{		\
  gtk_signal_emit_stop_by_name(			\
   GTK_OBJECT(widget),				\
-  press ?					\
+  is_press ?					\
    "key_press_event" : "key_release_event"	\
  );						\
 }
 
-	/* Check which ctree this signal is for */
+	/* If the focus_widget is not a GtkEditable then check if the
+	 * keyval is an accelerator key before all subsequence checks
+	 */
+	if((focus_widget != NULL) ?
+	    !GTK_IS_EDITABLE(focus_widget) : TRUE
+	)
+	{
+	    edv_archiver_op op = (edv_archiver_op)EDVMatchAccelKeyOPID(
+		cfg_list, EDV_CFG_PARM_ARCHIVER_ACCELERATOR_KEYS,
+		keyval, state
+	    );
+	    if(op > 0)
+	    {
+		if(is_press)
+		{
+		    edv_archiver_opid_struct *opid = EDVArchiverMatchOPID(
+			archiver, op
+		    );
+		    if(opid != NULL)
+			EDVArchiverOPCB(NULL, -1, opid);
+		}
+		DO_STOP_KEY_SIGNAL_EMIT
+		status = TRUE;
+		return(status);
+	    }
+	}
 
-	/* Contents clist */
+	/* Check which widget this signal is for */
+
+	/* Contents List */
 	if(widget == archiver->contents_clist)
 	{
-	    gint row;
-	    GList *glist;
 	    GtkCList *clist = GTK_CLIST(widget);
-
-
-	    /* Get last selected row */
-	    row = EDVCListGetSelectedLast(clist, NULL);
+	    gint row = EDVCListGetSelectedLast(clist, NULL);
 
 	    /* Handle by key value */
 	    switch(keyval)
 	    {
-	      case GDK_Return:
-	      case GDK_KP_Enter:
-	      case GDK_ISO_Enter:
-	      case GDK_3270_Enter:
-#if 0
-		if(TRUE)
-		{
-		    if(press)
-		    {
-			if(state & GDK_CONTROL_MASK)
-			    EDVArchiverOPProperties(archiver);
-			else if(state & GDK_SHIFT_MASK)
-			    EDVArchiverOPExtractAll(archiver);
-			else
-			    EDVArchiverOPExtract(archiver);
-		    }
-		    DO_STOP_KEY_SIGNAL_EMIT
-		    status = TRUE;
-		}
-#endif
-		break;
-
-	      case GDK_Insert: case GDK_plus:
-	      case GDK_KP_Add: case GDK_KP_Insert:
-#if 0
-		if(TRUE)
-		{
-		    if(press)
-			EDVArchiverOPAdd(archiver);
-
-		    DO_STOP_KEY_SIGNAL_EMIT
-		    status = TRUE;
-		}
-#endif
-		break;
-
-	      case GDK_Delete:
-		if(press)
-		{
-		    EDVArchiverOPDelete(archiver);
-		}
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
-		break;
-
 	      case GDK_space:
 	      case GDK_KP_Space:
 		row = clist->focus_row;
-		if((row >= 0) && (row < clist->rows) && press)
+		if((row >= 0) && (row < clist->rows) && is_press)
 		{
 		    gboolean already_selected = FALSE;
 
 		    /* Check if this row is already selected */
-		    glist = clist->selection;
+		    GList *glist = clist->selection;
 		    while(glist != NULL)
 		    {
 			if(row == (gint)glist->data)
@@ -413,39 +392,39 @@ gint EDVArchiverKeyEventCB(
 		 * item who's name starts with the letter of the key
 		 * that was pressed
 		 */
-		if(isalnum((char)keyval) && press &&
+		if(isalnum((char)keyval) && is_press &&
 		   ((state == 0x00000000) || (state == GDK_SHIFT_MASK))
 		)
 		{
 		    /* Get the column that is displaying the object
 		     * name as column_type_name
 		     */
-		    gint i, column_type_name = -1;
-		    const cfg_intlist_struct *column_type_intlist =
-			CFGItemListGetValueIntList(
-			    core_ptr->cfg_list,
-			    EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN
-			);
-		    if(column_type_intlist != NULL)
+		    gint column_type_name = -1;
+		    const cfg_intlist_struct *intlist = EDV_GET_INTLIST(
+			EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN
+		    );
+		    if(intlist != NULL)
 		    {
 			/* Iterate through column type intlist */
-			for(i = 0; i < column_type_intlist->total; i++)
+			gint i = 0;
+			GList *glist = intlist->list;
+			while(glist != NULL)
 			{
-			    /* Is column i displaying the name? */
-			    if(column_type_intlist->i[i] == EDV_ARCHIVER_COLUMN_TYPE_NAME)
+			    if((edv_archiver_column_type)glist->data ==
+				EDV_ARCHIVER_COLUMN_TYPE_NAME
+			    )
 			    {
 				column_type_name = i;
 				break;
 			    }
+			    i++;
+			    glist = g_list_next(glist);
 			}
 		    }
 
 		    gtk_clist_freeze(clist);
 		    EDVCListSeekCharacter(
-			clist, column_type_name, 0,
-			(gchar)((state & GDK_SHIFT_MASK) ?
-			    toupper((char)keyval) : keyval
-			)
+			clist, column_type_name, 0, keyval
 		    );
 		    gtk_clist_thaw(clist);
 
@@ -453,7 +432,6 @@ gint EDVArchiverKeyEventCB(
 		    status = TRUE;
 		}
 		break;
-
 	    }
 	}
 
@@ -639,18 +617,18 @@ void EDVArchiverResizeColumnCB(
 	/* Check which clist this signal is for */
 	if(GTK_WIDGET(clist) == archiver->contents_clist)
 	{
-	    gint column_type = -1;
+	    edv_archiver_column_type column_type = EDV_ARCHIVER_COLUMN_TYPE_NAME;
 	    cfg_intlist_struct *column_types_intlist, *column_width_intlist;
 
-
 	    /* Get column_type from the given column index */
 	    column_types_intlist = CFGItemListGetValueIntList(
 		core_ptr->cfg_list, EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN
 	    );
 	    if(column_types_intlist != NULL)
 	    {
-		if((column >= 0) && (column < column_types_intlist->total))
-		    column_type = column_types_intlist->i[column];
+		column_type = (edv_archiver_column_type)g_list_nth_data(
+		    column_types_intlist->list, column
+		);
 	    }
 
 	    /* Get column widths intlist */
@@ -659,37 +637,17 @@ void EDVArchiverResizeColumnCB(
 	    );
 	    if(column_width_intlist != NULL)
 	    {
-		/* Need to increase column_width_intlist allocation? */
-		if((column_type >= column_width_intlist->total) &&
-		   (column_type >= 0)
-		)
-		{
-		    gint n;
-		    gint prev_total = column_width_intlist->total;
-
-		    /* Increase array allocation */
-		    column_width_intlist->total = column_type + 1;
-		    column_width_intlist->i = (gint *)g_realloc(
-			column_width_intlist->i,
-			column_width_intlist->total * sizeof(gint)
+		GList *glist = g_list_nth(
+		    column_width_intlist->list, (guint)column_type
+		);
+		if(glist != NULL)
+		    glist->data = (gpointer)width;
+		else
+		    g_printerr(
+"EDVArchiverResizeColumnCB(): Warning:\
+ Specified column type %i not in list of column widths.\n",
+			column_type
 		    );
-		    /* Reset newly allocated indexes */
-		    for(n = prev_total; n < column_width_intlist->total; n++)
-			column_width_intlist->i[n] = 0;
-		}
-
-		/* Got column type in bounds as index on column width
-		 * intlist?
-		 */
-		if((column_type >= 0) &&
-		   (column_type < column_width_intlist->total)
-		)
-		{
-		    /* Record new width of column on the column width
-		     * intlist.
-		     */
-		    column_width_intlist->i[column_type] = width;
-		}
 	    }
 	}
 }
@@ -735,60 +693,60 @@ void EDVArchiverClickColumnCB(
 	    );
 	    if(column_types_intlist != NULL)
 	    {
-		if((column >= 0) && (column < column_types_intlist->total))
+		edv_archiver_column_type column_type = (edv_archiver_column_type)g_list_nth_data(
+		    column_types_intlist->list,
+		    column
+		);
+		switch(column_type)
 		{
-		    gint column_type = column_types_intlist->i[column];
-		    switch(column_type)
-		    {
-		      case EDV_ARCHIVER_COLUMN_TYPE_NAME:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_SIZE:
-			cmp_func = cmp_func_num;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_COMPRESSED_SIZE:
-			cmp_func = cmp_func_num;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_TYPE:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_PERMISSIONS:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_OWNER:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_GROUP:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_DATE_ACCESS:
-			cmp_func = EDVArchiverCListColumnSortDateAccessCB;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_DATE_MODIFIED:
-			cmp_func = EDVArchiverCListColumnSortDateModifyCB;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_DATE_CHANGED:
-			cmp_func = EDVArchiverCListColumnSortDateChangeCB;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_LOCATION:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_LINKED_TO:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_DEVICE_TYPE:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_COMPRESSION:
-			cmp_func = EDVArchiverCListColumnSortCompressionCB;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_METHOD:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_ARCHIVER_COLUMN_TYPE_CRC:
-			cmp_func = cmp_func_str;
-			break;
-		    }
+		  case EDV_ARCHIVER_COLUMN_TYPE_NAME:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_SIZE:
+		    cmp_func = cmp_func_num;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_COMPRESSED_SIZE:
+		    cmp_func = cmp_func_num;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_TYPE:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_PERMISSIONS:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_OWNER:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_GROUP:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_DATE_ACCESS:
+		    cmp_func = EDVArchiverCListColumnSortDateAccessCB;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_DATE_MODIFIED:
+		    cmp_func = EDVArchiverCListColumnSortDateModifyCB;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_DATE_CHANGED:
+		    cmp_func = EDVArchiverCListColumnSortDateChangeCB;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_LOCATION:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_LINKED_TO:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_DEVICE_TYPE:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_COMPRESSION:
+		    cmp_func = EDVArchiverCListColumnSortCompressionCB;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_METHOD:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_ARCHIVER_COLUMN_TYPE_CRC:
+		    cmp_func = cmp_func_str;
+		    break;
 		}
 	    }
 
@@ -994,38 +952,34 @@ void EDVArchiverComboActivateCB(GtkWidget *widget, gpointer data)
 	if(widget == archiver->location_combo)
 	{
 	    GtkCombo *combo = GTK_COMBO(widget);
-	    gchar *new_path = EDVCopyEvaluateInputPath(
+	    gchar *path = EDVEvaluatePath(
 		NULL,           /* No parent path, imply use toplevel */
 		gtk_entry_get_text(GTK_ENTRY(combo->entry))
 	    );
-	    if(new_path != NULL)
+	    if(path != NULL)
 	    {
 		EDVArchiverSetBusy(archiver, TRUE);
 		GUIBlockInput(archiver->toplevel, TRUE);
 
-
 		/* Update location combo, this is just to record history
 		 * of the new path on the location combo
 		 */
-		EDVArchiverSetLocation(archiver, new_path, TRUE);
+		EDVArchiverSetLocation(archiver, path, TRUE);
 
 		/* Clear the contents clist and load the listing of the
-		 * new archive specified by new_path
+		 * new archive specified by path
 		 */
 		EDVArchiverSelectArchive(
-		    archiver, new_path,
+		    archiver, path,
 		    EDVArchiverCurrentPassword(archiver)
 		);
 
+		EDVArchiverUpdateMenus(archiver);
+
+		g_free(path);
 
 		GUIBlockInput(archiver->toplevel, FALSE);
 		EDVArchiverSetBusy(archiver, FALSE);
-
-		EDVArchiverUpdateMenus(archiver);
-
-		/* Deallocate copy of the new path */
-		g_free(new_path);
-		new_path = NULL;
 	    }
 	}
 	/* Password entry */
@@ -1040,10 +994,10 @@ void EDVArchiverComboActivateCB(GtkWidget *widget, gpointer data)
 		EDVArchiverCurrentPassword(archiver)
 	    );
 
+	    EDVArchiverUpdateMenus(archiver);
+
 	    GUIBlockInput(archiver->toplevel, FALSE);
 	    EDVArchiverSetBusy(archiver, FALSE);
-
-	    EDVArchiverUpdateMenus(archiver);
 	}
 }
 
@@ -1087,8 +1041,7 @@ void EDVArchiverObjectModifiedNotifyCB(
 	 */
 	if(path != NULL)
 	{
-	    const gchar *cstrptr;
-
+	    const gchar *s;
 
 	    if(new_path == NULL)
 		new_path = path;
@@ -1097,8 +1050,8 @@ void EDVArchiverObjectModifiedNotifyCB(
 	     * does then the current location needs to be updated to the
 	     * new path
 	     */
-	    cstrptr = EDVArchiverCurrentLocation(archiver);
-	    if((cstrptr != NULL) ? !strcmp(cstrptr, path) : FALSE)
+	    s = EDVArchiverCurrentLocation(archiver);
+	    if((s != NULL) ? !strcmp(s, path) : FALSE)
 	    {
 		/* Old path matches current location, change values
 		 * reflecting the current location to the value of
@@ -1140,14 +1093,14 @@ void EDVArchiverObjectRemovedNotifyCB(
 	 */
 	if(path != NULL)
 	{
-	    const gchar *cstrptr;
+	    const gchar *s;
 
 	    /* Check if the removed object path matches the current
 	     * location. If it matches then the current location needs to
 	     * be updated to reflect that.
 	     */
-	    cstrptr = EDVArchiverCurrentLocation(archiver);
-	    if((cstrptr != NULL) ? !strcmp(cstrptr, path) : FALSE)
+	    s = EDVArchiverCurrentLocation(archiver);
+	    if((s != NULL) ? !strcmp(s, path) : FALSE)
 	    {
 		/* Removed object path matches the current location */
 
@@ -1329,12 +1282,10 @@ void EDVArchiverReconfiguredNotifyCB(edv_archiver_struct *archiver)
 	gchar *cur_path;
 	GtkRcStyle *standard_rcstyle, *lists_rcstyle;
 	GtkWidget *w;
-	GtkCList *clist;
 	const cfg_item_struct *cfg_list;
-	edv_status_bar_struct *status_bar;
+	edv_statusbar_struct *status_bar;
 	edv_core_struct *core_ptr;
 
-
 	if(archiver == NULL)
 	    return;
 
@@ -1364,8 +1315,11 @@ void EDVArchiverReconfiguredNotifyCB(edv_archiver_struct *archiver)
 	/* Update title */
 	EDVArchiverSetTitle(archiver, cur_path);
 
-	/* Regenerate tool bar */
-	EDVArchiverToolbarRegenerate(archiver);
+	/* Update Accelkey Labels */
+	EDVArchiverAccelkeysRegenerate(archiver);
+
+	/* Regenerate Tool Bar */
+	EDVArchiverToolBarRegenerate(archiver);
 
 	/* Show tool bar? */
 	w = archiver->tool_bar_handle;
@@ -1432,28 +1386,16 @@ void EDVArchiverReconfiguredNotifyCB(edv_archiver_struct *archiver)
 	    gtk_widget_modify_style_recursive(w, standard_rcstyle);
 
 
-	/* Reget listings */
+	/* Realize listings */
+	EDVArchiverContentsRealizeListing(archiver);
 
-	/* Reset displayed row values of the contents clist */
-	clist = (GtkCList *)archiver->contents_clist;
-	if(clist != NULL)
-	{
-	    gtk_clist_freeze(clist);
-	    EDVArchiverContentsResetRows(archiver);
-	    gtk_clist_thaw(clist);
-	}
-
-	/* Update menus */
 	EDVArchiverUpdateMenus(archiver);
 
-
 	/* Notify archiver's toplevel widget to resize */
 	w = archiver->toplevel;
 	if(w != NULL)
 	    gtk_widget_queue_resize(w);
 
-
-	/* Delete copy of current location */
 	g_free(cur_path);
 }
 
@@ -1482,11 +1424,8 @@ void EDVArchiverMimeTypeModifiedCB(
 	gint mt_num, edv_mimetype_struct *mt_ptr
 )
 {
-	const gchar *cstrptr;
 	gchar *cur_path;
 	edv_core_struct *core_ptr;
-	GtkCList *clist;
-
 
 	if(archiver == NULL)
 	    return;
@@ -1498,29 +1437,15 @@ void EDVArchiverMimeTypeModifiedCB(
 	if(core_ptr == NULL)
 	    return;
 
-	clist = (GtkCList *)archiver->contents_clist;
-	if(clist == NULL)
-	    return;
-
-
-	/* Get copy of current location path */
-	cstrptr = EDVArchiverCurrentLocation(archiver);
-	cur_path = (cstrptr != NULL) ? g_strdup(cstrptr) : NULL;
-
-
-	/* Reget listings */
-
-	/* Reset displayed row values of the contents clist */
-	gtk_clist_freeze(clist);
-	EDVArchiverContentsResetRows(archiver);
-	gtk_clist_thaw(clist);
+	/* Get the current location */
+	cur_path = STRDUP(EDVArchiverCurrentLocation(archiver));
 
+	/* Realize listings */
+	EDVArchiverContentsRealizeListing(archiver);
 
 /*	EDVArchiverUpdateMenus(archiver); */
 
-	/* Deallocate copy of current location path */
 	g_free(cur_path);
-	cur_path = NULL;
 }
 
 /*
@@ -1531,11 +1456,8 @@ void EDVArchiverMimeTypeRemovedCB(
 	edv_archiver_struct *archiver, gint mt_num
 )
 {
-	const gchar *cstrptr;
 	gchar *cur_path;
 	edv_core_struct *core_ptr;
-	GtkCList *clist;
-
 
 	if(archiver == NULL)
 	    return;
@@ -1547,28 +1469,14 @@ void EDVArchiverMimeTypeRemovedCB(
 	if(core_ptr == NULL)
 	    return;
 
-	clist = (GtkCList *)archiver->contents_clist;
-	if(clist == NULL)
-	    return;
-
-
-	/* Get copy of current location path */
-	cstrptr = EDVArchiverCurrentLocation(archiver);
-	cur_path = (cstrptr != NULL) ? g_strdup(cstrptr) : NULL;
-
-
-	/* Reget listings */
-
-	/* Reset displayed row values of the contents clist */
-	gtk_clist_freeze(clist);
-	EDVArchiverContentsResetRows(archiver);
-	gtk_clist_thaw(clist);
+	/* Get the current location */
+	cur_path = STRDUP(EDVArchiverCurrentLocation(archiver));
 
+	/* Realize listings */
+	EDVArchiverContentsRealizeListing(archiver);
 
 /*	EDVArchiverUpdateMenus(archiver); */
 
-	/* Deallocate copy of current location path */
 	g_free(cur_path);
-	cur_path = NULL;
 }
 
