@@ -24,16 +24,15 @@
 #include "edvcb.h"
 #include "edvutils.h"
 #include "edvutilsgtk.h"
+
 #include "edvcfglist.h"
 #include "config.h"
 
 
-
 static void EDVArchiverContentsResetColumns(
 	edv_core_struct *core_ptr, edv_archiver_struct *archiver,
 	GtkCList *clist
 );
-static void EDVArchiverContentsClear(GtkCList *clist);
 
 static void EDVArchiverContentsSetCellName(
 	edv_core_struct *core_ptr, edv_archiver_struct *archiver,
@@ -131,19 +130,25 @@ static gint EDVArchiverContentsAppendObject(
 	edv_core_struct *core_ptr, edv_archiver_struct *archiver,
 	GtkCList *clist, edv_archive_object_struct *obj
 );
-static void EDVArchiverContentsGetListing(
+static void EDVArchiverContentsAppendListing(
 	edv_archiver_struct *archiver, gboolean update_status_bar
 );
 
+/* Finding */
 gint EDVArchiverContentsFindRowByPath(
 	edv_archiver_struct *archiver, const gchar *path
 );
 
-void EDVArchiverContentsResetRows(edv_archiver_struct *archiver);
-void EDVArchiverContentsDoUpdate(
+/* Realize Listing */
+void EDVArchiverContentsRealizeListing(edv_archiver_struct *archiver);
+
+/* Get Listing */
+void EDVArchiverContentsGetListing(
 	edv_archiver_struct *archiver, gboolean update_status_bar
 );
+void EDVArchiverContentsClear(edv_archiver_struct *archiver);
 
+/* Object Callbacks */
 void EDVArchiverContentsObjectModifiedNotify(
 	edv_archiver_struct *archiver, const gchar *path,
 	const gchar *new_path, const struct stat *lstat_buf
@@ -152,6 +157,7 @@ void EDVArchiverContentsObjectRemovedNotify(
 	edv_archiver_struct *archiver, const gchar *path
 );
 
+/* Archive Object Callbacks */
 void EDVArchiverContentsArchiveObjectAddedNotify(
 	edv_archiver_struct *archiver, const gchar *arch_path,
 	const gchar *path, edv_archive_object_struct *obj
@@ -187,14 +193,15 @@ static void EDVArchiverContentsResetColumns(
 	GtkCList *clist
 )
 {
-	gint i, m, width, justify = GTK_JUSTIFY_LEFT;
+	gint i, width;
 	const gchar *title = NULL;
-	edv_archiver_column_type column_type;
+	GList *glist;
+	GtkJustification justify = GTK_JUSTIFY_LEFT;
 	GtkRcStyle *lists_rcstyle;
-	const cfg_intlist_struct	*column_types_intlist,
-					*column_width_intlist;
+	cfg_intlist_struct	*column_types_intlist,
+				*column_width_intlist;
 	const cfg_item_struct *cfg_list;
-
+	edv_archiver_column_type column_type;
 
 	if((core_ptr == NULL) || (archiver == NULL) || (clist == NULL))
 	    return;
@@ -203,14 +210,14 @@ static void EDVArchiverContentsResetColumns(
 	lists_rcstyle = core_ptr->lists_rcstyle;
 
 	/* Get column types mapping */
-	column_types_intlist = CFGItemListGetValueIntList(
-	    cfg_list, EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN
+	column_types_intlist = EDV_GET_INTLIST(
+	    EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN
 	);
 	if(column_types_intlist == NULL)
 	    return;
 
-	column_width_intlist = CFGItemListGetValueIntList(
-	    cfg_list, EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN_WIDTH
+	column_width_intlist = EDV_GET_INTLIST(
+	    EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN_WIDTH
 	);
 	if(column_width_intlist == NULL)
 	    return;
@@ -231,28 +238,23 @@ static void EDVArchiverContentsResetColumns(
 	gtk_clist_set_selection_mode(clist, GTK_SELECTION_EXTENDED);
 #endif
 
-	/* Iterate through each column but not exceeding the number of
-	 * columns specified by the column types or column widths
-	 * intlists
-	 */
-	m = MIN(
-	    MIN(clist->columns, column_types_intlist->total),
-	    column_width_intlist->total
-	);
-	for(i = 0; i < m; i++)
+	/* Iterate through each column */
+	for(i = 0, glist = column_types_intlist->list;
+	    glist != NULL;
+	    i++, glist = g_list_next(glist)
+	)
 	{
-	    /* Get column's type which determines what will be listed on
-	     * the current column i
+	    column_type = (edv_archiver_column_type)glist->data;
+
+	    /* Get the width for this column type */
+	    width = (gint)g_list_nth_data(
+		column_width_intlist->list,
+		(guint)column_type
+	    );
+
+	    /* Get column title and justification  based on the
+	     * column type
 	     */
-	    column_type = (edv_archiver_column_type)column_types_intlist->i[i];
-
-	    /* Get width of the column displaying this type */
-	    if((column_type >= 0) && (column_type < column_width_intlist->total))
-		width = column_width_intlist->i[column_type];
-	    else
-		width = 0;
-
-	    /* Title based on column type */
 	    switch(column_type)
 	    {
 	      case EDV_ARCHIVER_COLUMN_TYPE_NAME:
@@ -329,10 +331,7 @@ static void EDVArchiverContentsResetColumns(
 	    gtk_clist_set_column_width(clist, i, width);
 	    gtk_clist_set_column_justification(clist, i, justify);
 	}
-	/* Reset the rest of the columns incase the number of columns
-	 * in the intlists were less than the columns specified by the
-	 * clist
-	 */
+	/* Reset the rest of the columns */
 	for(; i < clist->columns; i++)
 	    gtk_clist_set_column_visibility(clist, i, FALSE);
 
@@ -343,17 +342,6 @@ static void EDVArchiverContentsResetColumns(
 	    );
 }
 
-/*
- *      Deletes all items in the given clist.
- */
-static void EDVArchiverContentsClear(GtkCList *clist)
-{
-	if(clist == NULL)
-	    return;
-
-	gtk_clist_clear(clist);
-}
-
 
 /*
  *	Sets the archive object name for the specified cell on the given
@@ -428,8 +416,8 @@ static void EDVArchiverContentsSetCellSize(
 	gboolean hide_dir_size, gboolean hide_link_size
 )
 {
-	gint	border_minor = 2,
-		type = obj->type;
+	const gint border_minor = 2;
+	const edv_object_type type = obj->type;
 	const gchar *s;
 
 	/* Get string for size */
@@ -460,8 +448,8 @@ static void EDVArchiverContentsSetCellCompressedSize(
 	gboolean hide_dir_size, gboolean hide_link_size
 )
 {
-	gint	border_minor = 2,
-		type = obj->type;
+	const gint border_minor = 2;
+	const edv_object_type type = obj->type;
 	const gchar *s;
 
 	/* Get string for size */
@@ -776,8 +764,8 @@ static void EDVArchiverContentsSetCellLinkedTo(
 )
 {
 	/* Get link destination */
-	const gchar *link_dest = (obj->linked_to != NULL) ?
-	    obj->linked_to : "";
+	const gchar *link_dest = (obj->link_value != NULL) ?
+	    obj->link_value : "";
 
 	/* Set cell */
 	gtk_clist_set_text(
@@ -798,9 +786,9 @@ static void EDVArchiverContentsSetCellDeviceType(
 	gint row, gint column
 )
 {
-	gint	border_minor = 2,
-		type = obj->type,
-		major, minor;
+	const gint border_minor = 2;
+	const edv_object_type type = obj->type;
+	gint major, minor;
 	gchar num_str[2 * 80];
 
 
@@ -843,7 +831,7 @@ static void EDVArchiverContentsSetCellCompression(
 	gboolean hide_dir_size, gboolean hide_link_size
 )
 {
-	gint border_minor = 2;
+	const gint border_minor = 2;
 	gchar s[80];
 
 	/* Get compression ratio and compression type string */
@@ -930,13 +918,14 @@ static void EDVArchiverContentsSetRow(
 	gint row
 )
 {
-	gint i, columns, date_relativity;
+	gint i;
 	gboolean hide_dir_size, hide_link_size, hide_link_permissions;
 	const gchar *date_format;
+	GList *glist;
+	edv_date_relativity date_relativity;
 	edv_archiver_column_type column_type;
-	const cfg_item_struct *cfg_list;
 	cfg_intlist_struct *column_types_intlist;
-
+	const cfg_item_struct *cfg_list;
 
 	if((core_ptr == NULL) || (archiver == NULL) ||
 	   (clist == NULL) || (obj == NULL)
@@ -946,41 +935,28 @@ static void EDVArchiverContentsSetRow(
 	cfg_list = core_ptr->cfg_list;
 
 	/* Get column types mapping */
-	column_types_intlist = CFGItemListGetValueIntList(
-	    cfg_list, EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN
+	column_types_intlist = EDV_GET_INTLIST(
+	    EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN
 	);
 	if(column_types_intlist == NULL)
 	    return;
 
 	/* Get additional display options */
-	date_relativity = CFGItemListGetValueI(
-	    cfg_list, EDV_CFG_PARM_DATE_RELATIVITY
-	);
-	date_format = CFGItemListGetValueS(
-	    cfg_list, EDV_CFG_PARM_DATE_FORMAT
-	);
-	hide_dir_size = CFGItemListGetValueI(
-	    cfg_list, EDV_CFG_PARM_ARCHIVER_CONTENTS_HIDE_DIR_SIZE
-	);
-	hide_link_size = CFGItemListGetValueI(
-	    cfg_list, EDV_CFG_PARM_ARCHIVER_CONTENTS_HIDE_LINK_SIZE
-	);
-	hide_link_permissions = CFGItemListGetValueI(
-	    cfg_list, EDV_CFG_PARM_ARCHIVER_CONTENTS_HIDE_LINK_PERMISSIONS
+	date_relativity = (edv_date_relativity)EDV_GET_I(
+	    EDV_CFG_PARM_DATE_RELATIVITY
 	);
+	date_format = EDV_GET_S(EDV_CFG_PARM_DATE_FORMAT);
+	hide_dir_size = EDV_GET_B(EDV_CFG_PARM_ARCHIVER_CONTENTS_HIDE_DIR_SIZE);
+	hide_link_size = EDV_GET_B(EDV_CFG_PARM_ARCHIVER_CONTENTS_HIDE_LINK_SIZE);
+	hide_link_permissions = EDV_GET_B(EDV_CFG_PARM_ARCHIVER_CONTENTS_HIDE_LINK_PERMISSIONS);
 
-	/* Get total number of columns on the contents clist */
-	columns = MIN(clist->columns, column_types_intlist->total);
-
-	/* Iterate through each column but not more than the columns
-	 * specified by the column types intlist.
-	 */
-	for(i = 0; i < columns; i++)
+	/* Iterate through each column */
+	for(i = 0, glist = column_types_intlist->list;
+	    glist != NULL;
+	    i++, glist = g_list_next(glist)
+	)
 	{
-	    /* Check column references on configuration list, see which
-	     * one this column should show
-	     */
-	    column_type = (edv_archiver_column_type)column_types_intlist->i[i];
+	    column_type = (edv_archiver_column_type)glist->data;
 	    switch(column_type)
 	    {
 	      case EDV_ARCHIVER_COLUMN_TYPE_NAME:
@@ -1144,10 +1120,10 @@ static gint EDVArchiverContentsAppendObject(
 }
 
 /*
- *	Gets all archive objects in the currently opened archive and appends
- *	them to the contents clist.
+ *	Gets all archive objects from the current selected archive
+ *	and appends them to the Contents List.
  */
-static void EDVArchiverContentsGetListing(
+static void EDVArchiverContentsAppendListing(
 	edv_archiver_struct *archiver, gboolean update_status_bar
 )
 {
@@ -1157,13 +1133,12 @@ static void EDVArchiverContentsGetListing(
 	edv_core_struct *core_ptr;
 	edv_archive_object_struct **archive_object, *obj;
 
-
 	if(archiver == NULL)
 	    return;
 
-	core_ptr = EDV_CORE(archiver->core_ptr);
 	clist = (GtkCList *)archiver->contents_clist;
-	if((core_ptr == NULL) || (clist == NULL))
+	core_ptr = EDV_CORE(archiver->core_ptr);
+	if((clist == NULL) || (core_ptr == NULL))
 	    return;
 
 	/* Get listing of archive objects */
@@ -1264,17 +1239,16 @@ gint EDVArchiverContentsFindRowByPath(
 }
 
 /*
- *      Updates all rows on the contents clist by getting the row data
- *      and updates the clist's rows.
+ *	Updates all rows on the Contents List with each row's
+ *	associated archive object.
  *
- *      This is designed to be called whenever the displayed values
- *      of each row need to be set again from internal data, usually
- *      when a MIME Type has been added/modified/removed. This function
- *      should not be used to `refresh' the list (get new values of
- *      disk object structures), use EDVArchiverContentsDoUpdate()
- *      instead.
+ *	This should be called when MIME Types or Devices have been
+ *	added/modified/removed or after reconfiguration.
+ *
+ *	This function should not be used to get a new listing, use
+ *	EDVArchiverContentsGetListing() instead.
  */
-void EDVArchiverContentsResetRows(edv_archiver_struct *archiver)
+void EDVArchiverContentsRealizeListing(edv_archiver_struct *archiver)
 {
 	gint i;
 	GtkWidget *w;
@@ -1282,7 +1256,6 @@ void EDVArchiverContentsResetRows(edv_archiver_struct *archiver)
 	edv_core_struct *core_ptr;
 	edv_archive_object_struct *obj;
 
-
 	if(archiver == NULL)
 	    return;
 
@@ -1293,6 +1266,8 @@ void EDVArchiverContentsResetRows(edv_archiver_struct *archiver)
 
 	clist = GTK_CLIST(w);
 
+	gtk_clist_freeze(clist);
+
 	/* Update columns */
 	EDVArchiverContentsResetColumns(core_ptr, archiver, clist);
 
@@ -1309,13 +1284,15 @@ void EDVArchiverContentsResetRows(edv_archiver_struct *archiver)
 		core_ptr, archiver, clist, obj, i
 	    );
 	}
+
+	gtk_clist_thaw(clist);
 }
 
 /*
- *	Procedure to clear and re update the contents list with the
- *	archive objects found in the current archive.
+ *	Gets a new listing of archive objects from the currently
+ *	selected archive.
  */
-void EDVArchiverContentsDoUpdate(
+void EDVArchiverContentsGetListing(
 	edv_archiver_struct *archiver, gboolean update_status_bar
 )
 {
@@ -1323,7 +1300,6 @@ void EDVArchiverContentsDoUpdate(
 	GtkCList *clist;
 	edv_core_struct *core_ptr;
 
-
 	if(archiver == NULL)
 	    return;
 
@@ -1334,10 +1310,10 @@ void EDVArchiverContentsDoUpdate(
 	w = archiver->contents_clist;
 	if(w == NULL)
 	    return;
-	else
-	    clist = GTK_CLIST(w);
 
+	clist = GTK_CLIST(w);
 
+	/* Report initial progress */
 	if(update_status_bar)
 	{
 	    /* Reset progress */
@@ -1347,24 +1323,28 @@ void EDVArchiverContentsDoUpdate(
 		FALSE
 	    );
 	    EDVStatusBarProgress(
-		archiver->status_bar, 0.0, TRUE
+		archiver->status_bar, 0.0f, TRUE
 	    );
 	}
 
+	gtk_clist_freeze(clist);
 
-	/* Delete all entries */
-	EDVArchiverContentsClear(clist);
-
+	/* Delete all rows in the Contents List */
+	EDVArchiverContentsClear(archiver);
 
 	/* Update columns */
 	EDVArchiverContentsResetColumns(
 	    core_ptr, archiver, clist
 	);
 
-	/* Get listing of archive objects */
-	EDVArchiverContentsGetListing(archiver, update_status_bar);
+	/* Append listing of archive objects from the current selected
+	 * archive
+	 */
+	EDVArchiverContentsAppendListing(archiver, update_status_bar);
 
+	gtk_clist_thaw(clist);
 
+	/* Report final progress */
 	if(update_status_bar)
 	{
 	    /* Reset progress */
@@ -1379,6 +1359,26 @@ void EDVArchiverContentsDoUpdate(
 	}
 }
 
+/*
+ *	Deletes all rows in the Contents List.
+ */
+void EDVArchiverContentsClear(edv_archiver_struct *archiver)
+{
+	GtkCList *clist;
+
+	if(archiver == NULL)
+	    return;
+
+	clist = (GtkCList *)archiver->contents_clist;
+	if(clist == NULL)
+	    return;
+
+	gtk_clist_freeze(clist);
+	gtk_clist_clear(clist);
+	gtk_clist_thaw(clist);
+}
+
+
 /*
  *      Called whenever a disk object has been modified.
  */
@@ -1421,18 +1421,16 @@ void EDVArchiverContentsObjectModifiedNotify(
 	    return;
 	}
 
-	/* Is given path that has been modified the same as the current
-	 * location?
+	/* Is specified path that has been modified the same as the
+	 * current location?
 	 */
 	if(!strcmp(new_path, cur_path))
 	{
 	    /* Reget listing */
-	    gtk_clist_freeze(clist);
-	    EDVArchiverContentsDoUpdate(
+	    EDVArchiverContentsGetListing(
 		archiver,
 		EDV_GET_B(EDV_CFG_PARM_LISTS_ANIMATE_UPDATES)
 	    );
-	    gtk_clist_thaw(clist);
 	}
 
 	DO_FREE_LOCALS
@@ -1451,19 +1449,15 @@ void EDVArchiverContentsObjectRemovedNotify(
 	edv_core_struct *core_ptr;
 	gchar *cur_path, *parent_path;
 
-
 	if(archiver == NULL)
 	    return;
 
+	w = archiver->contents_clist;
 	core_ptr = EDV_CORE(archiver->core_ptr);
-	if(core_ptr == NULL)
+	if((w == NULL) || (core_ptr == NULL))
 	    return;
 
-	w = archiver->contents_clist;
-	if(w == NULL)
-	    return;
-	else
-	    clist = GTK_CLIST(w);
+	clist = GTK_CLIST(w);
 
 #define DO_FREE_LOCALS		\
 {				\
@@ -1481,15 +1475,11 @@ void EDVArchiverContentsObjectRemovedNotify(
 	    return;
 	}
 
-	/* Is given path that has been removed the same as the current
-	 * location?
-	 */
+	/* Currently selected archive removed? */
 	if(!strcmp(path, cur_path))
 	{
-	    /* Clear contents list */
-	    gtk_clist_freeze(clist);
-	    EDVArchiverContentsClear(clist);
-	    gtk_clist_thaw(clist);
+	    /* Delete all rows in the Contents List */
+	    EDVArchiverContentsClear(archiver);
 	}
 
 	DO_FREE_LOCALS
