@@ -11,15 +11,21 @@
 #include "archiver.h"
 
 
+/* Finding */
 extern gint EDVArchiverContentsFindRowByPath(
 	edv_archiver_struct *archiver, const gchar *path
 );
 
-extern void EDVArchiverContentsResetRows(edv_archiver_struct *archiver);
-extern void EDVArchiverContentsDoUpdate(
+/* Realize Listing */
+extern void EDVArchiverContentsRealizeListing(edv_archiver_struct *archiver);
+
+/* Get Listing */
+extern void EDVArchiverContentsGetListing(
 	edv_archiver_struct *archiver, gboolean update_status_bar
 );
+extern void EDVArchiverContentsClear(edv_archiver_struct *archiver);
 
+/* Object Callbacks */
 extern void EDVArchiverContentsObjectModifiedNotify(
 	edv_archiver_struct *archiver, const gchar *path,
 	const gchar *new_path, const struct stat *lstat_buf
@@ -28,6 +34,7 @@ extern void EDVArchiverContentsObjectRemovedNotify(
 	edv_archiver_struct *archiver, const gchar *path
 );
 
+/* Archive Object Callbacks */
 extern void EDVArchiverContentsArchiveObjectAddedNotify(
 	edv_archiver_struct *archiver, const gchar *arch_path,
 	const gchar *path, edv_archive_object_struct *obj
@@ -43,5 +50,4 @@ extern void EDVArchiverContentsArchiveObjectRemovedNotify(
 );
 
 
-
 #endif	/* ARCHIVERCONTENTS_H */
