@@ -168,7 +168,7 @@ static void EDVArchiverDNDUpdateStatusBar(
 )
 {
 	gchar *buf = NULL;
-	edv_status_bar_struct *sb = (archiver != NULL) ?
+	edv_statusbar_struct *sb = (archiver != NULL) ?
 	    archiver->status_bar : NULL;
 	if(sb == NULL)
 	    return;
@@ -299,6 +299,9 @@ arquivo atual?\n"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "pen arkiv \"%s\" i stedet for  tilfye det til det\n\
 nvrendee arkivet?\n"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Otworzy archiwum \"%s\" zamiast dodawania go do\n\
+aktualnego archiwum?\n"
 #else
 "Open archive \"%s\" instead of adding it to the\n\
 current archive?\n"
@@ -322,6 +325,8 @@ current archive?\n"
 "Arquivo Aberto?"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "pent Arkiv?"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Otworzy archiwum?"
 #else
 "Open Archive?"
 #endif
@@ -583,7 +588,7 @@ gint EDVArchiverLocBarIconCrossingCB(
 	GdkBitmap *mask;
 	GdkPixmap *pixmap;
 	GtkWidget *w;
-	edv_status_bar_struct *sb;
+	edv_statusbar_struct *sb;
 	edv_archiver_struct *archiver = EDV_ARCHIVER(data);
 	if((widget == NULL) || (crossing == NULL) || (archiver == NULL))
 	    return(status);
@@ -612,6 +617,8 @@ gint EDVArchiverLocBarIconCrossingCB(
 "Arraste isto criar um elo a esta localidade"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Slep dette skape et ledd til denne plasseringen"
+#elif defined(PROG_LANGUAGE_POLISH)
+"Przecignij to by utworzy odnonik do tej lokacji"
 #else
 "Drag this to create a link to this location"
 #endif
