@@ -11,14 +11,17 @@
 #include "cdialog.h"
 #include "fb.h"
 #include "progressdialog.h"
+#include "toolbar.h"
 
-#include "edvtypes.h"
 #include "cfg.h"
+#include "edvtypes.h"
 #include "edvconfirm.h"
 #include "edvobj.h"
 #include "edvarchobj.h"
 #include "edvarchfio.h"
 #include "edvarchop.h"
+#include "findbar.h"
+#include "statusbar.h"
 #include "archiveopts.h"
 #include "archiveinfo.h"
 #include "archiver.h"
@@ -53,23 +56,21 @@ void EDVArchiverOPLeaveCB(
 	toolbar_item_struct *item, gint id, gpointer data
 );
 
-void EDVArchiverFindBarStartCB(gpointer fb, gpointer data);
+const gchar *EDVArchiverFindBarLocationCB(
+	edv_findbar_struct *fb, gpointer data
+);
+void EDVArchiverFindBarStartCB(edv_findbar_struct *fb, gpointer data);
 void EDVArchiverFindBarEndCB(
-	gpointer fb, gint total_matches, gpointer data
+	edv_findbar_struct *fb, gint total_matches, gpointer data
 );
-gchar *EDVArchiverFindBarLocationCB(gpointer fb, gpointer data);
 void EDVArchiverFindBarMatchCB(
 	const gchar *path, const struct stat *lstat_buf,
 	const gchar *excerpt, gint line_index,
 	gpointer data
 );
 
-void EDVArchiverBarStatusMessageCB(
-	gpointer bar, const gchar *message, gpointer data
-);
-void EDVArchiverBarStatusProgressCB(
-	gpointer bar, gfloat progress, gpointer data
-);
+void EDVArchiverStatusMessageCB(const gchar *message, gpointer data);
+void EDVArchiverStatusProgressCB(gfloat progress, gpointer data);
 
 void EDVArchiverOPSyncDisks(edv_archiver_struct *archiver);
 void EDVArchiverOPWriteProtect(edv_archiver_struct *archiver);
@@ -160,7 +161,7 @@ void EDVArchiverOPCB(
 	if(opid == NULL)
 	    return;
 
-	archiver = EDV_ARCHIVER(opid->archiver);
+	archiver = opid->archiver;
 	if(archiver == NULL)
 	    return;
 
@@ -401,9 +402,7 @@ void EDVArchiverOPEnterCB(
 {
 	const gchar *tooltip;
 	edv_archiver_opid_struct *opid = EDV_ARCHIVER_OPID(data);
-	edv_archiver_struct *archiver = EDV_ARCHIVER(
-	    (opid != NULL) ? opid->archiver : NULL
-	);
+	edv_archiver_struct *archiver = (opid != NULL) ? opid->archiver : NULL;
 	if(archiver == NULL)
 	    return;
 
@@ -420,9 +419,7 @@ void EDVArchiverOPLeaveCB(
 )
 {
 	edv_archiver_opid_struct *opid = EDV_ARCHIVER_OPID(data);
-	edv_archiver_struct *archiver = EDV_ARCHIVER(            
-	    (opid != NULL) ? opid->archiver : NULL
-	);
+	edv_archiver_struct *archiver = (opid != NULL) ? opid->archiver : NULL;
 	if(archiver == NULL)
 	    return;
 
@@ -433,7 +430,7 @@ void EDVArchiverOPLeaveCB(
 /*
  *	Find Bar get current location callback.
  */
-gchar *EDVArchiverFindBarLocationCB(gpointer fb, gpointer data)
+const gchar *EDVArchiverFindBarLocationCB(edv_findbar_struct *fb, gpointer data)
 {
 	return(EDVArchiverCurrentLocation(
 	    EDV_ARCHIVER(data)
@@ -443,7 +440,7 @@ gchar *EDVArchiverFindBarLocationCB(gpointer fb, gpointer data)
 /*
  *	Find Bar start find callback.
  */
-void EDVArchiverFindBarStartCB(gpointer fb, gpointer data)
+void EDVArchiverFindBarStartCB(edv_findbar_struct *fb, gpointer data)
 {
 	GtkCList *clist;
 	edv_archiver_struct *archiver = EDV_ARCHIVER(data);
@@ -467,7 +464,7 @@ void EDVArchiverFindBarStartCB(gpointer fb, gpointer data)
  *	Find Bar end find callback.
  */
 void EDVArchiverFindBarEndCB(
-	gpointer fb, gint total_matches, gpointer data
+	edv_findbar_struct *fb, gint total_matches, gpointer data
 )
 {
 	edv_archiver_struct *archiver = EDV_ARCHIVER(data);
@@ -504,11 +501,9 @@ void EDVArchiverFindBarMatchCB(
 
 
 /*
- *	Status Bar set message callback.
+ *	Status message callback.
  */
-void EDVArchiverBarStatusMessageCB(
-	gpointer bar, const gchar *message, gpointer data
-)
+void EDVArchiverStatusMessageCB(const gchar *message, gpointer data)
 {
 	edv_archiver_struct *archiver = EDV_ARCHIVER(data);
 	if(archiver == NULL)
@@ -518,11 +513,9 @@ void EDVArchiverBarStatusMessageCB(
 }
 
 /*
- *	Status Bar set progress callback.
+ *	Status progress callback.
  */
-void EDVArchiverBarStatusProgressCB(
-	gpointer bar, gfloat progress, gpointer data
-)
+void EDVArchiverStatusProgressCB(gfloat progress, gpointer data)
 {
 	edv_archiver_struct *archiver = EDV_ARCHIVER(data);
 	if(archiver == NULL)
@@ -2152,19 +2145,15 @@ void EDVArchiverOPRefresh(edv_archiver_struct *archiver)
 	if(clist != NULL)
 	{
 	    /* Record last scroll position */
-	    gfloat last_x = GTK_ADJUSTMENT_GET_VALUE(clist->hadjustment),
-		   last_y = GTK_ADJUSTMENT_GET_VALUE(clist->vadjustment);
+	    const gfloat	last_x = GTK_ADJUSTMENT_GET_VALUE(clist->hadjustment),
+				last_y = GTK_ADJUSTMENT_GET_VALUE(clist->vadjustment);
 
-	    gtk_clist_freeze(clist);
-
-	    /* Update list items */
-	    EDVArchiverContentsDoUpdate(
+	    /* Reget listing */
+	    EDVArchiverContentsGetListing(
 		archiver,
 		EDV_GET_B(EDV_CFG_PARM_LISTS_ANIMATE_UPDATES)
 	    );
 
-	    gtk_clist_thaw(clist);
-
 	    /* Scroll back to original position */
 	    EDVScrollCListToPosition(clist, last_x, last_y);
 	}
