@@ -5,8 +5,10 @@
 #ifndef ARCHIVEROPCB_H
 #define ARCHIVEROPCB_H
 
-
 #include <gtk/gtk.h>
+#include "toolbar.h"
+#include "findbar.h"
+#include "statusbar.h"
 #include "archiver.h"
 
 
@@ -17,7 +19,6 @@ extern gint EDVArchiverMenuItemEnterCB(
 extern gint EDVArchiverMenuItemLeaveCB(
 	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
 );
-extern gchar *EDVArchiverFindBarLocationCB(gpointer fb, gpointer data);
 
 extern void EDVArchiverOPCB(
 	toolbar_item_struct *item, gint id, gpointer data
@@ -29,9 +30,12 @@ extern void EDVArchiverOPLeaveCB(
 	toolbar_item_struct *item, gint id, gpointer data
 );
 
-extern void EDVArchiverFindBarStartCB(gpointer fb, gpointer data);
+extern const gchar *EDVArchiverFindBarLocationCB(
+	edv_findbar_struct *fb, gpointer data
+);
+extern void EDVArchiverFindBarStartCB(edv_findbar_struct *fb, gpointer data);
 extern void EDVArchiverFindBarEndCB(
-	gpointer fb, gint total_matches, gpointer data
+	edv_findbar_struct *fb, gint total_matches, gpointer data
 );
 extern void EDVArchiverFindBarMatchCB(
 	const gchar *path, const struct stat *lstat_buf,
@@ -39,12 +43,8 @@ extern void EDVArchiverFindBarMatchCB(
 	gpointer data
 );
 
-extern void EDVArchiverBarStatusMessageCB(
-	gpointer bar, const gchar *message, gpointer data
-);
-extern void EDVArchiverBarStatusProgressCB(
-	gpointer bar, gfloat progress, gpointer data
-);
+extern void EDVArchiverStatusMessageCB(const gchar *message, gpointer data);
+extern void EDVArchiverStatusProgressCB(gfloat progress, gpointer data);
 
 extern void EDVArchiverOPSyncDisks(edv_archiver_struct *archiver);
 extern void EDVArchiverOPWriteProtect(edv_archiver_struct *archiver);
