@@ -5,17 +5,20 @@
 #ifndef BROWSER_H
 #define BROWSER_H
 
-
 #include <gtk/gtk.h>
-
+#include "cfg.h"
 #include "edvtypes.h"
-#include "edvstatusbar.h"
 #include "toolbar.h"
 #include "mountbar.h"
 #include "findbar.h"
+#include "statusbar.h"
 #include "fopdlg.h"
 
 
+typedef struct _edv_browser_struct		edv_browser_struct;
+typedef struct _edv_browser_opid_struct		edv_browser_opid_struct;
+
+
 /*
  *	File Browser Contents List Column Types:
  */
@@ -48,13 +51,14 @@ typedef enum {
  *	on the edv_browser_struct.
  */
 typedef enum {
-	EDV_BROWSER_CELL_STYLE_NO_ACCESS	= 0,
-	EDV_BROWSER_CELL_STYLE_DANGLING_LINK	= 1,
-	EDV_BROWSER_CELL_STYLE_HIDDEN		= 2,
-	EDV_BROWSER_CELL_STYLE_EXECUTABLE	= 3
+	EDV_BROWSER_CELL_STYLE_NO_ACCESS,
+	EDV_BROWSER_CELL_STYLE_DANGLING_LINK,
+	EDV_BROWSER_CELL_STYLE_RECURSIVE_LINK,
+	EDV_BROWSER_CELL_STYLE_HIDDEN,
+	EDV_BROWSER_CELL_STYLE_EXECUTABLE
 } edv_browser_cell_style;
 /* Total number of cell styles */
-#define EDV_BROWSER_TOTAL_CELL_STYLES		4
+#define EDV_BROWSER_TOTAL_CELL_STYLES		5
 
 
 /*
@@ -63,93 +67,93 @@ typedef enum {
 typedef enum {
 
 	EDV_BROWSER_OP_NONE			= 0,
-	EDV_BROWSER_OP_SEPARATOR		= 10,
+	EDV_BROWSER_OP_SEPARATOR		= 100,
 
-	EDV_BROWSER_OP_CLOSE			= 20,
-	EDV_BROWSER_OP_EXIT			= 21,
+	EDV_BROWSER_OP_CLOSE			= 200,
+	EDV_BROWSER_OP_EXIT			= 201,
 
-	EDV_BROWSER_OP_SYNC_DISKS		= 30,
-	EDV_BROWSER_OP_RUN			= 31,
-	EDV_BROWSER_OP_RUN_TERMINAL		= 32,
-	EDV_BROWSER_OP_WRITE_PROTECT    	= 35,
+	EDV_BROWSER_OP_SYNC_DISKS		= 301,
+	EDV_BROWSER_OP_HISTORY			= 302,
+	EDV_BROWSER_OP_RUN			= 303,
+	EDV_BROWSER_OP_RUN_TERMINAL		= 304,
+	EDV_BROWSER_OP_WRITE_PROTECT    	= 305,
 
-	EDV_BROWSER_OP_NEW			= 40,
-	EDV_BROWSER_OP_NEW_FILE			= 41,
-	EDV_BROWSER_OP_NEW_DIRECTORY		= 42,
-	EDV_BROWSER_OP_NEW_LINK			= 43,
-	EDV_BROWSER_OP_NEW_FIFO			= 44,
-	EDV_BROWSER_OP_NEW_DEVICE_BLOCK		= 45,
-	EDV_BROWSER_OP_NEW_DEVICE_CHARACTER	= 46,
-	EDV_BROWSER_OP_NEW_SOCKET		= 47,
+	EDV_BROWSER_OP_NEW			= 400,
+	EDV_BROWSER_OP_NEW_FILE			= 410,
+	EDV_BROWSER_OP_NEW_DIRECTORY		= 412,
+	EDV_BROWSER_OP_NEW_LINK			= 413,
+	EDV_BROWSER_OP_NEW_FIFO			= 414,
+	EDV_BROWSER_OP_NEW_DEVICE_BLOCK		= 415,
+	EDV_BROWSER_OP_NEW_DEVICE_CHARACTER	= 416,
+	EDV_BROWSER_OP_NEW_SOCKET		= 417,
 
-	EDV_BROWSER_OP_OPEN			= 50,
-	EDV_BROWSER_OP_OPEN_WITH		= 51,
+	EDV_BROWSER_OP_OPEN			= 500,
+	EDV_BROWSER_OP_OPEN_WITH		= 501,
 
-	EDV_BROWSER_OP_GOTO_PARENT		= 60,
-	EDV_BROWSER_OP_GOTO_HOME		= 61,
-	EDV_BROWSER_OP_EXPAND			= 62,
-	EDV_BROWSER_OP_MOUNT			= 63,	/* Mount/unmount */
-	EDV_BROWSER_OP_EJECT			= 64,
+	EDV_BROWSER_OP_COPY_PATH		= 601,
+	EDV_BROWSER_OP_COPY_URL			= 602,
+	EDV_BROWSER_OP_PASTE			= 610,
 
-	EDV_BROWSER_OP_MOVE			= 65,
-	EDV_BROWSER_OP_COPY			= 66,
-	EDV_BROWSER_OP_LINK			= 67,
-	EDV_BROWSER_OP_RENAME			= 68,
-	EDV_BROWSER_OP_CHMOD			= 69,
-	EDV_BROWSER_OP_CHOWN			= 70,
-	EDV_BROWSER_OP_DELETE			= 71,
-	EDV_BROWSER_OP_SELECT_ALL		= 72,
-	EDV_BROWSER_OP_UNSELECT_ALL		= 73,
-	EDV_BROWSER_OP_INVERT_SELECTION		= 74,
-	EDV_BROWSER_OP_PROPERTIES		= 75,
+	EDV_BROWSER_OP_MOVE			= 700,
+	EDV_BROWSER_OP_COPY			= 701,
+	EDV_BROWSER_OP_LINK			= 702,
+	EDV_BROWSER_OP_RENAME			= 703,
+	EDV_BROWSER_OP_CHMOD			= 704,
+	EDV_BROWSER_OP_CHOWN			= 705,
+	EDV_BROWSER_OP_DELETE			= 706,
+	EDV_BROWSER_OP_PROPERTIES		= 707,
 
-	EDV_BROWSER_OP_FIND			= 76,
+	EDV_BROWSER_OP_SELECT_ALL		= 800,
+	EDV_BROWSER_OP_UNSELECT_ALL		= 801,
+	EDV_BROWSER_OP_INVERT_SELECTION		= 802,
+	EDV_BROWSER_OP_FIND			= 850,
 
-	EDV_BROWSER_OP_HISTORY			= 77,
-	EDV_BROWSER_OP_COPY_PATH		= 78,
-	EDV_BROWSER_OP_COPY_URL			= 79,
+	EDV_BROWSER_OP_DOWNLOAD			= 900,
 
-	EDV_BROWSER_OP_REFRESH			= 80,
-	EDV_BROWSER_OP_REFRESH_ALL		= 81,
+	EDV_BROWSER_OP_REFRESH			= 1000,
+	EDV_BROWSER_OP_REFRESH_ALL		= 1001,
+	EDV_BROWSER_OP_GOTO_PARENT		= 1100,
+	EDV_BROWSER_OP_GOTO_HOME		= 1101,
+	EDV_BROWSER_OP_EXPAND			= 1200,
 
-	EDV_BROWSER_OP_DOWNLOAD			= 85,
+	EDV_BROWSER_OP_SHOW_TOOL_BAR		= 1300,
+	EDV_BROWSER_OP_SHOW_LOCATION_BAR	= 1301,
+	EDV_BROWSER_OP_SHOW_MOUNT_BAR		= 1302,
+	EDV_BROWSER_OP_SHOW_FIND_BAR		= 1303,
+	EDV_BROWSER_OP_SHOW_STATUS_BAR		= 1304,
 
-	EDV_BROWSER_OP_SHOW_TOOL_BAR		= 90,
-	EDV_BROWSER_OP_SHOW_LOCATION_BAR	= 91,
-	EDV_BROWSER_OP_SHOW_MOUNT_BAR		= 92,
-	EDV_BROWSER_OP_SHOW_FIND_BAR		= 93,
-	EDV_BROWSER_OP_SHOW_STATUS_BAR		= 94,
+	EDV_BROWSER_OP_SHOW_HIDDEN_OBJECTS	= 1400,
+	EDV_BROWSER_OP_SHOW_NOACCESS_OBJECTS	= 1401,
 
-	EDV_BROWSER_OP_SHOW_HIDDEN_OBJECTS	= 95,
-	EDV_BROWSER_OP_SHOW_NOACCESS_OBJECTS	= 96,
+	EDV_BROWSER_OP_DIRECTORY_TREE_ORIGIN	= 1500,
 
-	EDV_BROWSER_OP_DIRECTORY_TREE_ORIGIN	= 97,
+	EDV_BROWSER_OP_MOUNT                    = 1600,	/* Mount/unmount */
+	EDV_BROWSER_OP_EJECT                    = 1620,
+	EDV_BROWSER_OP_DEVICE_CHECK             = 1650,
+	EDV_BROWSER_OP_DEVICE_TOOLS             = 1651,
+	EDV_BROWSER_OP_DEVICE_FORMAT            = 1652,
 
-	EDV_BROWSER_OP_MIME_TYPES		= 100,
-	EDV_BROWSER_OP_DEVICES			= 101,
+	EDV_BROWSER_OP_MIME_TYPES		= 1700,
+	EDV_BROWSER_OP_DEVICES			= 1701,
 
-	EDV_BROWSER_OP_NEW_BROWSER		= 110,
-	EDV_BROWSER_OP_NEW_IMBR			= 111,
-	EDV_BROWSER_OP_NEW_ARCHIVER		= 112,
-	EDV_BROWSER_OP_RECYCLE_BIN		= 113,
+	EDV_BROWSER_OP_NEW_BROWSER		= 1800,
+	EDV_BROWSER_OP_NEW_IMBR			= 1801,
+	EDV_BROWSER_OP_NEW_ARCHIVER		= 1802,
+	EDV_BROWSER_OP_RECYCLE_BIN		= 1900,
 
-	EDV_BROWSER_OP_OPTIONS			= 150,
-	EDV_BROWSER_OP_CUSTOMIZE		= 151,
+	EDV_BROWSER_OP_OPTIONS			= 2000,
+	EDV_BROWSER_OP_CUSTOMIZE		= 2001,
 
-	EDV_BROWSER_OP_DEVICE_CHECK		= 180,
-	EDV_BROWSER_OP_DEVICE_TOOLS		= 181,
-	EDV_BROWSER_OP_DEVICE_FORMAT		= 182,
-
-	EDV_BROWSER_OP_HELP_ABOUT		= 1000,
-	EDV_BROWSER_OP_HELP_CONTENTS		= 1001,
-	EDV_BROWSER_OP_HELP_FILE_BROWSER	= 1002,
-	EDV_BROWSER_OP_HELP_IMAGE_BROWSER	= 1003,
-	EDV_BROWSER_OP_HELP_ARCHIVER		= 1004,
-	EDV_BROWSER_OP_HELP_RECYCLE_BIN		= 1005,
-	EDV_BROWSER_OP_HELP_KEYS_LIST		= 1006,
-	EDV_BROWSER_OP_HELP_MIME_TYPES		= 1007,
-	EDV_BROWSER_OP_HELP_DEVICES		= 1008,
-	EDV_BROWSER_OP_HELP_COMMON_OPERATIONS	= 1009
+	EDV_BROWSER_OP_HELP_CONTENTS		= 3000,
+	EDV_BROWSER_OP_HELP_FILE_BROWSER	= 3010,
+	EDV_BROWSER_OP_HELP_IMAGE_BROWSER	= 3011,
+	EDV_BROWSER_OP_HELP_ARCHIVER		= 3012,
+	EDV_BROWSER_OP_HELP_RECYCLE_BIN		= 3030,
+	EDV_BROWSER_OP_HELP_KEYS_LIST		= 3050,
+	EDV_BROWSER_OP_HELP_MIME_TYPES		= 3051,
+	EDV_BROWSER_OP_HELP_DEVICES		= 3052,
+	EDV_BROWSER_OP_HELP_COMMON_OPERATIONS	= 3053,
+	EDV_BROWSER_OP_HELP_ABOUT		= 3100
 
 } edv_browser_op;
 
@@ -157,15 +161,12 @@ typedef enum {
 /*
  *	File Browser Operation ID:
  */
-typedef struct {
+struct _edv_browser_opid_struct {
 
-	gpointer	browser;
 	edv_browser_op	op;
-	gboolean	allow_multiple;		/* Allow multiple instances
-						 * of this operation in
-						 * lists */
-	toolbar_item_type tb_item_type;		/* Type of item when placed
-						 * on the tool bar */
+	edv_opid_flags	flags;
+	toolbar_item_type tb_item_type;
+	edv_browser_struct	*browser;
 
 	/* Operation callback */
 	void	(*func_cb)(
@@ -196,23 +197,22 @@ typedef struct {
 	guint8	**button_icon_data,	/* Shared */
 		**menu_icon_data;	/* Shared */
 
-} edv_browser_opid_struct;
+};
 #define EDV_BROWSER_OPID(p)	((edv_browser_opid_struct *)(p))
 
+
 /*
  *	File Browser:
  */
-typedef struct {
+struct _edv_browser_struct {
 
 	GtkWidget	*toplevel;
-	GtkAccelGroup	*accelgrp;
 	gboolean	processing;
 	gint		busy_count,
 			freeze_count;
 	gpointer	core_ptr;
 
-	edv_browser_opid_struct	**opid;
-	gint			total_opids;
+	GList		*opid_list;
 
 	gboolean	tool_bar_map_state,
 			location_bar_map_state,
@@ -252,7 +252,7 @@ typedef struct {
 
 	/* Important menu items */
 	GtkWidget	*open_mi,
-			*openwith_mi,
+			*open_with_mi,
 			*new_object_submi,
 			*new_object_submenu,
 			*new_file_mi,
@@ -276,6 +276,7 @@ typedef struct {
 			*delete_mi,
 			*copy_path_mi,
 			*copy_url_mi,
+			*paste_mi,
 			*select_all_mi,
 			*unselect_all_mi,
 			*invert_selection_mi,
@@ -334,12 +335,13 @@ typedef struct {
 			*directory_ctree_delete_mi,
 			*directory_ctree_copy_path_mi,
 			*directory_ctree_copy_url_mi,
+			*directory_ctree_paste_mi,
 			*directory_ctree_properties_mi;
 
 	/* Contents List right-click menu */
 	GtkWidget       *contents_clist_menu,
 			*contents_clist_open_mi,
-			*contents_clist_openwith_mi,
+			*contents_clist_open_with_mi,
 			*contents_clist_move_mi,
 			*contents_clist_copy_mi,
 			*contents_clist_link_mi,
@@ -348,7 +350,8 @@ typedef struct {
 			*contents_clist_chown_mi,
 			*contents_clist_delete_mi,
 			*contents_clist_copy_path_mi,
-                        *contents_clist_copy_url_mi,
+			*contents_clist_copy_url_mi,
+			*contents_clist_paste_mi,
 			*contents_clist_properties_mi;
 
 
@@ -356,8 +359,6 @@ typedef struct {
 	GtkStyle	*cell_style[EDV_BROWSER_TOTAL_CELL_STYLES];
 
 	/* Special icons */
-	GdkPixmap	*folder_home_pixmap;
-	GdkBitmap	*folder_home_mask;
 	GdkPixmap	*folder_parent_pixmap;
 	GdkBitmap	*folder_parent_mask;
 	GdkPixmap	*folder_noaccess_pixmap;
@@ -402,23 +403,32 @@ typedef struct {
 	gint		last_write_protect_state;
 
 
-
-	/* Status bar */
-	edv_status_bar_struct	*status_bar;
+	/* Status Bar */
+	edv_statusbar_struct	*status_bar;
 
 
-	/* File operation dialog */
+	/* File Operation Dialog */
 	edv_fopdlg_struct	*fopdlg;
 
-} edv_browser_struct;
+};
 #define EDV_BROWSER(p)	((edv_browser_struct *)(p))
 
 
+/* Utilities */
+extern edv_browser_opid_struct *EDVBrowserMatchOPID(
+	edv_browser_struct *browser, edv_browser_op op
+);
+extern gboolean EDVBrowserIsPathFromDirTreeOrigin(
+        edv_browser_struct *browser, const gchar *path
+);
+
+/* Title */
 extern void EDVBrowserSetTitle(
 	edv_browser_struct *browser,
 	const gchar *path
 );
 
+/* Location */
 extern gchar *EDVBrowserCurrentLocation(edv_browser_struct *browser);
 extern void EDVBrowserSetLocation(
 	edv_browser_struct *browser,
@@ -428,22 +438,27 @@ extern void EDVBrowserUpdateLocationIcon(
 	edv_browser_struct *browser, const gchar *path
 );
 
+/* Regenerating Menus, Bars, etc */
+extern void EDVBrowserAccelkeysRegenerate(edv_browser_struct *browser);
 extern void EDVBrowserListStylesRegenerate(edv_browser_struct *browser);
 extern void EDVBrowserToolBarRegenerate(edv_browser_struct *browser);
 extern void EDVBrowserNewObjectMenuRegenerate(edv_browser_struct *browser);
 extern void EDVBrowserDirectoryMenuRegenerate(edv_browser_struct *browser);
 extern void EDVBrowserContentsMenuRegenerate(edv_browser_struct *browser);
 
+/* Sync Configuration */
 extern void EDVBrowserSyncConfiguration(edv_browser_struct *browser);
 
-extern edv_browser_opid_struct **EDVBrowserOPIDListNew(
-	edv_browser_struct *browser,    /* Can be NULL */
-	gint *total
-);
-extern void EDVBrowserOPIDListDelete(
-	edv_browser_opid_struct **list, gint total
+/* Operation IDs */
+extern GList *EDVBrowserOPIDListNew(
+	edv_browser_struct *browser		/* Can be NULL */
 );
+extern void EDVBrowserOPIDListDelete(GList *glist);
 
+/* Accelkeys */
+extern cfg_accelkey_list_struct *EDVBrowserAccelkeysListNewDefault(void);
+
+/* File Browser */
 extern edv_browser_struct *EDVBrowserNew(gpointer core_ptr);
 extern void EDVBrowserSyncData(edv_browser_struct *browser);
 extern void EDVBrowserUpdateMenus(edv_browser_struct *browser);
