@@ -14,7 +14,7 @@
 #include "cfg.h"
 #include "edvobj.h"
 #include "edvdevices.h"
-#include "edvstatusbar.h"
+#include "statusbar.h"
 #include "browser.h"
 #include "browsercb.h"
 #include "browseropcb.h"
@@ -288,16 +288,18 @@ gint EDVBrowserDeleteEventCB(
 }
 
 /*
- *	File Browser "key_press_event" or "key_release_event" signal callback.
+ *	File Browser "key_press_event" or "key_release_event" signal
+ *	callback.
  */
 gint EDVBrowserKeyEventCB(
 	 GtkWidget *widget, GdkEventKey *key, gpointer data
 )
 {
 	gint status = FALSE;
+	gboolean is_press;  
 	gint etype;
 	guint keyval, state;
-	gboolean press;
+	GtkWidget *w, *focus_widget;
 	const cfg_item_struct *cfg_list;
 	edv_core_struct *core_ptr;
 	edv_browser_struct *browser = EDV_BROWSER(data);
@@ -311,13 +313,11 @@ gint EDVBrowserKeyEventCB(
 	if(core_ptr == NULL)
 	    return(status);
 
+	w = browser->toplevel;
+	focus_widget = (w != NULL) ? GTK_WINDOW(w)->focus_widget : NULL;        
 	cfg_list = core_ptr->cfg_list;
-
-	/* Get event type */
 	etype = key->type;
-
-	/* Get other key event values */
-	press = (etype == GDK_KEY_PRESS) ? TRUE : FALSE;
+	is_press = (etype == GDK_KEY_PRESS) ? TRUE : FALSE;
 	keyval = key->keyval;
 	state = key->state;
 
@@ -325,44 +325,53 @@ gint EDVBrowserKeyEventCB(
 #define DO_STOP_KEY_SIGNAL_EMIT	{		\
  gtk_signal_emit_stop_by_name(			\
   GTK_OBJECT(widget),				\
-  press ?					\
+  is_press ?					\
    "key_press_event" : "key_release_event"	\
  );						\
 }
 
+	/* If the focus_widget is not a GtkEditable then check if the
+	 * keyval is an accelerator key before all subsequence checks
+	 */
+	if((focus_widget != NULL) ?
+	    !GTK_IS_EDITABLE(focus_widget) : TRUE
+	)
+	{
+	    edv_browser_op op = (edv_browser_op)EDVMatchAccelKeyOPID(
+		cfg_list, EDV_CFG_PARM_BROWSER_ACCELERATOR_KEYS,
+		keyval, state
+	    );
+	    if(op > 0)
+	    {
+		if(is_press)
+		{
+		    edv_browser_opid_struct *opid = EDVBrowserMatchOPID(
+			browser, op
+		    );
+		    if(opid != NULL)
+			EDVBrowserOPCB(NULL, -1, opid);
+		}
+		DO_STOP_KEY_SIGNAL_EMIT
+		status = TRUE;
+		return(status);
+	    }
+	}
+
 	/* Check which widget this signal is for */
 
 	/* Directory Tree */
 	if(widget == browser->directory_ctree)
 	{
-	    GtkCTreeNode *node;
 	    GtkCList *clist = GTK_CLIST(widget);
 	    GtkCTree *ctree = GTK_CTREE(widget);
+	    GtkCTreeNode *node = EDVCTreeGetSelectedLast(ctree, NULL);
 
-	    /* Get last selected node */
-	    node = EDVCTreeGetSelectedLast(ctree, NULL);
-
-	    /* Handle by key value */
 	    switch(keyval)
 	    {
-	      case GDK_Delete:
-		if(press)
-		    EDVBrowserOPDelete(browser);
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
-		break;
-
-	      case GDK_BackSpace:
-		if(press)
-		    EDVBrowserOPGoToParent(browser);
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
-		break;
-
 	      case GDK_space:
 	      case GDK_KP_Space:
 		node = gtk_ctree_node_nth(ctree, clist->focus_row);
-		if((node != NULL) && press)
+		if((node != NULL) && is_press)
 		{
 		    gboolean already_selected = FALSE;
 
@@ -388,41 +397,20 @@ gint EDVBrowserKeyEventCB(
 		DO_STOP_KEY_SIGNAL_EMIT
 		status = TRUE;
 		break;
-
-	      case GDK_Insert:
-		if(state & GDK_CONTROL_MASK)
-		{
-		    if(press)
-			EDVBrowserOPCopyPath(browser);
-		    DO_STOP_KEY_SIGNAL_EMIT
-		    status = TRUE;
-		}
-		break;
 	    }
 	}
 	/* Contents List */
 	else if(widget == browser->contents_clist)
 	{
-	    gint row;
 	    GtkCList *clist = GTK_CLIST(widget);
+	    gint row = EDVCListGetSelectedLast(clist, NULL);
 
-	    /* Get last selected row */
-	    row = EDVCListGetSelectedLast(clist, NULL);
-
-	    /* Handle by key value */
 	    switch(keyval)
 	    {
-	      case GDK_Delete:
-		if(press)
-		    EDVBrowserOPDelete(browser);
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
-		break;
-
 	      case GDK_space:
 	      case GDK_KP_Space:
 		row = clist->focus_row;
-		if((row >= 0) && (row < clist->rows) && press)
+		if((row >= 0) && (row < clist->rows) && is_press)
 		{
 		    gboolean already_selected = FALSE;
 
@@ -449,53 +437,45 @@ gint EDVBrowserKeyEventCB(
 		status = TRUE;
 		break;
 
-	      case GDK_Insert:
-		if(state & GDK_CONTROL_MASK)
-		{
-		    if(press)
-			EDVBrowserOPCopyPath(browser);
-		    DO_STOP_KEY_SIGNAL_EMIT
-		    status = TRUE;
-		}
-		break;
-
 	      default:
 		/* For all other alphanumeric character keys and while
 		 * no modifier keys are held, attempt to seek to the
 		 * item who's name starts with the letter of the key
 		 * that was pressed
 		 */
-		if(isalnum((char)keyval) && press &&
+		if(isalnum((char)keyval) && is_press &&
 		   ((state == 0x00000000) || (state == GDK_SHIFT_MASK))
 		)
 		{
 		    /* Get the column that is displaying the object
 		     * name as column_type_name
 		     */
-		    gint i, column_type_name = -1;
+		    gint column_type_name = -1;
 		    const cfg_intlist_struct *intlist = EDV_GET_INTLIST(
 			EDV_CFG_PARM_BROWSER_CONTENTS_COLUMN
 		    );
 		    if(intlist != NULL)
 		    {
 			/* Iterate through column type intlist */
-			for(i = 0; i < intlist->total; i++)
+			gint i = 0;
+			GList *glist = intlist->list;
+			while(glist != NULL)
 			{
-			    /* Is column i displaying the name? */
-			    if(intlist->i[i] == EDV_BROWSER_COLUMN_TYPE_NAME)
+			    if((edv_browser_column_type)glist->data ==
+				EDV_BROWSER_COLUMN_TYPE_NAME
+			    )
 			    {
 				column_type_name = i;
 				break;
 			    }
+			    i++;
+			    glist = g_list_next(glist);
 			}
 		    }
 
 		    gtk_clist_freeze(clist);
 		    EDVCListSeekCharacter(
-			clist, column_type_name, 0,
-			(gchar)((state & GDK_SHIFT_MASK) ?
-			    toupper((char)keyval) : keyval
-			)
+			clist, column_type_name, 0, keyval
 		    );
 		    gtk_clist_thaw(clist);
 
@@ -503,7 +483,6 @@ gint EDVBrowserKeyEventCB(
 		    status = TRUE;
 		}
 		break;
-
 	    }
 	}
 
@@ -707,8 +686,10 @@ gint EDVBrowserButtonPressEventCB(
 		{
 		    if((row >= 0) && (row < clist->rows))
 		    {
-			EDVBrowserContentsDoOpenObject(
-			    browser, row, column, state
+			EDVBrowserContentsOpen(
+			    browser,
+			    row, column,
+			    state		/* Modifier keys */
 			);
 			status = TRUE;
 		    }
@@ -938,14 +919,12 @@ g_print("%i %i\n", x_max, (gint)(adj->value + adj->page_size));
 		    );
 		    EDVBrowserUpdateLocationIcon(browser, obj->full_path);
 
-		    /* Update contents clist */
-		    gtk_clist_freeze(clist);
-		    EDVBrowserContentsDoUpdate(
+		    /* Get listing */
+		    EDVBrowserContentsGetListing(
 			browser,
 			obj->full_path,
 			EDV_GET_B(EDV_CFG_PARM_LISTS_ANIMATE_UPDATES)
 		    );
-		    gtk_clist_thaw(clist);
 
 		    /* Get number of objects in the directory by the
 		     * number of rows in the just updated contents
@@ -1062,12 +1041,8 @@ void EDVBrowserTreeExpandCB(
 	    GUIBlockInput(browser->toplevel, TRUE);
 	    browser->processing = TRUE;
 
-	    gtk_clist_freeze(GTK_CLIST(ctree));
-
-	    /* Expand node and get child directories for each node */
-	    EDVBrowserDirTreeDoExpand(browser, node, TRUE);
-
-	    gtk_clist_thaw(GTK_CLIST(ctree));
+	    /* Expand node and get child nodes */
+	    EDVBrowserDirTreeExpand(browser, node, TRUE);
 
 	    /* Scroll to optimize viewing of expand nodes? */
 	    if(EDV_GET_B(EDV_CFG_PARM_TREE_EXPAND_OPTIMIZE_POS))
@@ -1157,18 +1132,18 @@ void EDVBrowserResizeColumnCB(
 	/* Check which clist this signal is for */
 	if(GTK_WIDGET(clist) == browser->contents_clist)
 	{
-	    gint column_type = -1;
+	    edv_browser_column_type column_type = EDV_BROWSER_COLUMN_TYPE_NAME;
 	    cfg_intlist_struct *column_types_intlist, *column_width_intlist;
 
-
 	    /* Get column_type from the given column index */
 	    column_types_intlist = EDV_GET_INTLIST(
 		EDV_CFG_PARM_BROWSER_CONTENTS_COLUMN
 	    );
 	    if(column_types_intlist != NULL)
 	    {
-		if((column >= 0) && (column < column_types_intlist->total))
-		    column_type = column_types_intlist->i[column];
+		column_type = (edv_browser_column_type)g_list_nth_data(
+		    column_types_intlist->list, column
+		);
 	    }
 
 	    /* Get column widths intlist */
@@ -1177,37 +1152,17 @@ void EDVBrowserResizeColumnCB(
 	    );
 	    if(column_width_intlist != NULL)
 	    {
-		/* Need to increase column_width_intlist allocation? */
-		if((column_type >= column_width_intlist->total) &&
-		   (column_type >= 0)
-		)
-		{
-		    gint n;
-		    gint prev_total = column_width_intlist->total;
-
-		    /* Increase array allocation */
-		    column_width_intlist->total = column_type + 1;
-		    column_width_intlist->i = (gint *)g_realloc(
-			column_width_intlist->i,
-			column_width_intlist->total * sizeof(gint)
+		GList *glist = g_list_nth(
+		    column_width_intlist->list, (guint)column_type
+		);
+		if(glist != NULL)
+		    glist->data = (gpointer)width;
+		else
+		    g_printerr(
+"EDVBrowserResizeColumnCB(): Warning:\
+ Specified column type %i not in list of column widths.\n",
+			column_type
 		    );
-		    /* Reset newly allocated indexes */
-		    for(n = prev_total; n < column_width_intlist->total; n++)
-			column_width_intlist->i[n] = 0;
-		}
-
-		/* Got column type in bounds as index on column width
-		 * intlist?
-		 */
-		if((column_type >= 0) &&
-		   (column_type < column_width_intlist->total)
-		)
-		{
-		    /* Record new width of column on the column width
-		     * intlist.
-		     */
-		    column_width_intlist->i[column_type] = width;
-		}
 	    }
 	}
 }
@@ -1256,60 +1211,60 @@ void EDVBrowserClickColumnCB(
 	    );
 	    if(column_types_intlist != NULL)
 	    {
-		if((column >= 0) && (column < column_types_intlist->total))
+		edv_browser_column_type column_type = (edv_browser_column_type)g_list_nth_data(
+		    column_types_intlist->list,  
+		    column
+		);
+		switch(column_type)
 		{
-		    gint column_type = column_types_intlist->i[column];
-		    switch(column_type)
-		    {
-		      case EDV_BROWSER_COLUMN_TYPE_NAME:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_SIZE:
-			cmp_func = cmp_func_num;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_TYPE:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_PERMISSIONS:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_OWNER:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_GROUP:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_DATE_ACCESS:
-			cmp_func = EDVBrowserCListColumnSortDateAccessCB;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_DATE_MODIFIED:
-			cmp_func = EDVBrowserCListColumnSortDateModifyCB;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_DATE_CHANGED:
-			cmp_func = EDVBrowserCListColumnSortDateChangeCB;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_HARD_LINKS:
-			cmp_func = cmp_func_num;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_LINKED_TO:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_DEVICE:
-			cmp_func = cmp_func_num;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_INODE:
-			cmp_func = cmp_func_num;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_DEVICE_TYPE:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_BLOCK_SIZE:
-			cmp_func = cmp_func_num;
-			break;
-		      case EDV_BROWSER_COLUMN_TYPE_BLOCKS:
-			cmp_func = cmp_func_num;
-			break;
-		    }
+		  case EDV_BROWSER_COLUMN_TYPE_NAME:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_SIZE:
+		    cmp_func = cmp_func_num;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_TYPE:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_PERMISSIONS:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_OWNER:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_GROUP:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_DATE_ACCESS:
+		    cmp_func = EDVBrowserCListColumnSortDateAccessCB;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_DATE_MODIFIED:
+		    cmp_func = EDVBrowserCListColumnSortDateModifyCB;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_DATE_CHANGED:
+		    cmp_func = EDVBrowserCListColumnSortDateChangeCB;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_HARD_LINKS:
+		    cmp_func = cmp_func_num;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_LINKED_TO:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_DEVICE:
+		    cmp_func = cmp_func_num;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_INODE:
+		    cmp_func = cmp_func_num;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_DEVICE_TYPE:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_BLOCK_SIZE:
+		    cmp_func = cmp_func_num;
+		    break;
+		  case EDV_BROWSER_COLUMN_TYPE_BLOCKS:
+		    cmp_func = cmp_func_num;
+		    break;
 		}
 	    }
 
@@ -1523,11 +1478,11 @@ void EDVBrowserComboActivateCB(GtkWidget *widget, gpointer data)
 	/* Check which widget was activated */
 	if(widget == browser->location_combo)
 	{
-	    gchar *new_path = EDVCopyEvaluateInputPath(
+	    gchar *path = EDVEvaluatePath(
 		NULL,		/* No parent path, imply use toplevel */
 		gtk_entry_get_text(GTK_ENTRY(combo->entry))
 	    );
-	    if(new_path != NULL)
+	    if(path != NULL)
 	    {
 		GtkWidget *toplevel = browser->toplevel;
 		GtkCTree *ctree = GTK_CTREE(browser->directory_ctree);
@@ -1537,7 +1492,7 @@ void EDVBrowserComboActivateCB(GtkWidget *widget, gpointer data)
 		GUIBlockInput(toplevel, TRUE);
 
 		/* Do not mark as processing or else
-		 * EDVBrowserDirTreeDoSelectPath() will not be able to
+		 * EDVBrowserDirTreeSelectPath() will not be able to
 		 * expand nodes because the expand signal callback will
 		 * detect the processing and not expand the node
 		 */
@@ -1546,10 +1501,8 @@ void EDVBrowserComboActivateCB(GtkWidget *widget, gpointer data)
 		 * the current Directory Tree Origin then the Directory
 		 * Tree Origin needs to be updated first
 		 */
-		if((browser->directory_ctree_origin_path != NULL) ?
-		    !strpfx(new_path, browser->directory_ctree_origin_path) : TRUE
-		)
-		    EDVBrowserDirTreeSetOriginPath(browser, new_path);
+		if(!EDVBrowserIsPathFromDirTreeOrigin(browser, path))
+		    EDVBrowserDirTreeSetOriginPath(browser, path);
 
 		/* Update location combo to record the new location in
 		 * the location history
@@ -1557,15 +1510,15 @@ void EDVBrowserComboActivateCB(GtkWidget *widget, gpointer data)
 		 * The combo will be updated again (without recording
 		 * history) if the new path is valid and selected in
 		 * the callbacks triggered by
-		 * EDVBrowserDirTreeDoSelectPath() farther below
+		 * EDVBrowserDirTreeSelectPath() farther below
 		 */
-		EDVBrowserSetLocation(browser, new_path, TRUE);
+		EDVBrowserSetLocation(browser, path, TRUE);
 
 		/* Update selected node on directory ctree */
 		if(clist != NULL)
 		{
-		    /* Attempt to select the node who's object path
-		     * matches new_path (recurse and expand as needed)
+		    /* Attempt to select the node who's object's path
+		     * matches path (recurse and expand as needed)
 		     *
 		     * The ctree will be frozen and thawed by the
 		     * callbacks each time it is expanded so we do not
@@ -1575,14 +1528,14 @@ void EDVBrowserComboActivateCB(GtkWidget *widget, gpointer data)
 		     * (but its history will not be re-recorded) when the
 		     * the node is selected
 		     */
-		    EDVBrowserDirTreeDoSelectPath(browser, new_path);
+		    EDVBrowserDirTreeSelectPath(browser, path);
 		}
 
 
 		GUIBlockInput(toplevel, FALSE);
 		EDVBrowserSetBusy(browser, FALSE);
 
-		g_free(new_path);
+		g_free(path);
 	    }
 	}
 }
@@ -1831,9 +1784,8 @@ void EDVBrowserReconfiguredNotifyCB(edv_browser_struct *browser)
 	gchar *cur_path;
 	GtkRcStyle *standard_rcstyle, *lists_rcstyle;
 	GtkWidget *w;
-	GtkCList *clist;
 	const cfg_item_struct *cfg_list;
-	edv_status_bar_struct *status_bar;
+	edv_statusbar_struct *status_bar;
 	edv_core_struct *core_ptr;
 
 	if(browser == NULL)
@@ -1865,6 +1817,9 @@ void EDVBrowserReconfiguredNotifyCB(edv_browser_struct *browser)
 	/* Update Title */
 	EDVBrowserSetTitle(browser, cur_path);
 
+	/* Recreate Accelkeys labels */
+	EDVBrowserAccelkeysRegenerate(browser);
+
 	/* Recreate Tool Bar */
 	EDVBrowserToolBarRegenerate(browser);
 
@@ -1958,34 +1913,17 @@ void EDVBrowserReconfiguredNotifyCB(edv_browser_struct *browser)
 	EDVBrowserListStylesRegenerate(browser);
 
 
-	/* Reget listings */
+	/* Realize listings */
+	EDVBrowserDirTreeRealizeListing(browser, NULL);
+	EDVBrowserContentsRealizeListing(browser);
 
-	/* Update all nodes and remove any nodes that reffer to non-existing
-	 * disk objects on the directory ctree
-	 */
-	EDVBrowserDirTreeDoSync(browser, NULL);
-
-	/* Reset contents list column heading and all rows */
-	clist = (GtkCList *)browser->contents_clist;
-	if(clist != NULL)
-	{
-	    gtk_clist_freeze(clist);
-	    EDVBrowserContentsResetRows(browser);
-	    gtk_clist_thaw(clist);
-	}
-
-
-	/* Update menus */
 	EDVBrowserUpdateMenus(browser);
 
-
 	/* Notify browser's toplevel widget to resize */
 	w = browser->toplevel;
 	if(w != NULL)
 	    gtk_widget_queue_resize(w);
 
-
-	/* Delete copy of current location */
 	g_free(cur_path);
 }
 
@@ -2016,10 +1954,8 @@ void EDVBrowserMimeTypeModifiedCB(
 )
 {
 	gchar *cur_path;
-	GtkCList *clist;
 	edv_core_struct *core_ptr;
 
-
 	if(browser == NULL)
 	    return;
 
@@ -2030,30 +1966,15 @@ void EDVBrowserMimeTypeModifiedCB(
 	if(core_ptr == NULL)
 	    return;
 
-
-	/* Get copy of current location path */
+	/* Get current location */
 	cur_path = STRDUP(EDVBrowserCurrentLocation(browser));
 
-
-	/* Reget listings */
-
-	/* Update all nodes and remove any nodes that reffer to non-existing
-	 * disk objects on the directory ctree.
-	 */
-	EDVBrowserDirTreeDoSync(browser, NULL);
-
-	/* Reset displayed row values of contents clist */
-	clist = (GtkCList *)browser->contents_clist;
-	if(clist != NULL)
-	{
-	    gtk_clist_freeze(clist);
-	    EDVBrowserContentsResetRows(browser);
-	    gtk_clist_thaw(clist);
-	}
+	/* Realize listings */
+	EDVBrowserDirTreeRealizeListing(browser, NULL);
+	EDVBrowserContentsRealizeListing(browser);
 
 /*	EDVBrowserUpdateMenus(browser); */
 
-	/* Delete copy of the current location */
 	g_free(cur_path);
 }
 
@@ -2066,10 +1987,8 @@ void EDVBrowserMimeTypeRemovedCB(
 )
 {
 	gchar *cur_path;
-	GtkCList *clist;
 	edv_core_struct *core_ptr;
 
-
 	if(browser == NULL)
 	    return;
 
@@ -2080,32 +1999,16 @@ void EDVBrowserMimeTypeRemovedCB(
 	if(core_ptr == NULL)
 	    return;
 
-
-	/* Get copy of current location path */
+	/* Get current location */
 	cur_path = STRDUP(EDVBrowserCurrentLocation(browser));
 
-
-	/* Reget listings */
-
-	/* Update all nodes and remove any nodes that reffer to non-existing
-	 * disk objects on the directory ctree.
-	 */
-	EDVBrowserDirTreeDoSync(browser, NULL);
-
-	/* Reset displayed row values of contents clist */
-	clist = (GtkCList *)browser->contents_clist;
-	if(clist != NULL)
-	{
-	    gtk_clist_freeze(clist);
-	    EDVBrowserContentsResetRows(browser);
-	    gtk_clist_thaw(clist);
-	}
+	/* Realize listings */
+	EDVBrowserDirTreeRealizeListing(browser, NULL);
+	EDVBrowserContentsRealizeListing(browser);
 
 /*	EDVBrowserUpdateMenus(browser); */
 
-	/* Deallocate copy of current location path */
 	g_free(cur_path);
-	cur_path = NULL;
 }
 
 
@@ -2134,10 +2037,8 @@ void EDVBrowserDeviceModifiedCB(
 )
 {
 	gchar *cur_path;
-	GtkCList *clist;
 	edv_core_struct *core_ptr;
 
-
 	if(browser == NULL)
 	    return;
 
@@ -2148,33 +2049,16 @@ void EDVBrowserDeviceModifiedCB(
 	if(core_ptr == NULL)
 	    return;
 
-
-	/* Get copy of current location path */
+	/* Get current location */
 	cur_path = STRDUP(EDVBrowserCurrentLocation(browser));
 
+	/* Realize listings */
+	EDVBrowserDirTreeRealizeListing(browser, NULL);
+	EDVBrowserContentsRealizeListing(browser);
 
-	/* Reget listings */
-
-	/* Update all nodes and remove any nodes that reffer to non-existing
-	 * disk objects on the directory ctree.
-	 */
-	EDVBrowserDirTreeDoSync(browser, NULL);
-
-	/* Reset displayed row values of contents clist */
-	clist = (GtkCList *)browser->contents_clist;
-	if(clist != NULL)
-	{
-	    gtk_clist_freeze(clist);
-	    EDVBrowserContentsResetRows(browser);
-	    gtk_clist_thaw(clist);
-	}
-
-	/* Update menus */
 	EDVBrowserUpdateMenus(browser);
 
-	/* Deallocate copy of current location path */
 	g_free(cur_path);
-	cur_path = NULL;
 }
 
 /*
@@ -2186,11 +2070,9 @@ void EDVBrowserDeviceRemovedCB(
 )
 {
 	gchar *cur_path;
-	GtkCList *clist;
 	edv_mountbar_struct *mb;
 	edv_core_struct *core_ptr;
 
-
 	if(browser == NULL)
 	    return;
 
@@ -2201,11 +2083,9 @@ void EDVBrowserDeviceRemovedCB(
 	if(core_ptr == NULL)
 	    return;
 
-
-	/* Get copy of current location path */
+	/* Get current location */
 	cur_path = STRDUP(EDVBrowserCurrentLocation(browser));
 
-
 	/* Check if mount bar is currently referencing this device, if it
 	 * is then its selected device needs to be set to -1
 	 */
@@ -2220,27 +2100,11 @@ void EDVBrowserDeviceRemovedCB(
 	     */
 	}
 
+	/* Realize listings */
+	EDVBrowserDirTreeRealizeListing(browser, NULL);
+	EDVBrowserContentsRealizeListing(browser);
 
-	/* Reget listings */
-
-	/* Update all nodes and remove any nodes that reffer to
-	 * non-existing objects on the directory ctree
-	 */
-	EDVBrowserDirTreeDoSync(browser, NULL);
-
-	/* Reset displayed row values of contents clist */
-	clist = (GtkCList *)browser->contents_clist;
-	if(clist != NULL)
-	{
-	    gtk_clist_freeze(clist);
-	    EDVBrowserContentsResetRows(browser);
-	    gtk_clist_thaw(clist);
-	}
-
-	/* Update menus */
 	EDVBrowserUpdateMenus(browser);
 
-	/* Deallocate copy of current location path */
 	g_free(cur_path);
-	cur_path = NULL;
 }
