@@ -26,28 +26,30 @@
 #include "config.h"
 
 
+/* Callbacks */
 static void EDVBrowserDirTreeFPromptCancelCB(gpointer data);
 
+/* Node Setting */
 static void EDVBrowserDirTreeSetNode(
 	edv_core_struct *core_ptr, edv_browser_struct *browser,
 	GtkCTree *ctree, GtkCTreeNode *node, edv_object_struct *obj
 );
 
+/* Getting */
 GtkCTreeNode *EDVBrowserDirTreeGetToplevel(edv_browser_struct *browser);
 
-GtkCTreeNode *EDVBrowserDirTreeInsertNode(
+static GtkCTreeNode *EDVBrowserDirTreeInsertNode(
 	edv_browser_struct *browser,
 	GtkCTreeNode *parent, GtkCTreeNode *sibling,
 	edv_object_struct *obj
 );
 
-void EDVBrowserDirTreeCreateToplevels(edv_browser_struct *browser);
-
+/* Set Origin Path */
 void EDVBrowserDirTreeSetOriginPath(
 	edv_browser_struct *browser, const gchar *path
 );
 
-
+/* Get Listing */
 static void EDVBrowserDirTreeDoGetChildrenListIterate(
 	edv_core_struct *core_ptr, edv_browser_struct *browser,
 	GtkCTree *ctree, GtkCTreeNode *parent,
@@ -58,33 +60,39 @@ static void EDVBrowserDirTreeDoGetChildrenList(
 	edv_browser_struct *browser, GtkCTreeNode *parent,
 	gboolean update_progress, gboolean recurse
 );
-
-void EDVBrowserDirTreeDoRefresh(
+void EDVBrowserDirTreeCreateToplevels(edv_browser_struct *browser);
+void EDVBrowserDirTreeGetListing(
 	edv_browser_struct *browser, GtkCTreeNode *node,
 	gboolean update_progress
 );
-void EDVBrowserDirTreeDoExpand(
+void EDVBrowserDirTreeClear(edv_browser_struct *browser);
+
+/* Expanding */
+void EDVBrowserDirTreeExpand(
 	edv_browser_struct *browser, GtkCTreeNode *node,
 	gboolean update_progress
 );
 
-static void EDVBrowserDirTreeDoSyncIterate(
+/* Realize Listing */
+static void EDVBrowserDirTreeRealizeListingIterate(
 	edv_browser_struct *browser, GtkCTree *ctree,
 	GtkCTreeNode *node,
 	gboolean parent_is_expanded
 );
-void EDVBrowserDirTreeDoSync(
+void EDVBrowserDirTreeRealizeListing(
 	edv_browser_struct *browser, GtkCTreeNode *node
 );
 
-static void EDVBrowserDirTreeDoSelectPathIterate(
+/* Selecting */
+static void EDVBrowserDirTreeSelectPathIterate(
 	GtkCTree *ctree, GtkCTreeNode *node, const gchar *path,
 	GtkCTreeNode **matched_node_ptr
 );
-void EDVBrowserDirTreeDoSelectPath(
+void EDVBrowserDirTreeSelectPath(
 	edv_browser_struct *browser, const gchar *path
 );
 
+/* Finding */
 static void EDVBrowserDirTreeFindNodeByPathIterate(
 	GtkCTree *ctree, GtkCTreeNode *node,
 	const gchar *path, GtkCTreeNode **matched_node_ptr
@@ -93,10 +101,12 @@ GtkCTreeNode *EDVBrowserDirTreeFindNodeByPath(
 	edv_browser_struct *browser, const gchar *path
 );
 
+/* Opening */
 void EDVBrowserDirTreeDoOpenWithObject(
 	edv_browser_struct *browser, GtkCTreeNode *node
 );
 
+/* Renaming */
 static void EDVBrowserDirTreeFPromptRenameApplyCB(
 	gpointer data, const gchar *value
 );
@@ -104,6 +114,7 @@ void EDVBrowserDirTreeDoFPromptRename(
 	edv_browser_struct *browser, GtkCTreeNode *node
 );
 
+/* Object Callbacks */
 void EDVBrowserDirTreeObjectAddedNotify(
 	edv_browser_struct *browser, const gchar *path,
 	const struct stat *lstat_buf
@@ -117,8 +128,9 @@ void EDVBrowserDirTreeObjectRemovedNotify(
 	edv_browser_struct *browser, const gchar *path
 );
 
+/* Mount Callbacks */
 void EDVBrowserDirTreeMountNotify(
-	edv_browser_struct *browser, edv_device_struct *dev_ptr,
+	edv_browser_struct *browser, edv_device_struct *dev,
 	gboolean is_mounted
 );
 
@@ -157,8 +169,6 @@ static void EDVBrowserDirTreeSetNode(
 )
 {
 	const gchar *text = obj->name;
-	GtkStyle *style = NULL;
-	GtkCTreeRow *row_ptr;
 	GdkPixmap	*pixmap,
 			*pixmap_exp,
 			*pixmap_ext,
@@ -167,6 +177,9 @@ static void EDVBrowserDirTreeSetNode(
 			*mask_exp,
 			*mask_ext,
 			*mask_hid;
+	GtkStyle	**cell_styles = browser->cell_style,
+			*style = NULL;
+	GtkCTreeRow *row_ptr;
 
 	/* Get icon */
 	EDVMatchObjectIcon(
@@ -174,7 +187,8 @@ static void EDVBrowserDirTreeSetNode(
 	    core_ptr->mimetype, core_ptr->total_mimetypes,
 	    obj->type,
 	    obj->full_path,
-	    obj->link_valid, obj->permissions,
+	    EDV_OBJECT_IS_LINK_VALID(obj),
+	    obj->permissions,
 	    0,                  /* Small icons */
 	    &pixmap, &mask,
 	    &pixmap_exp, &mask_exp,
@@ -183,32 +197,51 @@ static void EDVBrowserDirTreeSetNode(
 	);
 
 	/* Hidden? */
-	if(EDVIsObjectHidden(obj) && (pixmap_hid != NULL))
+	if(EDVIsObjectHidden(obj))
 	{
-	    pixmap = pixmap_hid;
-	    mask = mask_hid;
+	    if(pixmap_hid != NULL)
+	    {
+		pixmap = pixmap_hid;
+		mask = mask_hid;
+	    }
 	}
 
+#if 0
 	/* Home directory? */
 	if((!STRISEMPTY(obj->full_path) && 
 	    !STRISEMPTY(core_ptr->home_dir)) ? 
 	    !strcmp(obj->full_path, core_ptr->home_dir) : FALSE
 	)
 	{
-	    pixmap = browser->folder_home_pixmap;
-	    mask = browser->folder_home_mask;
+	    if(browser->folder_home_pixmap != NULL)
+	    {
+		pixmap = browser->folder_home_pixmap;
+		mask = browser->folder_home_mask;
+	    }
 	}
+#endif
 
 	/* Directory not accessable? */
 	if(!EDVIsObjectAccessable(core_ptr, obj))
 	{
-	    style = browser->cell_style[EDV_BROWSER_CELL_STYLE_NO_ACCESS];
-	    pixmap = browser->folder_noaccess_pixmap;
-	    mask = browser->folder_noaccess_mask;
+	    if(browser->folder_noaccess_pixmap != NULL)
+	    {
+		pixmap = browser->folder_noaccess_pixmap;
+		mask = browser->folder_noaccess_mask;
+	    }
+	    if(style == NULL)
+		style = cell_styles[EDV_BROWSER_CELL_STYLE_NO_ACCESS];
 	}
 
-	/* If the expamded icon is not available then use the standard
-	 * icon
+	/* Link destination is a grand parent? */
+	if(EDV_OBJECT_IS_LINK_TAR_GRAND_PARENT(obj))
+	{
+	    if(style == NULL)
+		style = cell_styles[EDV_BROWSER_CELL_STYLE_RECURSIVE_LINK];
+	}
+
+	/* If the expanded icon is not available then use the
+	 * standard icon as the expanded icon
 	 */
 	if(pixmap_exp == NULL)
 	{
@@ -216,27 +249,27 @@ static void EDVBrowserDirTreeSetNode(
 	    mask_exp = mask;
 	}
 
-	/* Get pointer ctree row from the given node */
+	/* Get the GtkCTreeRow in order to obtain current values */
 	row_ptr = GTK_CTREE_ROW(node);
 	if(row_ptr == NULL)
 	    return;
 
-	/* Update text? */
-	if(text != NULL)
-	    gtk_ctree_set_node_info(
-		ctree, node, text,
-		EDV_LIST_PIXMAP_TEXT_SPACING,
-		(pixmap != NULL) ? 
-		    pixmap : row_ptr->pixmap_closed,
-		(mask != NULL) ?
-		    mask : row_ptr->mask_closed,
-		(pixmap_exp != NULL) ?
-		    pixmap_exp : row_ptr->pixmap_opened,
-		(mask_exp != NULL) ?
-		    mask_exp : row_ptr->mask_opened,
-		row_ptr->is_leaf,
-		row_ptr->expanded
-	    );
+	/* Update node */
+	gtk_ctree_set_node_info(
+	    ctree, node,
+	    (text != NULL) ? text : "(null)",
+	    EDV_LIST_PIXMAP_TEXT_SPACING,
+	    (pixmap != NULL) ? 
+		pixmap : row_ptr->pixmap_closed,
+	    (mask != NULL) ?
+		mask : row_ptr->mask_closed,
+	    (pixmap_exp != NULL) ?
+		pixmap_exp : row_ptr->pixmap_opened,
+	    (mask_exp != NULL) ?
+		mask_exp : row_ptr->mask_opened,
+	    row_ptr->is_leaf,
+	    row_ptr->expanded
+	);
 
 	/* Set node style */
 	gtk_ctree_node_set_row_style(ctree, node, style);
@@ -273,7 +306,7 @@ GtkCTreeNode *EDVBrowserDirTreeGetToplevel(edv_browser_struct *browser)
  *	The specified object will be transfered and should not be
  *	referenced after this call.
  */
-GtkCTreeNode *EDVBrowserDirTreeInsertNode(
+static GtkCTreeNode *EDVBrowserDirTreeInsertNode(
 	edv_browser_struct *browser,
 	GtkCTreeNode *parent, GtkCTreeNode *sibling,
 	edv_object_struct *obj
@@ -328,7 +361,7 @@ GtkCTreeNode *EDVBrowserDirTreeInsertNode(
 	    return(NULL);
 	}
 
-	/* Set text, pixmaps, and style for the new node */
+	/* Set the text, pixmaps, and style for the new node */
 	EDVBrowserDirTreeSetNode(
 	    core_ptr, browser, ctree, node, obj
 	);
@@ -346,103 +379,41 @@ GtkCTreeNode *EDVBrowserDirTreeInsertNode(
 
 
 /*
- *	Creates the File Browser Directory Tree's toplevel nodes.
- *
- *	Any existing nodes will be deleted.
- */
-void EDVBrowserDirTreeCreateToplevels(edv_browser_struct *browser)
-{
-	const gchar *path;
-	edv_object_struct *obj;
-	GtkCTreeNode *node;
-	struct stat lstat_buf;
-	GtkCTree *ctree = (browser != NULL) ?
-	    (GtkCTree *)browser->directory_ctree : NULL;
-	if(ctree == NULL)
-	    return;
-
-	/* Mark as busy but do not mark as processing since callbacks
-	 * need to see things as not processing when nodes are expanded
-	 * in EDVBrowserDirTreeDoRefresh()
-	 */
-	EDVBrowserSetBusy(browser, TRUE);
-
-	/* Remove existing toplevel nodes (if any) */
-	node = EDVBrowserDirTreeGetToplevel(browser);
-	if(node != NULL)                             
-	    gtk_ctree_remove_node(ctree, node);
-
-
-	/* Get toplevel origin path */
-	path = browser->directory_ctree_origin_path;
-	if(STRISEMPTY(path))
-	    path = "/";
-
-	/* Begin creating toplevel nodes */
-
-	/* Create object for toplevel node */
-	obj = EDVObjectNew();
-	if(!lstat(path, &lstat_buf))
-	{
-	    EDVObjectSetPath(obj, path);
-	    EDVObjectSetStat(obj, &lstat_buf);
-	    obj->link_valid = TRUE;		/* Assume valid */
-	}
-	node = EDVBrowserDirTreeInsertNode(
-	    browser, NULL, NULL, obj
-	);
-	obj = NULL;
-
-	/* Created toplevel node? */
-	if(node != NULL)
-	{
-	    /* Get one level of nodes from this toplevel node */
-	    EDVBrowserDirTreeDoGetChildrenList(
-		browser, node, TRUE, FALSE
-	    );
-	}
-
-	EDVBrowserSetBusy(browser, FALSE);
-}
-
-/*
- *	Sets the File Browser Directory Tree's origin path and recreates
- *	the toplevel nodes.
+ *	Sets the origin path and recreates the toplevel nodes.
  */
 void EDVBrowserDirTreeSetOriginPath(
 	edv_browser_struct *browser, const gchar *path
 )
 {
+	const gchar *origin_path;
 	GtkCList *clist;
-	GtkCTree *ctree;
 	GtkCTreeNode *node;
+	GtkCTree *ctree;
 
 	if((browser == NULL) || STRISEMPTY(path))
 	    return;
 
-	ctree = GTK_CTREE(browser->directory_ctree);
+	origin_path = browser->directory_ctree_origin_path;
+	ctree = (GtkCTree *)browser->directory_ctree;
+	if(ctree == NULL)
+	    return;
+
 	clist = GTK_CLIST(ctree);
 
 	/* No change? */
-	if(path == browser->directory_ctree_origin_path)
+	if(path == origin_path)
 	    return;
-	if((browser->directory_ctree_origin_path != NULL) ?
-	    !strcmp(browser->directory_ctree_origin_path, path) : FALSE
-	)
+	if((origin_path != NULL) ? !strcmp(origin_path, path) : FALSE)
 	    return;
 
-	/* Set the new Directory Tree Origin path */
+	/* Set the new origin path */
 	g_free(browser->directory_ctree_origin_path);
 	browser->directory_ctree_origin_path = STRDUP(path);
 
-	/* Delete all existing nodes and recreate toplevels on the
-	 * Directory Tree
-	 */
-	gtk_clist_freeze(clist);
+	/* Delete all existing nodes and recreate toplevels */
 	EDVBrowserDirTreeCreateToplevels(browser);
-	gtk_clist_thaw(clist);
 
-	/* Select and expand toplevel node (do not freeze) */
+	/* Select and expand the toplevel node */
 	node = EDVBrowserDirTreeGetToplevel(browser);
 	if(node != NULL)
 	{
@@ -550,7 +521,11 @@ static void EDVBrowserDirTreeDoGetChildrenListIterate(
 
 
 		/* Destination child object is a directory? */
+#ifdef S_ISDIR
 		if(S_ISDIR(stat_buf.st_mode))
+#else
+		if(FALSE)
+#endif
 		{
 		    GtkCTreeNode *node;
 
@@ -560,7 +535,7 @@ static void EDVBrowserDirTreeDoGetChildrenListIterate(
 		    {
 			EDVObjectSetPath(obj, child_path);
 			EDVObjectSetStat(obj, &lstat_buf);
-			obj->link_valid = TRUE;
+			EDVObjectUpdateLinkFlags(obj);
 
 			/* Begin filter checks */
 			if((hide_object_hidden ?
@@ -621,11 +596,11 @@ static void EDVBrowserDirTreeDoGetChildrenListIterate(
 }
 
 /*
- *	Gets a list of child nodes for the specified parent node, any
+ *	Gets a list of child nodes of the specified parent node, any
  *	existing child nodes in the specified parent node will be
  *	deleted.
  *
- *	This will recurse no more than two levels from the specified
+ *	This will recurse no more than 2 levels from the specified
  *	parent node or not recurse at all of recurse is FALSE.
  *
  *	Inputs assumed valid.
@@ -661,12 +636,10 @@ static void EDVBrowserDirTreeDoGetChildrenList(
 		"Scanning directories...",
 		FALSE
 	    );
-	    EDVStatusBarProgress(browser->status_bar, -1.0, TRUE);
+	    EDVStatusBarProgress(browser->status_bar, -1.0f, TRUE);
 	}
 
-	/* First delete all child nodes from the specified parent
-	 * node
-	 */
+	/* Delete all child nodes from the specified parent node */
 	node = EDVNodeGetChild(parent);
 	while(node != NULL)
 	{
@@ -675,7 +648,9 @@ static void EDVBrowserDirTreeDoGetChildrenList(
 	    node = sibling_node;
 	}
 
-	/* Get child node for the specified parent node */
+	/* Get new listing of child nodes for the specified parent
+	 * node
+	 */
 	EDVBrowserDirTreeDoGetChildrenListIterate(
 	    core_ptr, browser, ctree, parent,
 	    update_progress, recurse,
@@ -690,80 +665,181 @@ static void EDVBrowserDirTreeDoGetChildrenList(
 	}
 }
 
+/*
+ *	Creates the toplevel nodes.
+ *
+ *	Any existing nodes will be deleted.
+ */
+void EDVBrowserDirTreeCreateToplevels(edv_browser_struct *browser)
+{
+	struct stat lstat_buf;
+	const gchar *path;
+	GtkCList *clist;
+	GtkCTreeNode *node;
+	GtkCTree *ctree;
+	edv_object_struct *obj;
+
+	if(browser == NULL)
+	    return;
+
+	ctree = (GtkCTree *)browser->directory_ctree;
+	if(ctree == NULL)
+	    return;
+
+	clist = GTK_CLIST(ctree);
+
+	gtk_clist_freeze(clist);
+
+	/* Delete all existing nodes */
+	EDVBrowserDirTreeClear(browser);
+
+	/* Get the origin path as the path for the toplevel node */
+	path = browser->directory_ctree_origin_path;
+	if(STRISEMPTY(path))
+#if defined(__WIN32)
+	    path = "C:\\";
+#else
+	    path = "/";
+#endif
+
+	/* Create object for toplevel node */
+	obj = EDVObjectNew();
+	if(!lstat(path, &lstat_buf))
+	{
+	    EDVObjectSetPath(obj, path);
+	    EDVObjectSetStat(obj, &lstat_buf);
+	    EDVObjectUpdateLinkFlags(obj);
+	}
+	node = EDVBrowserDirTreeInsertNode(
+	    browser, NULL, NULL, obj
+	);
+
+	/* Successfully created the toplevel node? */
+	if(node != NULL)
+	{
+	    /* Get one level of nodes from this toplevel node */
+	    EDVBrowserDirTreeDoGetChildrenList(
+		browser, node, TRUE, FALSE
+	    );
+	}
+
+	gtk_clist_thaw(clist);
+}
 
 /*
- *	Refreshes the File Browser's Directory Tree by refetching the
- *	list of child nodes from the specified node and recursing no
- *	more than 2 levels.
+ *	Gets a listing of child nodes from the specified node, recursing
+ *	no more than 2 levels.
  *
- *	All nodes will have their referenced object checked to see if
- *	it exists, if the object does not exist then the node is
- *	removed.
+ *	If the node is NULL then the toplevel node will be used.
  *
- *	The specified node may be removed by this call so it should not
- *	be referenced again.
+ *	Any existing child nodes of the specified node will be deleted
+ *	first before getting the new list of child nodes.
  */
-void EDVBrowserDirTreeDoRefresh(
+void EDVBrowserDirTreeGetListing(
 	edv_browser_struct *browser, GtkCTreeNode *node,
 	gboolean update_progress
 )
 {
-	GtkCTree *ctree = (browser != NULL) ?
-	    (GtkCTree *)browser->directory_ctree : NULL;
+	GtkCList *clist;
+	GtkCTree *ctree;
+
+	if(browser == NULL)
+	    return;
+
+	ctree = (GtkCTree *)browser->directory_ctree;
 	if(ctree == NULL)
 	    return;
 
+	clist = GTK_CLIST(ctree);
+
+	gtk_clist_freeze(clist);
+
 	/* Use toplevel node if the specified node is NULL */
 	if(node == NULL)
 	    node = EDVBrowserDirTreeGetToplevel(browser);
 
-	/* Remove all child nodes of the specified node and then
-	 * refetch all child nodes, recursing to at most 2 levels
+	/* Delete any existing child nodes from the specified node
+	 * and then get a new list of child nodes
 	 */
 	if(node != NULL)
 	    EDVBrowserDirTreeDoGetChildrenList(
 		browser, node, update_progress, TRUE
 	    );
 
-	/* Check all nodes (including the given node) to see if the
-	 * referenced object
-	 *
-	 * Any node that references an object that does not exist will
-	 * be removed, so the given node should not be referenced
-	 * after this call
-	 *
-	 * All child nodes will be updated on the directory ctree
-	 */
-	EDVBrowserDirTreeDoSync(browser, NULL);
+	/* Realize listing */
+	EDVBrowserDirTreeRealizeListing(browser, NULL);
+
+	gtk_clist_thaw(clist);
 }
 
 /*
- *	Procedure to create child nodes parented to the given node, each
- *	child node will be a child directory or a link that points to a
- *	directory in the directory specified by the given node.
+ *	Deletes all nodes on the Directory Tree.
  */
-void EDVBrowserDirTreeDoExpand(
+void EDVBrowserDirTreeClear(edv_browser_struct *browser)
+{
+	GtkCList *clist;
+	GtkCTreeNode *node;
+	GtkCTree *ctree;
+
+	if(browser == NULL)
+	    return;
+
+	ctree = (GtkCTree *)browser->directory_ctree;
+	if(ctree == NULL)
+	    return;
+
+	clist = GTK_CLIST(ctree);
+
+	node = EDVBrowserDirTreeGetToplevel(browser);
+	if(node != NULL)
+	{
+	    gtk_clist_freeze(clist);
+	    gtk_ctree_remove_node(ctree, node);
+	    gtk_clist_thaw(clist);
+	}
+}
+
+
+/*
+ *	Expands the specified node and gets a listing of child nodes
+ *	of the specified node.
+ */
+void EDVBrowserDirTreeExpand(
 	edv_browser_struct *browser, GtkCTreeNode *node,
 	gboolean update_progress
 )
 {
+	GtkCList *clist;
+	GtkCTree *ctree;
+
 	if((browser == NULL) || (node == NULL))
 	    return;
 
+	ctree = (GtkCTree *)browser->directory_ctree;
+	if(ctree == NULL)
+	    return;
+
+	clist = GTK_CLIST(ctree);
+
+	gtk_clist_freeze(clist);
+
 	/* Get child directories as child nodes of the given expanded
 	 * node, recursing at most 2 levels
 	 */
 	EDVBrowserDirTreeDoGetChildrenList(
 	    browser, node, update_progress, TRUE
 	);
+
+	gtk_clist_thaw(clist);
 }
 
 
 /*
- *	Called by EDVBrowserDirTreeDoSync() to update nodes and
- *	remove non-existant nodes.
+ *	Called by EDVBrowserDirTreeRealizeListing() to update existing
+ *	nodes and to remove all non-existant nodes, then recurse into
+ *	any child nodes.
  */
-static void EDVBrowserDirTreeDoSyncIterate(
+static void EDVBrowserDirTreeRealizeListingIterate(
 	edv_browser_struct *browser, GtkCTree *ctree,
 	GtkCTreeNode *node,
 	gboolean parent_is_expanded
@@ -785,7 +861,7 @@ static void EDVBrowserDirTreeDoSyncIterate(
 	    if(child_node != NULL)
 	    {
 		/* Recurse into child nodes */
-		EDVBrowserDirTreeDoSyncIterate(
+		EDVBrowserDirTreeRealizeListingIterate(
 		    browser, ctree,
 		    child_node,
 		    row_ptr->expanded
@@ -843,7 +919,11 @@ static void EDVBrowserDirTreeDoSyncIterate(
 			obj = NULL;
 		    }
 		    /* Destination does not goes to a directory? */
+#ifdef S_ISDIR
 		    else if(!S_ISDIR(stat_buf.st_mode))
+#else
+		    else if(TRUE)
+#endif
 		    {
 			/* Destination not a directory, remove the node */
 			gtk_ctree_remove_node(ctree, node);
@@ -853,11 +933,11 @@ static void EDVBrowserDirTreeDoSyncIterate(
 		    }
 		    else
 		    {
-			/* All checks passed, update the Object and
+			/* All checks passed, update the object and
 			 * the node
 			 */
 			EDVObjectSetStat(obj, &lstat_buf);
-			obj->link_valid = TRUE;
+			EDVObjectUpdateLinkFlags(obj);
 			EDVBrowserDirTreeSetNode(
 			    EDV_CORE(browser->core_ptr),
 			    browser, ctree,
@@ -880,22 +960,28 @@ static void EDVBrowserDirTreeDoSyncIterate(
 /*
  *	Updates the existing nodes and removes any non-existant nodes
  *	starting from the specified node.
+ *
+ *	If the node is NULL then the toplevel node will be used.
  */
-void EDVBrowserDirTreeDoSync(
+void EDVBrowserDirTreeRealizeListing(
 	edv_browser_struct *browser, GtkCTreeNode *node
 )
 {
+	GtkCList *clist;
 	GtkCTreeRow *row_ptr;
+	GtkCTree *ctree;
 	edv_core_struct *core_ptr;
-	GtkCTree *ctree = (browser != NULL) ?
-	    (GtkCTree *)browser->directory_ctree : NULL;
-	if(ctree == NULL)
+
+	if(browser == NULL)
 	    return;
 
+	ctree = (GtkCTree *)browser->directory_ctree;
 	core_ptr = EDV_CORE(browser->core_ptr);
-	if(core_ptr == NULL)
+	if((ctree == NULL) || (core_ptr == NULL))
 	    return;
 
+	clist = GTK_CLIST(ctree);
+
 	/* Use toplevel node if the specified node is NULL */
 	if(node == NULL)
 	    node = EDVBrowserDirTreeGetToplevel(browser);
@@ -904,24 +990,28 @@ void EDVBrowserDirTreeDoSync(
 
 	row_ptr = GTK_CTREE_ROW(node);
 
+	gtk_clist_freeze(clist);
+
 	/* Begin updating nodes and removing non-existant nodes */
-	EDVBrowserDirTreeDoSyncIterate(
+	EDVBrowserDirTreeRealizeListingIterate(
 	    browser, ctree,
 	    node,
 	    (row_ptr != NULL) ? row_ptr->expanded : FALSE
 	);
+
+	gtk_clist_thaw(clist);
 }
 
 
 /*
- *	Called by EDVBrowserDirTreeDoSelectPath() to seek through all
+ *	Called by EDVBrowserDirTreeSelectPath() to seek through all
  *	child directories for a prefix match to the given full path and
  *	recurse into child directories.
  *
  *	The given path is the full path that is intended to be selected
  *	if found.
  */
-static void EDVBrowserDirTreeDoSelectPathIterate(
+static void EDVBrowserDirTreeSelectPathIterate(
 	GtkCTree *ctree, GtkCTreeNode *node, const gchar *path,
 	GtkCTreeNode **matched_node_ptr
 )
@@ -983,7 +1073,7 @@ static void EDVBrowserDirTreeDoSelectPathIterate(
 		while(node != NULL)
 		{
 		    /* Check this node, recurse if it is a match */
-		    EDVBrowserDirTreeDoSelectPathIterate(
+		    EDVBrowserDirTreeSelectPathIterate(
 			ctree, node, path, matched_node_ptr
 		    );
 		    /* If we got a match, then do not continue search */
@@ -1003,7 +1093,7 @@ static void EDVBrowserDirTreeDoSelectPathIterate(
  *
  *	Nodes will be expanded and updated as needed.
  */
-void EDVBrowserDirTreeDoSelectPath(
+void EDVBrowserDirTreeSelectPath(
 	edv_browser_struct *browser, const gchar *path
 )
 {
@@ -1042,7 +1132,7 @@ void EDVBrowserDirTreeDoSelectPath(
 	/* Search for the path, expanding (thus updating nodes) and
 	 * select the matched node (if found)
 	 */
-	EDVBrowserDirTreeDoSelectPathIterate(
+	EDVBrowserDirTreeSelectPathIterate(
 	    ctree, node, full_path, matched_node_ptr
 	);
 
@@ -1203,32 +1293,31 @@ void EDVBrowserDirTreeDoOpenWithObject(
 	edv_browser_struct *browser, GtkCTreeNode *node
 )
 {
-	GtkWidget *w;
-	GtkCTree *ctree;
-	edv_object_struct *object;
 	const gchar *name;
 	gchar *full_path;
 	struct stat stat_buf;
-
+	GtkWidget *w, *toplevel;
+	GtkCTree *ctree;
+	edv_object_struct *obj;
+	edv_core_struct *core_ptr;
 
 	if((browser == NULL) || (node == NULL))
 	    return;
 
+	toplevel = browser->toplevel;
 	w = browser->directory_ctree;
-	if(w != NULL)
-	    ctree = GTK_CTREE(w);
-	else
+	core_ptr = EDV_CORE(browser->core_ptr);
+	if((w == NULL) || (core_ptr == NULL))
 	    return;
 
-	/* Get object from node data */
-	object = EDV_OBJECT(
-	    gtk_ctree_node_get_row_data(ctree, node)
-	);
-	if(object == NULL)
+	ctree = GTK_CTREE(w);
+
+	obj = EDV_OBJECT(gtk_ctree_node_get_row_data(ctree, node));
+	if(obj == NULL)
 	    return;
 
 	/* Check name of object for special notations */
-	name = object->name;
+	name = obj->name;
 	if(name != NULL)
 	{
 	    if(!strcmp(name, "."))
@@ -1243,13 +1332,13 @@ void EDVBrowserDirTreeDoOpenWithObject(
 	    }
 	    else
 	    {
-		full_path = STRDUP(object->full_path);
+		full_path = STRDUP(obj->full_path);
 	    }
 	}
 	else
 	{
 	    /* No name available, get copy of full path */
-	    full_path = STRDUP(object->full_path);
+	    full_path = STRDUP(obj->full_path);
 	}
 	if(full_path == NULL)
 	    return;
@@ -1268,19 +1357,30 @@ void EDVBrowserDirTreeDoOpenWithObject(
 	{
 	    gchar       *stdout_path_rtn = NULL,
 			*stderr_path_rtn = NULL;
+	    GList *paths_list = NULL;
 
-	    EDVOpenWithObjectPath(
-		EDV_CORE(browser->core_ptr), full_path,
-		NULL,		/* Command name */
-		browser->toplevel, TRUE,
-		&stdout_path_rtn, &stderr_path_rtn
+	    paths_list = g_list_append(
+		paths_list,
+		STRDUP(full_path)
 	    );
 
+	    EDVOpenWith(
+		core_ptr,
+		paths_list,		/* Paths List */
+		NULL,			/* Command Name */
+		toplevel,		/* Toplevel */
+		TRUE,			/* Verbose */
+		&stdout_path_rtn,
+		&stderr_path_rtn
+	    );
+
+	    g_list_foreach(paths_list, (GFunc)g_free, NULL);
+	    g_list_free(paths_list);
+
 	    g_free(stdout_path_rtn);
 	    g_free(stderr_path_rtn);
 	}
 
-	/* Delete copy of full path */
 	g_free(full_path);
 }
 
@@ -1409,30 +1509,32 @@ void EDVBrowserDirTreeDoFPromptRename(
 	edv_browser_struct *browser, GtkCTreeNode *node
 )
 {
-	GtkWidget *w;
-	GtkCList *clist;
-	GtkCTree *ctree;
-	edv_object_struct *object;
 	gint row, column;
 	gint cx, cy, px, py, pwidth, pheight;
+	GtkWidget *w, *toplevel;
+	GtkCList *clist;
+	GtkCTree *ctree;
+	edv_object_struct *obj;
+	edv_core_struct *core_ptr;
 
 	if((browser == NULL) || (node == NULL) || FPromptIsQuery())
 	    return;
 
+	toplevel = browser->toplevel;
+	w = browser->directory_ctree;
+	core_ptr = EDV_CORE(browser->core_ptr);
+	if((w == NULL) || (core_ptr == NULL))
+	    return;
+
+	ctree = GTK_CTREE(w);
+	clist = GTK_CLIST(ctree);
+
 	/* Check and warn if write protect is enabled */
 	if(EDVCheckWriteProtect(
-	    EDV_CORE(browser->core_ptr), TRUE, browser->toplevel
+	    core_ptr, TRUE, toplevel
 	))
 	    return;
 
-	w = browser->directory_ctree;
-	if(w != NULL)
-	    ctree = GTK_CTREE(w);
-	else
-	    return;
-
-	clist = GTK_CLIST(ctree);
-
 	EDVBrowserSyncData(browser);
 
 	/* Get row and column of the given node */
@@ -1459,19 +1561,19 @@ void EDVBrowserDirTreeDoFPromptRename(
 	pwidth = w->allocation.width;
 
 
-	/* Get disk object structure from the directory ctree node */
-	object = EDV_OBJECT(
+	/* Get object from the directory ctree node */
+	obj = EDV_OBJECT(
 	    gtk_ctree_node_get_row_data(ctree, node)
 	);
-	if(object == NULL)
+	if(obj == NULL)
 	    return;
 
 	/* Check if object name is a special notation that should not
 	 * be allowed to be renamed
 	 */
-	if(object->name != NULL)
+	if(obj->name != NULL)
 	{
-	    const gchar *name = object->name;
+	    const gchar *name = obj->name;
 	    if(!strcmp(name, ".") || !strcmp(name, "..") ||
 	       !strcmp(name, "/")
 	    )
@@ -1480,7 +1582,7 @@ void EDVBrowserDirTreeDoFPromptRename(
 
 	if(TRUE)
 	{
-	    gchar *value = STRDUP(object->name);
+	    gchar *value = STRDUP(obj->name);
 
 	    /* Create callback data */
 	    gpointer *cb_data = (gpointer *)g_malloc0(
@@ -1522,83 +1624,99 @@ void EDVBrowserDirTreeObjectAddedNotify(
 	const struct stat *lstat_buf
 )
 {
-	gchar *parent_path;
-	GtkCTreeNode *node, *parent_node;
 	struct stat stat_buf;
-	GtkCTree *ctree = (browser != NULL) ?
-	    (GtkCTree *)browser->directory_ctree : NULL;
-	if((ctree == NULL) || STRISEMPTY(path) || (lstat_buf == NULL))
+	gchar *parent_path;
+	GtkCList *clist;
+	GtkCTreeNode *node, *parent_node;
+	GtkCTree *ctree;
+	edv_core_struct *core_ptr;
+
+	if((browser == NULL) || STRISEMPTY(path) || (lstat_buf == NULL))
 	    return;
 
-	/* Check if the path goes to a directory */
+	ctree = (GtkCTree *)browser->directory_ctree;
+	core_ptr = EDV_CORE(browser->core_ptr);
+	if((ctree == NULL) || (core_ptr == NULL))
+	    return;
+
+	clist = GTK_CLIST(ctree);
+
+	/* Destination does not exist? */
 	if(stat(path, &stat_buf))
 	    return;
+
+	/* Destination does not lead to a directory? */
+#ifdef S_ISDIR
 	if(!S_ISDIR(stat_buf.st_mode))
+#else
+	if(TRUE)
+#endif
 	    return;
 
-	/* Get parent of the specified path, we need to use the parent
-	 * because that is the only way we know where to create the
-	 * new node in
-	 */
+	/* Get the parent of the specified path */
 	parent_path = g_dirname(path);
 	if(parent_path == NULL)
 	    return;
 
-	/* Look for the parent node that matches the parent of the
-	 * new object
+	/* Find the parent node that matches the parent of the specified
+	 * path
 	 */
 	parent_node = EDVBrowserDirTreeFindNodeByPath(browser, parent_path);
 	if(parent_node == NULL)
 	{
-	    /* Unable to find parent node, this implies we have no way
-	     * to create the node for the new object
+	    /* Unable to find the parent node, there is no way to
+	     * create the node to represent this new object
 	     */
 	    g_free(parent_path);
 	    return;
 	}
 
-	/* Check if the node specified by path already exists */
+	/* Check if the node specified by the specified path already
+	 * exists
+	 */
 	node = EDVBrowserDirTreeFindNodeByPath(browser, path);
 	if(node != NULL)
 	{
-	    /* Node already exists for the given path, so just update
-	     * the node by regetting child nodes and recursing at most
+	    /* The node already exists, so just update the node by
+	     * regetting its child nodes and recursing no more than
 	     * 2 levels
 	     */
-	    gtk_clist_freeze(GTK_CLIST(ctree));
+	    gtk_clist_freeze(clist);
 	    EDVBrowserDirTreeDoGetChildrenList(
 		browser, node, TRUE, TRUE
 	    );
-	    gtk_clist_thaw(GTK_CLIST(ctree));
+	    gtk_clist_thaw(clist);
 	}
 	else
 	{
-	    /* Add new node for the new object */
+	    /* Add a new node for the new object */
+
+	    /* Create new object */
 	    edv_object_struct *obj = EDVObjectNew();
-	    EDVObjectSetPath(obj, path);
-	    EDVObjectSetStat(obj, lstat_buf);
-	    obj->link_valid = TRUE;
+	    if(obj != NULL)
+	    {
+		EDVObjectSetPath(obj, path);
+		EDVObjectSetStat(obj, lstat_buf);
+		EDVObjectUpdateLinkFlags(obj);
+	    }
 
-	    gtk_clist_freeze(GTK_CLIST(ctree));
+	    gtk_clist_freeze(clist);
 
-	    /* Add object to the direcotry tree at the parent_node
-	     *
-	     * The object should not be referenced after this call
-	     */
+	    /* Add node */
 	    node = EDVBrowserDirTreeInsertNode(
 		browser, parent_node, NULL, obj
 	    );
 	    if(node != NULL)
 	    {
 		/* Get new listing of child objects for the new
-		 * node, recurse no more than 2 levels
+		 * node, recursing no more than 2 levels
 		 */
 		EDVBrowserDirTreeDoGetChildrenList(
 		    browser, node, TRUE, TRUE
 		);
 	    }
 
-	    gtk_clist_thaw(GTK_CLIST(ctree));
+	    gtk_clist_thaw(clist);
 	}
 
 	g_free(parent_path);
@@ -1619,14 +1737,22 @@ void EDVBrowserDirTreeObjectModifiedNotify(
 	const struct stat *lstat_buf
 )
 {
-	gint stat_result;
-	GtkCTreeNode *node;
 	struct stat stat_buf;
-	GtkCTree *ctree = (browser != NULL) ? 
-	    (GtkCTree *)browser->directory_ctree : NULL;
-	if((ctree == NULL) || STRISEMPTY(path) || (lstat_buf == NULL))
+	gint stat_result;
+	GtkCList *clist;
+	GtkCTreeNode *node;
+	GtkCTree *ctree;
+	edv_core_struct *core_ptr;
+	if((browser == NULL) || STRISEMPTY(path) || (lstat_buf == NULL))
 	    return;
 
+	ctree = (GtkCTree *)browser->directory_ctree;
+	core_ptr = EDV_CORE(browser->core_ptr);
+	if((ctree == NULL) || (core_ptr == NULL))
+	    return;
+
+	clist = GTK_CLIST(ctree);
+
 	/* If the new path is not given then assume it is the same as
 	 * the original path
 	 */
@@ -1634,40 +1760,77 @@ void EDVBrowserDirTreeObjectModifiedNotify(
 	    new_path = path;
 
 	/* Get destination stats of the modified object */
-	stat_result = stat(new_path, &stat_buf);
+	stat_result = (gint)stat((const char *)new_path, &stat_buf);
 
-	/* Destination invalid or does not go to a directory? */
-	if((!stat_result) ? !S_ISDIR(stat_buf.st_mode) : TRUE)
+	/* Is the destination invalid or it does not lead to a
+	 * directory?
+	 */
+#ifdef S_ISDIR
+	if((stat_result == 0) ? !S_ISDIR(stat_buf.st_mode) : TRUE)
+#else
+	if(stat_result != 0)
+#endif
 	{
-	    /* Destination does not go to a directory, so we need to
-	     * check if there is an existing node that matches the
-	     * original path
-	     *
-	     * If it exists then it should no longer be listed and must
-	     * be removed
+	    /* Destination is invalid or does not lead to a directory,
+	     * so we need to check if there is an existing node that
+	     * matches the specified old path
 	     */
 	    node = EDVBrowserDirTreeFindNodeByPath(browser, path);
 	    if(node != NULL)
 	    {
-		/* Found a node that reffers to the old path of the
-		 * object who's destination is no longer a directory,
+		/* No longer exists or it does not lead to a directory,
 		 * remove it
 		 */
+		gtk_clist_freeze(clist);
 		gtk_ctree_remove_node(ctree, node);
+		gtk_clist_thaw(clist);
 	    }
+
 	    return;
 	}
 
-	/* Look for a node that matches the old path of the object */
+	/* Find node that matches the specified old path */
 	node = EDVBrowserDirTreeFindNodeByPath(browser, path);
-	if(node == NULL)
+	if(node != NULL)
+	{
+	    /* Found an existing node that matches the specified old
+	     * path
+	     */
+	    edv_object_struct *obj = EDV_OBJECT(
+		gtk_ctree_node_get_row_data(ctree, node)
+	    );
+	    if(obj != NULL)
+	    {
+		/* Update the object */
+		EDVObjectSetPath(obj, new_path);
+		EDVObjectSetStat(obj, lstat_buf);
+		EDVObjectUpdateLinkFlags(obj);
+
+		gtk_clist_freeze(clist);
+
+		/* Update the node */
+		EDVBrowserDirTreeSetNode(
+		    core_ptr, browser, ctree, node, obj
+		);
+
+		/* Get new listing of child objects for the updated
+		 * node, recurse no more than 2 levels
+		 */
+		EDVBrowserDirTreeDoGetChildrenList(
+		    browser, node, TRUE, TRUE
+		);
+
+		gtk_clist_thaw(clist);
+	    }
+	}
+	else
 	{
 	    /* No existing node matches the old path, so check if an
 	     * existing node matches the parent of the new path
 	     */
 	    gchar *new_parent_path = g_dirname(new_path);
 
-	    /* Find node that matches the full path of the parent of
+	    /* Find node that matches the path of the parent of
 	     * the new path
 	     */
 	    GtkCTreeNode *parent_node = EDVBrowserDirTreeFindNodeByPath(
@@ -1682,9 +1845,9 @@ void EDVBrowserDirTreeObjectModifiedNotify(
 		edv_object_struct *obj = EDVObjectNew();
 		EDVObjectSetPath(obj, new_path);
 		EDVObjectSetStat(obj, lstat_buf);
-		obj->link_valid = TRUE;
+		EDVObjectUpdateLinkFlags(obj);
 
-		gtk_clist_freeze(GTK_CLIST(ctree));
+		gtk_clist_freeze(clist);
 
 		/* Add node to the parent_node, this will transfer
 		 * the object to the new node
@@ -1704,45 +1867,11 @@ void EDVBrowserDirTreeObjectModifiedNotify(
 		    );
 		}
 
-		gtk_clist_thaw(GTK_CLIST(ctree));
+		gtk_clist_thaw(clist);
 	    }
 
 	    g_free(new_parent_path);
 	}
-	else
-	{
-	    /* Got existing node that matches the original path, so
-	     * update the node and its object
-	     */
-	    edv_object_struct *obj = EDV_OBJECT(
-		gtk_ctree_node_get_row_data(ctree, node)
-	    );
-	    if(obj != NULL)
-	    {
-		EDVObjectSetPath(obj, new_path);
-		EDVObjectSetStat(obj, lstat_buf);
-		obj->link_valid = TRUE;
-
-		gtk_clist_freeze(GTK_CLIST(ctree));
-
-		/* Update node's text, pixmap, and style with respect
-		 * to the newly modified disk object
-		 */
-		EDVBrowserDirTreeSetNode(
-		    EDV_CORE(browser->core_ptr), browser,
-		    ctree, node, obj
-		);
-
-		/* Get new listing of child disk objects for the updated
-		 * node, recurse no more than 2 levels
-		 */
-		EDVBrowserDirTreeDoGetChildrenList(
-		    browser, node, TRUE, TRUE
-		);
-
-		gtk_clist_thaw(GTK_CLIST(ctree));
-	    }
-	}
 }
 
 /*
@@ -1755,19 +1884,30 @@ void EDVBrowserDirTreeObjectRemovedNotify(
 	edv_browser_struct *browser, const gchar *path
 )
 {
+	GtkCList *clist;
 	GtkCTreeNode *node;
-	GtkCTree *ctree = (browser != NULL) ? 
-	    (GtkCTree *)browser->directory_ctree : NULL;
-	if((ctree == NULL) || STRISEMPTY(path))
+	GtkCTree *ctree;
+	edv_core_struct *core_ptr;
+
+	if((browser == NULL) || STRISEMPTY(path))
 	    return;
 
+	ctree = (GtkCTree *)browser->directory_ctree;
+	core_ptr = EDV_CORE(browser->core_ptr);
+	if((ctree == NULL) || (core_ptr == NULL))
+	    return;
+
+	clist = GTK_CLIST(ctree);
+ 
 	/* Find node that matches the specified path */
 	node = EDVBrowserDirTreeFindNodeByPath(browser, path);
-	if(node == NULL)
-	    return;
-
-	/* Remove matched node and all of its child nodes */
-	gtk_ctree_remove_node(ctree, node);
+	if(node != NULL)
+	{
+	    /* Remove matched node and all of its child nodes */
+	    gtk_clist_freeze(clist);
+	    gtk_ctree_remove_node(ctree, node);
+	    gtk_clist_thaw(clist);
+	}
 }
 
 
@@ -1776,63 +1916,95 @@ void EDVBrowserDirTreeObjectRemovedNotify(
  *	unmounted.
  */
 void EDVBrowserDirTreeMountNotify(
-	edv_browser_struct *browser, edv_device_struct *dev_ptr,
+	edv_browser_struct *browser, edv_device_struct *dev,
 	gboolean is_mounted
 )
 {
 	gchar *mount_path;
+	GtkCList *clist;
 	GtkCTreeNode *node;
-	struct stat lstat_buf;
-	GtkCTree *ctree = (browser != NULL) ? 
-	    (GtkCTree *)browser->directory_ctree : NULL;
-	if((ctree == NULL) || (dev_ptr == NULL))
+	GtkCTree *ctree;
+	edv_core_struct *core_ptr;
+
+	if((browser == NULL) || (dev == NULL))
 	    return;
 
-	/* Get copy of mount path from device */
-	mount_path = STRDUP(dev_ptr->mount_path);
+	ctree = (GtkCTree *)browser->directory_ctree;
+	core_ptr = EDV_CORE(browser->core_ptr);
+	if((ctree == NULL) || (core_ptr == NULL))
+	    return;
+
+	clist = GTK_CLIST(ctree);
+
+	/* Get the mount path */
+	mount_path = STRDUP(dev->mount_path);
 	if(mount_path == NULL)
 	    return;
 
 	/* Simplify mount path */
 	EDVSimplifyPath(mount_path);
 
-
-	/* Find node that matches the mount path */
+	/* Find the node that matches this mount path */
 	node = EDVBrowserDirTreeFindNodeByPath(browser, mount_path);
 	if(node != NULL)
 	{
-	    /* Found existing node that matches the mount path, so
-	     * update the node and its object
-	     */
+	    /* Found existing node that matches this mount path */
+	    struct stat lstat_buf;
 	    edv_object_struct *obj = EDV_OBJECT(
 		gtk_ctree_node_get_row_data(ctree, node)
 	    );
 	    if((obj != NULL) && !lstat(mount_path, &lstat_buf))
 	    {
+		/* Update the object */
 		EDVObjectSetPath(obj, mount_path);
 		EDVObjectSetStat(obj, &lstat_buf);
-		obj->link_valid = TRUE;
+		EDVObjectUpdateLinkFlags(obj);
 
-		gtk_clist_freeze(GTK_CLIST(ctree));
+		gtk_clist_freeze(clist);
 
-		/* Update node's text, pixmap, and style with respect to
-		 * the newly modified disk object
-		 */
+		/* Update the node */
 		EDVBrowserDirTreeSetNode(
-		    EDV_CORE(browser->core_ptr), browser,
-		    ctree, node, obj
+		    core_ptr, browser, ctree,
+		    node, obj
 		);
 
-		/* Get new listing of child disk objects for the updated
+		/* Get new listing of child objects for the updated
 		 * node, recurse no more than 2 levels
 		 */
 		EDVBrowserDirTreeDoGetChildrenList(
 		    browser, node, TRUE, TRUE
 		);
 
-		gtk_clist_thaw(GTK_CLIST(ctree));
+		gtk_clist_thaw(clist);
 	    }
 	}
 
+	/* Unmounted? */
+	if(!is_mounted)
+	{
+	    /* Get current location */
+	    gchar *cur_path = STRDUP(EDVBrowserCurrentLocation(browser));
+	    if(cur_path != NULL)
+	    {
+		/* Is the current location an object that is within
+		 * this unmounted device?
+		 */
+		if(strpfx(cur_path, mount_path))
+		{
+		    /* Select the unmounted device's node as needed */
+		    GtkCTreeNode *cur_node = EDVBrowserDirTreeFindNodeByPath(
+			browser, cur_path    
+		    );
+		    if((node != NULL) && (node != cur_node))
+		    {
+			gtk_clist_freeze(clist);
+			gtk_ctree_select(ctree, node);
+			gtk_clist_thaw(clist);
+		    }
+		}
+	    }
+	    g_free(cur_path);
+	}
+
 	g_free(mount_path);
 }
