@@ -14,49 +14,54 @@
 #include "browser.h"
 
 
+/* Getting */
 extern GtkCTreeNode *EDVBrowserDirTreeGetToplevel(edv_browser_struct *browser);
 
-extern GtkCTreeNode *EDVBrowserDirTreeInsertNode(
-	edv_browser_struct *browser,
-	GtkCTreeNode *parent, GtkCTreeNode *sibling,
-	edv_object_struct *obj
-);
-
-extern void EDVBrowserDirTreeCreateToplevels(edv_browser_struct *browser);
-
+/* Set Origin Path */
 extern void EDVBrowserDirTreeSetOriginPath(
 	edv_browser_struct *browser, const gchar *path
 );
 
-extern void EDVBrowserDirTreeDoRefresh(
+/* Get Listing */
+extern void EDVBrowserDirTreeCreateToplevels(edv_browser_struct *browser);
+extern void EDVBrowserDirTreeGetListing(
 	edv_browser_struct *browser, GtkCTreeNode *node,
 	gboolean update_progress
 );
-extern void EDVBrowserDirTreeDoExpand(
+extern void EDVBrowserDirTreeClear(edv_browser_struct *browser);
+
+/* Expanding */
+extern void EDVBrowserDirTreeExpand(
 	edv_browser_struct *browser, GtkCTreeNode *node,
 	gboolean update_progress
 );
 
-extern void EDVBrowserDirTreeDoSync(
+/* Realize Listing */
+extern void EDVBrowserDirTreeRealizeListing(
 	edv_browser_struct *browser, GtkCTreeNode *node
 );
 
-extern void EDVBrowserDirTreeDoSelectPath(
+/* Selecting */
+extern void EDVBrowserDirTreeSelectPath(
 	edv_browser_struct *browser, const gchar *path
 );
 
+/* Finding */
 extern GtkCTreeNode *EDVBrowserDirTreeFindNodeByPath(
 	edv_browser_struct *browser, const gchar *path
 );
 
+/* Opening */
 extern void EDVBrowserDirTreeDoOpenWithObject(
 	edv_browser_struct *browser, GtkCTreeNode *node
 );
 
+/* Renaming */
 extern void EDVBrowserDirTreeDoFPromptRename(
 	edv_browser_struct *browser, GtkCTreeNode *node
 );
 
+/* Object Callbacks */
 extern void EDVBrowserDirTreeObjectAddedNotify(
 	edv_browser_struct *browser, const gchar *path,
 	const struct stat *lstat_buf
@@ -70,8 +75,9 @@ extern void EDVBrowserDirTreeObjectRemovedNotify(
 	edv_browser_struct *browser, const gchar *path
 );
 
+/* Mount Callbacks */
 extern void EDVBrowserDirTreeMountNotify(
-	edv_browser_struct *browser, edv_device_struct *dev_ptr,
+	edv_browser_struct *browser, edv_device_struct *dev,
 	gboolean is_mounted
 );
 
