@@ -29,6 +29,7 @@
 #include "edvop.h"
 #include "edvcb.h"
 #include "edvutils.h"
+
 #include "edvutilsgtk.h"
 #include "config.h"
 
@@ -43,7 +44,7 @@ static void EDVBrowserDNDUpdateStatusBar(
 static void EDVBrowserDragDataReceivedNexus(
 	edv_core_struct *core_ptr, edv_browser_struct *browser,
 	GdkDragContext *dc, guint info, GtkSelectionData *selection_data,
-	edv_object_struct *object       /* Can be NULL */
+	edv_object_struct *obj			/* Can be NULL */
 );
 
 gint EDVBrowserLocBarIconCrossingCB(
@@ -111,7 +112,7 @@ static void EDVBrowserDNDUpdateStatusBar(
 )
 {
 	gchar *buf = NULL;
-	edv_status_bar_struct *sb = (browser != NULL) ?
+	edv_statusbar_struct *sb = (browser != NULL) ?
 	    browser->status_bar : NULL;
 	if(sb == NULL)
 	    return;
@@ -273,7 +274,7 @@ static void EDVBrowserDNDUpdateStatusBar(
 static void EDVBrowserDragDataReceivedNexus(
 	edv_core_struct *core_ptr, edv_browser_struct *browser,
 	GdkDragContext *dc, guint info, GtkSelectionData *selection_data,
-	edv_object_struct *object		/* Can be NULL */
+	edv_object_struct *obj			/* Can be NULL */
 )
 {
 	gint initial_confirmation_result, nurls;
@@ -295,8 +296,7 @@ static void EDVBrowserDragDataReceivedNexus(
 	/* Get copy of parent_path as the object's full path if the
 	 * object is not NULL
 	 */
-	parent_path = (object != NULL) ?
-	    STRDUP(object->full_path) : NULL;
+	parent_path = (obj != NULL) ? STRDUP(obj->full_path) : NULL;
 
 	/* If parent_path is not obtainable from the disk object then
 	 * use the image browser's current location as the parent_path
@@ -781,7 +781,7 @@ gint EDVBrowserLocBarIconCrossingCB(
 	GdkBitmap *mask;
 	GdkPixmap *pixmap;
 	GtkWidget *w;
-	edv_status_bar_struct *sb;
+	edv_statusbar_struct *sb;
 	edv_browser_struct *browser = EDV_BROWSER(data);
 	if((widget == NULL) || (crossing == NULL) || (browser == NULL))
 	    return(status);
@@ -846,7 +846,7 @@ void EDVBrowserDirTreeDNDSetIcon(
 )
 {
 	GtkCTree *ctree;
-	edv_object_struct *object;
+	edv_object_struct *obj;
 
 	if((browser == NULL) || (node == NULL))
 	    return;
@@ -855,11 +855,8 @@ void EDVBrowserDirTreeDNDSetIcon(
 	if(ctree == NULL)
 	    return;
 
-	/* Get object */
-	object = EDV_OBJECT(
-	    gtk_ctree_node_get_row_data(ctree, node)
-	);
-	if(object != NULL)
+	obj = EDV_OBJECT(gtk_ctree_node_get_row_data(ctree, node));
+	if(obj != NULL)
 	{
 	    GdkPixmap *pixmap = NULL;
 	    GdkBitmap *mask = NULL;
@@ -1013,7 +1010,7 @@ void EDVBrowserDirTreeDragDataReceivedCB(
 	GtkCList *clist;
 	GtkCTree *ctree;
 	GtkCTreeNode *node;
-	edv_object_struct *object;
+	edv_object_struct *obj;
 	edv_core_struct *core_ptr;
 	edv_browser_struct *browser = EDV_BROWSER(data);
 	if((dc == NULL) || (browser == NULL))
@@ -1037,8 +1034,8 @@ void EDVBrowserDirTreeDragDataReceivedCB(
 
 	EDVBrowserSyncData(browser);
 
-	/* Find node that this drop occured on, then get disk object
-	 * structure referenced by the node
+	/* Find node that this drop occured on, then get the object
+	 * referenced by the node
 	 */
 	node = EDVNodeGetByCoordinates(
 	    ctree,
@@ -1047,21 +1044,23 @@ void EDVBrowserDirTreeDragDataReceivedCB(
 		clist->column_title_area.height +
 		clist->column_title_area.y : 0)
 	);
-	object = EDV_OBJECT((node != NULL) ?
+	obj = EDV_OBJECT((node != NULL) ?
 	    gtk_ctree_node_get_row_data(ctree, node) : NULL
 	);
 
-	/* If unable to obtain disk object structure or node then that
-	 * implies we have nothing to drop on. Since dropping on the
-	 * directory ctree requires that the drop occurs on a node, we
-	 * need to return due to having no node to drop on
+	/* If unable to obtain object or node then that implies we have
+	 * nothing to drop on
+	 *
+	 * Since dropping on the directory tree requires that the drop
+	 * occurs on a node, we need to return due to having no node to
+	 * drop on
 	 */
-	if((object != NULL) ? STRISEMPTY(object->full_path) : TRUE)
+	if((obj != NULL) ? STRISEMPTY(obj->full_path) : TRUE)
 	    return;
 
 	/* Handle received drag data */
 	EDVBrowserDragDataReceivedNexus(
-	    core_ptr, browser, dc, info, selection_data, object
+	    core_ptr, browser, dc, info, selection_data, obj
 	);
 }
 
@@ -1080,7 +1079,7 @@ void EDVBrowserDirTreeDragDataDeleteCB(
 	GtkCList *clist;
 	GtkCTree *ctree;
 	GtkCListRow *row_ptr;
-	edv_object_struct *object;
+	edv_object_struct *obj;
 	struct stat lstat_buf;
 	edv_core_struct *core_ptr;
 	edv_browser_struct *browser = EDV_BROWSER(data);
@@ -1104,10 +1103,10 @@ void EDVBrowserDirTreeDragDataDeleteCB(
 	)
 	{
 	    row_ptr = (GtkCListRow *)glist->data;
-	    object = EDV_OBJECT(
+	    obj = EDV_OBJECT(
 		gtk_ctree_node_get_row_data(ctree, (GtkCTreeNode *)row_ptr)
 	    );
-	    if((object != NULL) ? !STRISEMPTY(object->full_path) : FALSE)
+	    if((obj != NULL) ? !STRISEMPTY(obj->full_path) : FALSE)
 	    {
 		i = strc;
 		strc = i + 1;
@@ -1119,7 +1118,7 @@ void EDVBrowserDirTreeDragDataDeleteCB(
 		    strc = 0;
 		    break;
 		}
-		strv[i] = STRDUP(object->full_path);
+		strv[i] = STRDUP(obj->full_path);
 	    }
 	}
 
@@ -1147,8 +1146,7 @@ void EDVBrowserContentsDNDSetIcon(
 )
 {
 	GtkCList *clist;
-	edv_object_struct *object;
-
+	edv_object_struct *obj;
 
 	if(browser == NULL)
 	    return;
@@ -1157,11 +1155,8 @@ void EDVBrowserContentsDNDSetIcon(
 	if(clist == NULL)
 	    return;
 
-	/* Get object */
-	object = EDV_OBJECT(
-	    gtk_clist_get_row_data(clist, row)
-	);
-	if(object != NULL)
+	obj = EDV_OBJECT(gtk_clist_get_row_data(clist, row));
+	if(obj != NULL)
 	{
 	    gint i;
 	    gchar *text = NULL;
@@ -1229,7 +1224,7 @@ void EDVBrowserContentsDragDataGetCB(
 	GtkWidget *w;
 	GtkCList *clist;
 	url_struct *url;
-	edv_object_struct *object;
+	edv_object_struct *obj;
 	edv_core_struct *core_ptr;
 	edv_browser_struct *browser = EDV_BROWSER(data);
 	if((dc == NULL) || (browser == NULL))
@@ -1251,14 +1246,12 @@ void EDVBrowserContentsDragDataGetCB(
 	)
 	{
 	    row = (gint)glist->data;
-	    object = EDV_OBJECT(
-		gtk_clist_get_row_data(clist, row)
-	    );
-	    if(object == NULL)
+	    obj = EDV_OBJECT(gtk_clist_get_row_data(clist, row));
+	    if(obj == NULL)
 		continue;
 
 	    url = URLNew();
-	    url->path = STRDUP(object->full_path);
+	    url->path = STRDUP(obj->full_path);
 	    url_list = g_list_append(url_list, url);
 	}
 
@@ -1314,7 +1307,7 @@ void EDVBrowserContentsDragDataReceivedCB(
 	gint row, column;
 	GtkWidget *w;
 	GtkCList *clist;
-	edv_object_struct *object;
+	edv_object_struct *obj;
 	edv_core_struct *core_ptr;
 	edv_browser_struct *browser = EDV_BROWSER(data);
 	if((dc == NULL) || (browser == NULL))
@@ -1337,8 +1330,8 @@ void EDVBrowserContentsDragDataReceivedCB(
 
 	EDVBrowserSyncData(browser);
 
-	/* Find row that this drop occured on, then get disk object
-	 * structure referenced by the row
+	/* Find row that this drop occured on, then get the object
+	 * referenced by the row
 	 */
 	/* Find row and column based on given coordinates */
 	if(!gtk_clist_get_selection_info(
@@ -1353,18 +1346,16 @@ void EDVBrowserContentsDragDataReceivedCB(
 	    row = -1;
 	    column = 0;
 	}
-	/* Get disk object structure from selected row */
+	/* Get object from selected row */
 	if((row >= 0) && (row < clist->rows))
-	    object = EDV_OBJECT(
-		gtk_clist_get_row_data(clist, row)
-	    );
+	    obj = EDV_OBJECT(gtk_clist_get_row_data(clist, row));
 	else
-	    object = NULL;
+	    obj = NULL;
 
 	/* Handle received drag data */
 	EDVBrowserDragDataReceivedNexus(
 	    core_ptr, browser, dc, info, selection_data,
-	    object		/* Can be NULL */
+	    obj				/* Can be NULL */
 	);
 }
 
@@ -1382,7 +1373,7 @@ void EDVBrowserContentsDragDataDeleteCB(
 	GList *glist;
 	GtkWidget *w;
 	GtkCList *clist;
-	edv_object_struct *object;
+	edv_object_struct *obj;
 	struct stat lstat_buf;
 	edv_browser_struct *browser = EDV_BROWSER(data);
 	if((dc == NULL) || (browser == NULL))
@@ -1404,10 +1395,8 @@ void EDVBrowserContentsDragDataDeleteCB(
 	)
 	{
 	    row = (gint)glist->data;
-	    object = EDV_OBJECT(
-		gtk_clist_get_row_data(clist, row)
-	    );
-	    if((object != NULL) ? !STRISEMPTY(object->full_path) : FALSE)
+	    obj = EDV_OBJECT(gtk_clist_get_row_data(clist, row));
+	    if((obj != NULL) ? !STRISEMPTY(obj->full_path) : FALSE)
 	    {
 		i = strc;
 		strc = i + 1;
@@ -1419,7 +1408,7 @@ void EDVBrowserContentsDragDataDeleteCB(
 		    strc = 0;
 		    break;
 		}
-		strv[i] = STRDUP(object->full_path);
+		strv[i] = STRDUP(obj->full_path);
 	    }
 	}
 
