@@ -2,6 +2,7 @@
 #include <string.h>
 #include <ctype.h>
 #include <errno.h>
+#include <sys/stat.h>
 #include <gtk/gtk.h>
 
 #include "../include/string.h"
@@ -11,9 +12,10 @@
 #include "cdialog.h"
 #include "fb.h"
 #include "progressdialog.h"
+#include "toolbar.h"
 
-#include "edvtypes.h"
 #include "cfg.h"
+#include "edvtypes.h"
 #include "edvobj.h"
 #include "edvconfirm.h"
 #include "edvrecbin.h"
@@ -21,6 +23,9 @@
 #include "edvrecbinfop.h"
 #include "edvdevices.h"
 #include "edvmount.h"
+#include "mountbar.h"
+#include "findbar.h"
+#include "statusbar.h"
 #include "fopdlg.h"
 #include "browser.h"
 #include "browsercb.h"
@@ -30,6 +35,7 @@
 #include "browsercontents.h"
 #include "endeavour.h"
 #include "edvfcreate.h"
+#include "edvfop.h"
 #include "edvcb.h"
 #include "edvhelp.h"
 #include "edvop.h"
@@ -39,6 +45,10 @@
 #include "config.h"
 
 
+static void EDVBrowserToolbarMenuPositionCB(
+	GtkMenu *menu, gint *x, gint *y, gpointer data
+);
+
 void EDVBrowserMenuItemCB(GtkWidget *widget, gpointer data);
 gint EDVBrowserMenuItemEnterCB(
 	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
@@ -58,22 +68,24 @@ void EDVBrowserOPLeaveCB(
 );
 
 void EDVBrowserMountBarMountCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 );
 void EDVBrowserMountBarEjectCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 );
 void EDVBrowserMountBarGoToCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 );
 
-gchar *EDVBrowserFindBarLocationCB(gpointer fb, gpointer data);
-void EDVBrowserFindBarStartCB(gpointer fb, gpointer data);
+const gchar *EDVBrowserFindBarLocationCB(
+	edv_findbar_struct *fb, gpointer data
+);
+void EDVBrowserFindBarStartCB(edv_findbar_struct *fb, gpointer data);
 void EDVBrowserFindBarEndCB(
-	gpointer fb, gint total_matches, gpointer data
+	edv_findbar_struct *fb, gint total_matches, gpointer data
 );
 void EDVBrowserFindBarMatchCB(
 	const gchar *path, const struct stat *lstat_buf,
@@ -81,12 +93,8 @@ void EDVBrowserFindBarMatchCB(
 	gpointer data
 );
 
-void EDVBrowserBarStatusMessageCB(
-	gpointer bar, const gchar *message, gpointer data
-);
-void EDVBrowserBarStatusProgressCB(
-	gpointer bar, gfloat progress, gpointer data
-);
+void EDVBrowserStatusMessageCB(const gchar *message, gpointer data);
+void EDVBrowserStatusProgressCB(gfloat progress, gpointer data);
 
 void EDVBrowserOPSyncDisks(edv_browser_struct *browser);
 void EDVBrowserOPRun(edv_browser_struct *browser);
@@ -99,7 +107,9 @@ static void EDVBrowserOPNewObjectNexus(
 	edv_browser_struct *browser,
 	edv_object_type type, GtkWidget *toplevel
 );
-void EDVBrowserOPNewObject(edv_browser_struct *browser);
+void EDVBrowserOPNewObject(
+	edv_browser_struct *browser, toolbar_item_struct *item
+);
 void EDVBrowserOPNewFile(edv_browser_struct *browser);
 void EDVBrowserOPNewDirectory(edv_browser_struct *browser);
 void EDVBrowserOPNewLink(edv_browser_struct *browser);
@@ -134,6 +144,7 @@ void EDVBrowserOPProperties(edv_browser_struct *browser);
 
 void EDVBrowserOPCopyPath(edv_browser_struct *browser);
 void EDVBrowserOPCopyURL(edv_browser_struct *browser);
+void EDVBrowserOPPaste(edv_browser_struct *browser);
 
 void EDVBrowserOPDownload(edv_browser_struct *browser);
 
@@ -155,6 +166,34 @@ void EDVBrowserOPDirectoryTreeOrigin(edv_browser_struct *browser);
 #define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
+/*
+ *	Tool Bar Item GtkMenu position callback.
+ */
+static void EDVBrowserToolbarMenuPositionCB( 
+	GtkMenu *menu, gint *x, gint *y, gpointer data  
+)
+{
+	gint width, height;
+	GdkWindow *window;
+	GtkWidget *w;
+	toolbar_item_struct *item = TOOLBAR_ITEM(data);
+	if((menu == NULL) || (x == NULL) || (y == NULL) || (item == NULL))
+	    return;
+
+	w = item->w;
+	if(w == NULL)
+	    return;
+
+	window = w->window;
+	if(window == NULL)
+	    return;
+
+	gdk_window_get_root_position(window, x, y);
+	gdk_window_get_size(window, &width, &height);
+	*y = (*y) + height;
+}
+
+
 /*
  *	Menu item activate callback.
  *
@@ -201,21 +240,23 @@ void EDVBrowserOPCB(
 )
 {
 	gint dev_num;
+	GtkWidget *toplevel;
 	cfg_item_struct *cfg_list;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_browser_struct *browser;
 	edv_core_struct *core_ptr;
 	edv_browser_opid_struct *opid = EDV_BROWSER_OPID(data);
 	if(opid == NULL)
 	    return;
 
-	browser = EDV_BROWSER(opid->browser);
-	if(browser == NULL)
+	browser = opid->browser;
+	if((browser == NULL) || (opid->flags & EDV_OPID_NO_OP))
 	    return;
 
 	if(browser->processing || (browser->freeze_count > 0))
 	    return;
 
+	toplevel = browser->toplevel;
 	core_ptr = EDV_CORE(browser->core_ptr);
 	if(core_ptr == NULL)
 	    return;
@@ -226,10 +267,8 @@ void EDVBrowserOPCB(
 
 	/* Get last selected device (if any) */
 	dev_num = browser->selected_dev_num;
-	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
-	else
-	    dev_ptr = NULL;
+	dev = ((dev_num >= 0) && (dev_num < core_ptr->total_devices)) ?
+	    dev = core_ptr->device[dev_num] : NULL;
 
 	/* Handle by operation id code */
 	switch(opid->op)
@@ -241,165 +280,125 @@ void EDVBrowserOPCB(
 	  case EDV_BROWSER_OP_CLOSE:
 	    EDVBrowserOPClose(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_EXIT:
 	    EDVBrowserOPExit(browser);
 	    break;
 
-
 	  case EDV_BROWSER_OP_SYNC_DISKS:
 	    EDVBrowserOPSyncDisks(browser);
 	    break;
-
+	  case EDV_BROWSER_OP_HISTORY:
+	    EDVMapHistoryListWin(core_ptr, toplevel);
+	    break;
+	  case EDV_BROWSER_OP_RUN:
+	    EDVBrowserOPRun(browser);
+	    break;
+	  case EDV_BROWSER_OP_RUN_TERMINAL:
+	    EDVRunTerminal(core_ptr, NULL, toplevel);
+	    break;
 	  case EDV_BROWSER_OP_WRITE_PROTECT:
 	    EDVBrowserOPWriteProtect(browser);
 	    break;
 
-	  case EDV_BROWSER_OP_RUN:
-	    EDVBrowserOPRun(browser);
-	    break;
-
-	  case EDV_BROWSER_OP_RUN_TERMINAL:
-	    EDVRunTerminal(core_ptr, NULL, browser->toplevel);
-	    break;
-
-
 	  case EDV_BROWSER_OP_NEW:
-	    EDVBrowserOPNewObject(browser);
+	    EDVBrowserOPNewObject(browser, item);
 	    break;
-
 	  case EDV_BROWSER_OP_NEW_FILE:
 	    EDVBrowserOPNewFile(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_NEW_DIRECTORY:
 	    EDVBrowserOPNewDirectory(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_NEW_LINK:
 	    EDVBrowserOPNewLink(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_NEW_FIFO:
 	    EDVBrowserOPNewFifo(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_NEW_DEVICE_BLOCK:
 	    EDVBrowserOPNewDeviceBlock(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_NEW_DEVICE_CHARACTER:
 	    EDVBrowserOPNewDeviceCharacter(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_NEW_SOCKET:
 	    EDVBrowserOPNewSocket(browser);
 	    break;
 
-
 	  case EDV_BROWSER_OP_OPEN:
 	    EDVBrowserOPOpen(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_OPEN_WITH:
 	    EDVBrowserOPOpenWith(browser);
 	    break;
 
-
-	  case EDV_BROWSER_OP_GOTO_PARENT:
-	    EDVBrowserOPGoToParent(browser);
+	  case EDV_BROWSER_OP_COPY_PATH:
+	    EDVBrowserOPCopyPath(browser);         
 	    break;
-
-	  case EDV_BROWSER_OP_GOTO_HOME:
-	    EDVBrowserOPGoToHome(browser);
+	  case EDV_BROWSER_OP_COPY_URL:
+	    EDVBrowserOPCopyURL(browser);
 	    break;
-
-	  case EDV_BROWSER_OP_EXPAND:
-	    EDVBrowserOPExpand(browser);
-	    break;
-
-	  case EDV_BROWSER_OP_MOUNT:
-	    EDVBrowserOPMount(browser);
-	    break;
-
-	  case EDV_BROWSER_OP_EJECT:
-	    EDVBrowserOPEject(browser);
+	  case EDV_BROWSER_OP_PASTE:
+	    EDVBrowserOPPaste(browser);
 	    break;
 
 	  case EDV_BROWSER_OP_MOVE:
 	    EDVBrowserOPMove(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_COPY:
 	    EDVBrowserOPCopy(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_LINK:
 	    EDVBrowserOPLink(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_RENAME:
 	    EDVBrowserOPRename(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_CHMOD:
 	    EDVBrowserOPChMod(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_CHOWN:
 	    EDVBrowserOPChown(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_DELETE:
 	    EDVBrowserOPDelete(browser);
 	    break;
+	  case EDV_BROWSER_OP_PROPERTIES:
+	    EDVBrowserOPProperties(browser);
+	    break;                
 
 	  case EDV_BROWSER_OP_SELECT_ALL:
 	    EDVBrowserOPSelectAll(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_UNSELECT_ALL:
 	    EDVBrowserOPUnselectAll(browser);
 	    break;
-
 	  case EDV_BROWSER_OP_INVERT_SELECTION:
 	    EDVBrowserOPInvertSelection(browser);
 	    break;
-
-	  case EDV_BROWSER_OP_PROPERTIES:
-	    EDVBrowserOPProperties(browser);
-	    break;
-
 	  case EDV_BROWSER_OP_FIND:
 	    EDVMapBrowserFindWin(core_ptr, browser);
 	    break;
 
-	  case EDV_BROWSER_OP_HISTORY:
-	    EDVMapHistoryListWin(core_ptr, browser->toplevel);
-	    break;
-
-	  case EDV_BROWSER_OP_COPY_PATH:
-	    EDVBrowserOPCopyPath(browser);
-	    break;
-
-	  case EDV_BROWSER_OP_COPY_URL:
-	    EDVBrowserOPCopyURL(browser);
-	    break;
-
-
-	  case EDV_BROWSER_OP_REFRESH:
-	    EDVBrowserOPRefresh(browser);
-	    break;
-
-	  case EDV_BROWSER_OP_REFRESH_ALL:
-	    EDVBrowserOPRefreshAll(browser);
-	    break;
-
-
 	  case EDV_BROWSER_OP_DOWNLOAD:
 	    EDVBrowserOPDownload(browser);
 	    break;
 
+	  case EDV_BROWSER_OP_REFRESH:
+	    EDVBrowserOPRefresh(browser);
+	    break;
+	  case EDV_BROWSER_OP_REFRESH_ALL:
+	    EDVBrowserOPRefreshAll(browser);
+	    break;
+	  case EDV_BROWSER_OP_GOTO_PARENT:
+	    EDVBrowserOPGoToParent(browser);
+	    break;                
+	  case EDV_BROWSER_OP_GOTO_HOME:
+	    EDVBrowserOPGoToHome(browser);
+	    break;
+	  case EDV_BROWSER_OP_EXPAND:
+	    EDVBrowserOPExpand(browser);
+	    break;
 
 	  case EDV_BROWSER_OP_SHOW_TOOL_BAR:
 	    if(core_ptr != NULL)
@@ -413,7 +412,6 @@ void EDVBrowserOPCB(
 		EDVReconfiguredEmit(core_ptr);
 	    }
 	    break;
-
 	  case EDV_BROWSER_OP_SHOW_LOCATION_BAR:
 	    if(core_ptr != NULL)
 	    {
@@ -426,7 +424,6 @@ void EDVBrowserOPCB(
 		EDVReconfiguredEmit(core_ptr);
 	    }
 	    break;
-
 	  case EDV_BROWSER_OP_SHOW_MOUNT_BAR:
 	    if(core_ptr != NULL)
 	    {
@@ -439,7 +436,6 @@ void EDVBrowserOPCB(
 		EDVReconfiguredEmit(core_ptr);
 	    }
 	    break;
-
 	  case EDV_BROWSER_OP_SHOW_FIND_BAR:
 	    if(core_ptr != NULL)
 	    {
@@ -452,7 +448,6 @@ void EDVBrowserOPCB(
 		EDVReconfiguredEmit(core_ptr);
 	    }
 	    break;
-
 	  case EDV_BROWSER_OP_SHOW_STATUS_BAR:
 	    if(core_ptr != NULL)
 	    {
@@ -465,7 +460,6 @@ void EDVBrowserOPCB(
 		EDVReconfiguredEmit(core_ptr);
 	    }
 	    break;
-
 	  case EDV_BROWSER_OP_SHOW_HIDDEN_OBJECTS:
 	    if(core_ptr != NULL)
 	    {
@@ -478,7 +472,6 @@ void EDVBrowserOPCB(
 		EDVBrowserOPRefresh(browser);
 	    }
 	    break;
-
 	  case EDV_BROWSER_OP_SHOW_NOACCESS_OBJECTS:
 	    if(core_ptr != NULL)
 	    {
@@ -491,87 +484,82 @@ void EDVBrowserOPCB(
 		EDVBrowserOPRefresh(browser);
 	    }
 	    break;
-
 	  case EDV_BROWSER_OP_DIRECTORY_TREE_ORIGIN:
 	    EDVBrowserOPDirectoryTreeOrigin(browser);
 	    break;
 
+	  case EDV_BROWSER_OP_MOUNT:
+	    EDVBrowserOPMount(browser);
+	    break;
+	  case EDV_BROWSER_OP_EJECT:
+	    EDVBrowserOPEject(browser);
+	    break;
+	  case EDV_BROWSER_OP_DEVICE_CHECK:
+	    EDVRunDeviceCheck(core_ptr, dev, toplevel);
+	    break;
+	  case EDV_BROWSER_OP_DEVICE_TOOLS:
+	    EDVRunDeviceTools(core_ptr, dev, toplevel);
+	    break;
+	  case EDV_BROWSER_OP_DEVICE_FORMAT:
+	    EDVRunDeviceFormat(core_ptr, dev, toplevel);
+	    break;
+
 	  case EDV_BROWSER_OP_MIME_TYPES:
-	    EDVMapMIMETypesListWin(core_ptr, browser->toplevel);
+	    EDVMapMIMETypesListWin(core_ptr, toplevel);
 	    break;
-
 	  case EDV_BROWSER_OP_DEVICES:
-	    EDVMapDevicesListWin(core_ptr, browser->toplevel);
+	    EDVMapDevicesListWin(core_ptr, toplevel);
 	    break;
 
-
 	  case EDV_BROWSER_OP_NEW_BROWSER:
 	    EDVNewBrowser(core_ptr);
 	    break;
-
 	  case EDV_BROWSER_OP_NEW_IMBR:
 	    EDVNewImbr(core_ptr);
 	    break;
-
 	  case EDV_BROWSER_OP_NEW_ARCHIVER:
 	    EDVNewArchiver(core_ptr);
 	    break;
-
 	  case EDV_BROWSER_OP_RECYCLE_BIN:
 	    EDVMapRecBin(core_ptr);
 	    break;
 
 	  case EDV_BROWSER_OP_OPTIONS:
-	    EDVMapOptionsWin(core_ptr, browser->toplevel);
+	    EDVMapOptionsWin(core_ptr, toplevel);
 	    break;
-
 	  case EDV_BROWSER_OP_CUSTOMIZE:
-	    EDVMapCustomizeWin(core_ptr, browser->toplevel);
+	    EDVMapCustomizeWin(core_ptr, toplevel);
 	    break;
 
-
-	  case EDV_BROWSER_OP_DEVICE_CHECK:
-	    EDVRunDeviceCheck(core_ptr, dev_ptr, browser->toplevel);
-	    break;
-
-	  case EDV_BROWSER_OP_DEVICE_TOOLS:
-	    EDVRunDeviceTools(core_ptr, dev_ptr, browser->toplevel);
-	    break;
-
-	  case EDV_BROWSER_OP_DEVICE_FORMAT:
-	    EDVRunDeviceFormat(core_ptr, dev_ptr, browser->toplevel);
-	    break;
-
-
-	  case EDV_BROWSER_OP_HELP_ABOUT:
-	    EDVAbout(core_ptr, browser->toplevel);
-	    break;
 	  case EDV_BROWSER_OP_HELP_CONTENTS:
-	    EDVHelp(core_ptr, "Contents", browser->toplevel);
+	    EDVHelp(core_ptr, "Contents", toplevel);
 	    break;
 	  case EDV_BROWSER_OP_HELP_FILE_BROWSER:
-	    EDVHelp(core_ptr, "File Browser", browser->toplevel);
+	    EDVHelp(core_ptr, "File Browser", toplevel);
 	    break;
 	  case EDV_BROWSER_OP_HELP_IMAGE_BROWSER:
-	    EDVHelp(core_ptr, "Image Browser", browser->toplevel);
+	    EDVHelp(core_ptr, "Image Browser", toplevel);
 	    break;
 	  case EDV_BROWSER_OP_HELP_ARCHIVER:
-	    EDVHelp(core_ptr, "Archiver", browser->toplevel);
+	    EDVHelp(core_ptr, "Archiver", toplevel);
 	    break;
 	  case EDV_BROWSER_OP_HELP_RECYCLE_BIN:
-	    EDVHelp(core_ptr, "Recycle Bin", browser->toplevel);
+	    EDVHelp(core_ptr, "Recycle Bin", toplevel);
 	    break;
 	  case EDV_BROWSER_OP_HELP_KEYS_LIST:
-	    EDVHelp(core_ptr, "Keys List", browser->toplevel);
+	    EDVHelp(core_ptr, "Keys List", toplevel);
 	    break;
 	  case EDV_BROWSER_OP_HELP_MIME_TYPES:
-	    EDVHelp(core_ptr, "MIME Types", browser->toplevel);
+	    EDVHelp(core_ptr, "MIME Types", toplevel);
 	    break;
 	  case EDV_BROWSER_OP_HELP_DEVICES:
-	    EDVHelp(core_ptr, "Devices", browser->toplevel);
+	    EDVHelp(core_ptr, "Devices", toplevel);
 	    break;
 	  case EDV_BROWSER_OP_HELP_COMMON_OPERATIONS:
-	    EDVHelp(core_ptr, "Common Operations", browser->toplevel);
+	    EDVHelp(core_ptr, "Common Operations", toplevel);
+	    break;
+	  case EDV_BROWSER_OP_HELP_ABOUT:
+	    EDVAbout(core_ptr, toplevel);
 	    break;
 	}
 
@@ -589,9 +577,7 @@ void EDVBrowserOPEnterCB(
 {
 	const gchar *tooltip;
 	edv_browser_opid_struct *opid = EDV_BROWSER_OPID(data);
-	edv_browser_struct *browser = EDV_BROWSER(
-	    (opid != NULL) ? opid->browser : NULL
-	);
+	edv_browser_struct *browser = (opid != NULL) ? opid->browser : NULL;
 	if(browser == NULL)
 	    return;
 
@@ -608,9 +594,7 @@ void EDVBrowserOPLeaveCB(
 )
 {
 	edv_browser_opid_struct *opid = EDV_BROWSER_OPID(data);
-	edv_browser_struct *browser = EDV_BROWSER(
-	    (opid != NULL) ? opid->browser : NULL 
-	);
+	edv_browser_struct *browser = (opid != NULL) ? opid->browser : NULL;
 	if(browser == NULL)
 	    return;
 
@@ -622,7 +606,7 @@ void EDVBrowserOPLeaveCB(
  *	Mount Bar mount callback.
  */
 void EDVBrowserMountBarMountCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 )
 {
@@ -631,7 +615,7 @@ void EDVBrowserMountBarMountCB(
 	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 	edv_browser_struct *browser = EDV_BROWSER(data);
-	if((browser == NULL) || (dev_ptr == NULL))
+	if((browser == NULL) || (dev == NULL))
 	    return;
 
 	if(browser->processing)
@@ -645,13 +629,13 @@ void EDVBrowserMountBarMountCB(
 	EDVBrowserSetBusy(browser, TRUE);
 
 	/* Record original mount state */
-	original_mount_state = dev_ptr->is_mounted;
+	original_mount_state = EDV_DEVICE_IS_MOUNTED(dev);
 
 	/* Unmount or mount? */
-	if(dev_ptr->is_mounted)
-	    status = EDVMountDoUnmount(core_ptr, dev_ptr, toplevel);
+	if(EDV_DEVICE_IS_MOUNTED(dev))
+	    status = EDVMountDoUnmount(core_ptr, dev, toplevel);
 	else
-	    status = EDVMountDoMount(core_ptr, dev_ptr, toplevel);
+	    status = EDVMountDoMount(core_ptr, dev, toplevel);
 
 	/* Update all device mount states and stats */
 	EDVDevicesListUpdateMountStates(
@@ -682,7 +666,7 @@ void EDVBrowserMountBarMountCB(
 	else
 	{
 	    /* Report mount signal to all of endeavour's resources */
-	    EDVObjectMountEmit(core_ptr, dev_num, dev_ptr, dev_ptr->is_mounted);
+	    EDVObjectMountEmit(core_ptr, dev_num, dev, EDV_DEVICE_IS_MOUNTED(dev));
 	}
 }
 
@@ -690,7 +674,7 @@ void EDVBrowserMountBarMountCB(
  *	Mount bar eject callback.
  */
 void EDVBrowserMountBarEjectCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 )
 {
@@ -699,7 +683,7 @@ void EDVBrowserMountBarEjectCB(
 	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 	edv_browser_struct *browser = EDV_BROWSER(data);
-	if((browser == NULL) || (dev_ptr == NULL))
+	if((browser == NULL) || (dev == NULL))
 	    return;
 
 	if(browser->processing)
@@ -713,13 +697,13 @@ void EDVBrowserMountBarEjectCB(
 	EDVBrowserSetBusy(browser, TRUE);
 
 	/* Record original mount state */
-	original_mount_state = dev_ptr->is_mounted;
+	original_mount_state = EDV_DEVICE_IS_MOUNTED(dev);
 
 	/* Need to unmount first? */
-	if(dev_ptr->is_mounted)
-	    status = EDVMountDoUnmount(core_ptr, dev_ptr, toplevel);
+	if(EDV_DEVICE_IS_MOUNTED(dev))
+	    status = EDVMountDoUnmount(core_ptr, dev, toplevel);
 	/* Now eject */
-	status = EDVMountDoEject(core_ptr, dev_ptr, toplevel);
+	status = EDVMountDoEject(core_ptr, dev, toplevel);
 
 	/* Update all device mount states and stats */
 	EDVDevicesListUpdateMountStates(
@@ -751,7 +735,7 @@ void EDVBrowserMountBarEjectCB(
 	    /* Report eject (unmount) signal to all of endeavour's
 	     * resources
 	     */
-	    EDVObjectMountEmit(core_ptr, dev_num, dev_ptr, dev_ptr->is_mounted);
+	    EDVObjectMountEmit(core_ptr, dev_num, dev, EDV_DEVICE_IS_MOUNTED(dev));
 	}
 }
 
@@ -759,35 +743,43 @@ void EDVBrowserMountBarEjectCB(
  *	Mount bar go to mount path callback.
  */
 extern void EDVBrowserMountBarGoToCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 )
 {
 	gchar *path;
+	GtkWidget *toplevel;
 	edv_browser_struct *browser = EDV_BROWSER(data);
-	if((browser == NULL) || (dev_ptr == NULL))
+	if((browser == NULL) || (dev == NULL))
 	    return;
 
 	if(browser->processing)
 	    return;
 
-	path = STRDUP(dev_ptr->mount_path);
+	path = STRDUP(dev->mount_path);
+	toplevel = browser->toplevel;
 
 	EDVBrowserSetBusy(browser, TRUE);
+	GUIBlockInput(toplevel, TRUE);
+
+	/* Change directory tree origin as needed */
+	if(!EDVBrowserIsPathFromDirTreeOrigin(browser, path))
+	    EDVBrowserDirTreeSetOriginPath(browser, path);
 
 	/* Go to mount path */
-	EDVBrowserDirTreeDoSelectPath(browser, path);
-
-	EDVBrowserSetBusy(browser, FALSE);
+	EDVBrowserDirTreeSelectPath(browser, path);
 
 	g_free(path);
+
+	GUIBlockInput(toplevel, FALSE);
+	EDVBrowserSetBusy(browser, FALSE);
 }
 
 
 /*
  *	Find Bar get current location callback.
  */
-gchar *EDVBrowserFindBarLocationCB(gpointer fb, gpointer data)
+const gchar *EDVBrowserFindBarLocationCB(edv_findbar_struct *fb, gpointer data)
 {
 	return(EDVBrowserCurrentLocation(
 	    EDV_BROWSER(data)
@@ -797,7 +789,7 @@ gchar *EDVBrowserFindBarLocationCB(gpointer fb, gpointer data)
 /*
  *	Find Bar start find callback.
  */
-void EDVBrowserFindBarStartCB(gpointer fb, gpointer data)
+void EDVBrowserFindBarStartCB(edv_findbar_struct *fb, gpointer data)
 {
 	GtkCList *clist;
 	edv_browser_struct *browser = EDV_BROWSER(data);
@@ -821,7 +813,7 @@ void EDVBrowserFindBarStartCB(gpointer fb, gpointer data)
  *	Find Bar end find callback.
  */
 void EDVBrowserFindBarEndCB(
-	gpointer fb, gint total_matches, gpointer data
+	edv_findbar_struct *fb, gint total_matches, gpointer data
 )
 {
 	edv_browser_struct *browser = EDV_BROWSER(data);
@@ -857,11 +849,9 @@ void EDVBrowserFindBarMatchCB(
 
 
 /*
- *	Status Bar set message callback.
+ *	Status Message callback.
  */
-void EDVBrowserBarStatusMessageCB(
-	gpointer bar, const gchar *message, gpointer data
-)
+void EDVBrowserStatusMessageCB(const gchar *message, gpointer data)
 {
 	edv_browser_struct *browser = EDV_BROWSER(data);
 	if(browser == NULL)
@@ -871,11 +861,9 @@ void EDVBrowserBarStatusMessageCB(
 }
 
 /*
- *	Status Bar set progress callback.
+ *	Status Progress callback.
  */
-void EDVBrowserBarStatusProgressCB(
-	gpointer bar, gfloat progress, gpointer data
-)
+void EDVBrowserStatusProgressCB(gfloat progress, gpointer data)
 {
 	edv_browser_struct *browser = EDV_BROWSER(data);
 	if(browser == NULL)
@@ -1213,7 +1201,9 @@ static void EDVBrowserOPNewObjectNexus(
 /*
  *	New Object.
  */
-void EDVBrowserOPNewObject(edv_browser_struct *browser)
+void EDVBrowserOPNewObject(
+	edv_browser_struct *browser, toolbar_item_struct *item
+)
 {
 	GtkWidget *w;
 
@@ -1224,7 +1214,8 @@ void EDVBrowserOPNewObject(edv_browser_struct *browser)
 	if(w != NULL)
 	    gtk_menu_popup(
 		GTK_MENU(w), NULL, NULL,
-		NULL, NULL,
+		(item != NULL) ? EDVBrowserToolbarMenuPositionCB : NULL,
+		item,
 		1, GDK_CURRENT_TIME
 	    );
 }
@@ -1326,22 +1317,14 @@ void EDVBrowserOPNewSocket(edv_browser_struct *browser)
  */
 void EDVBrowserOPOpen(edv_browser_struct *browser)
 {
-	gint row;
-	GtkCList *clist;
-
-
 	if(browser == NULL)
 	    return;
 
-	clist = (GtkCList *)browser->contents_clist;
-	if(clist == NULL)
-	    return;
-
-	row = EDVCListGetSelectedLast(clist, NULL);
-	if(row > -1)
-	    EDVBrowserContentsDoOpenObject(
-		browser, row, 0, 0
-	    );
+	EDVBrowserContentsOpen(
+	    browser,
+	    -1, -1,		/* Use selected object(s) */
+	    0
+	);
 }
 
 /*
@@ -1349,27 +1332,26 @@ void EDVBrowserOPOpen(edv_browser_struct *browser)
  */
 void EDVBrowserOPOpenWith(edv_browser_struct *browser)
 {
-	gint row;
 	GtkCList *clist;
 
 	if(browser == NULL)
 	    return;
 
+	/* Is there an object selected on the Contents List? */
 	clist = GTK_CLIST(browser->contents_clist);
-
-	row = EDVCListGetSelectedLast(clist, NULL);
-	if(row > -1)
+	if(clist->selection != NULL)
 	{
-	    EDVBrowserContentsDoOpenWithObject(
-		browser, row, 0
+	    EDVBrowserContentsOpenWith(
+		browser,
+		-1, -1		/* Use selected object(s) */
 	    );
 	}
 	else
 	{
-	    /* No row on the contents clist was selected, so do
-	     * open with for the directory ctree
+	    /* Since no object was selected on the Contents List then
+	     * check if an object is selected on the Directory Tree
 	     */
-	    GtkCTree *ctree = (GtkCTree *)browser->directory_ctree;
+	    GtkCTree *ctree = GTK_CTREE(browser->directory_ctree);
 	    GtkCTreeNode *node = EDVCTreeGetSelectedLast(
 		ctree, NULL
 	    );
@@ -1527,17 +1509,12 @@ environment variable HOME is set.\n",
 	EDVBrowserSetBusy(browser, TRUE);
 	GUIBlockInput(toplevel, TRUE);
 
-	/* If the home prefix is not the same as the current Directory
-	 * Tree Origin then the Directory Tree Origin needs to be
-	 * updated first
-	 */
-	if((browser->directory_ctree_origin_path != NULL) ?
-	    !strpfx(path, browser->directory_ctree_origin_path) : TRUE
-	)
+	/* Change the Directory Tree origin as needed */
+	if(!EDVBrowserIsPathFromDirTreeOrigin(browser, path))
 	    EDVBrowserDirTreeSetOriginPath(browser, path);
 
 	/* Go to the home directory */
-	EDVBrowserDirTreeDoSelectPath(browser, path);
+	EDVBrowserDirTreeSelectPath(browser, path);
 
 	g_free(path);
 
@@ -1585,7 +1562,7 @@ void EDVBrowserOPMount(edv_browser_struct *browser)
 	gboolean original_mount_state;
 	gint status, dev_num;
 	GtkWidget *toplevel;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_core_struct *core_ptr;
 
 	if(browser == NULL)
@@ -1599,22 +1576,22 @@ void EDVBrowserOPMount(edv_browser_struct *browser)
 	/* Get number of last selected device index (if any) */
 	dev_num = browser->selected_dev_num;
 	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
+	    dev = core_ptr->device[dev_num];
 	else
-	    dev_ptr = NULL;
-	if(dev_ptr == NULL)
+	    dev = NULL;
+	if(dev == NULL)
 	    return;
 
 	EDVBrowserSetBusy(browser, TRUE);
 
 	/* Record original mount state */
-	original_mount_state = dev_ptr->is_mounted;
+	original_mount_state = EDV_DEVICE_IS_MOUNTED(dev);
 
 	/* Unmount or mount? */
-	if(dev_ptr->is_mounted)
-	    status = EDVMountDoUnmount(core_ptr, dev_ptr, toplevel);
+	if(EDV_DEVICE_IS_MOUNTED(dev))
+	    status = EDVMountDoUnmount(core_ptr, dev, toplevel);
 	else
-	    status = EDVMountDoMount(core_ptr, dev_ptr, toplevel);
+	    status = EDVMountDoMount(core_ptr, dev, toplevel);
 
 	/* Update all device mount states and stats */
 	EDVDevicesListUpdateMountStates(
@@ -1645,7 +1622,7 @@ void EDVBrowserOPMount(edv_browser_struct *browser)
 	else
 	{
 	    /* Report un mount signal to all of endeavour's resources */
-	    EDVObjectMountEmit(core_ptr, dev_num, dev_ptr, dev_ptr->is_mounted);
+	    EDVObjectMountEmit(core_ptr, dev_num, dev, EDV_DEVICE_IS_MOUNTED(dev));
 	}
 }
 
@@ -1657,7 +1634,7 @@ void EDVBrowserOPEject(edv_browser_struct *browser)
 	gboolean original_mount_state;
 	gint status, dev_num;
 	GtkWidget *toplevel;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_core_struct *core_ptr;
 
 
@@ -1672,22 +1649,22 @@ void EDVBrowserOPEject(edv_browser_struct *browser)
 	/* Get number of last selected device index (if any) */
 	dev_num = browser->selected_dev_num;
 	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
+	    dev = core_ptr->device[dev_num];
 	else
-	    dev_ptr = NULL;
-	if(dev_ptr == NULL)
+	    dev = NULL;
+	if(dev == NULL)
 	    return;
 
 	EDVBrowserSetBusy(browser, TRUE);
 
 	/* Record original mount state */
-	original_mount_state = dev_ptr->is_mounted;
+	original_mount_state = EDV_DEVICE_IS_MOUNTED(dev);
 
 	/* Need to unmount first? */
-	if(dev_ptr->is_mounted)
-	    status = EDVMountDoUnmount(core_ptr, dev_ptr, toplevel);
+	if(EDV_DEVICE_IS_MOUNTED(dev))
+	    status = EDVMountDoUnmount(core_ptr, dev, toplevel);
 	/* So now eject */
-	status = EDVMountDoEject(core_ptr, dev_ptr, toplevel);
+	status = EDVMountDoEject(core_ptr, dev, toplevel);
 
 	/* Update all device mount states and stats */
 	EDVDevicesListUpdateMountStates(
@@ -1719,7 +1696,7 @@ void EDVBrowserOPEject(edv_browser_struct *browser)
 	    /* Report eject (unmount) signal to all of endeavour's
 	     * resources
 	     */
-	    EDVObjectMountEmit(core_ptr, dev_num, dev_ptr, dev_ptr->is_mounted);
+	    EDVObjectMountEmit(core_ptr, dev_num, dev, EDV_DEVICE_IS_MOUNTED(dev));
 	}
 }
 
@@ -1894,7 +1871,6 @@ void EDVBrowserOPCopy(edv_browser_struct *browser)
 	edv_core_struct *core_ptr;
 	edv_fopdlg_struct *d;
 
-
 	if(browser == NULL)
 	    return;
 
@@ -2166,6 +2142,7 @@ void EDVBrowserOPDelete(edv_browser_struct *browser)
 	guint *index;
 	gint total_indices;
 	const gchar *error_mesg;
+	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 
 	if(browser == NULL)
@@ -2177,6 +2154,7 @@ void EDVBrowserOPDelete(edv_browser_struct *browser)
  total_object_paths = 0;			\
 }
 
+	toplevel = browser->toplevel;
 	core_ptr = EDV_CORE(browser->core_ptr);
 	if(core_ptr == NULL)
 	{
@@ -2185,7 +2163,7 @@ void EDVBrowserOPDelete(edv_browser_struct *browser)
 	}
 
 	/* Check and warn if write protect is enabled */
-	if(EDVCheckWriteProtect(core_ptr, TRUE, browser->toplevel))
+	if(EDVCheckWriteProtect(core_ptr, TRUE, toplevel))
 	{
 	    DO_FREE_LOCALS
 	    return;
@@ -2273,7 +2251,7 @@ void EDVBrowserOPDelete(edv_browser_struct *browser)
 
 	/* Confirm delete */
 	status = EDVConfirmDelete(
-	    core_ptr, browser->toplevel,
+	    core_ptr, toplevel,
 	    (total_object_paths == 1) ? object_path[0] : NULL,
 	    total_object_paths
 	);
@@ -2335,7 +2313,7 @@ void EDVBrowserOPDelete(edv_browser_struct *browser)
 		gint n;
 		struct stat lstat_buf;
 
-		/* Report recycle object added for all non-zero indexes */
+		/* Report recycle object added for all non-zero indices */
 		for(n = 0; n < total_indices; n++)
 		{
 		    if(index[n] != 0)
@@ -2422,17 +2400,12 @@ void EDVBrowserOPSelectAll(edv_browser_struct *browser)
 	edv_core_struct *core_ptr;
 	GtkCList *clist;
 
-
 	if(browser == NULL)
 	    return;
 
-	core_ptr = EDV_CORE(browser->core_ptr);
-	if(core_ptr == NULL)
-	    return;
-
-	/* Get contents clist */
 	clist = (GtkCList *)browser->contents_clist;
-	if(clist == NULL)
+	core_ptr = EDV_CORE(browser->core_ptr);
+	if((clist == NULL) || (core_ptr == NULL))
 	    return;
 
 	EDVBrowserSetBusy(browser, TRUE);
@@ -2463,17 +2436,12 @@ void EDVBrowserOPUnselectAll(edv_browser_struct *browser)
 	edv_core_struct *core_ptr;
 	GtkCList *clist;
 
-
 	if(browser == NULL)
 	    return;
 
-	core_ptr = EDV_CORE(browser->core_ptr);
-	if(core_ptr == NULL)
-	    return;
-
-	/* Get contents clist */
 	clist = (GtkCList *)browser->contents_clist;
-	if(clist == NULL)
+	core_ptr = EDV_CORE(browser->core_ptr);
+	if((clist == NULL) || (core_ptr == NULL))
 	    return;
 
 	EDVBrowserSetBusy(browser, TRUE);
@@ -2506,7 +2474,6 @@ void EDVBrowserOPInvertSelection(edv_browser_struct *browser)
 	GList *glist, *selection;
 	gint row, total_rows;
 
-
 	if(browser == NULL)
 	    return;
 
@@ -2559,57 +2526,48 @@ void EDVBrowserOPProperties(edv_browser_struct *browser)
 {
 	edv_object_struct *obj = NULL;
 
-
 	if(browser == NULL)
 	    return;
 
 	EDVBrowserSyncData(browser);
 
-	/* Get object from last selected directory ctree item or
-	 * contents clist item
+	/* Get object from last selected directory tree item or
+	 * contents list item
 	 */
 	/* Contents clist was last selected? */
 	if(browser->contents_clist_selected_row > -1)
 	{
-	    gint row;
-	    GList *glist;
-	    GtkCList *clist = (GtkCList *)browser->contents_clist;
-
-	    glist = (clist != NULL) ? clist->selection : NULL;
-	    while(glist != NULL)
-	    {
-		row = (gint)glist->data;
+	    GtkCList *clist = GTK_CLIST(browser->contents_clist);
+	    GList *glist = (clist != NULL) ? clist->selection_end : NULL;
+	    if(glist != NULL)
 		obj = EDV_OBJECT(
-		    gtk_clist_get_row_data(clist, row)
+		    gtk_clist_get_row_data(clist, (gint)glist->data)
 		);
-		break;
-	    }
 	}
 	/* Directory ctree was last selected? */
 	else if(browser->directory_ctree_selected_node != NULL)
 	{
-	    GList *glist;
-	    GtkCList *clist = (GtkCList *)browser->directory_ctree;
-	    GtkCTree *ctree = (GtkCTree *)clist;
-	    GtkCTreeNode *node;
-
-	    glist = (clist != NULL) ? clist->selection : NULL;
-	    while(glist != NULL)
+	    GtkCTree *ctree = GTK_CTREE(browser->directory_ctree);
+	    GtkCList *clist = GTK_CLIST(ctree);
+	    GList *glist = (clist != NULL) ? clist->selection_end : NULL;
+	    if(glist != NULL)
 	    {
-		node = (GtkCTreeNode *)glist->data;
+		GtkCTreeNode *node = (GtkCTreeNode *)glist->data;
 		obj = EDV_OBJECT(
 		    gtk_ctree_node_get_row_data(ctree, node)
 		);
-		break;
 	    }
 	}
+	/* No objects selected? */
+	if(obj == NULL)
+	    return;
 
-	if(obj != NULL)
-	    EDVNewPropertiesDialog(
-		EDV_CORE(browser->core_ptr),
-		obj,
-		browser->toplevel
-	    );
+	/* Create a new Properties Dialog */
+	EDVNewPropertiesDialog(
+	    EDV_CORE(browser->core_ptr),
+	    obj,
+	    browser->toplevel
+	);
 }
 
 /*
@@ -2620,7 +2578,6 @@ void EDVBrowserOPCopyPath(edv_browser_struct *browser)
 	edv_object_struct **sel_object;
 	gint total_sel_objects;
 
-
 	if(browser == NULL)
 	    return;
 
@@ -2652,7 +2609,6 @@ void EDVBrowserOPCopyURL(edv_browser_struct *browser)
 	edv_object_struct **sel_object;
 	gint total_sel_objects;
 
-
 	if(browser == NULL)
 	    return;
 
@@ -2676,6 +2632,194 @@ void EDVBrowserOPCopyURL(edv_browser_struct *browser)
 	g_free(sel_object);
 }
 
+/*
+ *	Paste.
+ */
+void EDVBrowserOPPaste(edv_browser_struct *browser)
+{
+	gboolean yes_to_all = FALSE;
+	gint status = -1;
+	const gchar *protocol;
+	gchar *buf;
+	GList *glist, *url_list = NULL;
+	GtkWidget *toplevel;
+	url_struct *url;
+	edv_object_struct *obj = NULL;
+	edv_core_struct *core_ptr;
+
+	if(browser == NULL)
+	    return;
+
+	toplevel = browser->toplevel;
+	core_ptr = EDV_CORE(browser->core_ptr);
+	if(core_ptr == NULL)
+	    return;
+
+	/* Check and warn if write protect is enabled */
+	if(EDVCheckWriteProtect(core_ptr, TRUE, toplevel))
+	    return;
+
+	EDVBrowserSyncData(browser);
+
+	/* Get string from clipboard */
+	buf = GUIDDEGetString(
+	    toplevel,
+	    GDK_SELECTION_PRIMARY,
+	    GDK_CURRENT_TIME
+	);
+	if(buf == NULL)
+	    return;
+
+	/* Get last selected object from the contents list only
+	 * if it is a directory, otherwise get last selected object
+	 * from the directory tree
+	 */
+	/* Contents clist was last selected? */
+	if(browser->contents_clist_selected_row > -1)
+	{
+	    GtkCList *clist = GTK_CLIST(browser->contents_clist);
+	    GList *glist = (clist != NULL) ? clist->selection_end : NULL;
+	    if(glist != NULL)
+	    {
+		obj = EDV_OBJECT(
+		    gtk_clist_get_row_data(clist, (gint)glist->data)
+		);
+		if((obj != NULL) ?
+		    (obj->type != EDV_OBJECT_TYPE_DIRECTORY) : TRUE
+		)
+		    obj = NULL;
+	    }
+	}
+	/* Directory ctree was last selected? */
+	if(obj == NULL)
+	{
+	    GtkCTree *ctree = GTK_CTREE(browser->directory_ctree);
+	    GtkCList *clist = GTK_CLIST(ctree);
+	    GList *glist = (clist != NULL) ? clist->selection_end : NULL;
+	    if(glist != NULL)
+	    {
+		GtkCTreeNode *node = (GtkCTreeNode *)glist->data;
+		obj = EDV_OBJECT(
+		    gtk_ctree_node_get_row_data(ctree, node)
+		);
+		if((obj != NULL) ?
+		    (obj->type != EDV_OBJECT_TYPE_DIRECTORY) : TRUE
+		)
+		    obj = NULL;
+	    }
+	}
+	/* No objects selected? */
+	if(obj == NULL)
+	{
+	    g_free(buf);
+	    return;
+	}
+
+	/* Decode URL list string into a list of URLs */
+	url_list = URLDecodeString(buf);
+	g_free(buf);
+	buf = NULL;
+
+	/* Make confirmation */
+	if(url_list != NULL)
+	{
+	    url = URL(url_list->data);
+	    if(EDVConfirmCopy(
+		core_ptr, toplevel,
+		(url != NULL) ? url->path : NULL, g_list_length(url_list),
+		obj->full_path
+	    ) != CDIALOG_RESPONSE_YES)
+	    {
+		g_list_foreach(url_list, (GFunc)URLDelete, NULL);
+		g_list_free(url_list);
+		return;
+	    }
+	}
+
+	/* Paste each URL */
+	for(glist = url_list; glist != NULL; glist = g_list_next(glist))
+	{
+	    url = URL(glist->data);
+	    if(url == NULL)
+		continue;
+
+	    protocol = url->protocol;
+	    if(STRISEMPTY(protocol))
+		protocol = "file";
+
+	    /* File? */
+	    if(!g_strcasecmp(protocol, "file"))
+	    {
+		const gchar *error_mesg;
+		gchar *new_path = NULL;
+		struct stat lstat_buf;
+		status = EDVFOPCopy(
+		    core_ptr,
+		    url->path, obj->full_path,
+		    &new_path, toplevel,
+		    TRUE, TRUE, &yes_to_all
+		);
+		error_mesg = EDVFOPGetError();
+		if(!STRISEMPTY(error_mesg) && (status != -4))
+		{
+		    EDVPlaySoundError(core_ptr);
+		    EDVMessageError(
+			"Operation Error",
+			error_mesg,
+			NULL,
+			toplevel
+		    );
+		}
+
+		/* Check if new_path is valid and that no error
+		 * occured
+		 *
+		 * This implies the operation was successful
+		 * and that we need to emit an object added signal
+		 */
+		if((!STRISEMPTY(new_path) && !status) ?
+		    !lstat(new_path, &lstat_buf) : FALSE
+		)
+		    EDVObjectAddedEmit(
+			core_ptr, new_path, &lstat_buf
+		    );
+
+		g_free(new_path);
+
+		/* Skip handling of the rest of the objects on error
+		 * (status != 0) and that the error was not a user
+		 * response of no (status != -5)
+		 */
+		if(status && (status != -5))
+		    break;
+	    }
+	    /* Download? */
+	    else if(!g_strcasecmp(protocol, "http") ||
+		    !g_strcasecmp(protocol, "ftp") ||
+		    !g_strcasecmp(protocol, "https")
+	    )
+	    {
+		EDVInternetDownloadObject(
+		    core_ptr, url, obj->full_path, toplevel
+		);
+	    }
+	}
+
+	/* Unmap progress dialog, it may have been mapped if any
+	 * operations occured in the above loop
+	 */
+	ProgressDialogBreakQuery(TRUE);
+	ProgressDialogSetTransientFor(NULL);
+
+	/* Play completed sound on success */
+	if(status == 0)
+	    EDVPlaySoundCompleted(core_ptr);
+
+	g_list_foreach(url_list, (GFunc)URLDelete, NULL);
+	g_list_free(url_list);
+}
+
+
 /*
  *	Download.
  */
@@ -2739,14 +2883,10 @@ void EDVBrowserOPRefresh(edv_browser_struct *browser)
 	    gfloat last_x = GTK_ADJUSTMENT_GET_VALUE(clist->hadjustment),
 		   last_y = GTK_ADJUSTMENT_GET_VALUE(clist->vadjustment);
 
-	    gtk_clist_freeze(clist);
+	    /* Get listing */
+	    EDVBrowserDirTreeGetListing(browser, node, TRUE);
 
-	    /* Update list items */
-	    EDVBrowserDirTreeDoRefresh(browser, node, TRUE);
-
-	    /* Reget selected node, since the refresh procedure might
-	     * have deleted the node
-	     */
+	    /* Reget selected node */
 	    node = EDVCTreeGetSelectedLast(ctree, &row_ptr);
 	    if(node != NULL)
 	    {
@@ -2754,8 +2894,6 @@ void EDVBrowserOPRefresh(edv_browser_struct *browser)
 		    gtk_ctree_expand(ctree, node);
 	    }
 
-	    gtk_clist_thaw(clist);
-
 	    /* Scroll back to original position */
 	    EDVScrollCListToPosition(clist, last_x, last_y);
 	}
@@ -2768,17 +2906,13 @@ void EDVBrowserOPRefresh(edv_browser_struct *browser)
 	    gfloat last_x = GTK_ADJUSTMENT_GET_VALUE(clist->hadjustment),
 		   last_y = GTK_ADJUSTMENT_GET_VALUE(clist->vadjustment);
 
-	    gtk_clist_freeze(clist);
-
-	    /* Update list items */
-	    EDVBrowserContentsDoUpdate(
+	    /* Reget listing */
+	    EDVBrowserContentsGetListing(
 		browser,
 		cur_path,
 		EDV_GET_B(EDV_CFG_PARM_LISTS_ANIMATE_UPDATES)
 	    );
 
-	    gtk_clist_thaw(clist);
-
 	    /* Scroll back to original position */
 	    EDVScrollCListToPosition(clist, last_x, last_y);
 	}
@@ -2911,7 +3045,11 @@ void EDVBrowserOPDirectoryTreeOrigin(edv_browser_struct *browser)
 	    g_free(s);
 	    return;
 	}
+#ifdef S_ISDIR
 	if(!S_ISDIR(stat_buf.st_mode))
+#else
+	if(TRUE)
+#endif
 	{
 	    gchar *buf = g_strdup_printf(
 "Object is not a directory:\n\
