@@ -5,10 +5,13 @@
 #ifndef BROWSEROPCB_H
 #define BROWSEROPCB_H
 
-
 #include <gtk/gtk.h>
+#include "toolbar.h"
 #include "edvtypes.h"
 #include "edvdevices.h"
+#include "mountbar.h"
+#include "findbar.h"
+#include "statusbar.h"
 #include "browser.h"
 
 
@@ -31,22 +34,24 @@ extern void EDVBrowserOPLeaveCB(
 );
 
 extern void EDVBrowserMountBarMountCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 );
 extern void EDVBrowserMountBarEjectCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 );
 extern void EDVBrowserMountBarGoToCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 );
 
-extern gchar *EDVBrowserFindBarLocationCB(gpointer fb, gpointer data);
-extern void EDVBrowserFindBarStartCB(gpointer fb, gpointer data);
+extern const gchar *EDVBrowserFindBarLocationCB(
+	edv_findbar_struct *fb, gpointer data
+);
+extern void EDVBrowserFindBarStartCB(edv_findbar_struct *fb, gpointer data);
 extern void EDVBrowserFindBarEndCB(
-	gpointer fb, gint total_matches, gpointer data
+	edv_findbar_struct *fb, gint total_matches, gpointer data
 );
 extern void EDVBrowserFindBarMatchCB(
 	const gchar *path, const struct stat *lstat_buf,
@@ -54,12 +59,8 @@ extern void EDVBrowserFindBarMatchCB(
 	gpointer data
 );
 
-extern void EDVBrowserBarStatusMessageCB(
-	gpointer mb, const gchar *message, gpointer data
-);
-extern void EDVBrowserBarStatusProgressCB(
-	gpointer bar, gfloat progress, gpointer data
-);
+extern void EDVBrowserStatusMessageCB(const gchar *message, gpointer data);
+extern void EDVBrowserStatusProgressCB(gfloat progress, gpointer data);
 
 extern void EDVBrowserOPSyncDisks(edv_browser_struct *browser);
 extern void EDVBrowserOPWriteProtect(edv_browser_struct *browser);
@@ -67,7 +68,9 @@ extern void EDVBrowserOPWriteProtect(edv_browser_struct *browser);
 extern void EDVBrowserOPClose(edv_browser_struct *browser);
 extern void EDVBrowserOPExit(edv_browser_struct *browser);
 
-extern void EDVBrowserOPNewObject(edv_browser_struct *browser);
+extern void EDVBrowserOPNewObject(
+	edv_browser_struct *browser, toolbar_item_struct *item
+);
 extern void EDVBrowserOPNewFile(edv_browser_struct *browser);
 extern void EDVBrowserOPNewDirectory(edv_browser_struct *browser);
 extern void EDVBrowserOPNewLink(edv_browser_struct *browser);
@@ -94,6 +97,7 @@ extern void EDVBrowserOPProperties(edv_browser_struct *browser);
 
 extern void EDVBrowserOPCopyPath(edv_browser_struct *browser);
 extern void EDVBrowserOPCopyURL(edv_browser_struct *browser);        
+extern void EDVBrowserOPPaste(edv_browser_struct *browser);
 
 extern void EDVBrowserOPDownload(edv_browser_struct *browser);
 
