@@ -19,6 +19,7 @@
 /* *incomplete* #define PROG_LANGUAGE_DUTCH	6 */
 /* *incomplete* #define PROG_LANGUAGE_NORWEGIAN	7 */
 /* *incomplete* #define PROG_LANGUAGE_PORTUGUESE	8 */
+/* #define PROG_LANGUAGE_POLISH		9 */
 
 
 /*
@@ -26,32 +27,32 @@
  */
 #define PROG_NAME		"Endeavour"
 #define PROG_NAME_FULL		"Endeavour Mark II"
-#define PROG_VERSION		"2.4.6"
+#define PROG_VERSION		"2.5.2"
 
 #define PROG_VERSION_MAJOR	2
-#define PROG_VERSION_MINOR	4
-#define PROG_VERSION_RELEASE	6
+#define PROG_VERSION_MINOR	5
+#define PROG_VERSION_RELEASE	2
 
 /*
  *      Copyright message:
  */
 #if defined(PROG_LANGUAGE_SPANISH)
 #define PROG_COPYRIGHT	"\
-El derecho de autor (C) 1997-2004 WolfPack Entertainment.\n\
+El derecho de autor (C) 1997-2005 WolfPack Entertainment.\n\
 Este programa es protegido por leyes internacionales de derecho de autor\n\
 y tratados, la distribucin y/o la modificacin de este software en la\n\
 infraccin de la Licencia del Pblico de GNU se prohiben estrictamente.\n\
 Violators ser procesado a la extensin ms repleta de la ley.\n"
 #elif defined(PROG_LANGUAGE_FRENCH)
 #define PROG_COPYRIGHT  "\
-Dposer (C) 1997-2004 WolfPack Entertainment.\n\
+Dposer (C) 1997-2005 WolfPack Entertainment.\n\
 Ce programme est protg par international dpose lois et traits, \n\
 distribution et/ou de ce logiciel dans violation du GNU Public Permis\n\
 strictement est interdit. Violators sera poursuivi  l'tendue plus pleine\n\
 de la loi.\n"
 #elif defined(PROG_LANGUAGE_GERMAN)
 #define PROG_COPYRIGHT  "\
-Urheberrecht (C) 1997-2004 WolfPack Entertainment.\n\
+Urheberrecht (C) 1997-2005 WolfPack Entertainment.\n\
 Dieses Programm wird von internationalem Urheberrecht Gesetzen und\n\
 Vertrgen, Austeilung bzw. nderung dieser Software in bertretung\n\
 DER GNU ffentlichkeit Erlaubnis streng verboten wird geschtzt.\n\
@@ -59,35 +60,35 @@ Verletzer werden zum vollsten Umfang des Gesetzes strafrechtlich\n\
 verfolgt werden.\n"
 #elif defined(PROG_LANGUAGE_ITALIAN)
 #define PROG_COPYRIGHT  "\
-Il copyright (C) 1997-2004 WolfPack Entertainment.\n\
+Il copyright (C) 1997-2005 WolfPack Entertainment.\n\
 Questo programma  protetto dalle leggi di copyright internazionali e\n\
 dai trattati, la distribuzione e/o la modifica di questo software nella\n\
 violazione dello GNU la Licenza Pubblica  strettamente proibita. Il\n\
 Violators sar perseguito all'estensione la pi piena della legge.\n"
 #elif defined(PROG_LANGUAGE_DUTCH)
 #define PROG_COPYRIGHT  "\
-Auteursrecht (C) 1997-2004 WolfPack Entertainment.\n\
+Auteursrecht (C) 1997-2005 WolfPack Entertainment.\n\
 Deze programma wordt door internationale auteursrecht wetten en\n\
 verdragen, verdeling en/of wijziging van deze software in overtreding\n\
 van de GNU Publiek Vergunning strikt verboden wordt beschermd.\n\
 Overtreders zullen te de volste omvang van de wet geprocedeerd worden.\n"
 #elif defined(PROG_LANGUAGE_PORTUGUESE)
 #define PROG_COPYRIGHT  "\
-Os direitos autorais (C) 1997-2004 WolfPack Entertainment.\n\
+Os direitos autorais (C) 1997-2005 WolfPack Entertainment.\n\
 Este programa  protegido por direitos internacionais leis autorais e\n\
 tratados, modificao de e/ou de distribuio deste software em infrao\n\
 do GNU Licena Pblica precisamente  proibida. O Violators ser\n\
 processado  plena extenso da lei.\n"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 #define PROG_COPYRIGHT  "\
-Copyright (C) 1997-2004 WolfPack Entertainment.\n\
+Copyright (C) 1997-2005 WolfPack Entertainment.\n\
 Dette programet beskytter av internasjonal copyrightlover og traktater,\n\
 distribusjon og/eller modifikasjon av denne programvaren i overtredelse\n\
 av GNU Public License er streng forbudt. Violators tiltalt til den\n\
 fulleste omfang av loven.\n"
 #else
 #define PROG_COPYRIGHT  "\
-Copyright (C) 1997-2004 WolfPack Entertainment.\n\
+Copyright (C) 1997-2005 WolfPack Entertainment.\n\
 This program is protected by international copyright laws and treaties,\n\
 distribution and/or modification of this software in violation of the\n\
 GNU Public License is strictly prohibited. Violators will be prosecuted\n\
@@ -135,6 +136,7 @@ to the fullest extent of the law.\n"
 #define ENV_VAR_NAME_HELPBROWSER		"HELPBROWSER"
 #define ENV_VAR_NAME_HOME			"HOME"
 #define ENV_VAR_NAME_PATH			"PATH"
+#define ENV_VAR_NAME_TMPDIR			"TMPDIR"
 #define ENV_VAR_NAME_USER			"USER"
 #define ENV_VAR_NAME_USERNAME			"USERNAME"
 
@@ -243,7 +245,9 @@ to the fullest extent of the law.\n"
 
 
 /*
- *	Default local data directory (home dir prefixed):
+ *	Default local data directory:
+ *
+ *	The home directory will be automatically prefixed.
  */
 #define EDV_DEF_LOCAL_DATA_DIR		".endeavour2"
 
@@ -257,6 +261,12 @@ to the fullest extent of the law.\n"
  */
 #define EDV_DEF_GLOBAL_ARCHDEP_DATA_DIR	PREFIX "/lib/endeavour2"
 
+/*
+ *	Default global configuration directory:
+ */
+#define EDV_DEF_GLOBAL_CONFIG_DIR	"/etc/endeavour2"
+
+
 /*
  *	Default configuration files (local data dir prefixed):
  */
@@ -303,7 +313,7 @@ to the fullest extent of the law.\n"
 /*
  *	Default device icon files:
  *
- *	These paths are initially set to all new device entries
+ *	These paths are initially set to all new device entries.
  */
 #define EDV_DEF_DEVICE_ICON_SMALL_FILE	EDV_DEF_GLOBAL_DATA_DIR	\
  "/icons/icon_drive_fixed_20x20.xpm"
@@ -315,11 +325,22 @@ to the fullest extent of the law.\n"
 /*
  *	Default programs:
  *
- *	Arguments allowed
+ *	Arguments and token strings allowed (see help pages for
+ *	supported token strings).
  */
-#define EDV_DEF_VIEWER_PROG		"/usr/bin/iv"
-#define EDV_DEF_TERMINAL_PROG		"/usr/X11R6/bin/xterm"
-#define EDV_DEF_RUN_IN_TERMINAL_CMD	"/usr/X11R6/bin/xterm -e"
+#if defined(DEBIAN)
+# define EDV_DEF_VIEWER_CMD		"see"
+#else
+# define EDV_DEF_VIEWER_CMD		"/usr/bin/iv -q=2 -i --auto_hide_iv_nonimage \"%paths\""
+#endif
+
+#if defined(DEBIAN)
+# define EDV_DEF_TERMINAL_PROG		"x-terminal-emulator"
+# define EDV_DEF_RUN_IN_TERMINAL_CMD	"x-terminal-emulator -e"
+#else
+# define EDV_DEF_TERMINAL_PROG		"/usr/X11R6/bin/xterm"
+# define EDV_DEF_RUN_IN_TERMINAL_CMD	"/usr/X11R6/bin/xterm -e"
+#endif
 
 #define EDV_DEF_FORMAT_FRONT_PROG	EDV_DEF_GLOBAL_ARCHDEP_DATA_DIR \
  "/bin/format.front"
@@ -404,6 +425,8 @@ to the fullest extent of the law.\n"
 #define DEF_IMBR_THUMB_HEIGHT		90
 #define DEF_IMBR_THUMB_BORDER		2
 
+#define DEF_PRESENTATION_FONT		"-adobe-helvetica-medium-r-normal-*-12-*-*-*-p-*-iso8859-1"
+
 
 /*
  *	Default Archiver gGometry:
@@ -574,6 +597,15 @@ to the fullest extent of the law.\n"
 #define EDV_GDKCOLOR_DANGLING_LINK_FG_SELECTED	EDV_GDKCOLOR_LIGHT_GREY
 #define EDV_GDKCOLOR_DANGLING_LINK_FG_INSENSITIVE	EDV_GDKCOLOR_LIGHT_GREY
 
+#define EDV_GDKCOLOR_RECURSIVE_LINK_FG	EDV_GDKCOLOR_ORANGE
+#define EDV_GDKCOLOR_RECURSIVE_LINK_FG_SELECTED	EDV_GDKCOLOR_ORANGE
+#define EDV_GDKCOLOR_RECURSIVE_LINK_FG_INSENSITIVE	\
+{	(gulong)0,				\
+	(gushort)(1.0f * (gushort)-1),		\
+	(gushort)(0.75f * (gushort)-1),		\
+	(gushort)(0.25f * (gushort)-1)		\
+}
+
 #define EDV_GDKCOLOR_HIDDEN_OBJECT_FG	EDV_GDKCOLOR_LIGHT_GREY
 #define EDV_GDKCOLOR_HIDDEN_OBJECT_FG_SELECTED	EDV_GDKCOLOR_WHITE
 #define EDV_GDKCOLOR_HIDDEN_OBJECT_FG_INSENSITIVE	EDV_GDKCOLOR_LIGHT_GREY
