@@ -261,6 +261,7 @@ static void DeskIconDraw(deskicon_struct *di)
 	s = di->label_str;
 	if(w != NULL)
 	{
+	    const gint	border_minor = 2;
 	    GdkWindow *window = w->window;
 	    GtkStyle *style = gtk_widget_get_style(w);
 	    gint        state = GTK_WIDGET_STATE(w),
@@ -296,8 +297,8 @@ static void DeskIconDraw(deskicon_struct *di)
 		    gdk_gc_set_foreground(gc, &style->text[state]);
 
 		    /* Calculate starting position */
-		    x = 0;
-		    y = 2;
+		    x = border_minor;
+		    y = border_minor;
 
 		    /* Iterate through each line */
 		    while(*line != '\0')
@@ -321,15 +322,14 @@ static void DeskIconDraw(deskicon_struct *di)
 			    /* Draw this line */
 			    gdk_draw_text(
 				window, font, gc,
-				x + b.lbearing,
+				x - b.lbearing,
 				y + font->ascent,
 				line, line_len
 			    );
 			}
 
 			/* Increment y position */
-			y += font->ascent + font->descent +
-			    ((line_end != NULL) ? 2 : 0);
+			y += font->ascent + font->descent;
 
 			/* Seek to next line */
 			line += line_len;
@@ -958,6 +958,7 @@ static gboolean DeskIconLoadLabel(
 	/* Update label */
 	if(!STRISEMPTY(label))
 	{
+	    const gint	border_minor = 2;
 	    gint	longest_line_width = 0,
 			height_lines = 0;
 
@@ -1000,8 +1001,7 @@ static gboolean DeskIconLoadLabel(
 		    }
 
 		    /* Increment height for this line */
-		    height_lines += font->ascent + font->descent +
-			((s2 != NULL) ? 2 : 0);
+		    height_lines += font->ascent + font->descent;
 
 		    /* Seek to next line */
 		    s += len;
@@ -1025,8 +1025,8 @@ static gboolean DeskIconLoadLabel(
 	    }
 
 	    /* Calculate resulting label size (with border) */
-	    di->label_width = width = longest_line_width + (2 * 2);
-	    di->label_height = height = height_lines + (2 * 2);
+	    di->label_width = width = longest_line_width + (2 * border_minor);
+	    di->label_height = height = height_lines + (2 * border_minor);
 
 	    /* Set new label size */
 	    if((width > 0) && (height > 0))
