@@ -676,12 +676,11 @@ static void EDVDevicesEditWinApplyCB(
 	GtkWidget *widget, gpointer data
 )
 {
-	GtkWidget *w;
 	GtkEntry *entry;
 	GtkCombo *combo;
 	edv_core_struct *core_ptr;
 	gint dev_num;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_device_listwin_struct *lw;
 	edv_device_icon_picker_struct *ei;
 	edv_device_editwin_struct *ew = EDV_DEVICE_EDITWIN(data);
@@ -697,9 +696,9 @@ static void EDVDevicesEditWinApplyCB(
 	 * list
 	 */
 	dev_num = ew->dev_num;
-	dev_ptr = ((dev_num >= 0) && (dev_num < core_ptr->total_devices)) ?
+	dev = ((dev_num >= 0) && (dev_num < core_ptr->total_devices)) ?
 	    core_ptr->device[dev_num] : NULL;
-	if(dev_ptr == NULL)
+	if(dev == NULL)
 	    return;
 
 
@@ -709,24 +708,24 @@ static void EDVDevicesEditWinApplyCB(
 	entry = (GtkEntry *)ew->name_entry;
 	if(entry != NULL)
 	{
-	    g_free(dev_ptr->name);
-	    dev_ptr->name = STRDUP(gtk_entry_get_text(entry));
+	    g_free(dev->name);
+	    dev->name = STRDUP(gtk_entry_get_text(entry));
 	}
 
 	/* Device path */
 	entry = (GtkEntry *)ew->device_path_entry;
 	if(entry != NULL)
 	{
-	    g_free(dev_ptr->device_path);
-	    dev_ptr->device_path = STRDUP(gtk_entry_get_text(entry));
+	    g_free(dev->device_path);
+	    dev->device_path = STRDUP(gtk_entry_get_text(entry));
 	}
 
 	/* Mount path */
 	entry = (GtkEntry *)ew->mount_path_entry;
 	if(entry != NULL)
 	{
-	    g_free(dev_ptr->mount_path);
-	    dev_ptr->mount_path = STRDUP(gtk_entry_get_text(entry));
+	    g_free(dev->mount_path);
+	    dev->mount_path = STRDUP(gtk_entry_get_text(entry));
 	}
 
 	/* File system type */
@@ -734,7 +733,7 @@ static void EDVDevicesEditWinApplyCB(
 	if(combo != NULL)
 	{
 	    entry = GTK_ENTRY(combo->entry);
-	    dev_ptr->fs_type = EDVDeviceGetFSFromString(
+	    dev->fs_type = EDVDeviceGetFSTypeFromName(
 		gtk_entry_get_text(entry)
 	    );
 	}
@@ -743,64 +742,61 @@ static void EDVDevicesEditWinApplyCB(
 	entry = (GtkEntry *)ew->command_mount_entry;
 	if(entry != NULL)
 	{
-	    g_free(dev_ptr->command_mount);
-	    dev_ptr->command_mount = STRDUP(gtk_entry_get_text(entry));
+	    g_free(dev->command_mount);
+	    dev->command_mount = STRDUP(gtk_entry_get_text(entry));
 	}
 	/* Unmount command */
 	entry = (GtkEntry *)ew->command_unmount_entry;
 	if(entry != NULL)
 	{
-	    g_free(dev_ptr->command_unmount);
-	    dev_ptr->command_unmount = STRDUP(gtk_entry_get_text(entry));
+	    g_free(dev->command_unmount);
+	    dev->command_unmount = STRDUP(gtk_entry_get_text(entry));
 	}
 	/* Eject command */
 	entry = (GtkEntry *)ew->command_eject_entry;
 	if(entry != NULL)
 	{
-	    g_free(dev_ptr->command_eject);
-	    dev_ptr->command_eject = STRDUP(gtk_entry_get_text(entry));
+	    g_free(dev->command_eject);
+	    dev->command_eject = STRDUP(gtk_entry_get_text(entry));
 	}
 
 	/* Check command */
 	entry = (GtkEntry *)ew->command_check_entry;
 	if(entry != NULL)
 	{
-	    g_free(dev_ptr->command_check);
-	    dev_ptr->command_check = STRDUP(gtk_entry_get_text(entry));
+	    g_free(dev->command_check);
+	    dev->command_check = STRDUP(gtk_entry_get_text(entry));
 	}
 	/* Tools command */
 	entry = (GtkEntry *)ew->command_tools_entry;
 	if(entry != NULL)
 	{
-	    g_free(dev_ptr->command_tools);
-	    dev_ptr->command_tools = STRDUP(gtk_entry_get_text(entry));
+	    g_free(dev->command_tools);
+	    dev->command_tools = STRDUP(gtk_entry_get_text(entry));
 	}
 	/* Format command */
 	entry = (GtkEntry *)ew->command_format_entry;
 	if(entry != NULL)
 	{
-	    g_free(dev_ptr->command_format);
-	    dev_ptr->command_format = STRDUP(gtk_entry_get_text(entry));
+	    g_free(dev->command_format);
+	    dev->command_format = STRDUP(gtk_entry_get_text(entry));
 	}
 
-	/* No unmount */
-	w = ew->no_unmount_check;
-	if((w != NULL) ? GTK_IS_TOGGLE_BUTTON(w) : FALSE)
-	{
-	    dev_ptr->no_unmount = GTK_TOGGLE_BUTTON(w)->active;
-	}
-	/* Read only */
-	w = ew->read_only_check;
-	if((w != NULL) ? GTK_IS_TOGGLE_BUTTON(w) : FALSE)
-	{
-	    dev_ptr->read_only = GTK_TOGGLE_BUTTON(w)->active;
-	}
+	/* No Unmount */
+	if(GTK_TOGGLE_BUTTON_GET_ACTIVE(ew->no_unmount_check))
+	    dev->flags |= EDV_DEVICE_NO_UNMOUNT;
+	else
+	    dev->flags &= ~EDV_DEVICE_NO_UNMOUNT;
+	/* Read Only */
+	if(GTK_TOGGLE_BUTTON_GET_ACTIVE(ew->read_only_check))
+	    dev->flags |= EDV_DEVICE_READ_ONLY;
+	else
+	    dev->flags &= ~EDV_DEVICE_READ_ONLY;
 	/* Unlisted */
-	w = ew->unlisted_check;
-	if((w != NULL) ? GTK_IS_TOGGLE_BUTTON(w) : FALSE)
-	{
-	    dev_ptr->unlisted = GTK_TOGGLE_BUTTON(w)->active;
-	}
+	if(GTK_TOGGLE_BUTTON_GET_ACTIVE(ew->unlisted_check))
+	    dev->flags |= EDV_DEVICE_UNLISTED;
+	else
+	    dev->flags &= ~EDV_DEVICE_UNLISTED;
 
 	/* Begin applying icons file paths */
 
@@ -811,8 +807,8 @@ static void EDVDevicesEditWinApplyCB(
 	    gint i;
 	    for(i = 0; i < EDV_DEVICE_TOTAL_ICON_STATES; i++)
 	    {
-		g_free(dev_ptr->small_icon_file[i]);
-		dev_ptr->small_icon_file[i] = STRDUP(ei->path[i]);
+		g_free(dev->small_icon_file[i]);
+		dev->small_icon_file[i] = STRDUP(ei->path[i]);
 	    }
 	}
 
@@ -823,8 +819,8 @@ static void EDVDevicesEditWinApplyCB(
 	    gint i;
 	    for(i = 0; i < EDV_DEVICE_TOTAL_ICON_STATES; i++)
 	    {
-		g_free(dev_ptr->medium_icon_file[i]);
-		dev_ptr->medium_icon_file[i] = STRDUP(ei->path[i]);
+		g_free(dev->medium_icon_file[i]);
+		dev->medium_icon_file[i] = STRDUP(ei->path[i]);
 	    }
 	}
 
@@ -835,8 +831,8 @@ static void EDVDevicesEditWinApplyCB(
 	    gint i;
 	    for(i = 0; i < EDV_DEVICE_TOTAL_ICON_STATES; i++)
 	    {
-		g_free(dev_ptr->large_icon_file[i]);
-		dev_ptr->large_icon_file[i] = STRDUP(ei->path[i]);
+		g_free(dev->large_icon_file[i]);
+		dev->large_icon_file[i] = STRDUP(ei->path[i]);
 	    }
 	}
 
@@ -846,7 +842,7 @@ static void EDVDevicesEditWinApplyCB(
 
 
 	/* Re-realize the device */
-	EDVDeviceRealize(dev_ptr, TRUE);
+	EDVDeviceRealize(dev, TRUE);
 
 	/* Update all device mount states and stats */
 	EDVDevicesListUpdateMountStates(
@@ -857,7 +853,7 @@ static void EDVDevicesEditWinApplyCB(
 	);
 
 	/* Send device modified signal to all of endeavour's resources */
-	EDVDeviceModifiedEmit(core_ptr, dev_num, dev_ptr);
+	EDVDeviceModifiedEmit(core_ptr, dev_num, dev);
 }
 
 /*
@@ -881,14 +877,12 @@ void EDVDevicesEditWinFetchValues(
 	edv_device_editwin_struct *ew, gint dev_num
 )
 {
-	GtkWidget *w;
 	GtkEntry *entry;
 	GtkCombo *combo;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_core_struct *core_ptr;
 	edv_device_icon_picker_struct *ei;
 
-
 	if(ew == NULL)
 	    return;
 
@@ -897,11 +891,9 @@ void EDVDevicesEditWinFetchValues(
 	    return;
 
 	/* Get pointer to device structure on core's devices list */
-	if((dev_num < 0) || (dev_num >= core_ptr->total_devices))
-	    return;
-	else
-	    dev_ptr = core_ptr->device[dev_num];
-	if(dev_ptr == NULL)
+	dev = ((dev_num >= 0) && (dev_num < core_ptr->total_devices)) ?
+	    core_ptr->device[dev_num] : NULL;
+	if(dev == NULL)
 	    return;
 
 
@@ -916,7 +908,7 @@ void EDVDevicesEditWinFetchValues(
 	{
 	    gtk_entry_set_text(
 		entry,
-		(dev_ptr->name != NULL) ? dev_ptr->name : ""
+		(dev->name != NULL) ? dev->name : ""
 	    );
 	}
 
@@ -926,7 +918,7 @@ void EDVDevicesEditWinFetchValues(
 	{
 	    gtk_entry_set_text(
 		entry,
-		(dev_ptr->device_path != NULL) ? dev_ptr->device_path : ""
+		(dev->device_path != NULL) ? dev->device_path : ""
 	    );
 	}
 
@@ -936,7 +928,7 @@ void EDVDevicesEditWinFetchValues(
 	{
 	    gtk_entry_set_text(
 		entry,
-		(dev_ptr->mount_path != NULL) ? dev_ptr->mount_path : ""
+		(dev->mount_path != NULL) ? dev->mount_path : ""
 	    );
 	}
 
@@ -947,7 +939,8 @@ void EDVDevicesEditWinFetchValues(
 	{
 	    entry = (GtkEntry *)combo->entry;
 	    gtk_entry_set_text(
-		entry, EDVDeviceGetFSStringFromNumber(dev_ptr->fs_type)
+		entry,
+		EDVDeviceGetFSNameFromType(dev->fs_type)
 	    );
 	}
 
@@ -956,21 +949,21 @@ void EDVDevicesEditWinFetchValues(
 	if(entry != NULL)
 	    gtk_entry_set_text(
 		entry,
-		(dev_ptr->command_mount != NULL) ? dev_ptr->command_mount : ""
+		(dev->command_mount != NULL) ? dev->command_mount : ""
 	    );
 	/* Unmount command */
 	entry = (GtkEntry *)ew->command_unmount_entry;
 	if(entry != NULL)
 	    gtk_entry_set_text(
 		entry,
-		(dev_ptr->command_unmount != NULL) ? dev_ptr->command_unmount : ""
+		(dev->command_unmount != NULL) ? dev->command_unmount : ""
 	    );
 	/* Eject command */
 	entry = (GtkEntry *)ew->command_eject_entry;
 	if(entry != NULL)
 	    gtk_entry_set_text(
 		entry,
-		(dev_ptr->command_eject != NULL) ? dev_ptr->command_eject : ""
+		(dev->command_eject != NULL) ? dev->command_eject : ""
 	    );
 
 	/* Check command */
@@ -978,35 +971,38 @@ void EDVDevicesEditWinFetchValues(
 	if(entry != NULL)
 	    gtk_entry_set_text(
 		entry,
-		(dev_ptr->command_check != NULL) ? dev_ptr->command_check : ""
+		(dev->command_check != NULL) ? dev->command_check : ""
 	    );
 	/* Tools command */
 	entry = (GtkEntry *)ew->command_tools_entry;
 	if(entry != NULL)
 	    gtk_entry_set_text(
 		entry,
-		(dev_ptr->command_tools != NULL) ? dev_ptr->command_tools : ""
+		(dev->command_tools != NULL) ? dev->command_tools : ""
 	    );
 	/* Format command */
 	entry = (GtkEntry *)ew->command_format_entry;
 	if(entry != NULL)
 	    gtk_entry_set_text(
 		entry,
-		(dev_ptr->command_format != NULL) ? dev_ptr->command_format : ""
+		(dev->command_format != NULL) ? dev->command_format : ""
 	    );
 
-	/* No unmount */
-	w = ew->no_unmount_check;
-	if((w != NULL) ? GTK_IS_TOGGLE_BUTTON(w) : FALSE)
-	    GTK_TOGGLE_BUTTON(w)->active = dev_ptr->no_unmount;
-	/* Read only */
-	w = ew->read_only_check;
-	if((w != NULL) ? GTK_IS_TOGGLE_BUTTON(w) : FALSE)
-	    GTK_TOGGLE_BUTTON(w)->active = dev_ptr->read_only;
+	/* No Unmount */
+	GTK_TOGGLE_BUTTON_SET_ACTIVE(
+	    ew->no_unmount_check,
+	    EDV_DEVICE_IS_NO_UNMOUNT(dev)
+	);
+	/* Read Only */
+	GTK_TOGGLE_BUTTON_SET_ACTIVE(
+	    ew->read_only_check,
+	    EDV_DEVICE_IS_READ_ONLY(dev)
+	);
 	/* Unlisted */
-	w = ew->unlisted_check;
-	if((w != NULL) ? GTK_IS_TOGGLE_BUTTON(w) : FALSE)
-	    GTK_TOGGLE_BUTTON(w)->active = dev_ptr->unlisted;
+	GTK_TOGGLE_BUTTON_SET_ACTIVE(
+	    ew->unlisted_check,
+	    EDV_DEVICE_IS_UNLISTED(dev)
+	);
 
 	/* Begin loading icons */
 
@@ -1035,14 +1031,13 @@ void EDVDevicesEditWinFetchValues(
   ei->path[i] = STRDUP(path[i]);			\
  }							\
 }
-
 	/* Small icons */
 	ei = ew->icon_small;
 	if(ei != NULL)
 	{
-	    GdkPixmap **pixmap = dev_ptr->small_pixmap;
-	    GdkBitmap **mask = dev_ptr->small_mask;
-	    gchar **path = dev_ptr->small_icon_file;
+	    GdkPixmap **pixmap = dev->small_pixmap;
+	    GdkBitmap **mask = dev->small_mask;
+	    gchar **path = dev->small_icon_file;
 
 	    if(ei->adj != NULL)
 		ei->adj->value = 0.0f;
@@ -1059,9 +1054,9 @@ void EDVDevicesEditWinFetchValues(
 	ei = ew->icon_medium;
 	if(ei != NULL)
 	{
-	    GdkPixmap **pixmap = dev_ptr->medium_pixmap;
-	    GdkBitmap **mask = dev_ptr->medium_mask;
-	    gchar **path = dev_ptr->medium_icon_file;
+	    GdkPixmap **pixmap = dev->medium_pixmap;
+	    GdkBitmap **mask = dev->medium_mask;
+	    gchar **path = dev->medium_icon_file;
 
 	    if(ei->adj != NULL)
 		ei->adj->value = 0.0f;
@@ -1078,9 +1073,9 @@ void EDVDevicesEditWinFetchValues(
 	ei = ew->icon_large;
 	if(ei != NULL)
 	{
-	    GdkPixmap **pixmap = dev_ptr->large_pixmap;
-	    GdkBitmap **mask = dev_ptr->large_mask;
-	    gchar **path = dev_ptr->large_icon_file;
+	    GdkPixmap **pixmap = dev->large_pixmap;
+	    GdkBitmap **mask = dev->large_mask;
+	    gchar **path = dev->large_icon_file;
 
 	    if(ei->adj != NULL)
 		ei->adj->value = 0.0f;
@@ -1092,14 +1087,8 @@ void EDVDevicesEditWinFetchValues(
 		    ei, (gint)ei->adj->value
 		);
 	}
-
 #undef DO_LOAD_ICON
 
-
-#if 0
-	if(ew->toplevel != NULL)
-	    gtk_widget_queue_resize(ew->toplevel);
-#endif
 }
 
 
@@ -2413,7 +2402,7 @@ void EDVDevicesEditWinUpdateMenus(edv_device_editwin_struct *ew)
 	gboolean        sensitive,
 			has_changes;
 	gint dev_num;
-	const edv_device_struct *dev_ptr;
+	const edv_device_struct *dev;
 	GtkWidget *w;
 	edv_core_struct *core_ptr;
 
@@ -2427,9 +2416,9 @@ void EDVDevicesEditWinUpdateMenus(edv_device_editwin_struct *ew)
 	has_changes = ew->has_changes;
 	dev_num = ew->dev_num;
 	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
+	    dev = core_ptr->device[dev_num];
 	else
-	    dev_ptr = NULL;
+	    dev = NULL;
 
 #define MAP(w)                  \
 { if((w) != NULL) { gtk_widget_show(w); } }
