@@ -5,7 +5,6 @@
 
 #include "../include/string.h"
 #include "../include/disk.h"
-#include "../include/prochandle.h"
 
 #include "guiutils.h"
 #include "cdialog.h"
@@ -73,10 +72,10 @@ static void EDVDevicesListWinDownCB(GtkWidget *widget, gpointer data);
 static void EDVDevicesListWinCloseCB(GtkWidget *widget, gpointer data);
 
 static void EDVDevicesListWinUpdateDisplay(
-	edv_device_listwin_struct *lw, edv_device_struct *dev_ptr
+	edv_device_listwin_struct *lw, edv_device_struct *dev
 );
 void EDVDevicesListWinSetRow(
-	edv_device_listwin_struct *lw, gint row, edv_device_struct *dev_ptr
+	edv_device_listwin_struct *lw, gint row, edv_device_struct *dev
 );
 void EDVDevicesListWinFetchValues(edv_device_listwin_struct *lw);
 
@@ -85,16 +84,16 @@ void EDVDevicesListWinReconfiguredNotifyCB(
 );
 void EDVDevicesListWinMountNotifyCB(
 	edv_device_listwin_struct *lw,
-	gint dev_num, edv_device_struct *dev_ptr,
+	gint dev_num, edv_device_struct *dev,
 	gboolean is_mounted
 );
 void EDVDevicesListWinDeviceAddedCB(
 	edv_device_listwin_struct *lw,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 );
 void EDVDevicesListWinDeviceModifiedCB(
 	edv_device_listwin_struct *lw,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 );
 void EDVDevicesListWinDeviceRemovedCB(
 	edv_device_listwin_struct *lw, gint dev_num
@@ -455,7 +454,7 @@ static void EDVDevicesListWinMountCB(GtkWidget *widget, gpointer data)
 	gint status, row, dev_num;
 	GtkWidget *toplevel;
 	GtkCList *clist;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_core_struct *core_ptr;
 	edv_device_listwin_struct *lw = EDV_DEVICE_LISTWIN(data);
 	if(lw == NULL)
@@ -470,21 +469,21 @@ static void EDVDevicesListWinMountCB(GtkWidget *widget, gpointer data)
 	/* Get selected row and device number index as the row index */
 	dev_num = row = EDVCListGetSelectedLast(clist, NULL);
 	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
+	    dev = core_ptr->device[dev_num];
 	else
-	    dev_ptr = NULL;
-	if(dev_ptr == NULL)
+	    dev = NULL;
+	if(dev == NULL)
 	    return;
 
-	original_mount_state = dev_ptr->is_mounted;
+	original_mount_state = EDV_DEVICE_IS_MOUNTED(dev);
 
 	EDVDevicesListSetBusy(lw, TRUE);
 
 	/* Unmount or mount? */
-	if(dev_ptr->is_mounted)
-	    status = EDVMountDoUnmount(core_ptr, dev_ptr, toplevel);
+	if(EDV_DEVICE_IS_MOUNTED(dev))
+	    status = EDVMountDoUnmount(core_ptr, dev, toplevel);
 	else
-	    status = EDVMountDoMount(core_ptr, dev_ptr, toplevel);
+	    status = EDVMountDoMount(core_ptr, dev, toplevel);
 
 	/* Update all device mount states and stats */
 	EDVDevicesListUpdateMountStates(
@@ -514,12 +513,10 @@ static void EDVDevicesListWinMountCB(GtkWidget *widget, gpointer data)
 	}
 	else
 	{
-	    /* Report mount signal to all of endeavour's resources */
-	    EDVObjectMountEmit(core_ptr, dev_num, dev_ptr, dev_ptr->is_mounted);
-
-/* Warning, some widgets on this devices list may be invalid at this
- * point if fetched earlier in this function
- */
+	    /* Report mount */
+	    EDVObjectMountEmit(
+		core_ptr, dev_num, dev, EDV_DEVICE_IS_MOUNTED(dev)
+	    );
 	}
 }
 
@@ -532,7 +529,7 @@ static void EDVDevicesListWinEjectCB(GtkWidget *widget, gpointer data)
 	gint status, row, dev_num;
 	GtkWidget *toplevel;
 	GtkCList *clist;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_core_struct *core_ptr;
 	edv_device_listwin_struct *lw = EDV_DEVICE_LISTWIN(data);
 	if(lw == NULL)
@@ -547,21 +544,21 @@ static void EDVDevicesListWinEjectCB(GtkWidget *widget, gpointer data)
 	/* Get selected row and device number index as the row index */
 	dev_num = row = EDVCListGetSelectedLast(clist, NULL);
 	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
+	    dev = core_ptr->device[dev_num];
 	else
-	    dev_ptr = NULL;
-	if(dev_ptr == NULL)
+	    dev = NULL;
+	if(dev == NULL)
 	    return;
 
-	original_mount_state = dev_ptr->is_mounted;
+	original_mount_state = EDV_DEVICE_IS_MOUNTED(dev);
 
 	EDVDevicesListSetBusy(lw, TRUE);
 
 	/* Need to unmount first? */
-	if(dev_ptr->is_mounted)
-	    EDVMountDoUnmount(core_ptr, dev_ptr, toplevel);
+	if(EDV_DEVICE_IS_MOUNTED(dev))
+	    EDVMountDoUnmount(core_ptr, dev, toplevel);
 	/* So now eject */
-	status = EDVMountDoEject(core_ptr, dev_ptr, toplevel);
+	status = EDVMountDoEject(core_ptr, dev, toplevel);
 
 	/* Update all device mount states and stats */
 	EDVDevicesListUpdateMountStates(
@@ -590,10 +587,10 @@ static void EDVDevicesListWinEjectCB(GtkWidget *widget, gpointer data)
 	}
 	else
 	{
-	    /* Report eject (unmount) signal to all of endeavour's
-	     * resources
-	     */
-	    EDVObjectMountEmit(core_ptr, dev_num, dev_ptr, dev_ptr->is_mounted);
+	    /* Report eject (unmount) */
+	    EDVObjectMountEmit(
+		core_ptr, dev_num, dev, EDV_DEVICE_IS_MOUNTED(dev)
+	    );
 	}
 }
 
@@ -605,7 +602,7 @@ static void EDVDevicesListWinPropertiesCB(GtkWidget *widget, gpointer data)
 	gint row, dev_num;
 	const gchar *mount_path;
 	GtkCList *clist;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_core_struct *core_ptr;
 	edv_device_listwin_struct *lw = EDV_DEVICE_LISTWIN(data);
 	if(lw == NULL)
@@ -619,16 +616,16 @@ static void EDVDevicesListWinPropertiesCB(GtkWidget *widget, gpointer data)
 	/* Get selected row and device number index as the row index */
 	dev_num = row = EDVCListGetSelectedLast(clist, NULL);
 	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
+	    dev = core_ptr->device[dev_num];
 	else
-	    dev_ptr = NULL;
-	if(dev_ptr == NULL)
+	    dev = NULL;
+	if(dev == NULL)
 	    return;
 
 	EDVDevicesListSetBusy(lw, TRUE);
 
 	/* Get mount path */
-	mount_path = dev_ptr->mount_path;
+	mount_path = dev->mount_path;
 	if(!STRISEMPTY(mount_path))
 	{
 	    struct stat lstat_buf;
@@ -641,7 +638,7 @@ static void EDVDevicesListWinPropertiesCB(GtkWidget *widget, gpointer data)
 		{
 		    EDVObjectSetPath(obj, mount_path);
 		    EDVObjectSetStat(obj, &lstat_buf);
-		    EDVObjectValidateLink(obj);
+		    EDVObjectUpdateLinkFlags(obj);
 
 		    /* Create a new Properties Dialog */
 		    EDVNewPropertiesDialogPage(
@@ -663,15 +660,16 @@ static void EDVDevicesListWinPropertiesCB(GtkWidget *widget, gpointer data)
  */
 static void EDVDevicesListWinFSCKCB(GtkWidget *widget, gpointer data)
 {
-	const gchar *cmd;
 	gint row, dev_num;
+	GtkWidget *toplevel;
 	GtkCList *clist;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_core_struct *core_ptr;
 	edv_device_listwin_struct *lw = EDV_DEVICE_LISTWIN(data);
 	if(lw == NULL)
 	    return;
 
+	toplevel = lw->toplevel;
 	clist = (GtkCList *)lw->devices_clist;
 	core_ptr = EDV_CORE(lw->core_ptr);
 	if((clist == NULL) || (core_ptr == NULL))
@@ -680,18 +678,16 @@ static void EDVDevicesListWinFSCKCB(GtkWidget *widget, gpointer data)
 	/* Get selected row and device number index as the row index */
 	dev_num = row = EDVCListGetSelectedLast(clist, NULL);
 	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
+	    dev = core_ptr->device[dev_num];
 	else
-	    dev_ptr = NULL;
-	if(dev_ptr == NULL)
+	    dev = NULL;
+	if(dev == NULL)
 	    return;
 
 	EDVDevicesListSetBusy(lw, TRUE);
 
-	/* Get fsck command */
-	cmd = dev_ptr->command_check;
-	if(!STRISEMPTY(cmd))
-	    Exec(cmd);
+	/* Run the device check */
+	EDVRunDeviceCheck(core_ptr, dev, toplevel);
 
 	EDVDevicesListSetBusy(lw, FALSE);
 }
@@ -701,15 +697,16 @@ static void EDVDevicesListWinFSCKCB(GtkWidget *widget, gpointer data)
  */
 static void EDVDevicesListWinToolsCB(GtkWidget *widget, gpointer data)
 {
-	const gchar *cmd;
 	gint row, dev_num;
+	GtkWidget *toplevel;
 	GtkCList *clist;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_core_struct *core_ptr;
 	edv_device_listwin_struct *lw = EDV_DEVICE_LISTWIN(data);
 	if(lw == NULL)
 	    return;
 
+	toplevel = lw->toplevel;
 	clist = (GtkCList *)lw->devices_clist;
 	core_ptr = EDV_CORE(lw->core_ptr);
 	if((clist == NULL) || (core_ptr == NULL))
@@ -718,18 +715,16 @@ static void EDVDevicesListWinToolsCB(GtkWidget *widget, gpointer data)
 	/* Get selected row and device number index as the row index */
 	dev_num = row = EDVCListGetSelectedLast(clist, NULL);
 	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
+	    dev = core_ptr->device[dev_num];
 	else
-	    dev_ptr = NULL;
-	if(dev_ptr == NULL)
+	    dev = NULL;
+	if(dev == NULL)
 	    return;
 
 	EDVDevicesListSetBusy(lw, TRUE);
 
-	/* Get tools command */
-	cmd = dev_ptr->command_tools;
-	if(!STRISEMPTY(cmd))
-	    Exec(cmd);
+	/* Run the device tools */
+	EDVRunDeviceTools(core_ptr, dev, toplevel);                           
 
 	EDVDevicesListSetBusy(lw, FALSE);
 }
@@ -739,15 +734,16 @@ static void EDVDevicesListWinToolsCB(GtkWidget *widget, gpointer data)
  */
 static void EDVDevicesListWinFormatCB(GtkWidget *widget, gpointer data)
 {
-	const gchar *cmd;
 	gint row, dev_num;
+	GtkWidget *toplevel;
 	GtkCList *clist;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_core_struct *core_ptr;
 	edv_device_listwin_struct *lw = EDV_DEVICE_LISTWIN(data);
 	if(lw == NULL)
 	    return;
 
+	toplevel = lw->toplevel;
 	clist = (GtkCList *)lw->devices_clist;
 	core_ptr = EDV_CORE(lw->core_ptr);
 	if((clist == NULL) || (core_ptr == NULL))
@@ -756,18 +752,16 @@ static void EDVDevicesListWinFormatCB(GtkWidget *widget, gpointer data)
 	/* Get selected row and device number index as the row index */
 	dev_num = row = EDVCListGetSelectedLast(clist, NULL);
 	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
+	    dev = core_ptr->device[dev_num];
 	else
-	    dev_ptr = NULL;
-	if(dev_ptr == NULL)
+	    dev = NULL;
+	if(dev == NULL)
 	    return;
 
 	EDVDevicesListSetBusy(lw, TRUE);
 
-	/* Get format command */
-	cmd = dev_ptr->command_format;
-	if(!STRISEMPTY(cmd))
-	    Exec(cmd);
+	/* Run the device format */
+	EDVRunDeviceFormat(core_ptr, dev, toplevel);
 
 	EDVDevicesListSetBusy(lw, FALSE);
 }
@@ -880,14 +874,16 @@ static void EDVDevicesListWinAddCB(
 )
 {
 	gint row, dev_num;
-	edv_device_struct *dev_ptr;
+	GtkWidget *toplevel;
 	GtkCList *clist;
+	edv_device_struct *dev;
 	edv_core_struct *core_ptr;
 	edv_device_editwin_struct *ew;
 	edv_device_listwin_struct *lw = EDV_DEVICE_LISTWIN(data);
 	if(lw == NULL)
 	    return;
 
+	toplevel = lw->toplevel;
 	clist = (GtkCList *)lw->devices_clist;
 	core_ptr = EDV_CORE(lw->core_ptr);
 	if((clist == NULL) || (core_ptr == NULL))
@@ -948,7 +944,7 @@ static void EDVDevicesListWinAddCB(
 		core_ptr->device[i] = core_ptr->device[i - 1];
 	}
 	/* Create new device structure */
-	core_ptr->device[dev_num] = dev_ptr = EDVDeviceNew(
+	core_ptr->device[dev_num] = dev = EDVDeviceNew(
 	    EDV_FS_TYPE_EMPTY,
 	    "New Device",
 	    "/dev/null",
@@ -966,7 +962,7 @@ static void EDVDevicesListWinAddCB(
 
 
 	/* Send device added signal to all of endeavour's resources */
-	EDVDeviceAddedEmit(core_ptr, dev_num, dev_ptr);
+	EDVDeviceAddedEmit(core_ptr, dev_num, dev);
 
 
 	/* Map devices edit window, creating it as needed */
@@ -977,7 +973,7 @@ static void EDVDevicesListWinAddCB(
 	    );
 	if(ew != NULL)
 	{
-	    EDVCenterWindowToWindow(lw->toplevel, ew->toplevel);
+	    EDVCenterWindowToWindow(toplevel, ew->toplevel);
 	    EDVDevicesEditWinMap(ew);
 	    EDVDevicesEditWinFetchValues(ew, dev_num);
 	    EDVDevicesEditWinResetHasChanges(ew, FALSE);
@@ -996,7 +992,7 @@ static void EDVDevicesListWinEditCB(
 	gint row, dev_num;
 	GtkWidget *toplevel;
 	GtkCList *clist;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_core_struct *core_ptr;
 	edv_device_editwin_struct *ew;
 	edv_device_listwin_struct *lw = EDV_DEVICE_LISTWIN(data);
@@ -1015,17 +1011,15 @@ static void EDVDevicesListWinEditCB(
 	/* Get device number index as the selected row's index */
 	dev_num = row;
 
-	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
-	else
-	    dev_ptr = NULL;
-	if(dev_ptr == NULL)
+	dev = ((dev_num >= 0) && (dev_num < core_ptr->total_devices)) ?
+	    core_ptr->device[dev_num] : NULL;
+	if(dev == NULL)
 	    return;
 
 	/* Check if this device is internally created by this program
 	 * which means it cannot be edited
 	 */
-	if(dev_ptr->internal)
+	if(EDV_DEVICE_IS_INTERNAL(dev))
 	{
 	    EDVPlaySoundWarning(core_ptr);
 	    EDVMessageWarning(
@@ -1049,7 +1043,7 @@ program and may not be edited.",
 	    );
 	if(ew != NULL)
 	{
-	    EDVCenterWindowToWindow(lw->toplevel, ew->toplevel);
+	    EDVCenterWindowToWindow(toplevel, ew->toplevel);
 	    EDVDevicesEditWinMap(ew);
 	    EDVDevicesEditWinFetchValues(ew, dev_num);
 	    EDVDevicesEditWinResetHasChanges(ew, FALSE);
@@ -1066,7 +1060,7 @@ static void EDVDevicesListWinRemoveCB(
 )
 {
 	gint row, dev_num;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	GtkWidget *toplevel;
 	GtkCList *clist;
 	edv_core_struct *core_ptr;
@@ -1086,17 +1080,15 @@ static void EDVDevicesListWinRemoveCB(
 	/* Get device number index as the selected row's index */
 	dev_num = row;
 
-	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
-	else
-	    dev_ptr = NULL;
-	if(dev_ptr == NULL)
+	dev = ((dev_num >= 0) && (dev_num < core_ptr->total_devices)) ?
+	    core_ptr->device[dev_num] : NULL;
+	if(dev == NULL)
 	    return;
 
 	/* Check if this device is internally allocated, in which case
 	 * it cannot be removed
 	 */
-	if(dev_ptr->internal)
+	if(EDV_DEVICE_IS_INTERNAL(dev))
 	{
 	    EDVPlaySoundWarning(core_ptr);
 	    EDVMessageWarning(
@@ -1116,7 +1108,7 @@ program and may not be removed.",
 	    gint status;
 	    gchar *buf = g_strdup_printf(
 "Are you sure you want to remove the device \"%s\"?",
-		dev_ptr->device_path
+		dev->device_path
 	    );
 
 	    EDVPlaySoundQuestion(core_ptr);
@@ -1153,7 +1145,7 @@ program and may not be removed.",
 
 	/* Delete device structure */
 	EDVDeviceDelete(core_ptr->device[dev_num]);
-	core_ptr->device[dev_num] = dev_ptr = NULL;
+	core_ptr->device[dev_num] = dev = NULL;
 
 	/* Reduce total */
 	core_ptr->total_devices--;
@@ -1225,7 +1217,7 @@ static void EDVDevicesListWinUpCB(
 	   (core_ptr->total_devices == clist->rows)
 	)
 	{
-	    edv_device_struct *tmp_dev_ptr;
+	    edv_device_struct *tmp_dev;
 
 	    /* Shift clist rows */
 	    gtk_clist_freeze(clist);
@@ -1235,9 +1227,9 @@ static void EDVDevicesListWinUpCB(
 	    /* Shift device structure pointers on the core structure's
 	     * devices list.
 	     */
-	    tmp_dev_ptr = core_ptr->device[row - 1];
+	    tmp_dev = core_ptr->device[row - 1];
 	    core_ptr->device[row - 1] = core_ptr->device[row];
-	    core_ptr->device[row] = tmp_dev_ptr;
+	    core_ptr->device[row] = tmp_dev;
 
 	    /* Emit device modified signal for both devices involved in
 	     * shift.
@@ -1291,7 +1283,7 @@ static void EDVDevicesListWinDownCB(
 	   (core_ptr->total_devices == clist->rows)
 	)
 	{
-	    edv_device_struct *tmp_dev_ptr;
+	    edv_device_struct *tmp_dev;
 
 	    /* Shift clist rows */
 	    gtk_clist_freeze(clist);
@@ -1301,9 +1293,9 @@ static void EDVDevicesListWinDownCB(
 	    /* Shift device structure pointers on the core structure's
 	     * devices list.
 	     */
-	    tmp_dev_ptr = core_ptr->device[row + 1];
+	    tmp_dev = core_ptr->device[row + 1];
 	    core_ptr->device[row + 1] = core_ptr->device[row];
-	    core_ptr->device[row] = tmp_dev_ptr;
+	    core_ptr->device[row] = tmp_dev;
 
 	    /* Emit device modified signal for both devices involved in
 	     * shift.
@@ -1345,10 +1337,10 @@ static void EDVDevicesListWinCloseCB(
  *	Updates the displayed device on the given list window.
  *
  *	This will destroy the display_client widget and create a
- *	new one if dev_ptr is not NULL.
+ *	new one if dev is not NULL.
  */
 static void EDVDevicesListWinUpdateDisplay(
-	edv_device_listwin_struct *lw, edv_device_struct *dev_ptr
+	edv_device_listwin_struct *lw, edv_device_struct *dev
 )
 {
 	const gint	border_major = 5,
@@ -1405,11 +1397,11 @@ static void EDVDevicesListWinUpdateDisplay(
 	/* If device is not available then do not recreate the
 	 * display widgets
 	 */
-	if(dev_ptr == NULL)
+	if(dev == NULL)
 	    return;
 
 	/* Realize device as needed */
-	EDVDeviceRealize(dev_ptr, FALSE);
+	EDVDeviceRealize(dev, FALSE);
 
 
 	/* Get parent to create display client widget on */
@@ -1448,21 +1440,21 @@ static void EDVDevicesListWinUpdateDisplay(
 	    /* First try to get large sized pixmap, use standard state
 	     * always
 	     */
-	    pixmap = dev_ptr->large_pixmap[EDV_DEVICE_ICON_STATE_STANDARD];
-	    mask = dev_ptr->large_mask[EDV_DEVICE_ICON_STATE_STANDARD];
+	    pixmap = dev->large_pixmap[EDV_DEVICE_ICON_STATE_STANDARD];
+	    mask = dev->large_mask[EDV_DEVICE_ICON_STATE_STANDARD];
 	    /* No large? Then try medium */
 	    if(pixmap == NULL)
 #endif
 	    if(TRUE)
 	    {
-		pixmap = dev_ptr->medium_pixmap[EDV_DEVICE_ICON_STATE_STANDARD];
-		mask = dev_ptr->medium_mask[EDV_DEVICE_ICON_STATE_STANDARD];
+		pixmap = dev->medium_pixmap[EDV_DEVICE_ICON_STATE_STANDARD];
+		mask = dev->medium_mask[EDV_DEVICE_ICON_STATE_STANDARD];
 	    }
 	    /* No medium? Then try small */
 	    if(pixmap == NULL)
 	    {
-		pixmap = dev_ptr->small_pixmap[EDV_DEVICE_ICON_STATE_STANDARD];
-		mask = dev_ptr->small_mask[EDV_DEVICE_ICON_STATE_STANDARD];
+		pixmap = dev->small_pixmap[EDV_DEVICE_ICON_STATE_STANDARD];
+		mask = dev->small_mask[EDV_DEVICE_ICON_STATE_STANDARD];
 	    }
 
 	    /* Got pixmap and mask pair? */
@@ -1474,13 +1466,13 @@ static void EDVDevicesListWinUpdateDisplay(
 	    }
 	}
 	/* Name label (or device path if name is empty) */
-	if(!STRISEMPTY(dev_ptr->name))
+	if(!STRISEMPTY(dev->name))
 	{
-	    lw->dev_name_label = w = gtk_label_new(dev_ptr->name);
+	    lw->dev_name_label = w = gtk_label_new(dev->name);
 	}
 	else
 	{
-	    const gchar	*dev_path = dev_ptr->device_path,
+	    const gchar	*dev_path = dev->device_path,
 			*dev_name = EDVGetPathName(dev_path);
 	    if(dev_name == NULL)
 		dev_name = "(null)";
@@ -1522,14 +1514,14 @@ static void EDVDevicesListWinUpdateDisplay(
 	GTK_RC_STYLE_UNREF(rcstyle);
 
 	/* Device path */
-	if(!STRISEMPTY(dev_ptr->device_path))
+	if(!STRISEMPTY(dev->device_path))
 	{
 	    rcstyle = gtk_rc_style_new();
 	    rcstyle->font_name = STRDUP(
 "-adobe-courier-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
 	    );
 	    lw->dev_device_path_label = w = gtk_label_new(
-		dev_ptr->device_path
+		dev->device_path
 	    );
 	    gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
 	    gtk_widget_modify_style(w, rcstyle);
@@ -1564,14 +1556,14 @@ static void EDVDevicesListWinUpdateDisplay(
 	GTK_RC_STYLE_UNREF(rcstyle);
 
 	/* Mount path */
-	if(!STRISEMPTY(dev_ptr->mount_path))
+	if(!STRISEMPTY(dev->mount_path))
 	{
 	    rcstyle = gtk_rc_style_new();
 	    rcstyle->font_name = STRDUP(
 "-adobe-courier-medium-r-normal-*-12-*-*-*-*-*-iso8859-1"
 	    );
 	    lw->dev_mount_path_label = w = gtk_label_new(
-		dev_ptr->mount_path
+		dev->mount_path
 	    );
 	    gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
 	    gtk_widget_modify_style(w, rcstyle);
@@ -1587,7 +1579,7 @@ static void EDVDevicesListWinUpdateDisplay(
 
 	/* Mount/unmount button */
 	lw->dev_mount_btn = w = GUIButtonPixmap(
-	    (guint8 **)(dev_ptr->is_mounted ?
+	    (guint8 **)(EDV_DEVICE_IS_MOUNTED(dev) ?
 		icon_unmount_20x20_xpm : icon_mount_20x20_xpm
 	    )
 	);
@@ -1613,10 +1605,10 @@ static void EDVDevicesListWinUpdateDisplay(
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Fotstykke eller av fotstykkeinnretning"
 #else
-"Mount/unmount device"
+"Mount/unmount the device"
 #endif
 	);
-	GTK_WIDGET_SET_SENSITIVE(w, !dev_ptr->no_unmount)
+	GTK_WIDGET_SET_SENSITIVE(w, !EDV_DEVICE_IS_NO_UNMOUNT(dev));
 	if(standard_rcstyle != NULL)
 	    gtk_widget_modify_style_recursive(w, standard_rcstyle);
 	gtk_widget_show(w);
@@ -1647,12 +1639,12 @@ static void EDVDevicesListWinUpdateDisplay(
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Kast ut medier fra innretningen"
 #else
-"Eject media from the device"
+"Eject the media from the device"
 #endif
 	);
 	GTK_WIDGET_SET_SENSITIVE(
 	    w,
-	    !STRISEMPTY(dev_ptr->command_eject) ? TRUE : FALSE
+	    !STRISEMPTY(dev->command_eject) ? TRUE : FALSE
 	)
 	if(standard_rcstyle != NULL)
 	    gtk_widget_modify_style_recursive(w, standard_rcstyle);
@@ -1684,12 +1676,12 @@ static void EDVDevicesListWinUpdateDisplay(
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Modifiser fotstykkestieiendomer"
 #else
-"Modify mount path properties"
+"Modify the properties of the mount path"
 #endif
 	);
 	GTK_WIDGET_SET_SENSITIVE(
 	    w,
-	    !STRISEMPTY(dev_ptr->mount_path) ? TRUE : FALSE
+	    !STRISEMPTY(dev->mount_path) ? TRUE : FALSE
 	)
 	if(standard_rcstyle != NULL)
 	    gtk_widget_modify_style_recursive(w, standard_rcstyle);
@@ -1726,7 +1718,7 @@ static void EDVDevicesListWinUpdateDisplay(
 	);
 	GTK_WIDGET_SET_SENSITIVE(
 	    w,
-	    !STRISEMPTY(dev_ptr->command_check) ? TRUE : FALSE
+	    !STRISEMPTY(dev->command_check) ? TRUE : FALSE
 	)
 	if(standard_rcstyle != NULL)
 	    gtk_widget_modify_style_recursive(w, standard_rcstyle);
@@ -1763,7 +1755,7 @@ static void EDVDevicesListWinUpdateDisplay(
 	);
 	GTK_WIDGET_SET_SENSITIVE(
 	    w,
-	    !STRISEMPTY(dev_ptr->command_tools) ? TRUE : FALSE
+	    !STRISEMPTY(dev->command_tools) ? TRUE : FALSE
 	)
 	if(standard_rcstyle != NULL)
 	    gtk_widget_modify_style_recursive(w, standard_rcstyle);
@@ -1800,7 +1792,7 @@ static void EDVDevicesListWinUpdateDisplay(
 	);
 	GTK_WIDGET_SET_SENSITIVE(
 	    w,
-	    !STRISEMPTY(dev_ptr->command_format) ? TRUE : FALSE
+	    !STRISEMPTY(dev->command_format) ? TRUE : FALSE
 	)
 	if(standard_rcstyle != NULL)
 	    gtk_widget_modify_style_recursive(w, standard_rcstyle);
@@ -1814,12 +1806,12 @@ static void EDVDevicesListWinUpdateDisplay(
 	parent3 = w;
 
 	/* Create the Usage Pie Chart if mounted */
-	if(dev_ptr->is_mounted)
+	if(EDV_DEVICE_IS_MOUNTED(dev))
 	{
 	    const gulong	adj_division = 10l,
-				total_kb = dev_ptr->blocks_total,
-				free_kb = dev_ptr->blocks_free,
-				available_kb = dev_ptr->blocks_available,
+				total_kb = dev->blocks_total,
+				free_kb = dev->blocks_free,
+				available_kb = dev->blocks_available,
 				used_kb = MAX(total_kb - free_kb, 0l);
 	    gchar *ss_kb, *ss_mb, *text, *text2;
 	    GdkColor c;
@@ -1863,10 +1855,10 @@ static void EDVDevicesListWinUpdateDisplay(
 	    g_free(ss_mb);
 
 	    ss_kb = STRDUP(
-		EDVGetObjectSizeStr(core_ptr, dev_ptr->blocks_free)
+		EDVGetObjectSizeStr(core_ptr, dev->blocks_free)
 	    );
 	    ss_mb = STRDUP(
-		EDVGetObjectSizeStr(core_ptr, dev_ptr->blocks_free / 1000)
+		EDVGetObjectSizeStr(core_ptr, dev->blocks_free / 1000)
 	    );
 	    text2 = g_strdup_printf(
 	        "%s kb (%s mb)",
@@ -2007,7 +1999,7 @@ static void EDVDevicesListWinUpdateDisplay(
  *	values specified by the given device structure.
  */
 void EDVDevicesListWinSetRow(
-	edv_device_listwin_struct *lw, gint row, edv_device_struct *dev_ptr
+	edv_device_listwin_struct *lw, gint row, edv_device_struct *dev
 )
 {
 	GtkCList *clist;
@@ -2017,7 +2009,7 @@ void EDVDevicesListWinSetRow(
 	GdkBitmap *mask = NULL;
 
 
-	if((lw == NULL) || (dev_ptr == NULL))
+	if((lw == NULL) || (dev == NULL))
 	    return;
 
 	core_ptr = EDV_CORE(lw->core_ptr);
@@ -2031,14 +2023,14 @@ void EDVDevicesListWinSetRow(
 	/* Realize device structure so we can have use of its
 	 * icon pixmap and mask pairs.
 	 */
-	EDVDeviceRealize(dev_ptr, FALSE);
+	EDVDeviceRealize(dev, FALSE);
 
 
 	/* Get small icon pixmap and mask pair for this row */
-	pixmap = dev_ptr->small_pixmap[
+	pixmap = dev->small_pixmap[
 	    EDV_DEVICE_ICON_STATE_STANDARD
 	];
-	mask = dev_ptr->small_mask[
+	mask = dev->small_mask[
 	    EDV_DEVICE_ICON_STATE_STANDARD
 	];
 
@@ -2049,9 +2041,9 @@ void EDVDevicesListWinSetRow(
 	    /* Set column 0 as name (or device path if name is not given) */
 	    if(clist->columns > 0)
 	    {
-		const gchar *cell_text = dev_ptr->name;
-		if((cell_text == NULL) && (dev_ptr->device_path != NULL))
-		    cell_text = EDVGetPathName(dev_ptr->device_path);
+		const gchar *cell_text = dev->name;
+		if((cell_text == NULL) && (dev->device_path != NULL))
+		    cell_text = EDVGetPathName(dev->device_path);
 		if(cell_text == NULL)
 		    cell_text = "(null)";
 
@@ -2069,7 +2061,7 @@ void EDVDevicesListWinSetRow(
 	    /* Set column 1 as device path */
 	    if(clist->columns > 1)
 	    {
-		const gchar *cell_text = dev_ptr->device_path;
+		const gchar *cell_text = dev->device_path;
 		if(cell_text == NULL)
 		    cell_text = "(null)";
 
@@ -2080,7 +2072,7 @@ void EDVDevicesListWinSetRow(
 	    /* Set column 2 as mount path */
 	    if(clist->columns > 2)
 	    {
-		const gchar *cell_text = dev_ptr->mount_path;
+		const gchar *cell_text = dev->mount_path;
 		if(cell_text == NULL)
 		    cell_text = "(null)";
 
@@ -2093,7 +2085,7 @@ void EDVDevicesListWinSetRow(
 	    {
 		gtk_clist_set_text(
 		    clist, row, 3,
-		    EDVDeviceGetFSStringFromNumber(dev_ptr->fs_type)
+		    EDVDeviceGetFSNameFromType(dev->fs_type)
 		);
 	    }
 
@@ -2110,7 +2102,7 @@ void EDVDevicesListWinFetchValues(edv_device_listwin_struct *lw)
 	gchar **strv;
 	GtkCList *clist;
 	edv_core_struct *core_ptr;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 
 
 	if(lw == NULL)
@@ -2141,8 +2133,8 @@ void EDVDevicesListWinFetchValues(edv_device_listwin_struct *lw)
 	/* Iterate through all devices on the core structure */
 	for(i = 0; i < core_ptr->total_devices; i++)
 	{
-	    dev_ptr = core_ptr->device[i];
-	    if(dev_ptr == NULL)
+	    dev = core_ptr->device[i];
+	    if(dev == NULL)
 		continue;
 
 	    /* Append a new clist row */
@@ -2151,7 +2143,7 @@ void EDVDevicesListWinFetchValues(edv_device_listwin_struct *lw)
 	    /* Set new clist row values with the current device 
 	     * structure's values.
 	     */
-	    EDVDevicesListWinSetRow(lw, row, dev_ptr);
+	    EDVDevicesListWinSetRow(lw, row, dev);
 	}
 
 	gtk_clist_thaw(clist);
@@ -2201,13 +2193,13 @@ void EDVDevicesListWinReconfiguredNotifyCB(
  */
 void EDVDevicesListWinMountNotifyCB(
 	edv_device_listwin_struct *lw,
-	gint dev_num, edv_device_struct *dev_ptr,
+	gint dev_num, edv_device_struct *dev,
 	gboolean is_mounted
 )
 {
 	/* Just forward this to the device modified callback */
 	EDVDevicesListWinDeviceModifiedCB(
-	    lw, dev_num, dev_ptr
+	    lw, dev_num, dev
 	);
 }
 
@@ -2216,7 +2208,7 @@ void EDVDevicesListWinMountNotifyCB(
  */
 void EDVDevicesListWinDeviceAddedCB(
 	edv_device_listwin_struct *lw,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 )
 {
 	gint row, new_row;
@@ -2225,7 +2217,7 @@ void EDVDevicesListWinDeviceAddedCB(
 	edv_core_struct *core_ptr;
 
 
-	if((lw == NULL) || (dev_ptr == NULL))
+	if((lw == NULL) || (dev == NULL))
 	    return;
 
 	core_ptr = EDV_CORE(lw->core_ptr);
@@ -2269,7 +2261,7 @@ void EDVDevicesListWinDeviceAddedCB(
 	    return;
 
 	/* Update clist row text with values from the new device */
-	EDVDevicesListWinSetRow(lw, new_row, dev_ptr);
+	EDVDevicesListWinSetRow(lw, new_row, dev);
 
 	EDVDevicesListWinUpdateMenus(lw);
 
@@ -2283,14 +2275,14 @@ void EDVDevicesListWinDeviceAddedCB(
  */
 void EDVDevicesListWinDeviceModifiedCB(
 	edv_device_listwin_struct *lw,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 )
 {
 	GtkCList *clist;
 	edv_core_struct *core_ptr;
 
 
-	if((lw == NULL) || (dev_ptr == NULL))
+	if((lw == NULL) || (dev == NULL))
 	    return;
 
 	core_ptr = EDV_CORE(lw->core_ptr);
@@ -2309,13 +2301,13 @@ void EDVDevicesListWinDeviceModifiedCB(
 	    gint sel_row = EDVCListGetSelectedLast(clist, NULL);
 
 	    /* Update this row with the values from the given device */
-	    EDVDevicesListWinSetRow(lw, dev_num, dev_ptr);
+	    EDVDevicesListWinSetRow(lw, dev_num, dev);
 
 	    /* This row currently selected? */
 	    if(dev_num == sel_row)
 	    {
 		/* Update displayed device info */
-		EDVDevicesListWinUpdateDisplay(lw, dev_ptr);
+		EDVDevicesListWinUpdateDisplay(lw, dev);
 	    }
 	}
 
@@ -2624,7 +2616,7 @@ edv_device_listwin_struct *EDVDevicesListWinNew(
 	parent3 = w;
 
 	/* Vbox for add, edit, and remove set of buttons */
-	w = gtk_hbox_new(FALSE, 2 * border_minor);
+	w = gtk_hbox_new(FALSE, border_minor);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
