@@ -4,8 +4,8 @@
 #include <time.h>
 #include <sys/time.h>
 #include <signal.h>
-#include <unistd.h>
 #include <gtk/gtk.h>
+#include <unistd.h>
 
 #include "../../include/string.h"
 #include "../../include/fio.h"
@@ -40,8 +40,6 @@
 #include "../images/pdi_folder_32x32.xpm"
 #include "../images/pdi_folderfile_32x32.xpm"
 
-#define DOWNLOAD_PROG	"/usr/bin/wget"
-
 
 static glong CurrentMillitime(void);
 
@@ -361,10 +359,10 @@ static gint DownloadMonitor(
 	);
 
 	/* Format source and target paths for message */
-	p1 = EDVCopyShortenPath(
+	p1 = EDVShortenPath(
 	    src, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX - 10
 	);
-	p2 = EDVCopyShortenPath(
+	p2 = EDVShortenPath(
 	    tar, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX - 10
 	);
 	/* Format initial message */
@@ -1195,7 +1193,7 @@ int main(int argc, char *argv[])
 			download_last_object = FALSE;
 	gint i, status = 0;
 	const gchar *arg_ptr;
-	const gchar *download_prog = DOWNLOAD_PROG;
+	gchar *prog = NULL;
 	gchar *source_url = NULL;
 	gchar *destination_path = NULL;
 	gchar *destination_file = NULL;
@@ -1209,6 +1207,8 @@ int main(int argc, char *argv[])
   ctx = NULL;				\
  }					\
 					\
+ g_free(prog);				\
+ prog = NULL;				\
  g_free(source_url);			\
  source_url = NULL;			\
  g_free(destination_path);		\
@@ -2000,44 +2000,77 @@ do not want to download the object then click on \"Cancel\".",
 	    }
 	}
 
-	/* Check if the download program does not exist */
-	if(access(download_prog, F_OK))
+	/* Get the GNU WGet program */
+	prog = EDVWhich(WGET_PROG);
+	if(prog == NULL)
 	{
 	    gchar *buf = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Incapaz de encontrar el programa de la descarga:\n\
 \n\
-    %s\n"
+    %s\n\
+\n\
+Verifique por favor que el programa es instalado en una\n\
+ubicacion especificada por el ambiente de %s y que\n\
+es ejecutable por este programa.",
 #elif defined(PROG_LANGUAGE_FRENCH)
 "Incapable de trouver le programme de chargement:\n\
 \n\
-    %s\n"
+    %s\n\
+\n\
+S'il vous plait verifier que le programme est installe\n\
+a un emplacement spe'cifie' par l'environnement de\n\
+%s et que c'est realisable par ce programme.",
 #elif defined(PROG_LANGUAGE_GERMAN)
-"Unfhig, zu finden, programm ldt:\n\
+"Unfahig, das downloadprogramm zu finden:\n\
 \n\
-    %s\n"
+    %s\n\
+\n\
+Bitte beglaubigt, dass das programm von der %s umwelt\n\
+an einem ort installiert wird, der und angegeben wird,\n\
+dass es ausfuhrbar durch dieses programm ist.",
 #elif defined(PROG_LANGUAGE_ITALIAN)
-"Incapace per trovare scarica il programma:\n\
+"Incapace per trovare lo scarica il programma:\n\
 \n\
-    %s\n"
+    %s\n\
+\n\
+Per favore di verificare che il programma e installato a\n\
+una posizione specificata dall'ambiente di %s e che\n\
+e eseguibile da questo programma.",
 #elif defined(PROG_LANGUAGE_DUTCH)
-"Onbekwaam te vinden programma downloadt:\n\
+"Onbekwaam om het te vinden downloadt programma:\n\
 \n\
-    %s\n"
+    %s\n\
+\n\
+Bevestigt u alstublieft dat het programma door de %s\n\
+omgeving aan een locatie wordt geinstalleerd die door dit\n\
+programma gespecificeerd wordt en dat het uitvoerbaar is.",
 #elif defined(PROG_LANGUAGE_PORTUGUESE)
-"Incapaz de achar programa de download:\n\
+"Incapaz de achar o programa de download:\n\
 \n\
-    %s\n"
+    %s\n\
+\n\
+Por favor verifique-se que o programa e instalado numa\n\
+situacao especificado pelo ambiente de %s e que e\n\
+executable por este programa.",
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
-"Maktesls finne download program:\n\
+"Maktesl?s finne download program:\n\
 \n\
-    %s\n"
+    %s\n\
+\n\
+Ver sa snill og bekreft at programet installerer pa en\n\
+plassering spesifisert ved %s miljo og at det er\n\
+gjennomforbar ved dette programet.",
 #else
-"Unable to find download program:\n\
+"Unable to find the download program:\n\
 \n\
-    %s\n"
+    %s\n\
+\n\
+Please verify that the program is installed at a location\n\
+specified by the %s environment and that it is\n\
+executable by this program.",
 #endif
-		, download_prog
+		WGET_PROG, ENV_VAR_NAME_PATH
 	    );
 	    CDialogSetTransientFor(NULL);
 	    CDialogGetResponse(
@@ -2117,13 +2150,13 @@ objects.\n",
 	{
 	    gchar *cmd = g_strdup_printf(
 		"\"%s\" \"%s\" --tries=1 --progress=dot -c",
-		download_prog, source_url
+		prog, source_url
 	    );
 	    /* Execute the download command
 	     *
 	     * Note that wget writes stdout output to stderr
 	     */
-	    gint p = ExecOE(cmd, NULL, stdout_file);
+	    const gint p = ExecOE(cmd, NULL, stdout_file);
 	    if(p <= 0)
 	    {
 		/* Unable to execute download command */
