@@ -1,13 +1,13 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/types.h>
 #include <ctype.h>
 #include <time.h>
 #include <errno.h>
-#include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
 #include <glib.h>
+#include <unistd.h>
 
 #include "../include/string.h"
 #include "../include/fio.h"
@@ -1414,13 +1414,13 @@ static void EDVArchFIOParseLineRPM(
 
 	    len = (gint)(buf_ptr - s);
 
-	    g_free(obj->linked_to);
-	    obj->linked_to = (gchar *)g_malloc(
+	    g_free(obj->link_value);
+	    obj->link_value = (gchar *)g_malloc(
 		(len + 1) * sizeof(gchar)
 	    );
 	    if(len > 0)
-		strncpy((char *)obj->linked_to, (const char *)s, len);
-	    obj->linked_to[len] = '\0';
+		strncpy((char *)obj->link_value, (const char *)s, len);
+	    obj->link_value[len] = '\0';
 
 	    while(ISSPACE(*buf_ptr))
 		buf_ptr++;
@@ -1712,13 +1712,13 @@ lrwxrwxrwx root/root   0 2001-11-19 02:57 file.ext -> link.dest
 
 	    len = (gint)(buf_ptr - s);
 
-	    g_free(obj->linked_to);
-	    obj->linked_to = (gchar *)g_malloc(
+	    g_free(obj->link_value);
+	    obj->link_value = (gchar *)g_malloc(
 		(len + 1) * sizeof(gchar)
 	    );
 	    if(len > 0)
-		strncpy((char *)obj->linked_to, (const char *)s, len);
-	    obj->linked_to[len] = '\0';
+		strncpy((char *)obj->link_value, (const char *)s, len);
+	    obj->link_value[len] = '\0';
 
 	    while(ISSPACE(*buf_ptr))
 		buf_ptr++;
@@ -2605,8 +2605,10 @@ edv_archive_object_struct *EDVArchFIOStat(
 	/* Get archive stats and making sure it is a file */
 	if(stat((const char *)arch_obj, &stat_buf))
 	    return(obj);
+#ifdef S_ISREG
 	if(!S_ISREG(stat_buf.st_mode))
 	    return(obj);
+#endif
 
 	/* Get stats by the archive's extension */
 
@@ -3631,8 +3633,10 @@ edv_archive_object_struct **EDVArchFIOGetListing(
 	/* Get archive stats and make sure it is a file */
 	if(stat((const char *)arch_obj, &stat_buf))
 	    return(list);
+#ifdef S_ISREG
 	if(!S_ISREG(stat_buf.st_mode))
 	    return(list);
+#endif
 
 	/* Get listing by the archive's extension */
 
@@ -4154,8 +4158,10 @@ gchar **EDVArchFIOGetComment(
 	/* Get archive stats and make sure it is a file */
 	if(stat(arch_obj, &stat_buf))
 	    return(strv);
+#ifdef S_ISREG
 	if(!S_ISREG(stat_buf.st_mode))
 	    return(strv);
+#endif
 
 	/* Get comment by the archive's extension */
 
@@ -4403,8 +4409,10 @@ gint EDVArchFIOSetComment(
 	/* Get archive stats and make sure it is a file */
 	if(stat(arch_obj, &stat_buf))
 	    return(-1);
+#ifdef S_ISREG
 	if(!S_ISREG(stat_buf.st_mode))
 	    return(-1);
+#endif
 
 	/* Generate comment line */
 	comment = NULL;
