@@ -10,25 +10,21 @@
 #include <sys/stat.h>
 #include <glib.h>
 #include "edvtypes.h"
-#include "edvobj.h"
 
 /*
  *	Archive Object:
  */
 typedef struct {
 
-	edv_object_type	type;		/* One of EDV_OBJECT_TYPE_* */
+	edv_object_type	type;
 
 	gchar		*name;
 	gchar		*full_path;	/* This is not always an absolute
 					 * path, because paths stored in
 					 * the archive are not always
-					 * absolute paths
-					 */
+					 * absolute paths */
 
-	gchar		*linked_to;	/* Link destination, only for type
-					 * EDV_OBJECT_TYPE_LINK
-					 */
+	gchar		*link_value;	/* Only for EDV_OBJECT_TYPE_LINK */
 
 	edv_permission_flags	permissions;	/* Any of EDV_PERMISSION_* */
 
@@ -47,14 +43,12 @@ typedef struct {
 					 * of EDV_OBJECT_TYPE_DEVICE_*
 					 *
 					 * Use EDVGetDeviceNumbers() to parse
-					 * this value casted as a dev_t
-					 */
+					 * this value casted as a dev_t */
 
 	gboolean	encrypted;
 
 	gfloat		compression_ratio;	/* 0.0 = not compressed
-						 * 1.0 = total compression
-						 */
+						 * 1.0 = total compression */
 
 	gchar		*method;	/* Method of storage */
 	gchar		*crc;		/* CRC checksum */
