@@ -60,6 +60,7 @@ void EDVSignalCB(int s);
 
 /* Timeout Callbacks */
 gint EDVManageTimeoutCB(gpointer data);
+gint EDVCheckDevicesCB(gpointer data);
 
 /* New/Map Window Callbacks */
 void EDVNewBrowserCB(GtkWidget *widget, gpointer data);
@@ -139,7 +140,7 @@ void EDVObjectRemovedEmit(
 /* Mount/Unmount Emitters */
 void EDVObjectMountEmit(
 	edv_core_struct *core_ptr,
-	gint dev_num, edv_device_struct *dev_ptr,
+	gint dev_num, edv_device_struct *dev,
 	gboolean is_mounted
 );
 
@@ -185,11 +186,11 @@ void EDVMimeTypeRemovedEmit(
 /* Device Emitters */
 void EDVDeviceAddedEmit(
 	edv_core_struct *core_ptr,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 );
 void EDVDeviceModifiedEmit(
 	edv_core_struct *core_ptr,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 );
 void EDVDeviceRemovedEmit(
 	edv_core_struct *core_ptr, gint dev_num
@@ -502,7 +503,7 @@ gint EDVManageTimeoutCB(gpointer data)
 		if(deviceswin->processing)
 		    still_processing = TRUE;
 	    }
-	    /* MIME Types List Window */
+	    /* MIME Types Window */
 	    mimetypeswin = core_ptr->mimetype_listwin;
 	    if(mimetypeswin != NULL)
 	    {
@@ -750,7 +751,7 @@ gint EDVManageTimeoutCB(gpointer data)
 		deviceswin = NULL;
 	    }
 	}
-	/* MIME Types List Window */
+	/* MIME Types Window */
 	mimetypeswin = core_ptr->mimetype_listwin;
 	if(mimetypeswin != NULL)
 	{
@@ -869,6 +870,47 @@ gint EDVManageTimeoutCB(gpointer data)
 }
 
 
+/*
+ *	Check devices timeout callback.
+ */
+gint EDVCheckDevicesCB(gpointer data)
+{
+	gboolean last_mount_state;
+	gint i;
+	edv_device_struct *d;
+        edv_core_struct *core_ptr = EDV_CORE(data);
+        if(core_ptr == NULL)                       
+            return(FALSE);
+
+/* TODO */
+
+	/* Iterate through each device */
+	for(i = 0; i < core_ptr->total_devices; i++)
+	{
+	    d = core_ptr->device[i];
+	    if(d == NULL)
+		continue;
+
+	    /* Record previous mount state */
+	    last_mount_state = EDV_DEVICE_IS_MOUNTED(d);
+
+	    /* Get current mount state */
+	    EDVDeviceUpdateMountState(d);
+
+	    /* Change in mount state? */
+	    if(EDV_DEVICE_IS_MOUNTED(d) != last_mount_state)
+	    {
+		/* Report mount/unmount */
+		EDVObjectMountEmit(core_ptr, i, d, EDV_DEVICE_IS_MOUNTED(d));
+	    }
+	}
+
+
+
+	return(TRUE);
+}
+
+
 /*
  *	New File Browser callback.
  */
@@ -1424,7 +1466,7 @@ void EDVWriteProtectChangedEmit(
 
 	/* Begin emitting signal */
 
-	/* Browsers */
+	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserWriteProtectChangedCB(
 		core_ptr->browser[i], state
@@ -1483,7 +1525,7 @@ void EDVObjectAddedEmit(
 
 	/* Begin emitting signal */
 
-	/* Browsers */
+	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserObjectAddedNotifyCB(
 		core_ptr->browser[i], dpath, lstat_buf
@@ -1523,7 +1565,7 @@ void EDVObjectModifiedEmit(
 
 	/* Begin emitting signal */
 
-	/* Browsers */
+	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserObjectModifiedNotifyCB(
 		core_ptr->browser[i], dpath, new_path, lstat_buf
@@ -1569,7 +1611,7 @@ void EDVObjectRemovedEmit(edv_core_struct *core_ptr, const gchar *path)
 
 	/* Begin emitting signal */
 
-	/* Browsers */
+	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserObjectRemovedNotifyCB(
 		core_ptr->browser[i], dpath
@@ -1602,7 +1644,7 @@ void EDVObjectRemovedEmit(edv_core_struct *core_ptr, const gchar *path)
  */
 void EDVObjectMountEmit(
 	edv_core_struct *core_ptr,
-	gint dev_num, edv_device_struct *dev_ptr,
+	gint dev_num, edv_device_struct *dev,
 	gboolean is_mounted
 )
 {
@@ -1615,25 +1657,25 @@ void EDVObjectMountEmit(
 
 	/* Devices list window */
 	EDVDevicesListWinMountNotifyCB(
-	    core_ptr->device_listwin, dev_num, dev_ptr, is_mounted
+	    core_ptr->device_listwin, dev_num, dev, is_mounted
 	);
 
-	/* Browsers */
+	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserMountNotifyCB(
-		core_ptr->browser[i], dev_num, dev_ptr, is_mounted
+		core_ptr->browser[i], dev_num, dev, is_mounted
 	    );
 
 	/* Image Browsers */
 	for(i = 0; i < core_ptr->total_imbrs; i++)
 	    EDVImbrMountNotifyCB(
-		core_ptr->imbr[i], dev_num, dev_ptr, is_mounted
+		core_ptr->imbr[i], dev_num, dev, is_mounted
 	    );
 
 	/* Property Dialogs */
 	for(i = 0; i < core_ptr->total_propdlgs; i++)
 	    EDVPropDlgMountNotifyCB(
-		core_ptr->propdlg[i], dev_num, dev_ptr, is_mounted
+		core_ptr->propdlg[i], dev_num, dev, is_mounted
 	    );
 }
 
@@ -1769,7 +1811,7 @@ void EDVRecycledObjectAddedEmit(
 
 	/* Begin emitting signal */
 
-	/* Browsers */
+	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserRecycledObjectAddedNotifyCB(
 		core_ptr->browser[i], index
@@ -1842,7 +1884,7 @@ void EDVRecycledObjectRemovedEmit(
 
 	/* Begin emitting signal */
 
-	/* Browsers */
+	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserRecycledObjectRemovedNotifyCB(
 		core_ptr->browser[i], index
@@ -1955,7 +1997,7 @@ void EDVReconfiguredEmit(edv_core_struct *core_ptr)
 	    core_ptr->device_listwin
 	);
 
-	/* MIME Types List Window */
+	/* MIME Types Window */
 	EDVMimeTypesListWinReconfiguredNotifyCB(
 	    core_ptr->mimetype_listwin
 	);
@@ -1989,12 +2031,12 @@ void EDVMimeTypeAddedEmit(
 
 	/* Begin emitting signal */
 
-	/* Mime Types list window */
+	/* MIME Types Window */
 	EDVMimeTypesListWinMimeTypeAddedCB(
 	    core_ptr->mimetype_listwin, mt_num, mt_ptr
 	);
 
-	/* Browsers */
+	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserMimeTypeAddedCB(
 		core_ptr->browser[i], mt_num, mt_ptr
@@ -2044,12 +2086,12 @@ void EDVMimeTypeModifiedEmit(
 
 	/* Begin emitting signal */
 
-	/* MIME Types list window */
+	/* MIME Types Window */
 	EDVMimeTypesListWinMimeTypeModifiedCB(
 	    core_ptr->mimetype_listwin, mt_num, mt_ptr
 	);
 
-	/* Browsers */
+	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserMimeTypeModifiedCB(
 		core_ptr->browser[i], mt_num, mt_ptr
@@ -2099,12 +2141,12 @@ void EDVMimeTypeRemovedEmit(
 
 	/* Begin emitting signal */
 
-	/* MIME Types list window */
+	/* MIME Types Window */
 	EDVMimeTypesListWinMimeTypeRemovedCB(
 	    core_ptr->mimetype_listwin, mt_num
 	);
 
-	/* Browsers */
+	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserMimeTypeRemovedCB(
 		core_ptr->browser[i], mt_num
@@ -2134,7 +2176,7 @@ void EDVMimeTypeRemovedEmit(
  */
 void EDVDeviceAddedEmit(
 	edv_core_struct *core_ptr,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 )
 {
 	gint i;
@@ -2142,7 +2184,7 @@ void EDVDeviceAddedEmit(
 	if(core_ptr == NULL)
 	    return;
 
-	/* Reget devices list on devices popup list widget */
+	/* Update the Devices Popup List */
 	EDVUpdateDevicesPUList(core_ptr);
 
 
@@ -2150,19 +2192,19 @@ void EDVDeviceAddedEmit(
 
 	/* Devices list window */
 	EDVDevicesListWinDeviceAddedCB(
-	    core_ptr->device_listwin, dev_num, dev_ptr
+	    core_ptr->device_listwin, dev_num, dev
 	);
 
-	/* Browsers */
+	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserDeviceAddedCB(
-		core_ptr->browser[i], dev_num, dev_ptr
+		core_ptr->browser[i], dev_num, dev
 	    );
 
 	/* Image Browsers */
 	for(i = 0; i < core_ptr->total_imbrs; i++)
 	    EDVImbrDeviceAddedCB(
-		core_ptr->imbr[i], dev_num, dev_ptr
+		core_ptr->imbr[i], dev_num, dev
 	    );
 }
 
@@ -2171,7 +2213,7 @@ void EDVDeviceAddedEmit(
  */
 void EDVDeviceModifiedEmit(
 	edv_core_struct *core_ptr,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 )
 {
 	gint i;
@@ -2179,27 +2221,27 @@ void EDVDeviceModifiedEmit(
 	if(core_ptr == NULL)
 	    return;
 
-	/* Reget devices list on devices popup list widget */
+	/* Update the Devices Popup List */
 	EDVUpdateDevicesPUList(core_ptr);
 
 
 	/* Begin emitting signal */
 
-	/* Devices list window */
+	/* Devices Window */
 	EDVDevicesListWinDeviceModifiedCB(
-	    core_ptr->device_listwin, dev_num, dev_ptr
+	    core_ptr->device_listwin, dev_num, dev
 	);
 
-	/* Browsers */
+	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserDeviceModifiedCB(
-		core_ptr->browser[i], dev_num, dev_ptr
+		core_ptr->browser[i], dev_num, dev
 	    );
 
 	/* Image Browsers */
 	for(i = 0; i < core_ptr->total_imbrs; i++)
 	    EDVImbrDeviceModifiedCB(
-		core_ptr->imbr[i], dev_num, dev_ptr
+		core_ptr->imbr[i], dev_num, dev
 	    );
 }
 
@@ -2215,18 +2257,18 @@ void EDVDeviceRemovedEmit(
 	if(core_ptr == NULL)
 	    return;
 
-	/* Reget devices list on devices popup list widget */
+	/* Update the Devices Popup List */
 	EDVUpdateDevicesPUList(core_ptr);
 
 
 	/* Begin emitting signal */
 
-	/* Devices list window */
+	/* Devices Window */
 	EDVDevicesListWinDeviceRemovedCB(
 	    core_ptr->device_listwin, dev_num
 	);
 
-	/* Browsers */
+	/* File Browsers */
 	for(i = 0; i < core_ptr->total_browsers; i++)
 	    EDVBrowserDeviceRemovedCB(
 		core_ptr->browser[i], dev_num
@@ -2253,7 +2295,7 @@ void EDVHistoryAddedEmit(
 
 	/* Begin emitting signal */
 
-	/* History window */
+	/* History Window */
 	EDVHistoryListWinHistoryAddedCB(
 	    core_ptr->history_listwin,
 	    h_num, h_ptr
@@ -2273,7 +2315,7 @@ void EDVHistoryRemovedEmit(
 
 	/* Begin emitting signal */
 
-	/* History window */
+	/* History Window */
 	EDVHistoryListWinHistoryRemovedCB(
 	    core_ptr->history_listwin,
 	    h_num
