@@ -20,6 +20,7 @@ extern void EDVSignalCB(int s);
 
 /* Timeout Callbacks */
 extern gint EDVManageTimeoutCB(gpointer data);
+extern gint EDVCheckDevicesCB(gpointer data);
 
 /* New/Map Window Callbacks */
 extern void EDVNewBrowserCB(GtkWidget *widget, gpointer data);
@@ -95,7 +96,7 @@ extern void EDVObjectRemovedEmit(
 /* Mount/Unmount Emitters */
 extern void EDVObjectMountEmit(
 	edv_core_struct *core_ptr,
-	gint dev_num, edv_device_struct *dev_ptr,
+	gint dev_num, edv_device_struct *dev,
 	gboolean is_mounted
 );
 
@@ -141,11 +142,11 @@ extern void EDVMimeTypeRemovedEmit(
 /* Device Emitters */
 extern void EDVDeviceAddedEmit(
 	edv_core_struct *core_ptr,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 );
 extern void EDVDeviceModifiedEmit(
 	edv_core_struct *core_ptr,
-	gint dev_num, edv_device_struct *dev_ptr
+	gint dev_num, edv_device_struct *dev
 );
 extern void EDVDeviceRemovedEmit(
 	edv_core_struct *core_ptr, gint dev_num
