@@ -1,7 +1,14 @@
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 #include <gtk/gtk.h>
+#if defined(_WIN32)
+# include <gdk/gdkwin32.h>
+# define HAVE_WIN32
+#else
+# include <gdk/gdkx.h>
+# define HAVE_X
+#endif
+#include <unistd.h>
 
 #include "../include/string.h"
 #include "../include/disk.h"
@@ -15,11 +22,11 @@
 #include "edvtypes.h"
 #include "edvid.h"
 #include "edvpixmap.h"
+#include "edvcursor.h"
 #include "edvobj.h"
 #include "edvrecbin.h"
 #include "edvdate.h"
 #include "edvhistory.h"
-#include "edvcursor.h"
 #include "edvobj.h"
 #include "edvrecbinfio.h"
 #include "edvdevices.h"
@@ -40,10 +47,15 @@
 #include "edvinterps.h"
 #include "edvutils.h"
 #include "edvutilsgtk.h"
+
+#define NEED_EDV_CFG_LIST_SOURCE
 #include "edvcfglist.h"
 #include "config.h"
 
 
+static GList *g_list_new_length(guint length, gpointer datas);
+static void g_list_set_nth_data(GList *glist, guint n, gpointer data);
+
 static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr);
 static void EDVDoCreateStandardCursors(edv_core_struct *core_ptr);
 
@@ -68,6 +80,31 @@ void EDVDelete(
 #define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
+/*
+ *	Creates a new GList of the specified length.
+ */
+static GList *g_list_new_length(guint length, gpointer datas)
+{
+	gint i;
+	GList *glist = NULL;
+
+	for(i = 0; i < length; i++)
+	    glist = g_list_append(glist, datas);
+
+	return(glist);
+}
+
+/*
+ *	Sets the data of the nth item in the GList.
+ */
+static void g_list_set_nth_data(GList *glist, guint n, gpointer data)
+{
+	glist = g_list_nth(glist, n);
+	if(glist != NULL)
+	    glist->data = data;
+}
+
+
 /*
  *      Sets configuration values on the given core structure to their
  *	default values.
@@ -78,9 +115,12 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 		*tmp_dir,
 		*home_dir,
 		*global_data_dir,
-		*local_data_dir;
-	cfg_color_struct *color;
+		*local_data_dir,
+		*global_config_dir;
+	GList *glist;
 	cfg_intlist_struct *intlist;
+	cfg_color_struct *color;
+	cfg_accelkey_list_struct *ak_list;
 	const cfg_item_struct src_cfg_list[] = EDV_CONFIGURATION_LIST;
 	cfg_item_struct *cfg_list;
 
@@ -113,11 +153,16 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	    home_dir, EDV_DEF_LOCAL_DATA_DIR
 	));
 
+	/* Global Configuration Directory */
+	global_config_dir = STRDUP(EDV_DEF_GLOBAL_CONFIG_DIR);
+
 	/* Tempory Directory */
-	tmp_dir = STRDUP(getenv("TMPDIR"));
+	tmp_dir = STRDUP(g_getenv(ENV_VAR_NAME_TMPDIR));
 	if(tmp_dir == NULL)
-#ifdef P_tmpdir
+#if defined(P_tmpdir)
 	    tmp_dir = STRDUP(P_tmpdir);
+#elif defined(_WIN32)
+	    tmp_dir = STRDUP("C:\\TEMP");
 #else
 	    tmp_dir = STRDUP("/tmp");
 #endif
@@ -134,6 +179,7 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	EDV_SET_S(EDV_CFG_PARM_DIR_START_UP, startup_dir);
 	EDV_SET_S(EDV_CFG_PARM_DIR_GLOBAL, global_data_dir);
 	EDV_SET_S(EDV_CFG_PARM_DIR_LOCAL, local_data_dir);
+	EDV_SET_S(EDV_CFG_PARM_DIR_GLOBAL_CONFIG, global_config_dir);
 	EDV_SET_S(EDV_CFG_PARM_DIR_TMP, tmp_dir);
 
 	/* Files */
@@ -143,10 +189,17 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	    PrefixPaths(local_data_dir, EDV_DEF_RECYCLED_INDEX_FILE)
 	);
 	/* MIME Types (Local) */
+#if defined(DEBIAN)
+        EDV_SET_S(              
+            EDV_CFG_PARM_FILE_MIME_TYPES,
+            PrefixPaths(global_config_dir, EDV_DEF_MIMETYPES_FILE)
+        );
+#else
 	EDV_SET_S(
 	    EDV_CFG_PARM_FILE_MIME_TYPES,
 	    PrefixPaths(local_data_dir, EDV_DEF_MIMETYPES_FILE)
 	);
+#endif
 	/* MIME Types (Global) */
 	EDV_SET_S(
 	    EDV_CFG_PARM_FILE_MIME_TYPES_GLOBAL,
@@ -185,7 +238,7 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 
 	/* Programs */
 	/* Default Viewer */
-	EDV_SET_S(EDV_CFG_PARM_PROG_DEF_VIEWER, EDV_DEF_VIEWER_PROG); 
+	EDV_SET_S(EDV_CFG_PARM_PROG_DEF_VIEWER, EDV_DEF_VIEWER_CMD);
 	/* Terminal */
 	EDV_SET_S(EDV_CFG_PARM_PROG_TERMINAL, EDV_DEF_TERMINAL_PROG);
 	/* Run In Terminal Command */
@@ -350,27 +403,24 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	EDV_SET_B(EDV_CFG_PARM_BROWSER_SHOW_STATUS_BAR, TRUE);
 
 	/* Tool Bar */
-	intlist = CFGIntListNew(NULL, 15);
-	if((intlist != NULL) ? (intlist->i != NULL) : FALSE)
-	{
-	    gint *v = intlist->i;
-	    v[0] = EDV_BROWSER_OP_NEW_FILE;
-	    v[1] = EDV_BROWSER_OP_NEW_DIRECTORY;
-	    v[2] = EDV_BROWSER_OP_NEW_LINK;
-	    v[3] = EDV_BROWSER_OP_SEPARATOR;
-	    v[4] = EDV_BROWSER_OP_MOVE;
-	    v[5] = EDV_BROWSER_OP_COPY;
-	    v[6] = EDV_BROWSER_OP_RENAME;
-	    v[7] = EDV_BROWSER_OP_DELETE;
-	    v[8] = EDV_BROWSER_OP_PROPERTIES;
-	    v[9] = EDV_BROWSER_OP_SEPARATOR;
-	    v[10] = EDV_BROWSER_OP_REFRESH;
-	    v[11] = EDV_BROWSER_OP_SEPARATOR;
-	    v[12] = EDV_BROWSER_OP_NEW_BROWSER;
-	    v[13] = EDV_BROWSER_OP_NEW_IMBR;
-	    v[14] = EDV_BROWSER_OP_RECYCLE_BIN;
-	    EDV_SET_INTLIST(EDV_CFG_PARM_BROWSER_TOOL_BAR, intlist);
-	}
+	glist = NULL;
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_GOTO_PARENT);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_GOTO_HOME);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_DIRECTORY_TREE_ORIGIN);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_REFRESH);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_MOVE);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_COPY);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_RENAME);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_DELETE);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_PROPERTIES);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_NEW_BROWSER);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_NEW_IMBR);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_OP_RECYCLE_BIN);
+	intlist = CFGIntListNew(glist);
+	g_list_free(glist);
+	EDV_SET_INTLIST(EDV_CFG_PARM_BROWSER_TOOL_BAR, intlist);
 	CFGIntListDelete(intlist);
 
 	EDV_SET_I(
@@ -388,46 +438,77 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	EDV_SET_B(EDV_CFG_PARM_BROWSER_CONTENTS_HIDE_LINK_PERMISSIONS, FALSE);
 
 	/* Browser Contents Columns */
-	intlist = CFGIntListNew(NULL, 9);
-	if((intlist != NULL) ? (intlist->i != NULL) : FALSE)
-	{
-	    gint *v = intlist->i;
-	    v[0] = EDV_BROWSER_COLUMN_TYPE_NAME;
-	    v[1] = EDV_BROWSER_COLUMN_TYPE_SIZE;
-	    v[2] = EDV_BROWSER_COLUMN_TYPE_TYPE;
-	    v[3] = EDV_BROWSER_COLUMN_TYPE_PERMISSIONS;
-	    v[4] = EDV_BROWSER_COLUMN_TYPE_OWNER;
-	    v[5] = EDV_BROWSER_COLUMN_TYPE_GROUP;
-	    v[6] = EDV_BROWSER_COLUMN_TYPE_DATE_MODIFIED;
-	    v[7] = EDV_BROWSER_COLUMN_TYPE_HARD_LINKS;
-	    v[8] = EDV_BROWSER_COLUMN_TYPE_LINKED_TO;
-	    EDV_SET_INTLIST(EDV_CFG_PARM_BROWSER_CONTENTS_COLUMN, intlist);
-	}
+	glist = NULL;
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_COLUMN_TYPE_NAME);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_COLUMN_TYPE_SIZE);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_COLUMN_TYPE_TYPE);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_COLUMN_TYPE_PERMISSIONS);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_COLUMN_TYPE_OWNER);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_COLUMN_TYPE_GROUP);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_COLUMN_TYPE_DATE_MODIFIED);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_COLUMN_TYPE_HARD_LINKS);
+	glist = g_list_append(glist, (gpointer)EDV_BROWSER_COLUMN_TYPE_LINKED_TO);
+	intlist = CFGIntListNew(glist);
+	g_list_free(glist);
+	EDV_SET_INTLIST(EDV_CFG_PARM_BROWSER_CONTENTS_COLUMN, intlist);
 	CFGIntListDelete(intlist);
 
 	/* Browser Contents Column Widths */
-	intlist = CFGIntListNew(NULL, EDV_BROWSER_CONTENTS_CLIST_COLUMNS_MAX);
-	if((intlist != NULL) ? (intlist->i != NULL) : FALSE)
-	{
-	    gint *v = intlist->i;
-	    v[EDV_BROWSER_COLUMN_TYPE_NAME] = 150;
-	    v[EDV_BROWSER_COLUMN_TYPE_SIZE] = 70;
-	    v[EDV_BROWSER_COLUMN_TYPE_TYPE] = 100;
-	    v[EDV_BROWSER_COLUMN_TYPE_PERMISSIONS] = 80;
-	    v[EDV_BROWSER_COLUMN_TYPE_OWNER] = 80;
-	    v[EDV_BROWSER_COLUMN_TYPE_GROUP] = 80;
-	    v[EDV_BROWSER_COLUMN_TYPE_DATE_ACCESS] = 120;
-	    v[EDV_BROWSER_COLUMN_TYPE_DATE_MODIFIED] = 120;
-	    v[EDV_BROWSER_COLUMN_TYPE_DATE_CHANGED] = 120;
-	    v[EDV_BROWSER_COLUMN_TYPE_HARD_LINKS] = 70;
-	    v[EDV_BROWSER_COLUMN_TYPE_LINKED_TO] = 150;
-	    v[EDV_BROWSER_COLUMN_TYPE_DEVICE] = 60;
-	    v[EDV_BROWSER_COLUMN_TYPE_INODE] = 70;
-	    v[EDV_BROWSER_COLUMN_TYPE_DEVICE_TYPE] = 90;
-	    v[EDV_BROWSER_COLUMN_TYPE_BLOCK_SIZE] = 80;
-	    v[EDV_BROWSER_COLUMN_TYPE_BLOCKS] = 60;
-	    EDV_SET_INTLIST(EDV_CFG_PARM_BROWSER_CONTENTS_COLUMN_WIDTH, intlist);
-	}
+	glist = g_list_new_length(
+	    EDV_BROWSER_CONTENTS_CLIST_COLUMNS_MAX,
+	    (gpointer)0
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_NAME, (gpointer)150
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_SIZE, (gpointer)70
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_TYPE, (gpointer)100
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_PERMISSIONS, (gpointer)80
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_OWNER, (gpointer)80
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_GROUP, (gpointer)80
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_DATE_ACCESS, (gpointer)120
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_DATE_MODIFIED, (gpointer)120
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_DATE_CHANGED, (gpointer)120
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_HARD_LINKS, (gpointer)70
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_LINKED_TO, (gpointer)150
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_DEVICE, (gpointer)60
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_INODE, (gpointer)70
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_DEVICE_TYPE, (gpointer)90
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_BLOCK_SIZE, (gpointer)80
+	);
+	g_list_set_nth_data(glist,
+	    EDV_BROWSER_COLUMN_TYPE_BLOCKS, (gpointer)60
+	);
+	intlist = CFGIntListNew(glist);
+	g_list_free(glist);
+	EDV_SET_INTLIST(EDV_CFG_PARM_BROWSER_CONTENTS_COLUMN_WIDTH, intlist);
 	CFGIntListDelete(intlist);
 
 	/* Show Hidden Objects */
@@ -435,6 +516,11 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	/* Show No Access Objects */
 	EDV_SET_B(EDV_CFG_PARM_BROWSER_SHOW_OBJECT_NOACCESS, TRUE);
 
+	/* Accelerator Keys */
+	ak_list = EDVBrowserAccelkeysListNewDefault();
+	EDV_SET_ACCELKEY_LIST(EDV_CFG_PARM_BROWSER_ACCELERATOR_KEYS, ak_list);
+	CFGAccelkeyListDelete(ak_list);
+
 
 	/* Image Browser Geometry */
 	EDV_SET_I(EDV_CFG_PARM_IMBR_X, 0);
@@ -453,26 +539,25 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	EDV_SET_B(EDV_CFG_PARM_IMBR_SHOW_STATUS_BAR, TRUE);
 
 	/* Tool Bar */
-	intlist = CFGIntListNew(NULL, 14);
-	if((intlist != NULL) ? (intlist->i != NULL) : FALSE)
-	{
-	    gint *v = intlist->i;
-	    v[0] = EDV_IMBR_OP_GOTO_PARENT;
-	    v[1] = EDV_IMBR_OP_REFRESH;
-	    v[2] = EDV_IMBR_OP_SEPARATOR;
-	    v[3] = EDV_IMBR_OP_MOVE;
-	    v[4] = EDV_IMBR_OP_COPY;
-	    v[5] = EDV_IMBR_OP_DELETE;
-	    v[6] = EDV_IMBR_OP_PROPERTIES;
-	    v[7] = EDV_IMBR_OP_SEPARATOR;
-	    v[8] = EDV_IMBR_OP_STOP;
-	    v[9] = EDV_IMBR_OP_CONTINUE;
-	    v[10] = EDV_IMBR_OP_SEPARATOR;
-	    v[11] = EDV_IMBR_OP_NEW_BROWSER;
-	    v[12] = EDV_IMBR_OP_NEW_IMBR;
-	    v[13] = EDV_IMBR_OP_RECYCLE_BIN;
-	    EDV_SET_INTLIST(EDV_CFG_PARM_IMBR_TOOL_BAR, intlist);
-	}
+	glist = NULL;
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_GOTO_PARENT);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_GOTO_HOME);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_REFRESH);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_MOVE);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_COPY);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_DELETE);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_PROPERTIES);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_STOP);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_CONTINUE);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_NEW_BROWSER);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_NEW_IMBR);
+	glist = g_list_append(glist, (gpointer)EDV_IMBR_OP_RECYCLE_BIN);
+	intlist = CFGIntListNew(glist);
+	g_list_free(glist);
+	EDV_SET_INTLIST(EDV_CFG_PARM_IMBR_TOOL_BAR, intlist);
 	CFGIntListDelete(intlist);
 
 	EDV_SET_I(
@@ -509,6 +594,28 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	/* Show Non-Image Objects */
 	EDV_SET_B(EDV_CFG_PARM_IMBR_SHOW_OBJECT_NONIMAGE, TRUE);
 
+	/* Accelerator Keys */
+	ak_list = EDVImbrAccelkeysListNewDefault();
+	EDV_SET_ACCELKEY_LIST(EDV_CFG_PARM_IMBR_ACCELERATOR_KEYS, ak_list);
+	CFGAccelkeyListDelete(ak_list);
+
+
+	/* Image Browser Presentation Mode */
+	EDV_SET_B(EDV_CFG_PARM_PRESENTATION_SHOW_NAVIGATOR, TRUE);
+	EDV_SET_S(
+	    EDV_CFG_PARM_PRESENTATION_FONT,
+	    DEF_PRESENTATION_FONT
+	);
+	color = CFGColorNew(1.0f, 1.0f, 1.0f, 1.0f);
+	EDV_SET_COLOR(EDV_CFG_PARM_PRESENTATION_COLOR_FG, color);
+	CFGColorDelete(color);
+	EDV_SET_B(EDV_CFG_PARM_PRESENTATION_COLOR_FG_INVERT, TRUE);
+	color = CFGColorNew(0.0f, 0.0f, 0.5f, 1.0f);
+	EDV_SET_COLOR(EDV_CFG_PARM_PRESENTATION_COLOR_BG, color);
+	CFGColorDelete(color);                                   
+	EDV_SET_I(EDV_CFG_PARM_PRESENTATION_HIDE_POINTER_DELAY, 3);
+	EDV_SET_B(EDV_CFG_PARM_PRESENTATION_SLIDESHOW, FALSE);
+	EDV_SET_I(EDV_CFG_PARM_PRESENTATION_SLIDESHOW_DELAY, 3);
 
 	/* Archiver Geometry */
 	EDV_SET_I(EDV_CFG_PARM_ARCHIVER_X, 0);
@@ -524,22 +631,19 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	EDV_SET_B(EDV_CFG_PARM_ARCHIVER_SHOW_STATUS_BAR, TRUE);
 
 	/* Tool Bar */
-	intlist = CFGIntListNew(NULL, 10);
-	if((intlist != NULL) ? (intlist->i != NULL) : FALSE)
-	{
-	    gint *v = intlist->i;
-	    v[0] = EDV_ARCHIVER_OP_NEW;
-	    v[1] = EDV_ARCHIVER_OP_OPEN;
-	    v[2] = EDV_ARCHIVER_OP_SEPARATOR;
-	    v[3] = EDV_ARCHIVER_OP_ADD;
-	    v[4] = EDV_ARCHIVER_OP_EXTRACT;
-	    v[5] = EDV_ARCHIVER_OP_EXTRACT_ALL;
-	    v[6] = EDV_ARCHIVER_OP_DELETE;
-	    v[7] = EDV_ARCHIVER_OP_SEPARATOR;
-	    v[8] = EDV_ARCHIVER_OP_REFRESH;
-	    v[9] = EDV_ARCHIVER_OP_COMMENT_AND_STATISTICS;
-	    EDV_SET_INTLIST(EDV_CFG_PARM_ARCHIVER_TOOL_BAR, intlist);
-	}
+	glist = NULL;
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_OPEN);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_ADD);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_EXTRACT);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_EXTRACT_ALL);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_DELETE);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_REFRESH);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_OP_COMMENT_AND_STATISTICS);
+	intlist = CFGIntListNew(glist);
+	g_list_free(glist);
+	EDV_SET_INTLIST(EDV_CFG_PARM_ARCHIVER_TOOL_BAR, intlist);
 	CFGIntListDelete(intlist);
 
 	EDV_SET_I(
@@ -555,47 +659,83 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	EDV_SET_B(EDV_CFG_PARM_ARCHIVER_CONTENTS_HIDE_LINK_PERMISSIONS, FALSE);
 
 	/* Archiver Contents Columns */
-	intlist = CFGIntListNew(NULL, 8);
-	if((intlist != NULL) ? (intlist->i != NULL) : FALSE)
-	{
-	    gint *v = intlist->i;
-	    v[0] = EDV_ARCHIVER_COLUMN_TYPE_NAME;
-	    v[1] = EDV_ARCHIVER_COLUMN_TYPE_SIZE;
-	    v[2] = EDV_ARCHIVER_COLUMN_TYPE_TYPE;
-	    v[3] = EDV_ARCHIVER_COLUMN_TYPE_PERMISSIONS;
-	    v[4] = EDV_ARCHIVER_COLUMN_TYPE_OWNER;
-	    v[5] = EDV_ARCHIVER_COLUMN_TYPE_GROUP;
-	    v[6] = EDV_ARCHIVER_COLUMN_TYPE_DATE_MODIFIED;
-	    v[7] = EDV_ARCHIVER_COLUMN_TYPE_LINKED_TO;
-	    EDV_SET_INTLIST(EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN, intlist);
-	}
+	glist = NULL;
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_COLUMN_TYPE_NAME);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_COLUMN_TYPE_SIZE);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_COLUMN_TYPE_TYPE);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_COLUMN_TYPE_PERMISSIONS);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_COLUMN_TYPE_OWNER);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_COLUMN_TYPE_GROUP);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_COLUMN_TYPE_DATE_MODIFIED);
+	glist = g_list_append(glist, (gpointer)EDV_ARCHIVER_COLUMN_TYPE_LINKED_TO);
+	intlist = CFGIntListNew(glist);
+	g_list_free(glist);
+	EDV_SET_INTLIST(EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN, intlist);
 	CFGIntListDelete(intlist);
 
 	/* Archiver Contents Column Widths */
-	intlist = CFGIntListNew(NULL, EDV_ARCHIVER_CONTENTS_CLIST_COLUMNS_MAX);
-	if((intlist != NULL) ? (intlist->i != NULL) : FALSE)
-	{
-	    gint *v = intlist->i;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_NAME] = 150;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_SIZE] = 70;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_COMPRESSED_SIZE] = 70;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_TYPE] = 100;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_PERMISSIONS] = 80;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_OWNER] = 80;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_GROUP] = 80;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_DATE_ACCESS] = 120;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_DATE_MODIFIED] = 120;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_DATE_CHANGED] = 120;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_LOCATION] = 150;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_LINKED_TO] = 150;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_DEVICE_TYPE] = 90;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_COMPRESSION] = 80;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_METHOD] = 80;
-	    v[EDV_ARCHIVER_COLUMN_TYPE_CRC] = 80;
-	    EDV_SET_INTLIST(EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN_WIDTH, intlist);
-	}
+	glist = g_list_new_length(
+	    EDV_ARCHIVER_CONTENTS_CLIST_COLUMNS_MAX,
+	    (gpointer)0
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_NAME, (gpointer)150
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_SIZE, (gpointer)70
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_COMPRESSED_SIZE, (gpointer)70
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_TYPE, (gpointer)100
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_PERMISSIONS, (gpointer)80
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_OWNER, (gpointer)80
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_GROUP, (gpointer)80
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_DATE_ACCESS, (gpointer)120
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_DATE_MODIFIED, (gpointer)120
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_DATE_CHANGED, (gpointer)120
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_LOCATION, (gpointer)150
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_LINKED_TO, (gpointer)150
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_DEVICE_TYPE, (gpointer)90
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_COMPRESSION, (gpointer)80
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_METHOD, (gpointer)80
+	);
+	g_list_set_nth_data(glist,
+	    EDV_ARCHIVER_COLUMN_TYPE_CRC, (gpointer)80
+	);
+	intlist = CFGIntListNew(glist);
+	g_list_free(glist);
+	EDV_SET_INTLIST(EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN_WIDTH, intlist);
 	CFGIntListDelete(intlist);
 
+	/* Accelerator Keys */
+	ak_list = EDVArchiverAccelkeysListNewDefault();
+	EDV_SET_ACCELKEY_LIST(EDV_CFG_PARM_ARCHIVER_ACCELERATOR_KEYS, ak_list);
+	CFGAccelkeyListDelete(ak_list);
+
 
 	/* Recycle Bin Geometry */
 	EDV_SET_I(EDV_CFG_PARM_RECBIN_X, 0);
@@ -613,18 +753,16 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	EDV_SET_B(EDV_CFG_PARM_RECBIN_SHOW_STATUS_BAR, TRUE);
 
 	/* Tool Bar */
-	intlist = CFGIntListNew(NULL, 6);
-	if((intlist != NULL) ? (intlist->i != NULL) : FALSE)
-	{
-	    gint *v = intlist->i;
-	    v[0] = EDV_RECBIN_OP_RECOVER;
-	    v[1] = EDV_RECBIN_OP_SEPARATOR;
-	    v[2] = EDV_RECBIN_OP_PURGE;
-	    v[3] = EDV_RECBIN_OP_PURGE_ALL;
-	    v[4] = EDV_RECBIN_OP_SEPARATOR;
-	    v[5] = EDV_RECBIN_OP_REFRESH;
-	    EDV_SET_INTLIST(EDV_CFG_PARM_RECBIN_TOOL_BAR, intlist);
-	}
+	glist = NULL;
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_RECOVER);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_PURGE);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_PURGE_ALL);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_SEPARATOR);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_OP_REFRESH);
+	intlist = CFGIntListNew(glist);
+	g_list_free(glist);
+	EDV_SET_INTLIST(EDV_CFG_PARM_RECBIN_TOOL_BAR, intlist);
 	CFGIntListDelete(intlist);
 
 	EDV_SET_I(
@@ -640,43 +778,74 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	EDV_SET_B(EDV_CFG_PARM_RECBIN_CONTENTS_HIDE_LINK_PERMISSIONS, FALSE);
 
 	/* Recycle Bin Contents Columns */
-	intlist = CFGIntListNew(NULL, 7);
-	if((intlist != NULL) ? (intlist->i != NULL) : FALSE)
-	{
-	    gint *v = intlist->i;
-	    v[0] = EDV_RECBIN_COLUMN_TYPE_NAME;
-	    v[1] = EDV_RECBIN_COLUMN_TYPE_SIZE;
-	    v[2] = EDV_RECBIN_COLUMN_TYPE_TYPE;
-	    v[3] = EDV_RECBIN_COLUMN_TYPE_PERMISSIONS;
-	    v[4] = EDV_RECBIN_COLUMN_TYPE_OWNER;
-	    v[5] = EDV_RECBIN_COLUMN_TYPE_GROUP;
-	    v[6] = EDV_RECBIN_COLUMN_TYPE_ORIGINAL_LOCATION;
-	    EDV_SET_INTLIST(EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN, intlist);
-	}
+	glist = NULL;
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_COLUMN_TYPE_NAME);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_COLUMN_TYPE_SIZE);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_COLUMN_TYPE_TYPE);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_COLUMN_TYPE_PERMISSIONS);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_COLUMN_TYPE_OWNER);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_COLUMN_TYPE_GROUP);
+	glist = g_list_append(glist, (gpointer)EDV_RECBIN_COLUMN_TYPE_ORIGINAL_LOCATION);
+	intlist = CFGIntListNew(glist);
+	g_list_free(glist);
+	EDV_SET_INTLIST(EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN, intlist);
 	CFGIntListDelete(intlist);
 
 	/* Recycle Bin Contents Column Widths */
-	intlist = CFGIntListNew(NULL, EDV_RECBIN_CONTENTS_CLIST_COLUMNS_MAX);
-	if((intlist != NULL) ? (intlist->i != NULL) : FALSE)  
-	{
-	    gint *v = intlist->i;
-	    v[EDV_RECBIN_COLUMN_TYPE_NAME] = 150;
-	    v[EDV_RECBIN_COLUMN_TYPE_SIZE] = 70;
-	    v[EDV_RECBIN_COLUMN_TYPE_TYPE] = 100;
-	    v[EDV_RECBIN_COLUMN_TYPE_PERMISSIONS] = 80;
-	    v[EDV_RECBIN_COLUMN_TYPE_OWNER] = 80;
-	    v[EDV_RECBIN_COLUMN_TYPE_GROUP] = 80;
-	    v[EDV_RECBIN_COLUMN_TYPE_DATE_ACCESS] = 120;
-	    v[EDV_RECBIN_COLUMN_TYPE_DATE_MODIFIED] = 120;
-	    v[EDV_RECBIN_COLUMN_TYPE_DATE_CHANGED] = 120;
-	    v[EDV_RECBIN_COLUMN_TYPE_DATE_DELETED] = 120;
-	    v[EDV_RECBIN_COLUMN_TYPE_LINKED_TO] = 150;
-	    v[EDV_RECBIN_COLUMN_TYPE_ORIGINAL_LOCATION] = 150;
-	    v[EDV_RECBIN_COLUMN_TYPE_INDEX] = 60;
-	    EDV_SET_INTLIST(EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN_WIDTH, intlist);
-	}
+	glist = g_list_new_length(
+	    EDV_RECBIN_CONTENTS_CLIST_COLUMNS_MAX,
+	    (gpointer)0
+	);
+	g_list_set_nth_data(glist,
+	    EDV_RECBIN_COLUMN_TYPE_NAME, (gpointer)150
+	);
+	g_list_set_nth_data(glist,
+	    EDV_RECBIN_COLUMN_TYPE_SIZE, (gpointer)70
+	);
+	g_list_set_nth_data(glist,
+	    EDV_RECBIN_COLUMN_TYPE_TYPE, (gpointer)100
+	);
+	g_list_set_nth_data(glist,
+	    EDV_RECBIN_COLUMN_TYPE_PERMISSIONS, (gpointer)80
+	);
+	g_list_set_nth_data(glist,
+	    EDV_RECBIN_COLUMN_TYPE_OWNER, (gpointer)80
+	);
+	g_list_set_nth_data(glist,
+	    EDV_RECBIN_COLUMN_TYPE_GROUP, (gpointer)80
+	);
+	g_list_set_nth_data(glist,
+	    EDV_RECBIN_COLUMN_TYPE_DATE_ACCESS, (gpointer)120
+	);
+	g_list_set_nth_data(glist,
+	    EDV_RECBIN_COLUMN_TYPE_DATE_MODIFIED, (gpointer)120
+	);
+	g_list_set_nth_data(glist,
+	    EDV_RECBIN_COLUMN_TYPE_DATE_CHANGED, (gpointer)120
+	);
+	g_list_set_nth_data(glist,
+	    EDV_RECBIN_COLUMN_TYPE_DATE_DELETED, (gpointer)120
+	);
+	g_list_set_nth_data(glist,
+	    EDV_RECBIN_COLUMN_TYPE_LINKED_TO, (gpointer)150
+	);
+	g_list_set_nth_data(glist,
+	    EDV_RECBIN_COLUMN_TYPE_ORIGINAL_LOCATION, (gpointer)150
+	);
+	g_list_set_nth_data(glist,
+	    EDV_RECBIN_COLUMN_TYPE_INDEX, (gpointer)60
+	);
+	intlist = CFGIntListNew(glist);
+	g_list_free(glist);
+	EDV_SET_INTLIST(EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN_WIDTH, intlist);
 	CFGIntListDelete(intlist);
 
+	/* Accelerator Keys */
+	ak_list = EDVRecBinAccelkeysListNewDefault();
+	EDV_SET_ACCELKEY_LIST(EDV_CFG_PARM_RECBIN_ACCELERATOR_KEYS, ak_list);
+	CFGAccelkeyListDelete(ak_list);
+
+
 	/* Find Window Geometry */
 	EDV_SET_I(EDV_CFG_PARM_FINDWIN_X, 0);
 	EDV_SET_I(EDV_CFG_PARM_FINDWIN_Y, 0);
@@ -713,20 +882,19 @@ static void EDVDoCreateStandardConfiguration(edv_core_struct *core_ptr)
 	g_free(home_dir);
 	g_free(global_data_dir);
 	g_free(local_data_dir);
+	g_free(global_config_dir);
 }
 
 /*
- *      Creates a standard list of cursors on the given core structure.
+ *      Creates a standard list of cursors.
  */
 static void EDVDoCreateStandardCursors(edv_core_struct *core_ptr)
 {
-	gint i, cursor_code;
-	GdkCursorType gdk_cursor_type;
-	edv_cursor_struct *cur;
+	GdkWindow *root = GDK_ROOT_PARENT();
+	GdkColor c_fg, c_bg;
 
-
-#define DO_APPEND_CURSOR	{			\
- i = MAX(core_ptr->total_cursors, 0);			\
+#define APPEND_CURSOR(_cursor_)		{		\
+ const gint i = MAX(core_ptr->total_cursors, 0);	\
  core_ptr->total_cursors = i + 1;			\
 							\
  core_ptr->cursor = (edv_cursor_struct **)g_realloc(	\
@@ -735,40 +903,213 @@ static void EDVDoCreateStandardCursors(edv_core_struct *core_ptr)
  );							\
  if(core_ptr->cursor == NULL) {				\
   core_ptr->total_cursors = 0;				\
-  i = -1;						\
-  cur = NULL;						\
+  EDVCursorDelete(_cursor_);				\
  } else {						\
-  core_ptr->cursor[i] = cur = EDVCursorNewByGDKPreset(	\
-   cursor_code, gdk_cursor_type				\
-  );							\
+  core_ptr->cursor[i] = (_cursor_);			\
  }							\
 }
+#define APPEND_CURSOR_PRESET(_code_,_gdk_type_)	{	\
+ edv_cursor_struct *cursor = EDVCursorNewGDKPreset(	\
+  (_code_), (_gdk_type_)				\
+ );							\
+ APPEND_CURSOR(cursor);					\
+}
+#define APPEND_CURSOR_PIXMAP(_code_,_cm_,_tm_,_hx_,_hy_) {	\
+ APPEND_CURSOR(EDVCursorNew(				\
+  (_code_),						\
+  gdk_cursor_new_from_pixmap(				\
+   (_cm_), (_tm_), &c_fg, &c_bg, (_hx_), (_hy_)		\
+  )							\
+ ));							\
+}
 
-	cursor_code = EDV_CURSOR_CODE_BUSY;
-	gdk_cursor_type = GDK_WATCH;
-	DO_APPEND_CURSOR
+	/* Set foreground and background colors */
+	c_fg.red	= 0xffff;
+	c_fg.green	= 0xffff;
+	c_fg.blue	= 0xffff;
+	c_bg.red	= 0x0000;
+	c_bg.green	= 0x0000;
+	c_bg.blue	= 0x0000;
 
-	cursor_code = EDV_CURSOR_CODE_TEXT;
-	gdk_cursor_type = GDK_XTERM;
-	DO_APPEND_CURSOR
+	/* Begin creating cursors */
 
-	cursor_code = EDV_CURSOR_CODE_TRANSLATE;
-	gdk_cursor_type = GDK_FLEUR;
-	DO_APPEND_CURSOR
+	if(FALSE)
+	{
+	    const gint width = 20, height = 20;
+	    const gchar color_mask_data[] = {
+0x00, 0x00, 0x00,
+0xfe, 0x03, 0x00,
+0x00, 0x00, 0x00,
+0xfc, 0x01, 0x00,
+0xfc, 0x01, 0x00,
+0xac, 0x01, 0x00,
+0xd8, 0x00, 0x00,
+0x70, 0x00, 0x00,
+0x20, 0x00, 0x00,
+0x50, 0x00, 0x00,
+0xf8, 0x00, 0x00,
+0xdc, 0x01, 0x00,
+0xac, 0x01, 0x00,
+0x54, 0x01, 0x00,
+0x00, 0x00, 0x00,
+0xfe, 0x03, 0x00,
+0x00, 0x00, 0x00,
+0x00, 0x00, 0x00,
+0x00, 0x00, 0x00,
+0x00, 0x00, 0x00
+	    };  
+	    const gchar trans_mask_data[] = {
+0xff, 0x07, 0x00,
+0xff, 0x07, 0x00,
+0xff, 0x07, 0x00,
+0xfe, 0x03, 0x00,
+0xfe, 0x03, 0x00,
+0xfe, 0x03, 0x00,
+0xfc, 0x01, 0x00,
+0xf8, 0x00, 0x00,
+0x70, 0x00, 0x00,
+0xf8, 0x00, 0x00,
+0xfc, 0x01, 0x00,
+0xfe, 0x03, 0x00,
+0xfe, 0x03, 0x00,
+0xfe, 0x03, 0x00,
+0xff, 0x07, 0x00,
+0xff, 0x07, 0x00,
+0xff, 0x07, 0x00,
+0x00, 0x00, 0x00,
+0x00, 0x00, 0x00,
+0x00, 0x00, 0x00
+	    };
+	    GdkBitmap *color_mask = gdk_bitmap_create_from_data(
+		root, color_mask_data, width, height
+	    );
+	    GdkBitmap *trans_mask = gdk_bitmap_create_from_data(
+		root, trans_mask_data, width, height
+	    );
+	    APPEND_CURSOR_PIXMAP(
+		EDV_CURSOR_CODE_BUSY,
+		color_mask, trans_mask, 5, 8
+	    );
+	    GDK_BITMAP_UNREF(color_mask);
+	    GDK_BITMAP_UNREF(trans_mask);
+	}
+	else
+	{
+	    APPEND_CURSOR_PRESET(EDV_CURSOR_CODE_BUSY, GDK_WATCH);
+	}
 
-	cursor_code = EDV_CURSOR_CODE_RESIZE;
-	gdk_cursor_type = GDK_SIZING;
-	DO_APPEND_CURSOR
+	if(TRUE)
+	{
+	    const gint width = 24, height = 24;
+	    const gchar color_mask_data[] = {
+0x03, 0x00, 0x00,
+0x05, 0x00, 0x00,
+0x09, 0x00, 0x00,
+0x11, 0x00, 0x00,
+0x21, 0x00, 0x00,
+0x41, 0x00, 0x00,
+0x81, 0x00, 0x00,
+0x01, 0x01, 0x00,
+0x01, 0xc2, 0x7f,
+0xc1, 0x03, 0x00,
+0x49, 0x80, 0x3f,
+0x95, 0x80, 0x3f,
+0x93, 0x80, 0x35,
+0x20, 0x01, 0x1b,
+0x20, 0x01, 0x0e,
+0xc0, 0x00, 0x04,
+0x00, 0x00, 0x0a,
+0x00, 0x00, 0x1f,
+0x00, 0x80, 0x3b,
+0x00, 0x80, 0x35,
+0x00, 0x80, 0x2a,
+0x00, 0x00, 0x00,
+0x00, 0xc0, 0x7f,
+0x00, 0x00, 0x00
+	    };
+	    const gchar trans_mask_data[] = {
+0x03, 0x00, 0x00,
+0x07, 0x00, 0x00,
+0x0f, 0x00, 0x00,
+0x1f, 0x00, 0x00,
+0x3f, 0x00, 0x00,
+0x7f, 0x00, 0x00,
+0xff, 0x00, 0x00,
+0xff, 0xe1, 0xff,
+0xff, 0xe3, 0xff,
+0xff, 0xe3, 0xff,
+0x7f, 0xc0, 0x7f,
+0xf7, 0xc0, 0x7f,
+0xf3, 0xc0, 0x7f,
+0xe0, 0x81, 0x3f,
+0xe0, 0x01, 0x1f,
+0xc0, 0x00, 0x0e,
+0x00, 0x00, 0x1f,
+0x00, 0x80, 0x3f,
+0x00, 0xc0, 0x7f,
+0x00, 0xc0, 0x7f,
+0x00, 0xc0, 0x7f,
+0x00, 0xe0, 0xff,
+0x00, 0xe0, 0xff,
+0x00, 0xe0, 0xff
+	    };
+	    GdkBitmap *color_mask = gdk_bitmap_create_from_data(
+		root, color_mask_data, width, height
+	    );   
+	    GdkBitmap *trans_mask = gdk_bitmap_create_from_data(
+		root, trans_mask_data, width, height
+	    );
+	    APPEND_CURSOR_PIXMAP(
+		EDV_CURSOR_CODE_PASSIVE_BUSY,
+		color_mask, trans_mask, 0, 0
+	    );
+	    GDK_BITMAP_UNREF(color_mask);
+	    GDK_BITMAP_UNREF(trans_mask);
+	}
+	else
+	{
+	    APPEND_CURSOR_PRESET(EDV_CURSOR_CODE_BUSY, GDK_WATCH);
+	}
 
-	cursor_code = EDV_CURSOR_CODE_CROSSHAIR;
-	gdk_cursor_type = GDK_TCROSS;
-	DO_APPEND_CURSOR
+	APPEND_CURSOR_PRESET(EDV_CURSOR_CODE_TEXT, GDK_XTERM);
+	APPEND_CURSOR_PRESET(EDV_CURSOR_CODE_HAND, GDK_HAND2);
+	APPEND_CURSOR_PRESET(EDV_CURSOR_CODE_TRANSLATE, GDK_FLEUR);
+	APPEND_CURSOR_PRESET(EDV_CURSOR_CODE_RESIZE, GDK_SIZING);
+	APPEND_CURSOR_PRESET(EDV_CURSOR_CODE_CROSSHAIR, GDK_TCROSS);
 
-	cursor_code = EDV_CURSOR_CODE_HAND;
-	gdk_cursor_type = GDK_HAND2;
-	DO_APPEND_CURSOR
+	if(TRUE)
+	{
+	    const gint width = 16, height = 16;
+	    const gchar color_mask_data[] = {
+		0x00, 0x00, 0x00, 0x00,
+		0x00, 0x00, 0x00, 0x00,
+		0x00, 0x00, 0x00, 0x00,
+		0x00, 0x00, 0x00, 0x00
+	    };
+	    const gchar trans_mask_data[] = {
+		0x00, 0x00, 0x00, 0x00,
+		0x00, 0x00, 0x00, 0x00,
+		0x00, 0x00, 0x00, 0x00,
+		0x00, 0x00, 0x00, 0x00
+	    };
+	    GdkBitmap *color_mask = gdk_bitmap_create_from_data(
+		root, color_mask_data, width, height
+	    );
+	    GdkBitmap *trans_mask = gdk_bitmap_create_from_data(
+		root, trans_mask_data, width, height
+	    );
+	    APPEND_CURSOR_PIXMAP(
+		EDV_CURSOR_CODE_INVISIBLE,
+		color_mask, trans_mask, 0, 0
+	    );
+	    GDK_BITMAP_UNREF(color_mask);
+	    GDK_BITMAP_UNREF(trans_mask);
+	}
 
-#undef DO_APPEND_CURSOR
+
+#undef APPEND_CURSOR_PRESET
+#undef APPEND_CURSOR_PIXMAP
+#undef APPEND_CURSOR
 }
 
 
@@ -866,12 +1207,13 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *err_rtn)
 	core_ptr->manage_toid = 0;
 	core_ptr->need_close_all_windows = FALSE;
 	core_ptr->need_reset = FALSE;
+	core_ptr->check_devices_toid = 0;
 
 	core_ptr->interps_signal_count = 0;
 
 	core_ptr->pid = getpid();
 	core_ptr->prog_file = NULL;
-	core_ptr->home_dir = STRDUP(getenv(ENV_VAR_NAME_HOME));
+	core_ptr->home_dir = STRDUP(g_getenv(ENV_VAR_NAME_HOME));
 
 	core_ptr->user_id = getuid();
 	core_ptr->effective_user_id = geteuid();
@@ -1848,8 +2190,8 @@ by going to Settings->Options... and Settings->Customize...\n"
 	    );
 	}
 
-#if 1
-	/* Display Copyright?
+#if !defined(DEBIAN)
+	/* Display License/Copyright?
 	 *
 	 * Use the About dialog to display the copyright if the version
 	 * has changed or there was an error loading the configuration
@@ -1908,7 +2250,7 @@ void EDVDelete(edv_core_struct *core_ptr, gboolean save_config)
 	}
 
 
-	/* Remove InterPS lock link if it reffers to this process */
+	/* Remove InterPS lock link if it refers to this process */
 	if(EDVInterPSGetLock(core_ptr->cfg_list) == core_ptr->pid)
 	    EDVInterPSRemoveLock(core_ptr->cfg_list);
 
@@ -1916,12 +2258,10 @@ void EDVDelete(edv_core_struct *core_ptr, gboolean save_config)
 	/* Begin deleting resources */
 
 	/* Remove timeouts callbacks */
-	if(core_ptr->manage_toid > 0)
-	{
-	    gtk_timeout_remove(core_ptr->manage_toid);
-	    core_ptr->manage_toid = 0;
-	}
-
+	GTK_TIMEOUT_REMOVE(core_ptr->check_devices_toid);
+	core_ptr->check_devices_toid = 0;
+	GTK_TIMEOUT_REMOVE(core_ptr->manage_toid);
+	core_ptr->manage_toid = 0;
 
 	/* Delete all Property Dialogs */
 	for(i = 0; i < core_ptr->total_propdlgs; i++)
