@@ -39,7 +39,8 @@ edv_device_struct *EDVDeviceListMatchObject(
 	const gchar *path
 );
 
-/* Devices List Updating */
+/* Device Updating */
+void EDVDeviceUpdateMountState(edv_device_struct *d);
 void EDVDevicesListUpdateMountStates(
 	edv_device_struct **list, gint total
 );
@@ -48,8 +49,8 @@ void EDVDevicesListUpdateStats(
 );
 
 /* Filesystem */
-guint32 EDVDeviceGetFSFromString(const gchar *fs_type_str);
-const gchar *EDVDeviceGetFSStringFromNumber(guint32 fs_type);
+guint32 EDVDeviceGetFSTypeFromName(const gchar *name);
+const gchar *EDVDeviceGetFSNameFromType(guint32 type);
 
 /* Devices */
 edv_device_struct *EDVDeviceNew(
@@ -315,29 +316,32 @@ edv_device_struct *EDVDeviceListMatchObject(
 }
 
 
+/*
+ *	Updates the Device's mount state.
+ */
+void EDVDeviceUpdateMountState(edv_device_struct *d)
+{
+	EDVDeviceUpdateMountStateFromSystem(d);
+}
+
 /*
  *	Updates the mount states on the Devices List.
- *
- *	The is_mounted state will be updated on all the devices in the
- *	list.
  */
 void EDVDevicesListUpdateMountStates(
 	edv_device_struct **list, gint total
 )
 {
-	EDVDevicesListUpdateMountStatesFromSystem(
-	    list, total
-	);
+	EDVDevicesListUpdateMountStatesFromSystem(list, total);
 }
 
 /*
- *	Updates statistics on the Devices List.
+ *	Updates the statistics of each device in Devices List.
  *
  *	If a Device is not marked as mounted then it will be skipped and
- *	its stats will be garbage.
+ *	its stats will not be 0's.
  *
- *	EDVDevicesListUpdateMountStates() should be called prior to this
- *	function per update.
+ *	EDVDevicesListUpdateMountStates() should be called prior to
+ *	calling this function.
  */
 void EDVDevicesListUpdateStats(
 	edv_device_struct **list, gint total
@@ -345,7 +349,7 @@ void EDVDevicesListUpdateStats(
 {
 	gint i;
 	const gchar *mount_path;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 #if defined(__SOLARIS__)
 	struct statvfs buf;
 #else
@@ -355,19 +359,19 @@ void EDVDevicesListUpdateStats(
 	/* Iterate through devices */
 	for(i = 0; i < total; i++)
 	{
-	    dev_ptr = list[i];
-	    if(dev_ptr == NULL)
+	    dev = list[i];
+	    if(dev == NULL)
 		continue;
 
 	    /* Reset stats */
-	    dev_ptr->blocks_total = 0l;
-	    dev_ptr->blocks_available = 0l;
-	    dev_ptr->blocks_free = 0l;
+	    dev->blocks_total = 0l;
+	    dev->blocks_available = 0l;
+	    dev->blocks_free = 0l;
 
 	    /* Get stats only if mounted */
-	    if(dev_ptr->is_mounted)
+	    if(EDV_DEVICE_IS_MOUNTED(dev))
 	    {
-		mount_path = dev_ptr->mount_path;
+		mount_path = dev->mount_path;
 #if defined(__SOLARIS__)
 		if(!STRISEMPTY(mount_path) ?
 		    !statvfs(mount_path, &buf) : FALSE
@@ -387,9 +391,9 @@ void EDVDevicesListUpdateStats(
 		    {
 			const gulong block_div = block_size / 1024l;
 
-			dev_ptr->blocks_total = buf.f_blocks * block_div;
-			dev_ptr->blocks_available = buf.f_bavail * block_div;
-			dev_ptr->blocks_free = buf.f_bfree * block_div;
+			dev->blocks_total = buf.f_blocks * block_div;
+			dev->blocks_available = buf.f_bavail * block_div;
+			dev->blocks_free = buf.f_bfree * block_div;
 		    }
 		    else if(block_size > 0l)
 		    {
@@ -397,9 +401,9 @@ void EDVDevicesListUpdateStats(
 			const gulong block_div = 1024l / block_size;
 
 			/* Note, block_div is in range of 1 to 1024 */
-			dev_ptr->blocks_total = buf.f_blocks / block_div;
-			dev_ptr->blocks_available = buf.f_bavail / block_div;
-			dev_ptr->blocks_free = buf.f_bfree / block_div;
+			dev->blocks_total = buf.f_blocks / block_div;
+			dev->blocks_available = buf.f_bavail / block_div;
+			dev->blocks_free = buf.f_bfree / block_div;
 		    }
 		}
 	    }
@@ -408,48 +412,61 @@ void EDVDevicesListUpdateStats(
 
 
 /*
- *	Returns one of EDV_FS_TYPE_* based on the given fs_type_str.
+ *	Gets the filesystem type code from the specified filesystem
+ *	conical name.
+ *
+ *	Returns one of EDV_FS_TYPE_*.
  */
-guint32 EDVDeviceGetFSFromString(const gchar *fs_type_str)
+guint32 EDVDeviceGetFSTypeFromName(const gchar *name)
 {
 	gint i;
-	const edv_fs_type_struct *fs_type_ptr;
-	const edv_fs_type_struct fs_type_list[] = EDV_FS_TYPE_LIST;
+	const edv_fs_type_struct *fs_type;
+	const edv_fs_type_struct list[] = EDV_FS_TYPE_LIST;
 
-	if(STRISEMPTY(fs_type_str))
+	if(STRISEMPTY(name))
 	    return(EDV_FS_TYPE_EMPTY);
 
-	for(i = 0; fs_type_list[i].fs_type; i++)
+	for(i = 0; list[i].fs_type != EDV_FS_TYPE_EMPTY; i++)
 	{
-	    fs_type_ptr = &fs_type_list[i];
-	    if(fs_type_ptr->name != NULL)
-	    {
-		if(!g_strcasecmp(fs_type_ptr->name, fs_type_str))
-		    return(fs_type_ptr->fs_type);
-	    }
+	    fs_type = &list[i];
+	    if(fs_type->name == NULL)
+		continue;
+
+	    if(g_strcasecmp(fs_type->name, name))
+		continue;
+
+	    return(fs_type->fs_type);
 	}
 
 	return(EDV_FS_TYPE_EMPTY);
 }
 
 /*
- *      Returns a statically allocated string containing the name of
- *	the file system specified by fs_type.
+ *	Gets the filesystem's conical name from the specified
+ *	filesystem type code.
+ *
+ *	Returns a statically allocated string describing the
+ *	filesystem's conical name.
  */
-const gchar *EDVDeviceGetFSStringFromNumber(guint32 fs_type)
+const gchar *EDVDeviceGetFSNameFromType(guint32 type)
 {
 	gint i;
-	const edv_fs_type_struct *fs_type_ptr;
-	const edv_fs_type_struct fs_type_list[] = EDV_FS_TYPE_LIST;
+	const edv_fs_type_struct *fs_type;
+	const edv_fs_type_struct list[] = EDV_FS_TYPE_LIST;
+	static gchar name[80];
 
-	for(i = 0; fs_type_list[i].fs_type; i++)
+	for(i = 0; list[i].fs_type != EDV_FS_TYPE_EMPTY; i++)
 	{
-	    fs_type_ptr = &fs_type_list[i];
-	    if(fs_type_ptr->name != NULL)
-	    {
-		if(fs_type_ptr->fs_type == fs_type)
-		    return(fs_type_ptr->name);
-	    }
+	    fs_type = &list[i];
+	    if(fs_type->name == NULL)
+		continue;
+
+	    if(fs_type->fs_type != type)
+		continue;
+
+	    strncpy(name, fs_type->name, sizeof(name));
+	    name[sizeof(name) - 1] = '\0';
+	    return(name);
 	}
 
 	return("");
@@ -472,22 +489,14 @@ edv_device_struct *EDVDeviceNew(
 	if(d == NULL)
 	    return(d);
 
+	d->flags = 0;
+
 	d->fs_type = fs_type;
 
 	d->name = STRDUP(name);
 	d->device_path = STRDUP(device_path);
 	d->mount_path = STRDUP(mount_path);
 
-	d->is_mounted = FALSE;
-
-	d->no_unmount = FALSE;
-	d->read_only = FALSE;
-	d->unlisted = FALSE;
-
-	d->realized = FALSE;
-
-	d->internal = FALSE;
-
 	memset(
 	    d->small_pixmap, 0x00,
 	    EDV_DEVICE_TOTAL_ICON_STATES * sizeof(GdkPixmap *)
@@ -685,7 +694,7 @@ void EDVDeviceRealize(
 	if(!force_rerealize)
 	{
 	    /* Device already realized? */
-	    if(d->realized)
+	    if(EDV_DEVICE_IS_REALIZED(d))
 		return;
 	}
 
@@ -721,7 +730,7 @@ void EDVDeviceRealize(
 	    );
 
 	/* Mark the Device as realized */
-	d->realized = TRUE;
+	d->flags |= EDV_DEVICE_REALIZED;
 }
 
 /*
