@@ -20,22 +20,27 @@
 #include "config.h"
 
 
+/* Get Devices List From System */
 void EDVDevicesListLoadFromSystem(
 	edv_device_struct ***list, gint *total,
 	gint (*progress_cb)(gpointer, gulong, gulong),
 	gpointer client_data
 );
 
+/* Update Mount State From System */
+void EDVDeviceUpdateMountStateFromSystem(edv_device_struct *dev);
 void EDVDevicesListUpdateMountStatesFromSystem(
 	edv_device_struct **list, gint total
 );
 
+/* Open Devices List */
 void EDVDevicesListLoadFromFile(
 	const gchar *filename,
 	edv_device_struct ***list, gint *total,
 	gint (*progress_cb)(gpointer, gulong, gulong),
 	gpointer client_data
 );
+/* Save Devices List */
 void EDVDeviceListSaveToFile(
 	const gchar *filename,
 	edv_device_struct **list, gint total,
@@ -69,7 +74,7 @@ void EDVDevicesListLoadFromSystem(
 	FILE *fp;
 	gulong file_size;
 	gint dev_num = -1;
-	edv_device_struct *dev_ptr = NULL;
+	edv_device_struct *dev = NULL;
 #if defined(__SOLARIS__)
 	struct vfstab *vfs_ptr = NULL;
 	int mtback;
@@ -124,11 +129,11 @@ void EDVDevicesListLoadFromSystem(
 	    /* Check if an existing device already exists in
 	     * the list that matches the device_path
 	     */
-	    dev_ptr = EDVDeviceListMatchDevicePath(
+	    dev = EDVDeviceListMatchDevicePath(
 		*list, *total,
 		&dev_num, mt_ptr->mnt_fsname
 	    );
-	    if(dev_ptr == NULL)
+	    if(dev == NULL)
 	    {
 		/* No existing device structure exists that matches the
 		 * device path, so create a new one
@@ -142,21 +147,25 @@ void EDVDevicesListLoadFromSystem(
 		{
 		    *total = 0;
 		    dev_num = -1;
-		    dev_ptr = NULL;
+		    dev = NULL;
 		    break;
 		}
 		else
 		{
-		    (*list)[dev_num] = dev_ptr = EDVDeviceNew(
+		    (*list)[dev_num] = dev = EDVDeviceNew(
 #if defined(__SOLARIS__)
-			EDVDeviceGetFSFromString(vfs_ptr->vfs_fstype),
-			NULL, vfs_ptr->vfs_special, vfs_ptr->vfs_mountp
+			EDVDeviceGetFSTypeFromName(vfs_ptr->vfs_fstype),
+			NULL,
+			vfs_ptr->vfs_special,
+			vfs_ptr->vfs_mountp
 #else
-			EDVDeviceGetFSFromString(mt_ptr->mnt_type),
-			NULL, mt_ptr->mnt_fsname, mt_ptr->mnt_dir
+			EDVDeviceGetFSTypeFromName(mt_ptr->mnt_type),
+			NULL,
+			mt_ptr->mnt_fsname,
+			mt_ptr->mnt_dir
 #endif
 		    );
-		    if(dev_ptr == NULL)
+		    if(dev == NULL)
 		    {
 			dev_num = -1;
 			break;
@@ -168,31 +177,31 @@ void EDVDevicesListLoadFromSystem(
 		    if(EDV_DEVICE_TOTAL_ICON_STATES >= 1)
 		    {
 			/* Small icon? */
-			if(dev_ptr->small_icon_file[0] == NULL)
+			if(dev->small_icon_file[0] == NULL)
 			{
-			    dev_ptr->small_icon_file[0] = STRDUP(
+			    dev->small_icon_file[0] = STRDUP(
 				EDV_DEF_DEVICE_ICON_SMALL_FILE
 			    );
 			}
 			/* Medium icon? */
-			if(dev_ptr->medium_icon_file[0] == NULL)
+			if(dev->medium_icon_file[0] == NULL)
 			{
-			    dev_ptr->medium_icon_file[0] = STRDUP(
+			    dev->medium_icon_file[0] = STRDUP(
 				EDV_DEF_DEVICE_ICON_MEDIUM_FILE
 			    );
 			}
 			/* Large icon? */
-			if(dev_ptr->large_icon_file[0] == NULL)
+			if(dev->large_icon_file[0] == NULL)
 			{
-			    dev_ptr->large_icon_file[0] = STRDUP(
+			    dev->large_icon_file[0] = STRDUP(
 				EDV_DEF_DEVICE_ICON_LARGE_FILE
 			    );
 			}
 		    }
 
 		    /* Default fsck program */
-		    g_free(dev_ptr->command_check);
-		    dev_ptr->command_check = g_strdup_printf(
+		    g_free(dev->command_check);
+		    dev->command_check = g_strdup_printf(
 			"%s %s",
 			EDV_DEF_FSCK_FRONT_PROG,
 #if defined(__SOLARIS__)
@@ -203,8 +212,8 @@ void EDVDevicesListLoadFromSystem(
 		    );
 
 		    /* Default format program */
-		    g_free(dev_ptr->command_format);
-		    dev_ptr->command_format = g_strdup_printf(
+		    g_free(dev->command_format);
+		    dev->command_format = g_strdup_printf(
 			"%s %s",
 			EDV_DEF_FORMAT_FRONT_PROG,
 #if defined(__SOLARIS__)
@@ -224,9 +233,9 @@ void EDVDevicesListLoadFromSystem(
 
 		/* File system type */
 #if defined(__SOLARIS__)
-		dev_ptr->fs_type = EDVDeviceGetFSFromString(vfs_ptr->vfs_fstype);
+		dev->fs_type = EDVDeviceGetFSTypeFromName(vfs_ptr->vfs_fstype);
 #else
-		dev_ptr->fs_type = EDVDeviceGetFSFromString(mt_ptr->mnt_type);
+		dev->fs_type = EDVDeviceGetFSTypeFromName(mt_ptr->mnt_type);
 #endif
 
 		/* Mount path */
@@ -236,11 +245,11 @@ void EDVDevicesListLoadFromSystem(
 		if(mt_ptr->mnt_dir != NULL)
 #endif
 		{
-		    g_free(dev_ptr->mount_path);
+		    g_free(dev->mount_path);
 #if defined(__SOLARIS__)
-		    dev_ptr->mount_path = STRDUP(vfs_ptr->vfs_mountp);
+		    dev->mount_path = STRDUP(vfs_ptr->vfs_mountp);
 #else
-		    dev_ptr->mount_path = STRDUP(mt_ptr->mnt_dir);
+		    dev->mount_path = STRDUP(mt_ptr->mnt_dir);
 #endif
 		}
 
@@ -271,16 +280,13 @@ void EDVDevicesListLoadFromSystem(
 
 
 /*
- *	Updates the mount states of all the Devices in the list with
- *	the system device's mount states.
- */
-void EDVDevicesListUpdateMountStatesFromSystem(
-	edv_device_struct **list, gint total
-)
+ *	Updates the mount state of the Device by checking with the
+ *	system device's mount state.
+ */  
+void EDVDeviceUpdateMountStateFromSystem(edv_device_struct *dev)
 {
+	const gchar *device_path;
 	FILE *fp;
-	gint dev_num = -1;
-	edv_device_struct *dev_ptr = NULL;
 #if defined(__SOLARIS__)
 	struct mnttab *mt_ptr = NULL;
 	int mtback;
@@ -288,26 +294,19 @@ void EDVDevicesListUpdateMountStatesFromSystem(
 	struct mntent *mt_ptr;
 #endif
 
-	if((list == NULL) || (total <= 0))
+	if(dev == NULL)
 	    return;
 
+	/* Reset mount state */
+	dev->flags &= ~EDV_DEVICE_MOUNTED;
 
-	/* Reset mount states on all device structures */
-	for(dev_num = 0; dev_num < total; dev_num++)
-	{
-	    dev_ptr = list[dev_num];
-	    if(dev_ptr == NULL)
-		continue;
-
-	    dev_ptr->is_mounted = FALSE;
-	}
-
+	if(STRISEMPTY(dev->device_path)) 
+	    return;
 
 	/* Open the system's mounted devices list file */
 #if defined(__SOLARIS__)
 	fp = FOpen("/etc/mnttab", "rb");
 #else
-/*	fp = setmntent("/etc/mtab", "rb"); */
 	fp = setmntent("/proc/mounts", "rb");
 #endif
 	if(fp == NULL)
@@ -323,24 +322,18 @@ void EDVDevicesListUpdateMountStatesFromSystem(
 	while(mt_ptr != NULL)
 #endif
 	{
-	    /* Check if the mounted device path matches a Device in
-	     * the specified list
-	     */
-	    dev_ptr = EDVDeviceListMatchDevicePath(
-		list, total,
+	    /* Check if this mount path matches this Device's path */
 #if defined(__SOLARIS__)
-		&dev_num, mt_ptr->mnt_special
+	    device_path = (const gchar *)mt_ptr->mnt_special;
 #else
-		&dev_num, mt_ptr->mnt_fsname
+	    device_path = (const gchar *)mt_ptr->mnt_fsname;
 #endif
-	    );
-	    if(dev_ptr != NULL)
+	    if(!STRISEMPTY(device_path) ?
+		!strcmp(dev->device_path, device_path) : FALSE
+	    )
 	    {
-		/* Entry from system's list of mounted devices matches
-		 * one of the Devices in the list so mark that Device as
-		 * mounted
-		 */
-		dev_ptr->is_mounted = TRUE;
+		dev->flags |= EDV_DEVICE_MOUNTED;
+		break;
 	    }
 
 	    /* Read next mount entry */
@@ -351,7 +344,6 @@ void EDVDevicesListUpdateMountStatesFromSystem(
 #endif
 	}
 
-
 	/* Close the system's mounted devices list file */
 #if defined(__SOLARIS__)
 	FClose(fp);
@@ -360,6 +352,19 @@ void EDVDevicesListUpdateMountStatesFromSystem(
 #endif
 }
 
+/*
+ *      Updates the mount states of all the Devices in the list with
+ *      the system device's mount states.
+ */  
+void EDVDevicesListUpdateMountStatesFromSystem(
+	edv_device_struct **list, gint total 
+)
+{
+	gint i;
+	for(i = 0; i < total; i++)
+	    EDVDeviceUpdateMountStateFromSystem(list[i]);
+}
+
 
 /*
  *	Appends the devices in the specified file to the device list
@@ -377,10 +382,9 @@ void EDVDevicesListLoadFromFile(
 	FILE *fp;
 	gulong file_size;
 	gint dev_num = -1;
-	edv_device_struct *dev_ptr = NULL;
+	edv_device_struct *dev = NULL;
 	struct stat stat_buf;
 
-
 	if((list == NULL) || (total == NULL) || STRISEMPTY(filename))
 	    return;
 
@@ -433,11 +437,11 @@ void EDVDevicesListLoadFromFile(
 		/* Check if an existing device already exists in
 		 * the list that matches the device_path
 		 */
-		dev_ptr = EDVDeviceListMatchDevicePath(
+		dev = EDVDeviceListMatchDevicePath(
 		    *list, *total,
 		    &dev_num, device_path
 		);
-		if(dev_ptr == NULL)
+		if(dev == NULL)
 		{
 		    /* No existing device structure exists that matches
 		     * the given device_path, so create a new one
@@ -451,14 +455,14 @@ void EDVDevicesListLoadFromFile(
 		    {
 			*total = 0;
 			dev_num = -1;
-			dev_ptr = NULL;
+			dev = NULL;
 		    }
 		    else
 		    {
-			(*list)[dev_num] = dev_ptr = EDVDeviceNew(
+			(*list)[dev_num] = dev = EDVDeviceNew(
 			    EDV_FS_TYPE_EMPTY, NULL, device_path, NULL
 			);
-			if(dev_ptr == NULL)
+			if(dev == NULL)
 			{
 			    dev_num = -1;
 			}
@@ -473,41 +477,56 @@ void EDVDevicesListLoadFromFile(
 	    {
 		gint v[1];
 		FGetValuesI(fp, v, 1);
-		if(dev_ptr != NULL)
-		    dev_ptr->fs_type = v[0];
+		if(dev != NULL)
+		    dev->fs_type = v[0];
 	    }
 	    /* NoUnmount */
 	    else if(!g_strcasecmp(parm, "NoUnmount"))
 	    {
 		gint v[1];
 		FGetValuesI(fp, v, 1);
-		if(dev_ptr != NULL)
-		    dev_ptr->no_unmount = (gboolean)v[0];
+		if(dev != NULL)
+		{
+		    if(v[0])
+			dev->flags |= EDV_DEVICE_NO_UNMOUNT;
+		    else
+			dev->flags &= ~EDV_DEVICE_NO_UNMOUNT;
+		}
 	    }
 	    /* ReadOnly */
 	    else if(!g_strcasecmp(parm, "ReadOnly"))
 	    {
 		gint v[1];
 		FGetValuesI(fp, v, 1);
-		if(dev_ptr != NULL)
-		    dev_ptr->read_only = (gboolean)v[0];
+		if(dev != NULL)
+		{
+		    if(v[0])
+			dev->flags |= EDV_DEVICE_READ_ONLY;
+		    else
+			dev->flags &= ~EDV_DEVICE_READ_ONLY;
+		}
 	    }
 	    /* Unlisted */
 	    else if(!g_strcasecmp(parm, "Unlisted"))
 	    {
 		gint v[1];
 		FGetValuesI(fp, v, 1);
-		if(dev_ptr != NULL)
-		    dev_ptr->unlisted = (gboolean)v[0];
+		if(dev != NULL)
+		{
+		    if(v[0])
+			dev->flags |= EDV_DEVICE_UNLISTED;
+		    else
+			dev->flags &= ~EDV_DEVICE_UNLISTED;
+		}
 	    }
 	    /* Name */
 	    else if(!g_strcasecmp(parm, "Name"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    g_free(dev_ptr->name);
-		    dev_ptr->name = STRDUP(v);
+		    g_free(dev->name);
+		    dev->name = STRDUP(v);
 		}
 		g_free(v);
 	    }
@@ -515,10 +534,10 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "MountPath"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    g_free(dev_ptr->mount_path);
-		    dev_ptr->mount_path = STRDUP(v);
+		    g_free(dev->mount_path);
+		    dev->mount_path = STRDUP(v);
 		}
 		g_free(v);
 	    }
@@ -526,10 +545,10 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "CommandMount"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    g_free(dev_ptr->command_mount);
-		    dev_ptr->command_mount = STRDUP(v);
+		    g_free(dev->command_mount);
+		    dev->command_mount = STRDUP(v);
 		}
 		g_free(v);
 	    }
@@ -537,10 +556,10 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "CommandUnmount"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    g_free(dev_ptr->command_unmount);
-		    dev_ptr->command_unmount = STRDUP(v);
+		    g_free(dev->command_unmount);
+		    dev->command_unmount = STRDUP(v);
 		}
 		g_free(v);
 	    }
@@ -548,10 +567,10 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "CommandEject"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    g_free(dev_ptr->command_eject);
-		    dev_ptr->command_eject = STRDUP(v);
+		    g_free(dev->command_eject);
+		    dev->command_eject = STRDUP(v);
 		}
 		g_free(v);
 	    }
@@ -559,10 +578,10 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "CommandCheck"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    g_free(dev_ptr->command_check);
-		    dev_ptr->command_check = STRDUP(v);
+		    g_free(dev->command_check);
+		    dev->command_check = STRDUP(v);
 		}
 		g_free(v);
 	    }
@@ -570,10 +589,10 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "CommandTools"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    g_free(dev_ptr->command_tools);
-		    dev_ptr->command_tools = STRDUP(v);
+		    g_free(dev->command_tools);
+		    dev->command_tools = STRDUP(v);
 		}
 		g_free(v);
 	    }
@@ -581,10 +600,10 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "CommandFormat"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    g_free(dev_ptr->command_format);
-		    dev_ptr->command_format = STRDUP(v);
+		    g_free(dev->command_format);
+		    dev->command_format = STRDUP(v);
 		}
 		g_free(v);
 	    }
@@ -593,9 +612,9 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "IconSmallStandard"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    gchar **t = &dev_ptr->small_icon_file[
+		    gchar **t = &dev->small_icon_file[
 			EDV_DEVICE_ICON_STATE_STANDARD
 		    ];
 		    g_free(*t);
@@ -607,9 +626,9 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "IconSmallSelected"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    gchar **t = &dev_ptr->small_icon_file[
+		    gchar **t = &dev->small_icon_file[
 			EDV_DEVICE_ICON_STATE_SELECTED
 		    ];
 		    g_free(*t);
@@ -621,9 +640,9 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "IconSmallUnmounted"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    gchar **t = &dev_ptr->small_icon_file[
+		    gchar **t = &dev->small_icon_file[
 			EDV_DEVICE_ICON_STATE_UNMOUNTED
 		    ];
 		    g_free(*t);
@@ -636,9 +655,9 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "IconMediumStandard"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    gchar **t = &dev_ptr->medium_icon_file[
+		    gchar **t = &dev->medium_icon_file[
 			EDV_DEVICE_ICON_STATE_STANDARD
 		    ];
 		    g_free(*t);
@@ -650,9 +669,9 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "IconMediumSelected"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    gchar **t = &dev_ptr->medium_icon_file[
+		    gchar **t = &dev->medium_icon_file[
 		        EDV_DEVICE_ICON_STATE_SELECTED
 		    ];
 		    g_free(*t);
@@ -664,9 +683,9 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "IconMediumUnmounted"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    gchar **t = &dev_ptr->medium_icon_file[
+		    gchar **t = &dev->medium_icon_file[
 			EDV_DEVICE_ICON_STATE_UNMOUNTED
 		    ];
 		    g_free(*t);
@@ -679,9 +698,9 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "IconLargeStandard"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    gchar **t = &dev_ptr->large_icon_file[
+		    gchar **t = &dev->large_icon_file[
 		        EDV_DEVICE_ICON_STATE_STANDARD
 		    ];
 		    g_free(*t);
@@ -693,9 +712,9 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "IconLargeSelected"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    gchar **t = &dev_ptr->large_icon_file[
+		    gchar **t = &dev->large_icon_file[
 			EDV_DEVICE_ICON_STATE_SELECTED
 		    ];
 		    g_free(*t);
@@ -707,9 +726,9 @@ void EDVDevicesListLoadFromFile(
 	    else if(!g_strcasecmp(parm, "IconLargeUnmounted"))
 	    {
 		gchar *v = FGetString(fp);
-		if(dev_ptr != NULL)
+		if(dev != NULL)
 		{
-		    gchar **t = &dev_ptr->large_icon_file[
+		    gchar **t = &dev->large_icon_file[
 			EDV_DEVICE_ICON_STATE_UNMOUNTED
 		    ];
 		    g_free(*t);
@@ -723,16 +742,16 @@ void EDVDevicesListLoadFromFile(
 	    {
 		glong v[1];
 		FGetValuesL(fp, v, 1);
-		if(dev_ptr != NULL)
-		    dev_ptr->last_mount_time = (gulong)v[0];
+		if(dev != NULL)
+		    dev->last_mount_time = (gulong)v[0];
 	    }
 	    /* LastCheckTime */
 	    else if(!g_strcasecmp(parm, "LastCheckTime"))
 	    {
 		glong v[1];
 		FGetValuesL(fp, v, 1);
-		if(dev_ptr != NULL)
-		    dev_ptr->last_check_time = (gulong)v[0];
+		if(dev != NULL)
+		    dev->last_check_time = (gulong)v[0];
 	    }
 
 	    /* End of a device block? */
@@ -742,7 +761,7 @@ void EDVDevicesListLoadFromFile(
 
 		/* Reset contexts */
 		dev_num = -1;
-		dev_ptr = NULL;
+		dev = NULL;
 	    }
 	    /* All else unsupported parameter or wrong context */
 	    else
@@ -769,7 +788,7 @@ void EDVDeviceListSaveToFile(
 )
 {
 	gint dev_num;
-	const edv_device_struct *dev_ptr;
+	const edv_device_struct *dev;
 	gchar *parent_path;
 	FILE *fp;
 	const gchar *path;
@@ -801,14 +820,14 @@ void EDVDeviceListSaveToFile(
 	/* Iterate through all device structures */
 	for(dev_num = 0; dev_num < total; dev_num++)
 	{
-	    dev_ptr = list[dev_num];
-	    if(dev_ptr == NULL)
+	    dev = list[dev_num];
+	    if(dev == NULL)
 		continue;
 
 	    /* Skip devices that are marked internal, meaning they
 	     * should not be saved to file
 	     */
-	    if(dev_ptr->internal)
+	    if(EDV_DEVICE_IS_INTERNAL(dev))
 		continue;
 
 	    /* Call progress callback */
@@ -825,93 +844,93 @@ void EDVDeviceListSaveToFile(
 	    fprintf(
 		fp,
 		"BeginDevice = %s\n",
-		dev_ptr->device_path
+		dev->device_path
 	    );
 
 	    /* FSType */
 	    fprintf(
 		fp,
 		"\tFSType = %i\n",
-		dev_ptr->fs_type
+		dev->fs_type
 	    );
 	    /* NoUnmount */
 	    fprintf(
 		fp,
 		"\tNoUnmount = %i\n",
-		dev_ptr->no_unmount
+		EDV_DEVICE_IS_NO_UNMOUNT(dev)
 	    );
 	    /* ReadOnly */
 	    fprintf(
 		fp,
 		"\tReadOnly = %i\n",
-		dev_ptr->read_only
+		EDV_DEVICE_IS_READ_ONLY(dev)
 	    );
 	    /* Unlisted */
 	    fprintf(
 		fp,
 		"\tUnlisted = %i\n",
-		dev_ptr->unlisted
+		EDV_DEVICE_IS_UNLISTED(dev)
 	    );
 	    /* Name */
-	    if(!STRISEMPTY(dev_ptr->name))
+	    if(!STRISEMPTY(dev->name))
 		fprintf(
 		    fp,
 		    "\tName = %s\n",
-		    dev_ptr->name
+		    dev->name
 		);
 	    /* MountPath */
-	    if(!STRISEMPTY(dev_ptr->mount_path))
+	    if(!STRISEMPTY(dev->mount_path))
 		fprintf(
 		    fp,
 		    "\tMountPath = %s\n",
-		    dev_ptr->mount_path
+		    dev->mount_path
 		);
 
 	    /* CommandMount */
-	    if(!STRISEMPTY(dev_ptr->command_mount))
+	    if(!STRISEMPTY(dev->command_mount))
 		fprintf(
 		    fp,
 		    "\tCommandMount = %s\n",
-		    dev_ptr->command_mount
+		    dev->command_mount
 		);
 	    /* CommandUnmount */
-	    if(!STRISEMPTY(dev_ptr->command_unmount))
+	    if(!STRISEMPTY(dev->command_unmount))
 		fprintf(
 		    fp,
 		    "\tCommandUnmount = %s\n",
-		    dev_ptr->command_unmount
+		    dev->command_unmount
 		);
 	    /* CommandEject */
-	    if(!STRISEMPTY(dev_ptr->command_eject))
+	    if(!STRISEMPTY(dev->command_eject))
 		fprintf(
 		    fp,
 		    "\tCommandEject = %s\n",
-		    dev_ptr->command_eject
+		    dev->command_eject
 		);
 	    /* CommandCheck */
-	    if(!STRISEMPTY(dev_ptr->command_check))
+	    if(!STRISEMPTY(dev->command_check))
 		fprintf(
 		    fp,
 		    "\tCommandCheck = %s\n",
-		    dev_ptr->command_check
+		    dev->command_check
 		);
 	    /* CommandTools */
-	    if(!STRISEMPTY(dev_ptr->command_tools))
+	    if(!STRISEMPTY(dev->command_tools))
 		fprintf(
 		    fp,
 		    "\tCommandTools = %s\n",
-		    dev_ptr->command_tools
+		    dev->command_tools
 		);
 	    /* CommandFormat */
-	    if(!STRISEMPTY(dev_ptr->command_format))
+	    if(!STRISEMPTY(dev->command_format))
 		fprintf(
 		    fp,
 		    "\tCommandFormat = %s\n",
-		    dev_ptr->command_format
+		    dev->command_format
 		);
 
 	    /* IconSmallStandard */
-	    path = dev_ptr->small_icon_file[EDV_DEVICE_ICON_STATE_STANDARD];
+	    path = dev->small_icon_file[EDV_DEVICE_ICON_STATE_STANDARD];
 	    if(!STRISEMPTY(path))
 		fprintf(
 		    fp,
@@ -919,7 +938,7 @@ void EDVDeviceListSaveToFile(
 		    path
 		);
 	    /* IconSmallSelected */
-	    path = dev_ptr->small_icon_file[EDV_DEVICE_ICON_STATE_SELECTED];
+	    path = dev->small_icon_file[EDV_DEVICE_ICON_STATE_SELECTED];
 	    if(!STRISEMPTY(path))
 		fprintf(
 		    fp,
@@ -927,7 +946,7 @@ void EDVDeviceListSaveToFile(
 		    path
 		);
 	    /* IconSmallUnmounted */
-	    path = dev_ptr->small_icon_file[EDV_DEVICE_ICON_STATE_UNMOUNTED];
+	    path = dev->small_icon_file[EDV_DEVICE_ICON_STATE_UNMOUNTED];
 	    if(!STRISEMPTY(path))
 		fprintf(
 		    fp,
@@ -936,7 +955,7 @@ void EDVDeviceListSaveToFile(
 		);
 
 	    /* IconMediumStandard */
-	    path = dev_ptr->medium_icon_file[EDV_DEVICE_ICON_STATE_STANDARD];
+	    path = dev->medium_icon_file[EDV_DEVICE_ICON_STATE_STANDARD];
 	    if(!STRISEMPTY(path))
 		fprintf(
 		    fp,
@@ -944,7 +963,7 @@ void EDVDeviceListSaveToFile(
 		    path
 		);
 	    /* IconMediumSelected */
-	    path = dev_ptr->medium_icon_file[EDV_DEVICE_ICON_STATE_SELECTED];
+	    path = dev->medium_icon_file[EDV_DEVICE_ICON_STATE_SELECTED];
 	    if(!STRISEMPTY(path))
 		fprintf(
 		    fp,
@@ -952,7 +971,7 @@ void EDVDeviceListSaveToFile(
 		    path
 		);
 	    /* IconMediumUnmounted */
-	    path = dev_ptr->medium_icon_file[EDV_DEVICE_ICON_STATE_UNMOUNTED];
+	    path = dev->medium_icon_file[EDV_DEVICE_ICON_STATE_UNMOUNTED];
 	    if(!STRISEMPTY(path))
 		fprintf(
 		    fp,
@@ -961,7 +980,7 @@ void EDVDeviceListSaveToFile(
 		);
 
 	    /* IconLargeStandard */
-	    path = dev_ptr->large_icon_file[EDV_DEVICE_ICON_STATE_STANDARD];
+	    path = dev->large_icon_file[EDV_DEVICE_ICON_STATE_STANDARD];
 	    if(!STRISEMPTY(path))
 		fprintf(
 		    fp,
@@ -969,7 +988,7 @@ void EDVDeviceListSaveToFile(
 		    path
 		);
 	    /* IconLargeSelected */
-	    path = dev_ptr->large_icon_file[EDV_DEVICE_ICON_STATE_SELECTED];
+	    path = dev->large_icon_file[EDV_DEVICE_ICON_STATE_SELECTED];
 	    if(!STRISEMPTY(path))
 		fprintf(
 		    fp,
@@ -977,7 +996,7 @@ void EDVDeviceListSaveToFile(
 		    path
 		);
 	    /* IconLargeUnmounted */
-	    path = dev_ptr->large_icon_file[EDV_DEVICE_ICON_STATE_UNMOUNTED];
+	    path = dev->large_icon_file[EDV_DEVICE_ICON_STATE_UNMOUNTED];
 	    if(!STRISEMPTY(path))
 		fprintf(
 		    fp,
@@ -986,18 +1005,18 @@ void EDVDeviceListSaveToFile(
 		);
 
 	    /* LastMountTime */
-	    if(dev_ptr->last_mount_time > 0l)
+	    if(dev->last_mount_time > 0l)
 		fprintf(
 		    fp,
 		    "\tLastMountTime = %ld\n",
-		    dev_ptr->last_mount_time
+		    dev->last_mount_time
 		);
 	    /* LastCheckTime */
-	    if(dev_ptr->last_check_time > 0l)
+	    if(dev->last_check_time > 0l)
 		fprintf(
 		    fp,
 		    "\tLastCheckTime = %ld\n",
-		    dev_ptr->last_check_time
+		    dev->last_check_time
 		);
 
 	    /* EndDevice */
