@@ -5,8 +5,8 @@
 #include <time.h>
 #include <errno.h>
 #include <sys/stat.h>
-#include <unistd.h>
 #include <gtk/gtk.h>
+#include <unistd.h>
 
 #include "../include/string.h"
 #include "../include/fio.h"
@@ -367,9 +367,13 @@ static gint EDVFCreateNexus(
 	{
 	    /* Given path exists, now check if its destination is not a
 	     * directory. If destination is not a directory then a new
-	     * object cannot be created.
+	     * object cannot be created
 	     */
+#ifdef S_ISDIR
 	    if(!S_ISDIR(stat_buf.st_mode))
+#else
+	    if(TRUE)
+#endif
 	    {
 		last_error =
 "The location to create the new object at is not a directory";
@@ -421,8 +425,11 @@ static gint EDVFCreateNexus(
 	/* Directory */
 	else if(type == EDV_OBJECT_TYPE_DIRECTORY)
 	{
-	    mode_t m = S_IRWXU | S_IRWXG | S_IRWXO;
-
+#if defined(S_IRWXU) && defined(S_IRWXG) && defined(S_IRWXO)
+	    const mode_t m = S_IRWXU | S_IRWXG | S_IRWXO;
+#else
+	    const mode_t m = 0;
+#endif
 	    if(mkdir((const char *)new_path, m))
 	    {
 		last_error =
