@@ -3,6 +3,7 @@
 #include <string.h>
 #include <ctype.h>
 #include <fnmatch.h>
+#include <sys/stat.h>
 #include <glib.h>
 
 #include "../include/string.h"
@@ -86,8 +87,8 @@ gint EDVFindRecycledObjectByName(
 /* Object Finding */
 static void EDVFindObjectByContentIterate(
 	const gchar *path, const gchar *expression,
-	gboolean recursive, gboolean case_sensitive,
-	gpointer client_data,
+	gboolean recursive, gboolean follow_links, gboolean case_sensitive,
+ 	gpointer client_data,
 	gint (*progress_cb)(const gchar *, gfloat, gpointer),
 	void (*match_cb)(
 		const gchar *, const struct stat *,
@@ -98,7 +99,7 @@ static void EDVFindObjectByContentIterate(
 );
 gint EDVFindObjectByContent(
 	const gchar *start_dir, const gchar *expression,
-	gboolean recursive, gboolean case_sensitive,
+	gboolean recursive, gboolean follow_links, gboolean case_sensitive,
 	gpointer client_data,
 	gint (*progress_cb)(const gchar *, gfloat, gpointer),
 	void (*match_cb)(
@@ -110,7 +111,7 @@ gint EDVFindObjectByContent(
 
 static void EDVFindObjectByNameIterate(
 	const gchar *path, const gchar *expression,
-	gboolean recursive, gboolean case_sensitive,
+	gboolean recursive, gboolean follow_links, gboolean case_sensitive,
 	gpointer client_data,
 	gint (*progress_cb)(const gchar *, gfloat, gpointer),
 	void (*match_cb)(const gchar *, const struct stat *, gpointer),
@@ -118,7 +119,7 @@ static void EDVFindObjectByNameIterate(
 );
 gint EDVFindObjectByName(
 	const gchar *start_dir, const gchar *expression,
-	gboolean recursive, gboolean case_sensitive,
+	gboolean recursive, gboolean follow_links, gboolean case_sensitive,
 	gpointer client_data,
 	gint (*progress_cb)(const gchar *, gfloat, gpointer),
 	void (*match_cb)(const gchar *, const struct stat *, gpointer)
@@ -794,7 +795,7 @@ gint EDVFindRecycledObjectByName(
  */
 static void EDVFindObjectByContentIterate(
 	const gchar *path, const gchar *expression,
-	gboolean recursive, gboolean case_sensitive,
+	gboolean recursive, gboolean follow_links, gboolean case_sensitive,
 	gpointer client_data,
 	gint (*progress_cb)(const gchar *, gfloat, gpointer),
 	void (*match_cb)(
@@ -815,10 +816,10 @@ static void EDVFindObjectByContentIterate(
 	strv = (gchar **)GetDirEntNames2((const char *)path, (int *)&strc);
 	if(strv != NULL)
 	{
-	    gint i;
+	    gint i, result;
 	    const gchar *name;
-	    gchar *child_path = NULL;
-	    struct stat stat_buf, lstat_buf;
+	    gchar *full_path = NULL;
+	    struct stat stat_buf;
 
 	    strv = (gchar **)StringQSort((char **)strv, (int)strc);
 	    if(strv == NULL)
@@ -827,12 +828,10 @@ static void EDVFindObjectByContentIterate(
 	    for(i = 0; i < strc; i++)
 	    {
 #define DO_FREE_CONTINUE	{	\
- g_free(child_path);			\
- child_path = NULL;			\
-					\
+ g_free(full_path);			\
+ full_path = NULL;			\
  g_free(strv[i]);			\
  strv[i] = NULL;			\
-					\
  continue;				\
 }
 		name = strv[i];
@@ -849,42 +848,44 @@ static void EDVFindObjectByContentIterate(
 		)
 		    DO_FREE_CONTINUE
 
-		/* Get full path to child object as child_path */
-		child_path = STRDUP(PrefixPaths(
+		/* Get full path */
+		full_path = STRDUP(PrefixPaths(
 		    (const char *)path, (const char *)name
 		));
-		if(child_path == NULL)
+		if(full_path == NULL)
 		    DO_FREE_CONTINUE
 
 		/* Report progress */
 		if(progress_cb != NULL)
 		{
-		    if(progress_cb(child_path, -1.0f, client_data))
+		    if(progress_cb(full_path, -1.0f, client_data))
 		    {
 			*stop_find = TRUE;
 			DO_FREE_CONTINUE
 		    }
 		}
 
-		/* Do match */
+		/* Match object content */
 		if(TRUE)
 		{
 		    gint line_index;
 		    gchar *excerpt = EDVFindGrepExcerptFile(
-			child_path, expression,
+			full_path, expression,
 			case_sensitive, &line_index
 		    );
 		    if(excerpt != NULL)
 		    {
-			/* Got match, increment number of matches and
-			 * call the match callback
-			 */
+			/* Got match */
+			struct stat lstat_buf;
+
+			/* Increment number of matches */
 			*total_matches = (*total_matches) + 1;
-			if((match_cb != NULL) &&
-			   !lstat((char *)child_path, &lstat_buf)
-			)
+
+			/* Get local stats and call match callback */
+			result = (gint)lstat((char *)full_path, &lstat_buf);
+			if((match_cb != NULL) && !result)
 			    match_cb(
-				child_path,	/* Path */
+				full_path,	/* Path */
 				&lstat_buf,	/* Local Stats */
 				excerpt,	/* Excerpt */
 				line_index,	/* Line Index */
@@ -895,17 +896,36 @@ static void EDVFindObjectByContentIterate(
 		    }
 		}
 
-
 		/* Get destination stats */
-		if(stat((char *)child_path, &stat_buf))
+		if(stat((char *)full_path, &stat_buf))
 		    DO_FREE_CONTINUE
 
 		/* Is it a directory and should we recurse into it? */
+#ifdef S_ISDIR
 		if(recursive && S_ISDIR(stat_buf.st_mode))
+#else
+		if(FALSE)
+#endif
 		{
+		    struct stat lstat_buf;
+
+		    result = (gint)lstat(
+			(char *)full_path, &lstat_buf
+		    );
+#ifdef S_ISLNK
+		    /* Skip links that go to directories in order to
+		     * avoid possible infinate recusion
+		     */
+		    if(!result)
+		    {
+			if(S_ISLNK(lstat_buf.st_mode) && !follow_links)
+			    DO_FREE_CONTINUE
+		    }
+#endif
+
 		    EDVFindObjectByContentIterate(
-			child_path, expression,
-			recursive, case_sensitive,
+			full_path, expression,
+			recursive, follow_links, case_sensitive,
 			client_data,
 			progress_cb, match_cb,
 			total_matches, stop_find
@@ -936,7 +956,7 @@ static void EDVFindObjectByContentIterate(
  */
 gint EDVFindObjectByContent(
 	const gchar *start_dir, const gchar *expression,
-	gboolean recursive, gboolean case_sensitive,
+	gboolean recursive, gboolean follow_links, gboolean case_sensitive,
 	gpointer client_data,
 	gint (*progress_cb)(const gchar *, gfloat, gpointer),
 	void (*match_cb)(
@@ -973,7 +993,7 @@ gint EDVFindObjectByContent(
 	/* Begin search */
 	EDVFindObjectByContentIterate(
 	    start_dir, lexpression,
-	    recursive, case_sensitive,
+	    recursive, follow_links, case_sensitive,
 	    client_data,
 	    progress_cb, match_cb,
 	    total_matches, stop_find
@@ -997,7 +1017,7 @@ gint EDVFindObjectByContent(
  */
 static void EDVFindObjectByNameIterate(
 	const gchar *path, const gchar *expression,
-	gboolean recursive, gboolean case_sensitive,
+	gboolean recursive, gboolean follow_links, gboolean case_sensitive,
 	gpointer client_data,
 	gint (*progress_cb)(const gchar *, gfloat, gpointer),
 	void (*match_cb)(const gchar *, const struct stat *, gpointer),
@@ -1014,10 +1034,10 @@ static void EDVFindObjectByNameIterate(
 	strv = (gchar **)GetDirEntNames2((const char *)path, (int *)&strc);
 	if(strv != NULL)
 	{
-	    gint i;
+	    gint i, result;
 	    const gchar *name;
-	    gchar *child_path = NULL;
-	    struct stat stat_buf, lstat_buf;
+	    gchar *full_path = NULL;
+	    struct stat stat_buf;
 
 	    strv = (gchar **)StringQSort((char **)strv, (int)strc);
 	    if(strv == NULL)
@@ -1026,12 +1046,10 @@ static void EDVFindObjectByNameIterate(
 	    for(i = 0; i < strc; i++)
 	    {
 #define DO_FREE_CONTINUE	{	\
- g_free(child_path);			\
- child_path = NULL;			\
-					\
+ g_free(full_path);			\
+ full_path = NULL;			\
  g_free(strv[i]);			\
  strv[i] = NULL;			\
-					\
  continue;				\
 }
 		name = strv[i];
@@ -1048,24 +1066,24 @@ static void EDVFindObjectByNameIterate(
 		)
 		    DO_FREE_CONTINUE
 
-		/* Get full path to child object as child_path */
-		child_path = STRDUP(PrefixPaths(
+		/* Get full path */
+		full_path = STRDUP(PrefixPaths(
 		    (const char *)path, (const char *)name
 		));
-		if(child_path == NULL)
+		if(full_path == NULL)
 		    DO_FREE_CONTINUE
 
 		/* Report progress */
 		if(progress_cb != NULL)
 		{
-		    if(progress_cb(child_path, -1.0f, client_data))
+		    if(progress_cb(full_path, -1.0f, client_data))
 		    {
 			*stop_find = TRUE;
 			DO_FREE_CONTINUE
 		    }
 		}
 
-		/* Do match */
+		/* Match object name */
 		if(TRUE)
 		{
 		    gchar *s = STRDUP(name);
@@ -1075,15 +1093,17 @@ static void EDVFindObjectByNameIterate(
 
 		    if(!fnmatch((const char *)expression, (char *)s, 0))
 		    {
-			/* Got match, increment number of matches and
-			 * call the match callback
-			 */
+			/* Got match */
+			struct stat lstat_buf;
+
+			/* Increment number of matches */
 			*total_matches = (*total_matches) + 1;
-			if((match_cb != NULL) &&
-			   !lstat((char *)child_path, &lstat_buf)
-			)
+
+			/* Get local stats and call match callback */
+			result = (gint)lstat((char *)full_path, &lstat_buf);
+			if((match_cb != NULL) && !result)
 			    match_cb(
-				child_path,	/* Path */
+				full_path,	/* Path */
 				&lstat_buf,	/* Stats */
 				client_data	/* Data */
 			    );
@@ -1093,15 +1113,35 @@ static void EDVFindObjectByNameIterate(
 		}
 
 		/* Get destination stats */
-		if(stat((char *)child_path, &stat_buf))
+		if(stat((char *)full_path, &stat_buf))
 		    DO_FREE_CONTINUE
 
 		/* Is it a directory and should we recurse into it? */
+#ifdef S_ISDIR
 		if(recursive && S_ISDIR(stat_buf.st_mode))
+#else
+		if(FALSE)
+#endif
 		{
+		    struct stat lstat_buf;
+
+		    result = (gint)lstat(
+			(char *)full_path, &lstat_buf
+		    );
+#ifdef S_ISLNK
+		    /* Skip links that go to directories in order to
+		     * avoid possible infinate recusion
+		     */
+		    if(!result)
+		    {
+			if(S_ISLNK(lstat_buf.st_mode) && !follow_links)
+			    DO_FREE_CONTINUE
+		    }
+#endif
+
 		    EDVFindObjectByNameIterate(
-			child_path, expression,
-			recursive, case_sensitive,
+			full_path, expression,
+			recursive, follow_links, case_sensitive,
 			client_data,
 			progress_cb, match_cb,
 			total_matches, stop_find
@@ -1131,7 +1171,7 @@ static void EDVFindObjectByNameIterate(
  */
 gint EDVFindObjectByName(
 	const gchar *start_dir, const gchar *expression,
-	gboolean recursive, gboolean case_sensitive,
+	gboolean recursive, gboolean follow_links, gboolean case_sensitive,
 	gpointer client_data,
 	gint (*progress_cb)(const gchar *, gfloat, gpointer),
 	void (*match_cb)(const gchar *, const struct stat *, gpointer)
@@ -1142,7 +1182,6 @@ gint EDVFindObjectByName(
 	gboolean *stop_find;
 	gint *total_matches;
 
-
 	if(STRISEMPTY(start_dir) || STRISEMPTY(expression))
 	    return(0);
 	if(!strcmp((const char *)expression, "*"))
@@ -1167,7 +1206,7 @@ gint EDVFindObjectByName(
 	/* Begin search */
 	EDVFindObjectByNameIterate(
 	    start_dir, lexpression,
-	    recursive, case_sensitive,
+	    recursive, follow_links, case_sensitive,
 	    client_data,
 	    progress_cb, match_cb,
 	    total_matches, stop_find
