@@ -9,7 +9,7 @@
 #include <glib.h>
 
 
-/* Archive object finding */
+/* Archive Finding */
 extern gint EDVFindArchiveObjectByName(
 	edv_core_struct *core_ptr,
 	const gchar *arch_path, const gchar *expression,
@@ -19,7 +19,7 @@ extern gint EDVFindArchiveObjectByName(
 	void (*match_cb)(const gchar *, const struct stat *, gpointer)
 );
 
-/* Recycled object finding */
+/* Recycled Object Finding */
 extern gint EDVFindRecycledObjectByContent(
 	const gchar *recycled_index_file, const gchar *expression,
 	gboolean case_sensitive,
@@ -39,10 +39,10 @@ extern gint EDVFindRecycledObjectByName(
 	void (*match_cb)(const gchar *, const struct stat *, gpointer)
 );
 
-/* Disk object finding */
+/* Object Finding */
 extern gint EDVFindObjectByContent(
 	const gchar *start_dir, const gchar *expression,
-	gboolean recursive, gboolean case_sensitive,
+	gboolean recursive, gboolean follow_links, gboolean case_sensitive,
 	gpointer client_data,
 	gint (*progress_cb)(const gchar *, gfloat, gpointer),
 	void (*match_cb)(
@@ -53,13 +53,11 @@ extern gint EDVFindObjectByContent(
 );
 extern gint EDVFindObjectByName(
 	const gchar *start_dir, const gchar *expression,
-	gboolean recursive, gboolean case_sensitive,
+	gboolean recursive, gboolean follow_links, gboolean case_sensitive,
 	gpointer client_data,
 	gint (*progress_cb)(const gchar *, gfloat, gpointer),
 	void (*match_cb)(const gchar *, const struct stat *, gpointer)
 );
 
 
-
-
 #endif	/* EDVFIND_H */
