@@ -14,14 +14,10 @@
  */
 typedef enum{
 	EDV_MIMETYPE_ICON_STATE_STANDARD,
-	EDV_MIMETYPE_ICON_STATE_SELECTED,
-		/* Directories=Expanded
-		 * Other=Selected
-		 */
-	EDV_MIMETYPE_ICON_STATE_EXTENDED,
-		/* Links=Broken
-		 * Other=Active/Opened/Reserved
-		 */
+	EDV_MIMETYPE_ICON_STATE_SELECTED,	/* Directories=Expanded
+						 * Other=Selected */
+	EDV_MIMETYPE_ICON_STATE_EXTENDED,	/* Links=Broken
+						 * Other=Active/Opened/Reserved	 */
 	EDV_MIMETYPE_ICON_STATE_HIDDEN
 } edv_mimetype_icon_state;
 #define EDV_MIMETYPE_TOTAL_ICON_STATES		4
