@@ -13,15 +13,15 @@
 extern const gchar *EDVMountGetError(void);
 
 extern gint EDVMountDoMount(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 );
 extern gint EDVMountDoUnmount(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 );
 extern gint EDVMountDoEject(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 );
 
