@@ -1,7 +1,8 @@
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
+#include <sys/types.h>
 #include <sys/stat.h>
+#include <unistd.h>
 
 #include <glib.h>
 
@@ -34,7 +35,7 @@ void EDVObjectSetPath2(
 void EDVObjectSetStat(
 	edv_object_struct *obj, const struct stat *lstat_buf
 );
-void EDVObjectValidateLink(edv_object_struct *obj);
+void EDVObjectUpdateLinkFlags(edv_object_struct *obj);
 void EDVObjectDelete(edv_object_struct *obj);
 
 
@@ -56,20 +57,36 @@ void EDVObjectDelete(edv_object_struct *obj);
  */
 edv_object_type EDVObjectGetTypeFromStatMode(mode_t m)
 {
-	if(S_ISLNK(m))
-	    return(EDV_OBJECT_TYPE_LINK);
-	else if(S_ISREG(m))
+#ifdef S_ISREG
+	if(S_ISREG(m))
+#else
+	if(TRUE)
+#endif
 	    return(EDV_OBJECT_TYPE_FILE);
+#ifdef S_ISDIR
 	else if(S_ISDIR(m))
 	    return(EDV_OBJECT_TYPE_DIRECTORY);
+#endif
+#ifdef S_ISLNK
+	else if(S_ISLNK(m))
+	    return(EDV_OBJECT_TYPE_LINK);
+#endif
+#ifdef S_ISCHR
 	else if(S_ISCHR(m))
 	    return(EDV_OBJECT_TYPE_DEVICE_CHARACTER);
+#endif
+#ifdef S_ISBLK
 	else if(S_ISBLK(m))
 	    return(EDV_OBJECT_TYPE_DEVICE_BLOCK);
+#endif
+#ifdef S_ISFIFO
 	else if(S_ISFIFO(m))
 	    return(EDV_OBJECT_TYPE_FIFO);
+#endif
+#ifdef S_ISSOCK
 	else if(S_ISSOCK(m))
 	    return(EDV_OBJECT_TYPE_SOCKET);
+#endif
 	else
 	    return(EDV_OBJECT_TYPE_FILE);
 }
@@ -87,25 +104,39 @@ mode_t EDVObjectGetTypeFromEDVType(edv_object_type type)
 	  case EDV_OBJECT_TYPE_UNKNOWN:
 	    break;
 	  case EDV_OBJECT_TYPE_FILE:
+#ifdef S_IFREG
 	    m |= S_IFREG;
+#endif
 	    break;
 	  case EDV_OBJECT_TYPE_DIRECTORY:
+#ifdef S_IFDIR
 	    m |= S_IFDIR;
+#endif
 	    break;
 	  case EDV_OBJECT_TYPE_LINK:
+#ifdef S_IFLNK
 	    m |= S_IFLNK;
+#endif
 	    break;
 	  case EDV_OBJECT_TYPE_FIFO:
+#ifdef S_IFIFO
 	    m |= S_IFIFO;
+#endif
 	    break;
 	  case EDV_OBJECT_TYPE_DEVICE_BLOCK:
+#ifdef S_IFBLK
 	    m |= S_IFBLK;
+#endif
 	    break;
 	  case EDV_OBJECT_TYPE_DEVICE_CHARACTER:
+#ifdef S_IFCHR
 	    m |= S_IFCHR;
+#endif
 	    break;
 	  case EDV_OBJECT_TYPE_SOCKET:
+#ifdef S_IFSOCK
 	    m |= S_IFSOCK;
+#endif
 	    break;
 	}
 
@@ -204,8 +235,8 @@ edv_object_struct *EDVObjectNew(void)
 	obj->type = EDV_OBJECT_TYPE_FILE;
 	obj->name = NULL;
 	obj->full_path = NULL;
-	obj->linked_to = NULL;
-	obj->link_valid = FALSE;
+	obj->link_value = NULL;
+	obj->link_flags = 0;
 	obj->permissions = 0x00000000;
 	obj->access_time = 0l;
 	obj->modify_time = 0l;
@@ -243,8 +274,8 @@ edv_object_struct *EDVObjectCopy(const edv_object_struct *obj)
 	tar->name = STRDUP(src->name);
 	tar->full_path = STRDUP(src->full_path);
 
-	tar->linked_to = STRDUP(src->linked_to);
-	tar->link_valid = src->link_valid;
+	tar->link_value = STRDUP(src->link_value);
+	tar->link_flags = src->link_flags;
 
 	tar->permissions = src->permissions;
 
@@ -294,24 +325,22 @@ void EDVObjectSetPath(
 	{
 	    const gchar *s;
 
-	    /* Set full path, assume given path is an absolute path */
+	    /* Set full path, always assume it is an absolute path */
 	    obj->full_path = STRDUP(path);
 
 	    /* Remove tailing deliminators if any */
 	    StripPath(obj->full_path);
 
-	    /* Find child and set name */
+	    /* Get name from path */
 	    s = EDVGetPathName(obj->full_path);
-	    if(!STRISEMPTY(s))
-		obj->name = STRDUP(s);
-	    else
-		obj->name = STRDUP(obj->full_path);
+	    obj->name = STRISEMPTY(s) ?
+		STRDUP(obj->full_path) : STRDUP(s);
 	}
 }
 
 /*
- *	Sets the Object's name and full path from the specified name
- *	and full path.
+ *	Sets the Object's name and full path from the specified parent
+ *	and name.
  */
 void EDVObjectSetPath2(
 	edv_object_struct *obj,
@@ -339,8 +368,12 @@ void EDVObjectSetPath2(
 /*
  *	Sets the Object's stats from the stats specified in lstat_buf.
  *
- *	The Object's path should be first with a call to
- *	EDVObjectSetPath*() before calling this function.
+ *	The object's name and full_path should be set by a prior call
+ *	to EDVObjectSetPath*().
+ *
+ *	The object's type, permissions, access_time, modify_time,
+ *	change_time, owner_id, group_id, hard_links, size, device,
+ *	inode, device_type, block_size, and blocks will be set.
  */
 void EDVObjectSetStat(
 	edv_object_struct *obj, const struct stat *lstat_buf
@@ -369,8 +402,10 @@ void EDVObjectSetStat(
 	/* Set number of hard links */
 	obj->hard_links = lstat_buf->st_nlink;
 
-	/* Assume link is valid for now */
-	obj->link_valid = TRUE;
+	/* Assume link is valid when setting stats, calling function
+	 * may update this afterwards
+	 */
+	obj->link_flags = EDV_OBJECT_LINK_VALID;
 
 	/* Set size in bytes */
 	obj->size = (gulong)lstat_buf->st_size;
@@ -387,7 +422,8 @@ void EDVObjectSetStat(
 	obj->blocks = lstat_buf->st_blocks;
 
 
-	/* If this is a link then update the linked_to destination */
+#ifdef S_ISLNK
+	/* If this is a link then update the Object's link_value */
 	if(S_ISLNK(m))
 	{
 	    gchar buf[PATH_MAX + NAME_MAX + 1];
@@ -401,34 +437,66 @@ void EDVObjectSetStat(
 		else
 		    buf[sizeof(buf) - 1] = '\0';
 
-		g_free(obj->linked_to);
-		obj->linked_to = STRDUP(buf);
+		g_free(obj->link_value);
+		obj->link_value = STRDUP(buf);
 	    }
 	    else
 	    {
-		g_free(obj->linked_to);
-		obj->linked_to = NULL;
+		g_free(obj->link_value);
+		obj->link_value = NULL;
 	    }
 	}
+#endif
 }
 
 /*
- *	Checks if the Object of type EDV_OBJECT_TYPE_LINK is valid and
- *	updates the Object's link_valid value.
+ *	Updates the object's link_flags.
+ *
+ *	The specified object must be of type EDV_OBJECT_TYPE_LINK and
+ *	its full_path and link_value must be set by a prior call to
+ *	EDVObjectSetStat().
  */
-void EDVObjectValidateLink(edv_object_struct *obj)
+void EDVObjectUpdateLinkFlags(edv_object_struct *obj)
 {
+	gchar *path, *parent;
 	struct stat stat_buf;
-	const gchar *full_path = (obj != NULL) ?
-	    obj->full_path : NULL;
-	if(STRISEMPTY(full_path))
+
+	if(obj == NULL)
 	    return;
 
-	/* Check if destination can be stat()'ed */
-	if(stat(full_path, &stat_buf))
-	    obj->link_valid = FALSE;
-	else
-	    obj->link_valid = TRUE;
+	obj->link_flags = 0;
+
+	if(!EDV_OBJECT_IS_LINK(obj) ||
+	   (obj->full_path == NULL) || (obj->link_value == NULL)
+	)
+	    return;
+
+	parent = g_dirname(obj->full_path);
+	if(parent == NULL)
+	    return;
+
+	path = EDVEvaluatePath(parent, obj->link_value);
+	if(path == NULL)
+	{
+	    g_free(parent);
+            return;
+	}
+
+	if(!stat(path, &stat_buf))
+	{
+	    obj->link_flags |= EDV_OBJECT_LINK_VALID;
+#ifdef S_ISDIR
+	    if(S_ISDIR(stat_buf.st_mode))
+	    {
+		obj->link_flags |= EDV_OBJECT_LINK_TAR_DIRECTORY;
+		if(EDVIsLinkInfinatelyRecursive(obj->full_path))
+		    obj->link_flags |= EDV_OBJECT_LINK_TAR_GRAND_PARENT;
+	    }
+#endif
+	}
+
+	g_free(path);
+	g_free(parent);
 }
 
 /*
@@ -442,7 +510,7 @@ void EDVObjectDelete(edv_object_struct *obj)
 	g_free(obj->name);
 	g_free(obj->full_path);
 
-	g_free(obj->linked_to);
+	g_free(obj->link_value);
 
 	g_free(obj);
 }
