@@ -1,8 +1,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#include <unistd.h>
 #include <gtk/gtk.h>
+#include <unistd.h>
 
 #include "../include/string.h"
 #include "../include/disk.h"
@@ -85,15 +85,15 @@ gint EDVNewPropertiesDialog(
 
 /* Running */
 void EDVRunDeviceCheck(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 );
 void EDVRunDeviceTools(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 );
 void EDVRunDeviceFormat(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 );
 
@@ -425,86 +425,64 @@ gint EDVNewBrowser(edv_core_struct *core_ptr)
 	 */
 	if(existing_windows > 0)
 	{
-	    gint	offset_x = CFGItemListGetValueI(
-			    cfg_list,
+	    gint	offset_x = EDV_GET_I(
 			    EDV_CFG_PARM_WINDOW_CASCADE_OFFSET_X
 			),
-			offset_y = CFGItemListGetValueI(
-			    cfg_list,
+			offset_y = EDV_GET_I(
 			    EDV_CFG_PARM_WINDOW_CASCADE_OFFSET_Y
 			),
-			x = CFGItemListGetValueI(
-			    cfg_list, EDV_CFG_PARM_BROWSER_X
+			x = EDV_GET_I(
+			    EDV_CFG_PARM_BROWSER_X
 			) + offset_x,
-			y = CFGItemListGetValueI(
-			    cfg_list, EDV_CFG_PARM_BROWSER_Y
+			y = EDV_GET_I(
+			    EDV_CFG_PARM_BROWSER_Y
 			) + offset_y;
-	    CFGItemListSetValueI(
-		cfg_list, EDV_CFG_PARM_BROWSER_X,
-		x, FALSE
-	    );
-	    CFGItemListSetValueI(
-		cfg_list, EDV_CFG_PARM_BROWSER_Y,
-		y, FALSE
-	    );
+	    EDV_SET_I(EDV_CFG_PARM_BROWSER_X, x);
+	    EDV_SET_I(EDV_CFG_PARM_BROWSER_Y, y);
 	}
 
 	/* Create new browser */
 	core_ptr->browser[i] = browser = EDVBrowserNew(core_ptr);
 	if(browser != NULL)
 	{
-	    gchar *startup_dir;
+	    gchar *startup_dir = EDVEvaluatePath(
+		NULL, EDV_GET_S(EDV_CFG_PARM_DIR_START_UP)
+            );
+	    GtkWidget *toplevel = browser->toplevel;
 	    GtkCList *clist;
 
 	    EDVBrowserSetBusy(browser, TRUE);
-	    GUIBlockInput(browser->toplevel, TRUE);
+	    GUIBlockInput(toplevel, TRUE);
 
 	    /* Need to map it immediatly after creation, before any
 	     * timeouts check on it
 	     */
 	    EDVBrowserMap(browser);
 
-	    /* Get copy of start up directory */
-	    startup_dir = EDVCopyEvaluateInputPath(
-		NULL,
-		CFGItemListGetValueS(
-		    cfg_list, EDV_CFG_PARM_DIR_START_UP
-		)
-	    );
-
 	    /* Get directory tree and create initial toplevel nodes */
 	    clist = GTK_CLIST(browser->directory_ctree);
 	    if(clist != NULL)
 	    {
-		const gchar *origin_path = browser->directory_ctree_origin_path;
-
 		/* Set directory tree origin as needed */
-		if((origin_path != NULL) ?
-		    !strpfx(startup_dir, origin_path) : TRUE
-		)
+		if(!EDVBrowserIsPathFromDirTreeOrigin(browser, startup_dir))
 		{
 		    EDVBrowserDirTreeSetOriginPath(browser, startup_dir);
-		    origin_path = browser->directory_ctree_origin_path;
 		}
 		else
 		{
-		    gtk_clist_freeze(clist);
-
-		    /* Create toplevels on the directory tree */
+		    /* Create toplevels */
 		    EDVBrowserDirTreeCreateToplevels(browser);
 
-		    gtk_clist_thaw(clist);
-
-		    /* Select startup directory, do not freeze */
-		    EDVBrowserDirTreeDoSelectPath(browser, startup_dir);
+		    /* Select startup directory */
+		    EDVBrowserDirTreeSelectPath(browser, startup_dir);
 		}
 	    }
 
-	    GUIBlockInput(browser->toplevel, FALSE);
-	    EDVBrowserSetBusy(browser, FALSE);
-
 	    g_free(startup_dir);
 
+	    GUIBlockInput(toplevel, FALSE);
+	    EDVBrowserSetBusy(browser, FALSE);
+
 	    return(i);
 	}
 	else
@@ -527,7 +505,6 @@ gint EDVNewImbr(edv_core_struct *core_ptr)
 	cfg_item_struct *cfg_list;
 	edv_imbr_struct *imbr;
 
-
 	if(core_ptr == NULL)
 	    return(-1);
 
@@ -569,64 +546,49 @@ gint EDVNewImbr(edv_core_struct *core_ptr)
 	 */
 	if(existing_windows > 0)
 	{
-	    gint	offset_x = CFGItemListGetValueI(
-			    cfg_list,
+	    gint	offset_x = EDV_GET_I(
 			    EDV_CFG_PARM_WINDOW_CASCADE_OFFSET_X
 			),
-			offset_y = CFGItemListGetValueI(
-			    cfg_list,
+			offset_y = EDV_GET_I(
 			    EDV_CFG_PARM_WINDOW_CASCADE_OFFSET_Y
 			),
-			x = CFGItemListGetValueI(
-			    cfg_list, EDV_CFG_PARM_IMBR_X
+			x = EDV_GET_I(
+			    EDV_CFG_PARM_IMBR_X
 			) + offset_x,
-			y = CFGItemListGetValueI(
-			    cfg_list, EDV_CFG_PARM_IMBR_Y
+			y = EDV_GET_I(
+			    EDV_CFG_PARM_IMBR_Y
 			) + offset_y;
-	    CFGItemListSetValueI(
-		cfg_list, EDV_CFG_PARM_IMBR_X,
-		x, FALSE
-	    );
-	    CFGItemListSetValueI(
-		cfg_list, EDV_CFG_PARM_IMBR_Y,
-		y, FALSE
-	    );
+	    EDV_SET_I(EDV_CFG_PARM_IMBR_X, x);
+	    EDV_SET_I(EDV_CFG_PARM_IMBR_Y, y);
 	}
 
 	/* Create new image browser */
 	core_ptr->imbr[i] = imbr = EDVImbrNew(core_ptr);
 	if(imbr != NULL)
 	{
-	    gchar *startup_dir;
-
+	    gchar *startup_dir = EDVEvaluatePath(
+		NULL, EDV_GET_S(EDV_CFG_PARM_DIR_START_UP)
+            );
+	    GtkWidget *toplevel = imbr->toplevel;
 
 	    EDVImbrSetBusy(imbr, TRUE);
-	    GUIBlockInput(imbr->toplevel, TRUE);
+	    GUIBlockInput(toplevel, TRUE);
 
 	    /* Need to map it immediatly after creation, before any
 	     * timeouts check on it
 	     */
 	    EDVImbrMap(imbr);
 
-	    /* Get copy of start up directory */
-	    startup_dir = EDVCopyEvaluateInputPath(
-		NULL,
-		CFGItemListGetValueS(
-		    cfg_list, EDV_CFG_PARM_DIR_START_UP
-		)
-	    );
-
 	    /* Switch to startup directory */
 	    EDVImbrSelectPath(imbr, startup_dir);
 
 	    EDVImbrUpdateMenus(imbr);
 
-	    GUIBlockInput(imbr->toplevel, FALSE);
-	    EDVImbrSetBusy(imbr, FALSE);
-
-	    /* Delete copy of start up directory */
 	    g_free(startup_dir);
 
+            GUIBlockInput(toplevel, FALSE);
+            EDVImbrSetBusy(imbr, FALSE);
+
 	    return(i);
 	}
 	else
@@ -649,7 +611,6 @@ gint EDVNewArchiverOpen(edv_core_struct *core_ptr, const gchar *path)
 	cfg_item_struct *cfg_list;
 	edv_archiver_struct *archiver;
 
-
 	if(core_ptr == NULL)
 	    return(-1);
 
@@ -691,28 +652,20 @@ gint EDVNewArchiverOpen(edv_core_struct *core_ptr, const gchar *path)
 	 */
 	if(existing_windows > 0)
 	{
-	    gint	offset_x = CFGItemListGetValueI(
-			    cfg_list,
+	    const gint	offset_x = EDV_GET_I(
 			    EDV_CFG_PARM_WINDOW_CASCADE_OFFSET_X
 			),
-			offset_y = CFGItemListGetValueI(
-			    cfg_list,
+			offset_y = EDV_GET_I(
 			    EDV_CFG_PARM_WINDOW_CASCADE_OFFSET_Y
 			),
-			x = CFGItemListGetValueI(
-			    cfg_list, EDV_CFG_PARM_ARCHIVER_X
+			x = EDV_GET_I(
+			    EDV_CFG_PARM_ARCHIVER_X
 			) + offset_x,
-			y = CFGItemListGetValueI(
-			    cfg_list, EDV_CFG_PARM_ARCHIVER_Y
+			y = EDV_GET_I(
+			    EDV_CFG_PARM_ARCHIVER_Y
 			) + offset_y;
-	    CFGItemListSetValueI(
-		cfg_list, EDV_CFG_PARM_ARCHIVER_X,
-		x, FALSE
-	    );
-	    CFGItemListSetValueI(
-		cfg_list, EDV_CFG_PARM_ARCHIVER_Y,
-		y, FALSE
-	    );
+	    EDV_SET_I(EDV_CFG_PARM_ARCHIVER_X, x);
+	    EDV_SET_I(EDV_CFG_PARM_ARCHIVER_Y, y);
 	}
 
 	/* Create new archiver */
@@ -727,7 +680,6 @@ gint EDVNewArchiverOpen(edv_core_struct *core_ptr, const gchar *path)
 	     */
 	    EDVArchiverMap(archiver);
 
-
 	    if(path != NULL)
 	    {
 		/* Clear the contents clist and load the listing of the
@@ -739,7 +691,6 @@ gint EDVNewArchiverOpen(edv_core_struct *core_ptr, const gchar *path)
 		);
 	    }
 
-
 	    EDVArchiverUpdateMenus(archiver);
 
 	    GUIBlockInput(archiver->toplevel, FALSE);
@@ -894,17 +845,17 @@ gint EDVNewPropertiesDialog(
  *	Runs the device check command on the given device reference.
  */
 void EDVRunDeviceCheck(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 )
 {
 	pid_t p;
 	const gchar *cmd;
 
-	if((core_ptr == NULL) || (dev_ptr == NULL))
+	if((core_ptr == NULL) || (dev == NULL))
 	    return;
 
-	cmd = dev_ptr->command_check;
+	cmd = dev->command_check;
 	if(cmd == NULL)
 	    return;
 
@@ -919,7 +870,7 @@ void EDVRunDeviceCheck(
 	p = Exec(cmd);
 	if(p > 0)
 	{
-	    dev_ptr->last_check_time = (gulong)time(NULL);
+	    dev->last_check_time = (gulong)time(NULL);
 	}
 	else
 	{
@@ -978,7 +929,7 @@ Appareil->Appareils... et dite la rfrence d'appareil.",
  *      Runs the device tools command on the given device reference.
  */
 void EDVRunDeviceTools(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 )
 {
@@ -986,10 +937,10 @@ void EDVRunDeviceTools(
 	const gchar *cmd;
 
 
-	if((core_ptr == NULL) || (dev_ptr == NULL))
+	if((core_ptr == NULL) || (dev == NULL))
 	    return;
 
-	cmd = dev_ptr->command_tools;
+	cmd = dev->command_tools;
 	if(cmd == NULL)
 	    return;
 
@@ -1059,17 +1010,17 @@ Appareil->Appareils... et dite la rfrence d'appareil.",
  *      Runs the device format command on the given device reference.
  */
 void EDVRunDeviceFormat(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 )
 {
 	pid_t p;
 	const gchar *cmd;
 
-	if((core_ptr == NULL) || (dev_ptr == NULL))
+	if((core_ptr == NULL) || (dev == NULL))
 	    return;
 
-	cmd = dev_ptr->command_format;
+	cmd = dev->command_format;
 	if(cmd == NULL)
 	    return;
 
@@ -1146,16 +1097,20 @@ void EDVRunTerminal(
 	GtkWidget *toplevel
 )
 {
+	const cfg_item_struct *cfg_list;
+
 	if(core_ptr == NULL)
 	    return;
 
+	cfg_list = core_ptr->cfg_list;
+
 	if(!STRISEMPTY(cmd))
 	{
 	    /* Get terminal command for running a program with a
 	     * terminal, format the command, then run the command
 	     */
-	    const gchar *cmd_src = CFGItemListGetValueS(
-		core_ptr->cfg_list, EDV_CFG_PARM_PROG_TERMINAL_RUN
+	    const gchar *cmd_src = EDV_GET_S(
+		EDV_CFG_PARM_PROG_TERMINAL_RUN
 	    );
 	    if(!STRISEMPTY(cmd_src))
 	    {
@@ -1171,8 +1126,8 @@ void EDVRunTerminal(
 	else
 	{
 	    /* No command given, just run terminal */
-	    const gchar *cmd_src = CFGItemListGetValueS(
-		core_ptr->cfg_list, EDV_CFG_PARM_PROG_TERMINAL
+	    const gchar *cmd_src = EDV_GET_S(
+		EDV_CFG_PARM_PROG_TERMINAL
 	    );
 	    if(!STRISEMPTY(cmd_src))
 		Exec(cmd_src);
@@ -1199,6 +1154,7 @@ void EDVMapRecBinDeskIcon(edv_core_struct *core_ptr)
  */
 void EDVMapRecBin(edv_core_struct *core_ptr)
 {
+	GtkWidget *toplevel;
 	GtkCList *clist;
 	const cfg_item_struct *cfg_list;
 	edv_recbin_struct *recbin;
@@ -1211,12 +1167,12 @@ void EDVMapRecBin(edv_core_struct *core_ptr)
 	/* Get pointer to Recycle Bin window, create it as needed */
 	recbin = core_ptr->recbin;
 	if(recbin == NULL)
-	    core_ptr->recbin = recbin = EDVRecBinNew(
-		core_ptr
-	    );
+	    core_ptr->recbin = recbin = EDVRecBinNew(core_ptr);
 	if(recbin == NULL)
 	    return;
 
+	toplevel = recbin->toplevel;
+
 	/* Need to map it immediatly after it is created so that it does
 	 * not get deleted in the timeout callback when the recycle bin
 	 * is updated further below
@@ -1224,7 +1180,7 @@ void EDVMapRecBin(edv_core_struct *core_ptr)
 	EDVRecBinMap(recbin);
 
 	EDVRecBinSetBusy(recbin, TRUE);
-	GUIBlockInput(recbin->toplevel, TRUE);
+	GUIBlockInput(toplevel, TRUE);
 
 	clist = (GtkCList *)recbin->contents_clist;
 	if(clist != NULL)
@@ -1237,7 +1193,7 @@ void EDVMapRecBin(edv_core_struct *core_ptr)
 	    gtk_clist_thaw(clist);
 	}
 
-	GUIBlockInput(recbin->toplevel, FALSE);
+	GUIBlockInput(toplevel, FALSE);
 	EDVRecBinSetBusy(recbin, FALSE);
 
 	EDVRecBinUpdateMenus(recbin);
@@ -1345,7 +1301,7 @@ void EDVMapCustomizeWin(
 	/* Get Customize Window, create it as needed */
 	optwin = core_ptr->customize_window;
 	if(optwin == NULL)
-	    core_ptr->customize_window = optwin = EDVCreateCustomizeWindow(
+	    core_ptr->customize_window = optwin = EDVCustomizeWindowNew(
 		core_ptr
 	    );
 	if(optwin == NULL)
@@ -2048,7 +2004,7 @@ void EDVUpdateDevicesPUList(edv_core_struct *core_ptr)
 	GtkRcStyle *rcstyle;
 	GtkWidget *w;
 	edv_device_icon_state state = EDV_DEVICE_ICON_STATE_STANDARD;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	pulist_struct *pulist;
 
 	if(core_ptr == NULL)
@@ -2073,30 +2029,30 @@ void EDVUpdateDevicesPUList(edv_core_struct *core_ptr)
 	/* Add Devices to the Popup List */
 	for(i = 0; i < core_ptr->total_devices; i++)
 	{
-	    dev_ptr = core_ptr->device[i];
-	    if(dev_ptr == NULL)
+	    dev = core_ptr->device[i];
+	    if(dev == NULL)
 		continue;
 
 	    /* Skip devices who are marked as unlisted, in which case 
 	     * they should not be listed on the devices popup list
 	     */
-	    if(dev_ptr->unlisted)
+	    if(EDV_DEVICE_IS_UNLISTED(dev))
 		continue;
 
 	    /* Realize device, loading icons as needed */
-	    EDVDeviceRealize(dev_ptr, FALSE);
+	    EDVDeviceRealize(dev, FALSE);
 
 	    /* Get device name */
-	    dev_name = dev_ptr->name;
-	    if((dev_name == NULL) && (dev_ptr->device_path != NULL))
-		dev_name = EDVGetPathName(dev_ptr->device_path);
+	    dev_name = dev->name;
+	    if((dev_name == NULL) && (dev->device_path != NULL))
+		dev_name = EDVGetPathName(dev->device_path);
 	    if(dev_name == NULL)
 		dev_name = "(null)";
 
 	    /* Add new item to devices popup list */
 	    n = PUListAddItemPixText(
 		pulist, dev_name,
-		dev_ptr->small_pixmap[state], dev_ptr->small_mask[state]
+		dev->small_pixmap[state], dev->small_mask[state]
 	    );
 	    if(n < 0)
 		continue;
