@@ -46,15 +46,15 @@ extern gint EDVNewPropertiesDialog(
 
 /* Running */
 extern void EDVRunDeviceCheck(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 );
 extern void EDVRunDeviceTools(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 );
 extern void EDVRunDeviceFormat(
-	edv_core_struct *core_ptr, edv_device_struct *dev_ptr,
+	edv_core_struct *core_ptr, edv_device_struct *dev,
 	GtkWidget *toplevel
 );
 
