@@ -1,7 +1,10 @@
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
+#include <sys/stat.h>
 #include <gtk/gtk.h>
+#include <unistd.h>
+
+#include "../include/string.h"
 
 #include "edvtypes.h"
 #include "edvmimetypes.h"
@@ -10,23 +13,36 @@
 #include "edvop.h"
 #include "edvutils.h"
 #include "edvutilsgtk.h"
+
 #include "edvcfglist.h"
 #include "config.h"
 
 
-static gchar *EDVOpenFormatCommandPath(
-	const gchar *cmd, const gchar *path
+static gboolean EDVOpenIsFileExecutable(const gchar *path);
+static gchar *EDVOpenFormatCommand(
+	edv_core_struct *core_ptr, const gchar *cmd, GList *paths_list
 );
 
-gint EDVOpenObjectPath(
-	edv_core_struct *core_ptr, const gchar *path,
+/* Open */
+static gint EDVOpenIteration(
+	edv_core_struct *core_ptr,
+	const gchar *path,
+	const gchar *command_name,
+	GtkWidget *toplevel, gboolean verbose,
+	gchar **stdout_path_rtn, gchar **stderr_path_rtn
+);
+gint EDVOpen(
+	edv_core_struct *core_ptr,
+	GList *paths_list,
 	const gchar *command_name,
 	GtkWidget *toplevel, gboolean verbose,
 	gchar **stdout_path_rtn, gchar **stderr_path_rtn
 );
 
-gint EDVOpenWithObjectPath(
-	edv_core_struct *core_ptr, const gchar *path,
+/* Open With */
+gint EDVOpenWith(
+	edv_core_struct *core_ptr,
+	GList *paths_list,
 	const gchar *command_name,
 	GtkWidget *toplevel, gboolean verbose,
 	gchar **stdout_path_rtn, gchar **stderr_path_rtn
@@ -45,6 +61,31 @@ gint EDVOpenWithObjectPath(
 #define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
+/*
+ *	Checks if the object specified by path exists, is a file, and
+ *	is executable.
+ */
+static gboolean EDVOpenIsFileExecutable(const gchar *path)
+{
+	struct stat stat_buf;
+
+	if(STRISEMPTY(path))
+	    return(FALSE);
+
+	/* Get destination stats */
+	if(stat(path, &stat_buf))
+	    return(FALSE);
+
+#ifdef S_ISREG
+	/* Does the path lead to a file? */
+	if(!S_ISREG(stat_buf.st_mode))
+	    return(FALSE);
+#endif
+
+	/* Is this file executable? */
+	return(!access(path, X_OK) ? TRUE : FALSE);
+}
+
 /*
  *	Substitutes the "%s" in the specified command with the specified
  *	path. Quotes '"' will be added as needed and '&' will be
@@ -53,85 +94,168 @@ gint EDVOpenWithObjectPath(
  *	Returns a dynamically allocated string describing the formatted
  *	command, the calling function must delete ther returned string.
  */
-static gchar *EDVOpenFormatCommandPath(
-	const gchar *cmd, const gchar *path
+static gchar *EDVOpenFormatCommand(
+	edv_core_struct *core_ptr, const gchar *cmd, GList *paths_list
 )
 {
-	gchar *rs, *st;
-	const gchar *ss, *ss2;
+	const gchar *path, *first_path, *last_path;
+	gchar	*s, *cmd_rtn,
+		*cwd_quoted, *display_quoted, *home_quoted,
+		*names_quoted, *paths_quoted,
+		*first_name_quoted, *last_name_quoted,
+		*first_path_quoted, *last_path_quoted,
+		*pid_quoted;
+	GList *glist;
 
-
-	if(cmd == NULL)
+	if((core_ptr == NULL) || (cmd == NULL))
 	    return(NULL);
 
-	if(path == NULL)
-	    path = "";
+	/* Begin creating substitution values */
 
-	/* Allocate return string */
-	rs = st = (gchar *)g_malloc(
-	    (STRLEN(cmd) + STRLEN(path) + 10) * sizeof(gchar)
+	/* Current working directory */
+	s = EDVGetCWD();
+	cwd_quoted = g_strdup_printf("\"%s\"", s);
+	g_free(s);
+
+	/* Display address */
+	display_quoted = g_strdup_printf(
+	    "\"%s\"",
+	    g_getenv(ENV_VAR_NAME_DISPLAY)
 	);
-	if(rs == NULL)
-	    return(NULL);
 
-	/* Look for token in in the specified command string (if any) */
-	ss = cmd;
-	ss2 = (const gchar *)strstr(
-	    (const char *)ss, "%s"
-	);
-	if(ss2 != NULL)
+	/* Home directory */
+	home_quoted = g_strdup_printf("\"%s\"", core_ptr->home_dir);
+
+	/* All selected object names */
+	names_quoted = STRDUP("\"");
+	for(glist = paths_list; glist != NULL; glist = g_list_next(glist))
 	{
-	    gboolean token_has_quotes = (strstr(ss, "\"%s\"") != NULL) ?
-		TRUE : FALSE;
+	    path = (gchar *)glist->data;
+	    if(path == NULL)
+		continue;
 
-	    /* Copy command to return string */
-	    gint len = (gint)(ss2 - ss);
-	    if(len > 0)
-		memcpy(st, ss, len);
-	    ss += len + STRLEN("%s");
-	    st += len;
-
-	    /* Copy the path to the return string */
-	    if(!token_has_quotes)
-		*st++ = '"';
-	    len = STRLEN(path);
-	    strcpy(st, path);
-	    st += len;
-	    if(!token_has_quotes)
-		*st++ = '"';    
-
-	    /* Copy the rest of the command to the return string */
-	    len = STRLEN(ss);
-	    strcpy(st, ss);
-	    st += len;
-
-	    len = STRLEN(" &");
-	    strcpy(st, " &");
-	    st += len;
-	}
-	else
-	{
-	    /* Copy command to return string */
-	    gint len = STRLEN(ss);
-	    if(len > 0)
-		memcpy(st, ss, len);
-	    st += len;
-
-	    /* Append the path to the return string with quotes */
-	    len = STRLEN(" \"");
-	    strcpy(st, " \"");
-	    st += len;
-
-	    len = STRLEN(path);
-	    strcpy(st, path);
-	    st += len;
-
-	    len = STRLEN("\" &");
-	    strcpy(st, "\" &");
-	    st += len;
+	    s = g_strconcat(
+		names_quoted,
+		EDVGetPathName(path),
+		(glist->next != NULL) ? " " : "\"",
+		NULL
+	    );
+	    g_free(names_quoted);
+	    names_quoted = s;
 	}
 
-	return(rs);
+	/* All selected object paths */
+	paths_quoted = STRDUP("\"");
+	for(glist = paths_list; glist != NULL; glist = g_list_next(glist))
+	{
+	    path = (gchar *)glist->data;
+	    if(path == NULL)
+		continue;
+
+	    s = g_strconcat(
+		paths_quoted,
+		path,
+		(glist->next != NULL) ? " " : "\"",
+		NULL
+	    );
+	    g_free(paths_quoted);
+	    paths_quoted = s;
+	}
+
+	/* First selected object name and path */
+	glist = g_list_first(paths_list);
+	first_path = (glist != NULL) ? (gchar *)glist->data : NULL;   
+	if(first_path == NULL)                                        
+	    first_path = "";
+	first_name_quoted = g_strdup_printf("\"%s\"", EDVGetPathName(first_path));
+	first_path_quoted = g_strdup_printf("\"%s\"", first_path);
+
+	/* Last selected object name and path */
+	glist = g_list_last(paths_list);
+	last_path = (glist != NULL) ? (gchar *)glist->data : NULL;
+	if(last_path == NULL)
+	    last_path = "";
+	last_name_quoted = g_strdup_printf("\"%s\"", EDVGetPathName(last_path));
+	last_path_quoted = g_strdup_printf("\"%s\"", last_path);
+
+	/* Process ID */
+	pid_quoted = g_strdup_printf("\"%i\"", core_ptr->pid);
+
+
+	/* Begin formatting the command, always use the quoted string
+	 * as the value and substitute for the quoted token first then
+	 * the unquoted token
+	 */
+	cmd_rtn = STRDUP(cmd);
+
+#define CMDSUB(_token_,_val_)	{			\
+ gchar *s = strsub(cmd_rtn, (_token_), (_val_));	\
+ g_free(cmd_rtn);					\
+ cmd_rtn = s;						\
+}
+
+	/* "%cwd" - Current working directory */
+	CMDSUB("\"%cwd\"", cwd_quoted);
+	CMDSUB("%cwd", cwd_quoted);
+
+	/* "%display" - Display address */
+	CMDSUB("\"%display\"", display_quoted);
+	CMDSUB("%display", display_quoted);    
+
+	/* "%home" - Home directory */
+	CMDSUB("\"%home\"", home_quoted);
+	CMDSUB("%home", home_quoted);
+
+	/* "%names" - Names of all selected objects (without paths) */
+	CMDSUB("\"%names\"", names_quoted);
+	CMDSUB("%names", names_quoted);
+
+	/* "%paths" - Full paths of all selected objects */
+	CMDSUB("\"%paths\"", last_path_quoted);
+	CMDSUB("%paths", last_path_quoted);
+
+	/* "%first_name" - Name of first selected object (without path) */
+	CMDSUB("\"%first_name\"", first_name_quoted);
+	CMDSUB("%first_name", first_name_quoted);
+
+	/* "%first_path" - Full path to last selected object */
+	CMDSUB("\"%first_path\"", first_path_quoted);
+	CMDSUB("%first_path", first_path_quoted);
+
+	/* "%name" - Name of last selected object (without path) */
+	CMDSUB("\"%name\"", last_name_quoted);
+	CMDSUB("%name", last_name_quoted);    
+
+	/* "%path" - Full path to last selected object */
+	CMDSUB("\"%path\"", last_path_quoted);
+	CMDSUB("%path", last_path_quoted);
+
+	/* "%pid" - This program's process id */
+	CMDSUB("\"%pid\"", pid_quoted);
+	CMDSUB("%pid", pid_quoted);
+
+	/* "%p" - Full path to last selected object */
+	CMDSUB("\"%p\"", last_path_quoted);
+	CMDSUB("%p", last_path_quoted);
+
+	/* "%s" - Full path to last selected object: */
+	CMDSUB("\"%s\"", last_path_quoted);
+	CMDSUB("%s", last_path_quoted);
+
+#undef CMDSUB
+
+	g_free(cwd_quoted);
+	g_free(display_quoted);
+	g_free(home_quoted);
+	g_free(names_quoted);
+	g_free(paths_quoted);
+	g_free(first_name_quoted);
+	g_free(last_name_quoted);
+	g_free(first_path_quoted);
+	g_free(last_path_quoted);
+	g_free(pid_quoted);
+
+	return(cmd_rtn);
 }
 
 
@@ -151,13 +275,13 @@ static gchar *EDVOpenFormatCommandPath(
  *
  *	Returns:
  *
- *	0	Success
- *	-1	General error
- *	-2	No MIME Type, no application, or ambiguous
- *	-3	System error
- *	-6	Call is a re-enterent to an existing call to this function
+ *	0	Success.
+ *	-1	General error.
+ *	-2	Bad value, no MIME Type, or no application.
+ *	-3	System error.
+ *	-6	Call is a re-enterent to an existing call to this function.
  */
-gint EDVOpenObjectPath(
+static gint EDVOpenIteration(
 	edv_core_struct *core_ptr, const gchar *path,
 	const gchar *command_name,
 	GtkWidget *toplevel, gboolean verbose,
@@ -167,19 +291,11 @@ gint EDVOpenObjectPath(
 	gboolean got_match;
 	gint i, status;
 	const gchar *name, *command_base;
-	const cfg_item_struct *cfg_list;
-	edv_mimetype_struct *mt_ptr;
+	const cfg_item_struct *cfg_list = core_ptr->cfg_list;
+	edv_mimetype_struct *mt;
 
-	/* Reset returns */
-	if(stdout_path_rtn != NULL)
-	    *stdout_path_rtn = NULL;
-	if(stderr_path_rtn != NULL)
-	    *stderr_path_rtn = NULL;
-
-	if((core_ptr == NULL) || STRISEMPTY(path))
-	    return(-1);
-
-	cfg_list = core_ptr->cfg_list;
+	if(STRISEMPTY(path))
+	    return(-2);
 
 	/* Get the object's name */
 	name = EDVGetPathName(path);
@@ -187,22 +303,22 @@ gint EDVOpenObjectPath(
 	/* Iterate through MIME Types list and look for a MIME Type
 	 * appropriate for the specified object
 	 */
-	mt_ptr = NULL;
+	mt = NULL;
 	got_match = FALSE;
 	for(i = 0; i < core_ptr->total_mimetypes; i++)
 	{
-	    mt_ptr = core_ptr->mimetype[i];
-	    if(mt_ptr == NULL)
+	    mt = core_ptr->mimetype[i];
+	    if(mt == NULL)
 		continue;
 
 	    /* Handle by the MIME Type's class */
 	    got_match = FALSE;
-	    switch(mt_ptr->mt_class)
+	    switch(mt->mt_class)
 	    {
 	      case EDV_MIMETYPE_CLASS_SYSTEM:
 		break;
 	      case EDV_MIMETYPE_CLASS_FORMAT:
-		if(EDVIsExtension(name, mt_ptr->value))
+		if(EDVIsExtension(name, mt->value))
 		{
 		    got_match = TRUE;
 		}
@@ -210,9 +326,9 @@ gint EDVOpenObjectPath(
 	      case EDV_MIMETYPE_CLASS_PROGRAM:
 		break;
 	      case EDV_MIMETYPE_CLASS_UNIQUE:
-		if(mt_ptr->value != NULL)
+		if(mt->value != NULL)
 		{
-		    if(!strcmp(path, mt_ptr->value))
+		    if(!strcmp(path, mt->value))
 			got_match = TRUE;
 		}
 		break;
@@ -221,22 +337,21 @@ gint EDVOpenObjectPath(
 	    if(got_match)
 		break;
 	}
-	/* Unable to match MIME Type? */
-	if(!got_match || (mt_ptr == NULL))
+	/* Unable to find a MIME Type appropriate for this object? */
+	if(!got_match || (mt == NULL))
 	{
-	    const char *def_viewer = EDV_GET_S(EDV_CFG_PARM_PROG_DEF_VIEWER);
+	    const char *def_viewer_cmd = EDV_GET_S(EDV_CFG_PARM_PROG_DEF_VIEWER);
 
-	    /* Since this object's name does not match any MIME Type,
-	     * check if the object itself is executable and if it is
-	     * then execute it
+	    /* If this object is a file and is set executable, then
+	     * attempt to run it
 	     */
-	    if(!access(path, X_OK))
+	    if(EDVOpenIsFileExecutable(path))
 	    {
 		gint pid;
-		gchar *parent, *pwd, *cmd;
+		gchar *parent, *cmd;
 
 		/* Record previous working dir */
-		pwd = EDVGetCWD();
+		gchar *pwd = EDVGetCWD();
 
 		/* Set new working dir as the parent of the specified
 		 * path
@@ -264,8 +379,8 @@ gint EDVOpenObjectPath(
 		EDVCHDir(pwd);
 		g_free(pwd);
 
-		/* Failed to execute the given object? */
-		if(status && verbose)
+		/* Failed to execute the object? */
+		if((status != 0) && verbose)
 		{
 		    gchar *buf = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -357,14 +472,17 @@ a specific MIME Type, try File->Open With.",
 		}
 		return(status);
 	    }
-	    /* Use the default viewer to view this object */
-	    else if(!STRISEMPTY(def_viewer))
+	    /* Object is not executable, use the default viewer to view
+	     * this object
+	     */
+	    else if(!STRISEMPTY(def_viewer_cmd))
 	    {
 		gint pid;
-		gchar *parent, *pwd, *cmd;
+		gchar *parent, *cmd;
+		GList *paths_list = NULL;
 
 		/* Record previous working dir */
-		pwd = EDVGetCWD();
+		gchar *pwd = EDVGetCWD();
 
 		/* Set new working dir as the parent of the specified
 		 * path
@@ -373,8 +491,14 @@ a specific MIME Type, try File->Open With.",
 		EDVCHDir(parent);
 		g_free(parent);
 
-		/* Format command to view the object */
-		cmd = EDVOpenFormatCommandPath(def_viewer, path);
+		/* Format command */
+		paths_list = g_list_append(
+		    paths_list,
+		    STRDUP(path)
+		);
+		cmd = EDVOpenFormatCommand(core_ptr, def_viewer_cmd, paths_list);
+		g_list_foreach(paths_list, (GFunc)g_free, NULL);
+		g_list_free(paths_list);
 
 		/* Execute command */
 		pid = EDVSystem(cmd);
@@ -391,7 +515,10 @@ a specific MIME Type, try File->Open With.",
 
 		return(status);
 	    }
-	    /* All else print warning */
+	    /* All else print warning about not finding a MIME Type,
+	     * not being able to execute, and not being able to use a
+	     * default viewer for this object
+	     */
 	    else if(verbose)
 	    {
 		gchar *buf = g_strdup_printf(
@@ -505,12 +632,12 @@ Help->MIME Types...",
 	}
 
 	/* At this point a MIME Type has been matched, find out how we
-	 * should open it by checking its handler code
+	 * should open it by checking the MIME Type's handler code
 	 *
-	 * Any handler code specifying an internal Endeavour resource
-	 * will return within this switch() statement
+	 * Any handler code specifying an internal Endeavour method
+	 * will return() within this switch() statement
 	 */
-	switch(mt_ptr->handler)
+	switch(mt->handler)
 	{
 	  case EDV_MIMETYPE_HANDLER_COMMAND:
 	    /* Open this object with a command, so go on with the
@@ -568,7 +695,7 @@ com este objeto nao  apoiado.\n",
 tilknyttet med dette objektet ikke sttter.\n",
 #else
 "Handler Not Supported",
-"The handler defined for the MIME Type associated\n\
+"The handler specified for the MIME Type associated\n\
 with this object is not supported.\n",
 #endif
 		NULL,
@@ -578,45 +705,44 @@ with this object is not supported.\n",
 	    break;
 	}
 
-	/* If this point has been reached, it means that an external
-	 * command should be executed to open the object
+	/* If this point has been reached, then it means that an
+	 * external command should be executed to open the object
 	 */
 
-	/* Get the base command command_base that matches the given
-	 * command name or the first defined command on the MIME Type
-	 * if no command name is given
+	/* Get the command_base that matches the specified command name,
+	 * or the first defined command on the MIME Type if no command
+	 * name is given
 	 */
 	command_base = NULL;
 	if(!STRISEMPTY(command_name))
 	{
-	    const gchar *s;
-	    /* Command name is given, iterate through commands and get
-	     * the command who's name matches the given command name
-	     * as the base command
+	    /* The command name is specified, find a command on this
+	     * MIME Type who's command name matches the specified
+	     * command name
 	     */
-	    for(i = 0; i < mt_ptr->total_commands; i++)
+	    const gchar *s;
+	    for(i = 0; i < mt->total_commands; i++)
 	    {
-		s = mt_ptr->command_name[i];
+		s = mt->command_name[i];
 		if(!STRISEMPTY(s) ? !g_strcasecmp(s, command_name) : FALSE)
 		{
-		    command_base = mt_ptr->command[i];
+		    command_base = mt->command[i];
 		    break;
 		}
 	    }
 	}
 	else
 	{
-	    /* No specified command name given, so use the default
-	     * (the first) command defined on the MIME Type (if any)
+	    /* No command name specified, so use the default (the
+	     * first) command defined on the MIME Type (if any)
 	     */
-	    if(mt_ptr->total_commands > 0)
-		command_base = mt_ptr->command[0];
+	    if(mt->total_commands > 0)
+		command_base = mt->command[0];
 	}
 
-	/* Unable to find base command from the matched MIME Type? */
+	/* Matched MIME Type has no command_base? */
 	if(STRISEMPTY(command_base))
 	{
-	    /* MIME Type has no such command */
 	    if(verbose)
 	    {
 		gchar *buf;
@@ -639,7 +765,7 @@ with this object is not supported.\n",
 #else
 "MIME Type \"%s\" does not have a \"%s\" command.\n"
 #endif
-			, mt_ptr->type, command_name
+			, mt->type, command_name
 		    );
 		else
 		    buf = g_strdup_printf(
@@ -660,7 +786,7 @@ with this object is not supported.\n",
 #else
 "MIME Type \"%s\" does not have any defined commands.\n"
 #endif
-			, mt_ptr->type
+			, mt->type
 		    );
 		EDVPlaySoundWarning(core_ptr);
 		EDVMessageWarning(
@@ -737,31 +863,30 @@ Help->MIME Types...",
 	}
 
 
-	/* If the matched base command is not an absolute path then it
-	 * implies that it reffers to another MIME Type, so try to find
-	 * another MIME Type who's class is EDV_MIMETYPE_CLASS_PROGRAM and
-	 * type matches the base command
+	/* If the matched command_base is not an absolute path then it
+	 * implies that it refers to another MIME Type
 	 */
 	if(*command_base != G_DIR_SEPARATOR)
 	{
-	    /* Find another MIME Type who's type matches the matched
-	     * base command
+	    /* Try to find that other MIME Type who's class is
+	     * EDV_MIMETYPE_CLASS_PROGRAM and its type matches
+	     * command_base
 	     */
-	    mt_ptr = NULL;
+	    mt = NULL;
 	    got_match = FALSE;
 	    for(i = 0; i < core_ptr->total_mimetypes; i++)
 	    {
-		mt_ptr = core_ptr->mimetype[i];
-		if(mt_ptr == NULL)
+		mt = core_ptr->mimetype[i];
+		if(mt == NULL)
 		    continue;
 
 		/* Check only MIME Types who's class is
 		 * EDV_MIMETYPE_CLASS_PROGRAM
 		 */
-		if(mt_ptr->mt_class == EDV_MIMETYPE_CLASS_PROGRAM)
+		if(mt->mt_class == EDV_MIMETYPE_CLASS_PROGRAM)
 		{
-		    if((mt_ptr->type != NULL) ?
-			!strcmp(mt_ptr->type, command_base) : FALSE
+		    if((mt->type != NULL) ?
+			!strcmp(mt->type, command_base) : FALSE
 		    )
 		    {
 			/* Found a referenced MIME Type, now get its
@@ -772,18 +897,15 @@ Help->MIME Types...",
 			 * obtained from a MIME Type of class
 			 * EDV_MIMETYPE_CLASS_PROGRAM
 			 */
-			if(mt_ptr->total_commands > 0)
-			    command_base = mt_ptr->command[0];
-			else
-			    command_base = NULL;
+			command_base = (mt->total_commands > 0) ?
+			    mt->command[0] : NULL;
 			got_match = TRUE;
+			break;
 		    }
 		}
-		if(got_match)
-		    break;
 	    }
 	    /* Unable to match MIME Type? */
-	    if(!got_match || (mt_ptr == NULL))
+	    if(!got_match || (mt == NULL))
 	    {
 		/* No MIME Type associated for the given path */
 		if(verbose)
@@ -884,17 +1006,13 @@ Help->MIME Types...",
 	}
 
 
-	/* mt_ptr at this point should be considered invalid */
-
-	/* The command_base may be modified at this point, check if
-	 * the MIME Type has no defined command
-	 */
+	/* MIME Type has no defined command? */
 	if(STRISEMPTY(command_base))
 	{
 	    if(verbose)
 	    {
 		gchar *buf;
-		if(mt_ptr != NULL)
+		if(mt != NULL)
 		    buf = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "\"%s\" de tipo MIME no tiene una orden definida."
@@ -913,7 +1031,7 @@ Help->MIME Types...",
 #else
 "MIME Type \"%s\" does not have a defined command."
 #endif
-			, mt_ptr->type
+			, mt->type
 		    );
 		else
 		    buf = STRDUP(
@@ -998,13 +1116,11 @@ Help->MIME Types...",
 	if(TRUE)
 	{
 	    gint pid;
-	    gchar *parent, *pwd, *cmd;
+	    gchar *parent, *cmd;
+	    GList *paths_list = NULL;
 
-	    /* Format command */
-	    cmd = EDVOpenFormatCommandPath(command_base, path);
-
-	    /* Record previous working dir */  
-	    pwd = EDVGetCWD();
+	    /* Record previous working dir */
+	    gchar *pwd = EDVGetCWD();  
 
 	    /* Set new working dir as the parent of the specified
 	     * path
@@ -1013,6 +1129,15 @@ Help->MIME Types...",
 	    EDVCHDir(parent);
 	    g_free(parent);
 
+	    /* Format command */
+	    paths_list = g_list_append(
+		paths_list,
+		STRDUP(path)
+	    );
+	    cmd = EDVOpenFormatCommand(core_ptr, command_base, paths_list);
+	    g_list_foreach(paths_list, (GFunc)g_free, NULL);
+	    g_list_free(paths_list);
+
 	    /* Execute command */
 	    pid = EDVSystem(cmd);
 	    if(pid <= 0)
@@ -1031,25 +1156,80 @@ Help->MIME Types...",
 }
 
 /*
- *      Procedure to execute an application selected on the `open with'
- *	popup list widget mapped at the current pointer position.
+ *	Opens the object(s) specified in the paths_list.
  *
- *      If and only if stdout_path_rtn or stderr_path_rtn are not NULL,
- *      then they will be set with a dynamically allocated string
- *      containing the stdout and stderr output file paths. Which the
- *      calling function must deallocate.
+ *	The command_name specifies which MIME Type command must be used
+ *	to open the object.
  *
- *      Returns:
+ *	If stdout_path_rtn or stderr_path_rtn are not NULL, then paths
+ *	to the stdout and stderr files will be returned. The calling
+ *	function must delete the returned strings.
  *
- *      0       Success
- *      -1      General error
- *      -2      No MIME Type, no application, or ambiguous
- *      -3      System error
- *	-4	User responded with `Cancel'
- *      -6      Call is a renterent to an existing call to this function
+ *	Returns:
+ *
+ *	0	Success.
+ *	-1	General error.
+ *	-2	Bad value, no MIME Type, or no application.
+ *	-3	System error.
+ *	-6	Call is a re-enterent to an existing call to this function.
  */
-gint EDVOpenWithObjectPath(
-	edv_core_struct *core_ptr, const gchar *path,
+gint EDVOpen(
+	edv_core_struct *core_ptr,
+	GList *paths_list,
+	const gchar *command_name,
+	GtkWidget *toplevel, gboolean verbose,
+	gchar **stdout_path_rtn, gchar **stderr_path_rtn
+)
+{
+	gint status;
+	GList *glist;
+
+	/* Reset returns */
+	if(stdout_path_rtn != NULL)
+	    *stdout_path_rtn = NULL;
+	if(stderr_path_rtn != NULL)
+	    *stderr_path_rtn = NULL;
+
+	if((core_ptr == NULL) || (paths_list == NULL))
+	    return(-1);
+
+	for(glist = paths_list; glist != NULL; glist = g_list_next(glist))
+	{
+	    status = EDVOpenIteration(
+		core_ptr, (gchar *)glist->data,
+		command_name,
+		toplevel, verbose,
+		stdout_path_rtn, stderr_path_rtn
+	    );
+	    if(status < 0)
+		return(status);
+	}
+
+	return(0);
+}
+
+
+/*
+ *	Opens the object(s) specified in the paths_list by prompting
+ *	the user to select a method from the Open With Popup List.
+ *
+ *	If and only if stdout_path_rtn or stderr_path_rtn are not NULL,
+ *	then they will be set with a dynamically allocated string
+ *	containing the stdout and stderr output file paths. Which the
+ *	calling function must deallocate.
+ *
+ *	Returns:
+ *
+ *	0	Success
+ *	-1	General error
+ *	-2	Bad value
+ *	-3	System error
+ *	-4	User responded with `Cancel'
+ *	-6	Call is a renterent to an existing call to this function
+ */
+gint EDVOpenWith(
+	edv_core_struct *core_ptr,
+	GList *paths_list,
 	const gchar *command_name,
 	GtkWidget *toplevel, gboolean verbose,
 	gchar **stdout_path_rtn, gchar **stderr_path_rtn
@@ -1058,7 +1238,7 @@ gint EDVOpenWithObjectPath(
 	const gchar *value, *command_base;
 	gint mt_num, status;
 	pulist_struct *pulist;
-	edv_mimetype_struct *mt_ptr;
+	edv_mimetype_struct *mt;
 	
 	/* Reset returns */
 	if(stdout_path_rtn != NULL)
@@ -1066,10 +1246,10 @@ gint EDVOpenWithObjectPath(
 	if(stderr_path_rtn != NULL)
 	    *stderr_path_rtn = NULL;
 
-	if((core_ptr == NULL) || STRISEMPTY(path))
+	if((core_ptr == NULL) || (paths_list == NULL))
 	    return(-1);
 
-	/* Get pointer to `open with' popup list */
+	/* Get the Open With Popup List */
 	pulist = core_ptr->openwith_pulist;
 	if(pulist == NULL)
 	    return(-1);
@@ -1089,26 +1269,19 @@ gint EDVOpenWithObjectPath(
 	if(value == NULL)
 	    return(-4);
 
-	/* Get MIME Type index number from the matched value */
+	/* Get MIME Type from the matched value */
 	mt_num = (gint)PUListGetDataFromValue(pulist, value);
-	if((mt_num >= 0) && (mt_num < core_ptr->total_mimetypes))
-	    mt_ptr = core_ptr->mimetype[mt_num];
-	else
-	    mt_ptr = NULL;
-
-	/* No such MIME Type? */
-	if(mt_ptr == NULL)
+	mt = ((mt_num >= 0) && (mt_num < core_ptr->total_mimetypes)) ?
+	    core_ptr->mimetype[mt_num] : NULL;
+	if(mt == NULL)
 	    return(-2);
 
 	/* MIME Type must be of class EDV_MIMETYPE_CLASS_PROGRAM */
-	if(mt_ptr->mt_class != EDV_MIMETYPE_CLASS_PROGRAM)
+	if(mt->mt_class != EDV_MIMETYPE_CLASS_PROGRAM)
 	    return(-2);
 
 	/* Get first command on the MIME Type as the base command */
-	if(mt_ptr->total_commands > 0)
-	    command_base = mt_ptr->command[0];
-	else
-	    command_base = NULL;
+	command_base = (mt->total_commands > 0) ? mt->command[0] : NULL;
 
 	/* MIME Type has no defined command? */
 	if(STRISEMPTY(command_base))
@@ -1116,7 +1289,7 @@ gint EDVOpenWithObjectPath(
 	    if(verbose)
 	    {
 		gchar *buf;
-		if(mt_ptr != NULL)
+		if(mt != NULL)
 		    buf = g_strdup_printf(
 #if defined(PROG_LANGUAGE_SPANISH)
 "\"%s\" de tipo MIME no tiene una orden definida."
@@ -1135,7 +1308,7 @@ gint EDVOpenWithObjectPath(
 #else
 "MIME Type \"%s\" does not have a defined command."
 #endif
-			, mt_ptr->type
+			, mt->type
 		    );
 		else
 		    buf = STRDUP(
@@ -1220,21 +1393,23 @@ Help->MIME Types...",
 	if(TRUE)
 	{
 	    gint pid;
-	    gchar *parent, *pwd, *cmd;
-
-	    /* Format command */
-	    cmd = EDVOpenFormatCommandPath(command_base, path);
+	    gchar *parent, *cmd;
 
 	    /* Record previous working dir */
-	    pwd = EDVGetCWD();
+	    gchar *pwd = EDVGetCWD();
 
 	    /* Set new working dir as the parent of the specified
 	     * path
 	     */
-	    parent = g_dirname(path);
+	    parent = g_dirname(
+		(paths_list != NULL) ? (gchar *)paths_list->data : NULL
+	    );
 	    EDVCHDir(parent);
 	    g_free(parent);
 
+	    /* Format command */
+	    cmd = EDVOpenFormatCommand(core_ptr, command_base, paths_list);
+
 	    /* Execute command */
 	    pid = EDVSystem(cmd);
 	    if(pid <= 0)
