@@ -1,7 +1,6 @@
 #include <glib.h>
 
 #include "edvtypes.h"
-#include "edvobj.h"
 #include "edvrecbin.h"
 
 
@@ -57,7 +56,7 @@ edv_recbin_object_struct *EDVRecBinObjectNew(void)
 
 	obj->type = EDV_OBJECT_TYPE_FILE;
 
-	obj->linked_to = NULL;
+	obj->link_value = NULL;
 	obj->permissions = 0x00000000;
 	obj->access_time = 0l;
 	obj->modify_time = 0l;
@@ -90,7 +89,7 @@ edv_recbin_object_struct *EDVRecBinObjectCopy(
 	tar->date_deleted = src->date_deleted;
 
 	tar->type = src->type;
-	tar->linked_to = STRDUP(src->linked_to);
+	tar->link_value = STRDUP(src->link_value);
 	tar->permissions = src->permissions;
 	tar->access_time = src->access_time;
 	tar->modify_time = src->modify_time;
@@ -112,7 +111,7 @@ void EDVRecBinObjectDelete(edv_recbin_object_struct *obj)
 
 	g_free(obj->name);
 	g_free(obj->original_path);
-	g_free(obj->linked_to);
+	g_free(obj->link_value);
 
 	g_free(obj);
 }
