@@ -12,7 +12,7 @@
 
 
 /*
- *	Recycled object structure:
+ *	Recycled Object:
  */
 typedef struct {
 
@@ -34,11 +34,9 @@ typedef struct {
 
 	/* Following are original statistics of the object */
 
-	gint		type;		/* One of EDV_OBJECT_TYPE_* */
+	edv_object_type	type;
 
-	gchar		*linked_to;	/* Link destination, only for type
-					 * EDV_OBJECT_TYPE_LINK
-					 */
+	gchar		*link_value;	/* Only for EDV_OBJECT_TYPE_LINK */
 
 	edv_permission_flags permissions;	/* Any of EDV_PERMISSION_* */
 
