@@ -1,13 +1,14 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/types.h>
 #include <ctype.h>
 #include <errno.h>
 #include <limits.h>
-#include <sys/types.h>
 #include <utime.h>
-#include <unistd.h>
+#include <sys/stat.h>
 #include <glib.h>
+#include <unistd.h>
 
 #include "../include/fio.h"
 #include "../include/disk.h"
@@ -108,19 +109,19 @@ gint EDVRecBinDiskObjectPurgeAll(
 
 static gchar *G_STRCAT(gchar *s, const gchar *s2)
 {
-        if(s != NULL) {
-            if(s2 != NULL) {
-                gchar *sr = g_strconcat(s, s2, NULL);
-                g_free(s);
-                s = sr;
-            }
-        } else {
-            if(s2 != NULL)
-                s = STRDUP(s2);
-            else
-                s = STRDUP("");
-        }
-        return(s);
+	if(s != NULL) {
+	    if(s2 != NULL) {
+		gchar *sr = g_strconcat(s, s2, NULL);
+		g_free(s);
+		s = sr;
+	    }
+	} else {
+	    if(s2 != NULL)
+		s = STRDUP(s2);
+	    else
+		s = STRDUP("");
+	}
+	return(s);
 }
 
 
@@ -287,7 +288,7 @@ static void EDVRecBinIndexWriteObjectIterate(
 	    (int)obj->type
 	);
 	/* LinkedTo */
-	if(!STRISEMPTY(obj->linked_to))
+	if(!STRISEMPTY(obj->link_value))
 	{
 	    /* Make a copy of the link destination and remove any non
 	     * printable characters from it
@@ -297,7 +298,7 @@ static void EDVRecBinIndexWriteObjectIterate(
 	     * value (which is obtained from the recycled file of the
 	     * link)
 	     */
-	    gchar *s = STRDUP(obj->linked_to), *s2;
+	    gchar *s = STRDUP(obj->link_value), *s2;
 	    for(s2 = s; *s2 != '\0'; s2++)
 	    {
 		if(!isprint((char)*s2))
@@ -731,8 +732,8 @@ static gint EDVRecBinObjectGetFromIndexFileIterate(
 		 * destination value (which is obtained from the
 		 * recycled file of the link)
 		 */
-		g_free(obj->linked_to);
-		obj->linked_to = (char *)FGetString(fp);
+		g_free(obj->link_value);
+		obj->link_value = (char *)FGetString(fp);
 	    }
 	    /* Permissions */
 	    else if(!g_strcasecmp(parm, "Permissions"))
@@ -1025,7 +1026,11 @@ gint EDVRecBinDiskObjectDelete(
 	/* Copy in_path to out_path by in_path's type */
 
 	/* Regular file? */
+#ifdef S_ISREG
 	if(S_ISREG(in_lstat_buf.st_mode))
+#else
+	if(TRUE)
+#endif
 	{
 	    guint8 *io_buf;
 	    gulong	file_size = in_lstat_buf.st_size,
@@ -1250,6 +1255,7 @@ gint EDVRecBinDiskObjectDelete(
 		}
 	    }
 	}
+#ifdef S_ISDIR
 	/* Directory? */
 	else if(S_ISDIR(in_lstat_buf.st_mode))
 	{
@@ -1324,6 +1330,8 @@ gint EDVRecBinDiskObjectDelete(
 		    status = -4;
 	    }
 	}
+#endif
+#ifdef S_ISLNK
 	/* Link? */
 	else if(S_ISLNK(in_lstat_buf.st_mode))
 	{
@@ -1340,9 +1348,8 @@ gint EDVRecBinDiskObjectDelete(
 		FILE *out_fp;
 		gchar buf[PATH_MAX + NAME_MAX + 1];
 
-
 		/* Read link destination value */
-		gint bytes_read = (gint)readlink(
+		const gint bytes_read = (gint)readlink(
 		    (const char *)in_path, (char *)buf, sizeof(buf)
 		);
 		if(bytes_read < 0)
@@ -1404,6 +1411,8 @@ gint EDVRecBinDiskObjectDelete(
 		    status = -4;
 	    }
 	}
+#endif
+#ifdef S_ISFIFO
 	/* FIFO pipe? */
 	else if(S_ISFIFO(in_lstat_buf.st_mode))
 	{
@@ -1466,6 +1475,8 @@ gint EDVRecBinDiskObjectDelete(
 		    status = -4;
 	    }
 	}
+#endif
+#ifdef S_ISBLK
 	/* Block device? */
 	else if(S_ISBLK(in_lstat_buf.st_mode))
 	{
@@ -1537,6 +1548,8 @@ gint EDVRecBinDiskObjectDelete(
 		    status = -4;
 	    }
 	}
+#endif
+#ifdef S_ISCHR
 	/* Character device? */
 	else if(S_ISCHR(in_lstat_buf.st_mode))
 	{
@@ -1606,6 +1619,8 @@ gint EDVRecBinDiskObjectDelete(
 		    status = -4;
 	    }
 	}
+#endif
+#ifdef S_ISSOCK
 	/* Socket? */
 	else if(S_ISSOCK(in_lstat_buf.st_mode))
 	{
@@ -1668,6 +1683,7 @@ gint EDVRecBinDiskObjectDelete(
 		    status = -4;
 	    }
 	}
+#endif
 	/* Unsupported type? */
 	else
 	{
@@ -2202,17 +2218,17 @@ gint EDVRecBinDiskObjectRecover(
 		    return(-1);
 		}
 
-                /* Read major number */
-                if(fread(&major, sizeof(gint), 1, in_fp) <
-                    (size_t)(1 * sizeof(gint))
-                )
-                    major = 0;
+		/* Read major number */
+		if(fread(&major, sizeof(gint), 1, in_fp) <
+		    (size_t)(1 * sizeof(gint))
+		)
+		    major = 0;
 
-                /* Read minor number */
-                if(fread(&minor, sizeof(gint), 1, in_fp) <
-                    (size_t)(1 * sizeof(gint))
-                )
-                    minor = 0;
+		/* Read minor number */
+		if(fread(&minor, sizeof(gint), 1, in_fp) <
+		    (size_t)(1 * sizeof(gint))
+		)
+		    minor = 0;
 
 		/* Close input file */
 		FClose(in_fp);
