@@ -1,11 +1,11 @@
 #include <stdlib.h>
 #include <string.h>
+#include <sys/types.h>
 #include <time.h>
 #include <errno.h>
-#include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
 #include <gtk/gtk.h>
+#include <unistd.h>
 
 #include "../include/string.h"
 #include "../include/disk.h"
@@ -1084,10 +1084,10 @@ gint EDVRecBinFOPRecover(
 
 	if(show_progress)
 	{
-	    gchar *p1 = EDVCopyShortenPath(
+	    gchar *p1 = EDVShortenPath(
 		obj->name, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
 	    );
-	    gchar *p2 = EDVCopyShortenPath(
+	    gchar *p2 = EDVShortenPath(
 		ltar_obj, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
 	    );
 	    gchar *buf = g_strdup_printf(
@@ -1242,7 +1242,7 @@ static guint EDVRecBinFOPDeleteIterate(
 {
 	gboolean no_delete;
 	guint index;
-	gint strc;
+	gint strc = 0;
 	gchar **strv;
 	struct stat lstat_buf, stat_buf;
 
@@ -1299,13 +1299,15 @@ static guint EDVRecBinFOPDeleteIterate(
 	}
 
 
-	/* If the given object to be deleted is locally a directory,
-	 * then get contents of the directory and delete recursivly
+	/* If the specified object to be deleted is locally a directory,
+	 * then get contents of the directory and delete recursively
 	 */
-	if(S_ISDIR(lstat_buf.st_mode))
-	    strv = GetDirEntNames2(path, &strc);
-	else
-	    strv = NULL;
+#ifdef S_ISDIR
+	strv = S_ISDIR(lstat_buf.st_mode) ?
+	    GetDirEntNames2(path, &strc) : NULL;
+#else
+	strv = NULL;
+#endif
 	if(strv != NULL)
 	{
 	    gint i;
@@ -1379,7 +1381,7 @@ static guint EDVRecBinFOPDeleteIterate(
 	 */
 	if(show_progress)
 	{
-	    gchar *p1 = EDVCopyShortenPath(
+	    gchar *p1 = EDVShortenPath(
 		path, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
 	    );
 	    gchar *buf = g_strdup_printf(
@@ -1446,7 +1448,11 @@ static guint EDVRecBinFOPDeleteIterate(
 
 	    /* Delete by object type */
 	    /* Directory? */
+#ifdef S_ISDIR
 	    if(S_ISDIR(m))
+#else
+	    if(FALSE)
+#endif
 	    {
 		if(rmdir(path))
 		{
@@ -1569,25 +1575,27 @@ static guint EDVRecBinFOPDeleteIterate(
 
 	    obj->type = EDVObjectGetTypeFromStatMode(m);
 
+#ifdef S_ISLNK
 	    if(S_ISLNK(m))
 	    {
-		gchar linked_to[PATH_MAX + NAME_MAX + 1];
-		gint bytes_read = readlink(
+		gchar link_value[PATH_MAX + NAME_MAX + 1];
+		const gint bytes_read = readlink(
 		    path,
-		    linked_to,
+		    link_value,
 		    PATH_MAX + NAME_MAX
 		);
 		if(bytes_read >= 0)
 		{
 		    if(bytes_read <= (PATH_MAX + NAME_MAX))
-			linked_to[bytes_read] = '\0';
+			link_value[bytes_read] = '\0';
 		    else
-			linked_to[PATH_MAX + NAME_MAX] = '\0';
+			link_value[PATH_MAX + NAME_MAX] = '\0';
 
-		    g_free(obj->linked_to);
-		    obj->linked_to = STRDUP(linked_to);
+		    g_free(obj->link_value);
+		    obj->link_value = STRDUP(link_value);
 		}
 	    }
+#endif
 
 	    obj->permissions = EDVObjectGetPermissionsFromStatMode(m);
 
@@ -1839,7 +1847,7 @@ gint EDVRecBinFOPPurge(
 
 	    if((obj != NULL) ? (obj->name != NULL) : FALSE)
 	    {
-		gchar *p1 = EDVCopyShortenPath(
+		gchar *p1 = EDVShortenPath(
 		    obj->name, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
 		);
 		buf = g_strdup_printf(
