@@ -3,8 +3,9 @@
 #include <ctype.h>
 #include <time.h>
 #include <errno.h>
-#include <unistd.h>
+#include <sys/stat.h>
 #include <gtk/gtk.h>
+#include <unistd.h>
 
 #include "../include/disk.h"
 
@@ -46,9 +47,9 @@ static void EDVRecBinSyncIndexFile(
 	GtkWidget *toplevel,
 	gboolean show_progress, gboolean interactive,
 	gboolean *yes_to_all, gint *status,
-	void (*status_message_cb)(gpointer, const gchar *, gpointer),
-	void (*status_progress_cb)(gpointer, gfloat, gpointer),
-	gpointer client_data
+	void (*status_message_cb)(const gchar *, gpointer),
+	void (*status_progress_cb)(gfloat, gpointer),
+	gpointer data
 );
 static void EDVRecBinSyncObjects(
 	edv_core_struct *core_ptr,
@@ -57,9 +58,9 @@ static void EDVRecBinSyncObjects(
 	GtkWidget *toplevel,
 	gboolean show_progress, gboolean interactive,
 	gboolean *yes_to_all, gint *status,
-	void (*status_message_cb)(gpointer, const gchar *, gpointer),
-	void (*status_progress_cb)(gpointer, gfloat, gpointer),
-	gpointer client_data
+	void (*status_message_cb)(const gchar *, gpointer),
+	void (*status_progress_cb)(gfloat, gpointer),
+	gpointer data
 );
 
 gint EDVRecBinSync(
@@ -67,19 +68,19 @@ gint EDVRecBinSync(
 	GtkWidget *toplevel,
 	gboolean show_progress, gboolean interactive,
 	gboolean *yes_to_all,
-	void (*status_message_cb)(gpointer, const gchar *, gpointer),
-	void (*status_progress_cb)(gpointer, gfloat, gpointer),
-	gpointer client_data
+	void (*status_message_cb)(const gchar *, gpointer),
+	void (*status_progress_cb)(gfloat, gpointer),
+	gpointer data
 );
 
 
-#define STATUS_MESSAGE(s)	{		\
+#define STATUS_MESSAGE(_s_)	{		\
  if(status_message_cb != NULL)			\
-  status_message_cb(NULL, (s), client_data);	\
+  status_message_cb((_s_), data);		\
 }
-#define STATUS_PROGRESS(f)	{		\
+#define STATUS_PROGRESS(_f_)	{		\
  if(status_progress_cb != NULL)			\
-  status_progress_cb(NULL, (f), client_data);	\
+  status_progress_cb((_f_), data);		\
 }
 
 #define MESSAGE_ERROR(t,s)	{	\
@@ -136,9 +137,9 @@ static void EDVRecBinSyncIndexFile(
 	GtkWidget *toplevel,
 	gboolean show_progress, gboolean interactive,
 	gboolean *yes_to_all, gint *status,
-	void (*status_message_cb)(gpointer, const gchar *, gpointer),
-	void (*status_progress_cb)(gpointer, gfloat, gpointer),
-	gpointer client_data
+	void (*status_message_cb)(const gchar *, gpointer),
+	void (*status_progress_cb)(gfloat, gpointer),
+	gpointer data
 )
 {
 	guint index;
@@ -457,9 +458,9 @@ static void EDVRecBinSyncObjects(
 	GtkWidget *toplevel,
 	gboolean show_progress, gboolean interactive,
 	gboolean *yes_to_all, gint *status,
-	void (*status_message_cb)(gpointer, const gchar *, gpointer),
-	void (*status_progress_cb)(gpointer, gfloat, gpointer),
-	gpointer client_data
+	void (*status_message_cb)(const gchar *, gpointer),
+	void (*status_progress_cb)(gfloat, gpointer),
+	gpointer data
 )
 {
 	gint i, strc;
@@ -1161,9 +1162,9 @@ gint EDVRecBinSync(
 	GtkWidget *toplevel,
 	gboolean show_progress, gboolean interactive,
 	gboolean *yes_to_all,
-	void (*status_message_cb)(gpointer, const gchar *, gpointer),
-	void (*status_progress_cb)(gpointer, gfloat, gpointer),
-	gpointer client_data
+	void (*status_message_cb)(const gchar *, gpointer),
+	void (*status_progress_cb)(gfloat, gpointer),
+	gpointer data
 )
 {
 	static gboolean reenterent = FALSE;
@@ -1188,9 +1189,7 @@ gint EDVRecBinSync(
 #define POSTOP_AND_RETURN(rtn_val)	{	\
  /* Report final progress */			\
  if(status_progress_cb != NULL)			\
-  status_progress_cb(				\
-   NULL, 1.0f, client_data			\
-  );						\
+  status_progress_cb(1.0f, data);		\
 						\
  g_free(recbin_dir);				\
  recbin_dir = NULL;				\
@@ -1214,7 +1213,7 @@ gint EDVRecBinSync(
 
 	/* Report initial progress */
 	if(status_progress_cb != NULL)
-	    status_progress_cb(NULL, 0.0f, client_data);
+	    status_progress_cb(0.0f, data);
 
 	/* Check for invalid input values */
 	if(core_ptr == NULL)
@@ -1282,7 +1281,11 @@ buf
 		POSTOP_AND_RETURN(status);
 	    }
 	}
+#ifdef S_ISDIR
 	else if(!S_ISDIR(stat_buf.st_mode))
+#else
+	else if(TRUE)
+#endif
 	{
 	    gchar *buf = g_strdup_printf(
 "Recycle bin directory path:\n\
@@ -1465,7 +1468,7 @@ buf
 		yes_to_all, &status,
 		status_message_cb,
 		status_progress_cb,
-		client_data
+		data
 	    );
 	}
 
@@ -1485,7 +1488,7 @@ buf
 		yes_to_all, &status,
 		status_message_cb,
 		status_progress_cb,
-		client_data
+		data
 	    );
 	}
 
