@@ -10,9 +10,10 @@
 #include <signal.h>
 #include <sched.h>
 #include <sys/wait.h>
+#include <sys/stat.h>
 #include <fnmatch.h>
-#include <unistd.h>
 #include <glib.h>
+#include <unistd.h>
 
 #include "../include/string.h"
 #include "../include/fio.h"
@@ -20,6 +21,7 @@
 
 #include "edvtypes.h"
 #include "edvutils.h"
+
 #include "config.h"
 
 
@@ -39,14 +41,13 @@ static gboolean EDVIsExtensionIterate(
 );
 gboolean EDVIsExtension(const gchar *name, const gchar *ext);
 
-gchar *EDVCopyShortenPath(const gchar *path, gint max);
-gchar *EDVCopyEvaluateInputPath(
-	const gchar *parent, const gchar *input_path
-);
+gchar *EDVShortenPath(const gchar *path, gint max);
+gchar *EDVEvaluatePath(const gchar *parent, const gchar *path);
 gint EDVCHDir(const gchar *path);
 gchar *EDVGetCWD(void);   
 gchar *EDVTmpName(const gchar *dir);
 gchar *EDVWhich(const gchar *name);
+gboolean EDVIsLinkInfinatelyRecursive(const gchar *path);
 
 void EDVGetDeviceNumbers(gint rdev, gint *major, gint *minor);
 gint EDVFormatDeviceNumbers(gint major, gint minor);
@@ -102,7 +103,6 @@ gchar *EDVSizeStrDelim(gulong i)
 	gchar ss[80], *ss_ptr;
 	static gchar ts[80], *ts_ptr;
 
-
 	g_snprintf(ss, sizeof(ss), "%ld", i);
 	slen = STRLEN(ss);
 
@@ -153,17 +153,17 @@ gchar *EDVSizeStrDelim(gulong i)
  */
 const gchar *EDVGetPathName(const gchar *path)
 {
-	const gchar *name = (path != NULL) ?
-	    strrchr(path, G_DIR_SEPARATOR) : NULL;
+	const gchar *name;
 
+	if(path == NULL)
+	    return(NULL);
+
+	name = strrchr(path, G_DIR_SEPARATOR);
 	if(name != NULL)
 	    name++;
 	else
 	    name = path;
 
-	if(name == NULL)
-	    return(NULL);
-
 	return((*name != '\0') ? name : path);
 }
 
@@ -342,7 +342,7 @@ gboolean EDVIsExtension(const gchar *name, const gchar *ext)
 	    for(ext_len = 0,
 		st = cur_ext,
 		ss = ext_ptr;
-		(ext_len < (sizeof(cur_ext) - 1)) &&
+		(ext_len < (gint)(sizeof(cur_ext) - 1)) &&
 		!ISBLANK(*ss) && (*ss != '\0');
 	        ext_len++
 	    )
@@ -367,17 +367,17 @@ gboolean EDVIsExtension(const gchar *name, const gchar *ext)
 
 
 /*
- *	Returns a dynamically allocated path that contains no more
- *	than max characters.
+ *	Returns a path no longer than the specified max characters.
  *
- *	If the given path is longer than max then the shortened
- *	return stirng will contain "..." prefixed to it.
+ *	If the specified path is longer than max then the shortened
+ *	return string will contain a "..." prefix.
+ *
+ *	The calling function must delete the returned string.
  */
-gchar *EDVCopyShortenPath(const gchar *path, gint max)
+gchar *EDVShortenPath(const gchar *path, gint max)
 {
 	gint len;
 
-
 	if(path == NULL)
 	    return(NULL);
 
@@ -398,73 +398,85 @@ gchar *EDVCopyShortenPath(const gchar *path, gint max)
 }
 
 /*
- *	Returns a dynamically allocated path evaluated (all variables
- *	and special notations substituted) based on the specified path.
+ *	Returns an evaluated path based on the specified path.
  *
- *	If input_path (after evaluation) is not an absolute path then the
- *	given parent path (if it is not NULL) will be prefixed to it.
+ *	The parent path should be an absolute path indicating the parent
+ *	or current path. The parent path is only used if the specified
+ *	path is not an absolute path. If the parent path is NULL then
+ *	the toplevel directory will be used as the parent path.
  *
- *	The final path will be simplified.
+ *	The path will be evaulated as follows:
  *
- *	The calling function must delete the returned pointer.
+ *	Check for home directory "~" prefix and substitute home
+ *	directory needed.
+ *
+ *	Simplified, all occurances of ".." evaluated.
+ *
+ *	Tailing directory deliminators removed.
+ *
+ *	The calling function must delete the returned string.
  */
-gchar *EDVCopyEvaluateInputPath(
-	const gchar *parent, const gchar *input_path
-)
+gchar *EDVEvaluatePath(const gchar *parent, const gchar *path)
 {
-	gchar *new_path;
+	gchar *eval_path;
 
-	if(input_path == NULL)
+	if(path == NULL)
 	    return(NULL);
 
 	if(parent == NULL)
+#if defined(_WIN32)
+	    parent = "C:\\";
+#else
 	    parent = "/";
+#endif
 
 	/* Check for special prefix substitutions for the input path */
-	if(strcasepfx(input_path, "~"))
+	if(strcasepfx(path, "~"))
 	{
 	    /* Prefix the value from the HOME environment variable to
 	     * the input path and generate the new path
 	     */
 	    const gchar	*home = g_getenv(ENV_VAR_NAME_HOME),
-			*s = input_path + STRLEN("~");
+			*s = path + STRLEN("~");
 
 	    /* If home directory environment variable value was not set
 	     * then assume toplevel
 	     */
 	    if(home == NULL)
+#if defined(_WIN32)
+		home = "C:\\";
+#else
 		home = "/";
+#endif
 
-	    /* Seek input path after the special prefix and past any
-	     * deliminator characters (deliminator character will be
-	     * added when the new path is generated)
+	    /* Seek s after the prefix and past any deliminator
+	     * characters
 	     */
 	    while(*s == G_DIR_SEPARATOR)
 		s++;
 
-	    /* Generate new path */
-	    new_path = STRDUP(PrefixPaths(home, s));
+	    /* Create the evaluated absolute path with the home dir
+	     * prefixed
+	     */
+	    eval_path = STRDUP(PrefixPaths(home, s));
 	}
 	else
 	{
-	    /* If the given input path is an absolute path then do not
-	     * prefix the given parent to it
-	     */
-	    if(g_path_is_absolute(input_path))
-		new_path = STRDUP(input_path);
-	    else
-		new_path = STRDUP(PrefixPaths(parent, input_path));
+	    /* Create the evaluated absolute path */
+	    eval_path = g_path_is_absolute(path) ?
+		STRDUP(path) :
+		STRDUP(PrefixPaths(parent, path));
 	}
 
 	/* Begin simplifying the generated path */
 
 	/* Simplify path, reducing occurances of "../" */
-	SimplifyPath(new_path);
+	SimplifyPath(eval_path);
 
 	/* Remove tailing deliminators */
-	StripPath(new_path);
+	StripPath(eval_path);
 
-	return(new_path);
+	return(eval_path);
 }
 
 /*
@@ -508,8 +520,12 @@ gchar *EDVTmpName(const gchar *dir)
 	gchar *path;
 
 	if(STRISEMPTY(dir))
-#ifdef P_tmpdir
+	    dir = g_getenv(ENV_VAR_NAME_TMPDIR);
+	if(STRISEMPTY(dir))
+#if defined(P_tmpdir)
 	    dir = P_tmpdir;
+#elif defined(_WIN32)
+	    dir = "C:\\TEMP";
 #else
 	    dir = "/tmp";
 #endif
@@ -545,14 +561,21 @@ gchar *EDVWhich(const gchar *name)
 	if(STRISEMPTY(name))
 	    return(NULL);
 
+	/* Specified name already has an absolute path to it? */
+	if(g_path_is_absolute(name))
+	    return(STRDUP(name));
+
+	/* Get the value of the path environment */
 	path_list = g_getenv(ENV_VAR_NAME_PATH);
 	if(path_list == NULL)
 	    return(NULL);
 
-	pathv = g_strsplit(path_list, ":", -1);
+	/* Break up the path environment into individual paths */
+	pathv = g_strsplit(path_list, G_SEARCHPATH_SEPARATOR_S, -1);
 	if(pathv == NULL)
 	    return(NULL);
 
+	/* Check each individual path location for the specified name */
 	matched_path = NULL;
 	for(i = 0; pathv[i] != NULL; i++);
 	for(i--; i >= 0; i--)
@@ -578,6 +601,75 @@ gchar *EDVWhich(const gchar *name)
 }
 
 
+/*
+ *	Checks if the specified link's destination can possibly be
+ *	infinately recursive.
+ */
+gboolean EDVIsLinkInfinatelyRecursive(const gchar *path)
+{
+	struct stat stat_buf;
+	gboolean status = FALSE;
+	gint len;
+	gchar *s, *parent, *cur_path;
+	gchar link_value[PATH_MAX + NAME_MAX + 1];
+
+	if(STRISEMPTY(path))
+	    return(status);
+
+	/* Is the link's destination not valid? */
+	if(stat(path, &stat_buf))
+	    return(status);
+
+#ifdef S_ISDIR
+	/* Is the link's destination not a directory? */
+	if(!S_ISDIR(stat_buf.st_mode))
+	    return(status);
+#endif
+
+	/* Record the parent of the starting link */
+	parent = g_dirname(path);
+        if(parent == NULL)
+            return(status);
+
+	/* Begin going through each link to reach the destination */
+	cur_path = STRDUP(path);
+	while(cur_path != NULL)
+	{
+	    /* Get the link's destination value, if we get an error it
+	     * means we have reached the end and cur_path is the final
+	     * destination
+	     */
+	    len = (gint)readlink(cur_path, link_value, sizeof(link_value));
+	    if(len <= 0)
+		break;
+	    if(len >= (gint)sizeof(link_value))
+		len = MAX((gint)(sizeof(link_value) - 1), 0);
+	    link_value[len] = '\0';
+
+	    /* Get this link's parent */
+	    s = g_dirname(cur_path);
+	    if(s == NULL)
+		break;
+
+	    /* Get the link's destination as the current path */
+	    g_free(cur_path);
+	    cur_path = EDVEvaluatePath(s, link_value);
+	    g_free(s);
+	}
+
+	if(cur_path != NULL)
+	{
+	    /* Is the destination a grand parent of the starting link? */
+            if(strpfx(parent, cur_path))
+                status = TRUE;
+	}
+
+	g_free(cur_path);
+	g_free(parent);
+
+	return(status);
+}
+
 /*
  *	Returns the device major and minor numbers parsed from the
  *	specified (dev_t)rdev value (obtained from stat()).
