@@ -16,6 +16,7 @@
 #include "cfg.h"
 #include "edvtypes.h"
 #include "edvpixmap.h"
+#include "edvcursor.h"
 #include "edvhistory.h"
 #include "edvhistoryfio.h"
 #include "edvmimetypes.h"
@@ -28,6 +29,18 @@
 #include "config.h"
 
 
+static gchar *G_STRCAT(gchar *s, const gchar *s2);
+
+/* Accelerator Key Matching */
+gint EDVMatchAccelKeyOPID(
+	const cfg_item_struct *cfg_list, const gchar *parm,
+	guint accel_key, guint accel_mods
+);
+cfg_accelkey_struct *EDVMatchAccelKey(
+        const cfg_item_struct *cfg_list, const gchar *parm,
+        gint opid 
+);
+
 /* String Formatting */
 gchar *EDVGetObjectSizeStr(edv_core_struct *core_ptr, gulong i);
 
@@ -49,7 +62,7 @@ GtkWidget *EDVNewPixmapWidget(
 
 /* Cursors */
 GdkCursor *EDVGetCursor(
-	edv_core_struct *core_ptr, gint cursor_code
+	edv_core_struct *core_ptr, edv_cursor_code code
 );
 
 /* GtkCTree Nodes */
@@ -124,10 +137,10 @@ gboolean EDVCheckEDVArchiverArchive(
 gint EDVMatchObjectIcon(
 	edv_device_struct **device, gint total_devices,
 	edv_mimetype_struct **mimetype, gint total_mimetypes,
-	edv_object_type type,	/* One of EDV_OBJECT_TYPE_* */
-	const gchar *path,	/* Full path or just name */
+	edv_object_type type,
+	const gchar *path,	/* Full path or name */
 	gboolean link_valid,
-	edv_permission_flags permissions,	/* Any of EDV_PERMISSION_* */
+	edv_permission_flags permissions,
 	gint icon_size,         /* 0 = small, 1 = medium, 2 = large */
 	GdkPixmap **pixmap_closed, GdkBitmap **mask_closed,
 	GdkPixmap **pixmap_opened, GdkBitmap **mask_opened,
@@ -257,6 +270,87 @@ static gchar *G_STRCAT(gchar *s, const gchar *s2)
 }
 
 
+/*
+ *	Returns the Operation ID of the specified Accelerator Key
+ *	found in the Cfg Item specified by parm or 0 if there is no
+ *	match.
+ */
+gint EDVMatchAccelKeyOPID(
+	const cfg_item_struct *cfg_list, const gchar *parm,
+	guint accel_key, guint accel_mods
+)
+{
+	cfg_accelkey_list_struct *ak_list;
+
+	if((cfg_list == NULL) || STRISEMPTY(parm))
+	    return(0);
+
+	accel_key = gdk_keyval_to_upper(accel_key);
+
+	ak_list = CFGItemListGetValueAccelkeyList(
+	    cfg_list, parm
+	);
+	if(ak_list != NULL)
+	{
+	    cfg_accelkey_struct *ak;
+
+	    GList *glist = ak_list->list;
+	    while(glist != NULL)
+	    {
+		ak = CFG_ACCELKEY(glist->data);
+		if(ak != NULL)
+		{
+		    if((gdk_keyval_to_upper(ak->key) == accel_key) &&
+		       (ak->modifiers == accel_mods)
+		    )
+			return(ak->opid);
+		}
+		glist = g_list_next(glist);
+	    }
+	}
+
+	return(0);
+}
+
+/*
+ *	Returns the Accelerator Key that matches the specified Operation
+ *	ID in the Cfg Item specified by parm.
+ */
+cfg_accelkey_struct *EDVMatchAccelKey(
+        const cfg_item_struct *cfg_list, const gchar *parm,
+        gint opid 
+)
+{
+	cfg_accelkey_list_struct *ak_list;
+
+	if((cfg_list == NULL) || STRISEMPTY(parm) || (opid == 0))
+	    return(NULL);
+
+	ak_list = CFGItemListGetValueAccelkeyList(
+	    cfg_list, parm
+	);
+	if(ak_list != NULL)
+	{
+	    GList *glist;
+	    cfg_accelkey_struct *ak;
+
+	    for(glist = ak_list->list;
+	        glist != NULL;
+	        glist = g_list_next(glist)
+	    )
+	    {
+		ak = CFG_ACCELKEY(glist->data);
+		if(ak == NULL)
+		    continue;
+		if(ak->opid == opid)
+		    return(ak);
+	    }
+	}
+
+	return(NULL);
+}
+
+
 /*
  *	Returns a statically allocated string describing the size
  *	of the object specified by i in units defined by the
@@ -515,13 +609,12 @@ GtkWidget *EDVNewPixmapWidget(
  *	error or failed match.
  */
 GdkCursor *EDVGetCursor(
-	edv_core_struct *core_ptr, gint cursor_code
+	edv_core_struct *core_ptr, edv_cursor_code code
 )
 {
 	gint i;
 	edv_cursor_struct *cur;
 
-
 	if(core_ptr == NULL)
 	    return(NULL);
 
@@ -531,7 +624,7 @@ GdkCursor *EDVGetCursor(
 	    if(cur == NULL)
 		continue;
 
-	    if(cur->code == cursor_code)
+	    if(cur->code == code)
 		return(cur->cursor);
 	}
 
@@ -1323,10 +1416,10 @@ gboolean EDVCheckEDVArchiverArchive(
 gint EDVMatchObjectIcon(
 	edv_device_struct **device, gint total_devices,
 	edv_mimetype_struct **mimetype, gint total_mimetypes,
-	edv_object_type type,	/* One of EDV_OBJECT_TYPE_* */
+	edv_object_type type,
 	const gchar *path,	/* Full path or name */
 	gboolean link_valid,
-	edv_permission_flags permissions,	/* Any of EDV_PERMISSION_ */
+	edv_permission_flags permissions,
 	gint icon_size,		/* 0 = small, 1 = medium, 2 = large */
 	GdkPixmap **pixmap_closed, GdkBitmap **mask_closed,
 	GdkPixmap **pixmap_opened, GdkBitmap **mask_opened,
@@ -1365,13 +1458,14 @@ gint EDVMatchObjectIcon(
 	if(mask_hidden != NULL)
 	    *mask_hidden = NULL;
 
-/* Sets the pixmap & mask pairs for the MIME Type and realizes it
+/* Sets the pixmap & mask pairs from the MIME Type, realizing the MIME
+ * type as needed
  *
  * If one or more pixmaps were obtained than got_match will be set to
  * TRUE
  */
 #define GET_MIMETYPE_ICONS(_m_)	{		\
- gint n;					\
+ edv_mimetype_icon_state n;			\
  const gint nstates = EDV_MIMETYPE_TOTAL_ICON_STATES; \
 						\
  /* Realize MIME Type first (as needed) to	\
@@ -2603,11 +2697,9 @@ void EDVCopyDiskObjectsToDDEURL(
 	gchar *buf = NULL;
 	edv_object_struct *obj;
 
-
 	if((core_ptr == NULL) || (list == NULL) || (total <= 0))
 	    return;
 
-
 	for(i = 0; i < total; i++)
 	{
 	    obj = list[i];
