@@ -13,12 +13,23 @@
 
 #include "cfg.h"
 #include "edvtypes.h"
+#include "edvcursor.h"
 #include "edvdevices.h"
 #include "edvmimetypes.h"
 #include "edvobj.h"
 #include "endeavour.h"
 
 
+/* Accelerator Key Matching */
+extern gint EDVMatchAccelKeyOPID(
+	const cfg_item_struct *cfg_list, const gchar *parm,
+	guint accel_key, guint accel_mods
+);
+extern cfg_accelkey_struct *EDVMatchAccelKey(
+	const cfg_item_struct *cfg_list, const gchar *parm,
+	gint opid
+);
+
 /* String Formatting */
 extern gchar *EDVGetObjectSizeStr(edv_core_struct *core_ptr, gulong i);
 
@@ -40,7 +51,7 @@ extern GtkWidget *EDVNewPixmapWidget(
 
 /* Cursors */
 extern GdkCursor *EDVGetCursor(
-	edv_core_struct *core_ptr, gint cursor_code
+	edv_core_struct *core_ptr, edv_cursor_code code
 );
 
 /* GtkCTree Nodes */
