@@ -43,22 +43,28 @@ void EDVFindBarSetSearch(
 	edv_findbar_struct *fb, const gchar *s,
 	gboolean record_history
 );
-gint EDVFindBarCurrentFindOP(edv_findbar_struct *fb);
+edv_findbar_operation EDVFindBarCurrentFindOP(edv_findbar_struct *fb);
 
 edv_findbar_struct *EDVFindBarNew(
 	gpointer core_ptr, GtkWidget *parent,
-	gint role,
-	void (*status_message_cb)(gpointer, const gchar *, gpointer),
-	void (*status_progress_cb)(gpointer, gfloat, gpointer),
-	gchar *(*get_location_cb)(gpointer, gpointer),
-	void (*start_cb)(gpointer, gpointer),
-	void (*end_cb)(gpointer, gint, gpointer),
+	edv_findbar_role role,
+	const gchar *(*get_location_cb)(
+		edv_findbar_struct *, gpointer
+	),
+	void (*start_cb)(
+		edv_findbar_struct *, gpointer
+	),
+	void (*end_cb)(
+		edv_findbar_struct *, gint, gpointer
+	),
 	void (*match_cb)(
 	    const gchar *, const struct stat *,
 	    const gchar *, gint,
 	    gpointer
 	),
-	gpointer client_data
+        void (*status_message_cb)(const gchar *, gpointer),
+        void (*status_progress_cb)(gfloat, gpointer),      
+	gpointer data
 );
 void EDVFindBarUpdateMenus(edv_findbar_struct *fb);
 void EDVFindBarMap(edv_findbar_struct *fb);
@@ -94,9 +100,9 @@ static gint EDVFindBarProgressCB(
 	    return(1);
 
 	if(fb->status_message_cb != NULL)
-	    fb->status_message_cb(fb, path, fb->client_data);
+	    fb->status_message_cb(path, fb->data);
 	if(fb->status_progress_cb != NULL)
-	    fb->status_progress_cb(fb, progress, fb->client_data);
+	    fb->status_progress_cb(progress, fb->data);
 
 	while(gtk_events_pending() > 0)
 	    gtk_main_iteration();
@@ -124,7 +130,7 @@ static void EDVFindBarMatchExcerptCB(
 		lstat_buf,		/* Stats */
 		excerpt,		/* Excerpt */
 		line_index,		/* Line Index */
-		fb->client_data		/* Data */
+		fb->data		/* Data */
 	    );
 
 	while(gtk_events_pending() > 0)
@@ -146,7 +152,7 @@ static void EDVFindBarMatchCB(
 static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 {
 	gboolean case_sensitive = FALSE;
-	gint op_code;
+	edv_findbar_operation operation;
 	const gchar *s;
 	gchar *location, *search_string;
 	gint total_matches;
@@ -157,7 +163,7 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 	if(fb == NULL)
 	    return;
 
-	if(fb->processing)
+	if(fb->freeze_count > 0)
 	    return;
 
 	core_ptr = EDV_CORE(fb->core_ptr);
@@ -168,13 +174,13 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 
 
 	/* Reset values for upcomming find operation */
-	fb->processing = TRUE;
+	fb->freeze_count++;
 	fb->stop_count = 0;
 	EDVFindBarUpdateMenus(fb);
 
 
 	/* Get find operation */
-	op_code = EDVFindBarCurrentFindOP(fb);
+	operation = EDVFindBarCurrentFindOP(fb);
 
 	/* Get copy of location */
 	s = NULL;
@@ -183,7 +189,7 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 	  case EDV_FINDBAR_ROLE_DISK_OBJECT:
 	  case EDV_FINDBAR_ROLE_ARCHIVE_OBJECT:
 	    if(fb->get_location_cb != NULL)
-		s = fb->get_location_cb(fb, fb->client_data);
+		s = fb->get_location_cb(fb, fb->data);
 	    break;
 	  case EDV_FINDBAR_ROLE_RECYCLED_OBJECT:
 	    s = EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLED_INDEX);
@@ -204,7 +210,7 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 	/* No wild cards in search string? */
 	if((strchr(search_string, '*') == NULL) &&
 	   (strchr(search_string, '?') == NULL) &&
-	   (op_code == EDV_FINDBAR_FIND_OBJECT_NAME)
+	   (operation == EDV_FINDBAR_FIND_OBJECT_NAME)
 	)
 	{
 	    /* Tack on two '*' characters to the beginning and end of
@@ -218,19 +224,19 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 	EDVFindBarSetSearch(fb, search_string, TRUE);
 
 	/* Case sensitive */
-	w = fb->case_sensitive_check;
-	if(w != NULL)
-	    case_sensitive = GTK_TOGGLE_BUTTON(w)->active;
+	case_sensitive = GTK_TOGGLE_BUTTON_GET_ACTIVE(
+	    fb->case_sensitive_check
+	);
 
 
 	/* Call start find callback to notify about start of find */
 	if(fb->start_cb != NULL)
-	    fb->start_cb(fb, fb->client_data);
+	    fb->start_cb(fb, fb->data);
 
 
 	/* Perform find procedure by find operation code */
 	total_matches = 0;
-	switch(op_code)
+	switch(operation)
 	{
 	  case EDV_FINDBAR_FIND_OBJECT_NAME:
 	    switch(fb->role)
@@ -238,7 +244,8 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 	      case EDV_FINDBAR_ROLE_DISK_OBJECT:
 		total_matches = EDVFindObjectByName(
 		    location, search_string,
-		    FALSE,			/* Recursive */
+		    FALSE,			/* Do not recurse */
+		    FALSE,			/* Do not follow links */
 		    case_sensitive,
 		    fb,
 		    EDVFindBarProgressCB,
@@ -277,8 +284,9 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 	      case EDV_FINDBAR_ROLE_DISK_OBJECT:
 		total_matches = EDVFindObjectByContent(
 		    location, search_string,
-		    FALSE,			/* Recursive */
-		    case_sensitive,
+		    FALSE,			/* Do not recurse */
+		    FALSE,			/* Do not follow links */
+		    case_sensitive,		/* Case sensitive */
 		    fb,
 		    EDVFindBarProgressCB,
 		    EDVFindBarMatchExcerptCB
@@ -307,7 +315,7 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 
 	/* Tally */
 	if(fb->status_progress_cb != NULL)
-	    fb->status_progress_cb(fb, 0.0, fb->client_data);
+	    fb->status_progress_cb(0.0f, fb->data);
 
 	if(total_matches > 0)
 	{
@@ -317,25 +325,30 @@ static void EDVFindBarFindCB(GtkWidget *widget, gpointer data)
 		(total_matches == 1) ? "" : "s"
 	    );
 	    if(fb->status_message_cb != NULL)
-		fb->status_message_cb(fb, buf, fb->client_data);
+		fb->status_message_cb(
+		    buf,
+		    fb->data
+		);
 	    g_free(buf);
 	}
 	else
 	{
 	    if(fb->status_message_cb != NULL)
-		fb->status_message_cb(fb, "No objects found", fb->client_data);
+		fb->status_message_cb(
+		    "No objects found",
+		    fb->data
+		);
 	}
 
 
-	/* Mark find bar as done processing */
-	fb->processing = FALSE;
+	fb->freeze_count--;
 
 	EDVFindBarUpdateMenus(fb);
 
 
 	/* Call end find callback to notify about end of find */
 	if(fb->end_cb != NULL)
-	    fb->end_cb(fb, total_matches, fb->client_data);
+	    fb->end_cb(fb, total_matches, fb->data);
 
 
 	g_free(location);
@@ -422,9 +435,7 @@ static gint EDVFindBarCrossingCB(
 	}
 
 	if(fb->status_message_cb != NULL)
-	    fb->status_message_cb(
-		fb, mesg, fb->client_data
-	    );
+	    fb->status_message_cb(mesg, fb->data);
 
 	return(status);
 }
@@ -497,14 +508,13 @@ void EDVFindBarSetSearch(
 /*
  *      Returns the current find operation code, one of EDV_FINDBAR_FIND_*.
  */
-gint EDVFindBarCurrentFindOP(edv_findbar_struct *fb)
+edv_findbar_operation EDVFindBarCurrentFindOP(edv_findbar_struct *fb)
 {
-	gint i;
+	edv_findbar_operation i;
 	const gchar *value, *value2;
 	GList *glist;
 	GtkCombo *combo;
 
-
 	if(fb == NULL)
 	    return(EDV_FINDBAR_FIND_OBJECT_NAME);
 
@@ -538,18 +548,24 @@ gint EDVFindBarCurrentFindOP(edv_findbar_struct *fb)
  */
 edv_findbar_struct *EDVFindBarNew(
 	gpointer core_ptr, GtkWidget *parent,
-	gint role,
-	void (*status_message_cb)(gpointer, const gchar *, gpointer),
-	void (*status_progress_cb)(gpointer, gfloat, gpointer),
-	gchar *(*get_location_cb)(gpointer, gpointer),
-	void (*start_cb)(gpointer, gpointer),
-	void (*end_cb)(gpointer, gint, gpointer),
+	edv_findbar_role role,
+	const gchar *(*get_location_cb)(
+		edv_findbar_struct *, gpointer
+	),
+	void (*start_cb)(
+		edv_findbar_struct *, gpointer
+	),
+	void (*end_cb)(
+		edv_findbar_struct *, gint, gpointer 
+	),
 	void (*match_cb)(
 	    const gchar *, const struct stat *,
 	    const gchar *, gint,
 	    gpointer
 	),
-	gpointer client_data
+        void (*status_message_cb)(const gchar *, gpointer),
+        void (*status_progress_cb)(gfloat, gpointer),
+	gpointer data
 )
 {
 	const gint border_minor = 2;
@@ -564,20 +580,19 @@ edv_findbar_struct *EDVFindBarNew(
 	    return(fb);
 
 	/* Reset values */
-	fb->initialized = TRUE;
-	fb->map_state = FALSE;
-	fb->processing = FALSE;
-	fb->core_ptr = core_ptr;
+	fb->freeze_count = 0;
 	fb->stop_count = 0;
+	fb->core_ptr = core_ptr;
+
 	fb->role = role;
 
-	fb->status_message_cb = status_message_cb;
-	fb->status_progress_cb = status_progress_cb;
 	fb->get_location_cb = get_location_cb;
 	fb->start_cb = start_cb;
 	fb->end_cb = end_cb;
 	fb->match_cb = match_cb;
-	fb->client_data = client_data;
+        fb->status_message_cb = status_message_cb;
+        fb->status_progress_cb = status_progress_cb;
+	fb->data = data;
 
 
 	/* Create toplevel */
@@ -832,16 +847,13 @@ void EDVFindBarUpdateMenus(edv_findbar_struct *fb)
 #define DO_HIDE		\
 { if(w != NULL) gtk_widget_hide(w); }
 #define DO_SET_CHECK_STATE	\
-{ \
- if((w != NULL) ? GTK_IS_CHECK_MENU_ITEM(w) : FALSE) \
-  GTK_CHECK_MENU_ITEM(w)->active = state; \
-}
+{ GUIMenuItemSetCheck(w, state, FALSE); }
 
 	/* Update buttons */
-	sensitive = fb->processing;
+	sensitive = (fb->freeze_count > 0) ? TRUE : FALSE;
 	GTK_WIDGET_SET_SENSITIVE(fb->stop_btn, sensitive)
 
-	sensitive = !fb->processing;
+	sensitive = (fb->freeze_count == 0) ? TRUE : FALSE;
 	GTK_WIDGET_SET_SENSITIVE(fb->search_combo, sensitive)
 	GTK_WIDGET_SET_SENSITIVE(fb->case_sensitive_check, sensitive)
 	GTK_WIDGET_SET_SENSITIVE(fb->find_op_combo, sensitive)
@@ -862,7 +874,6 @@ void EDVFindBarMap(edv_findbar_struct *fb)
 	    return;
 
 	gtk_widget_show(w);
-	fb->map_state = TRUE;
 }
 
 /*
@@ -875,7 +886,6 @@ void EDVFindBarUnmap(edv_findbar_struct *fb)
 	    return;   
 
 	gtk_widget_hide(w);
-	fb->map_state = FALSE;
 }
 
 /*
