@@ -16,7 +16,7 @@
 #include "edvobj.h"
 #include "edvrecbin.h"
 #include "edvrecbinfio.h"
-#include "edvstatusbar.h"
+#include "statusbar.h"
 #include "findwin.h"
 #include "findwincb.h"
 #include "endeavour.h"
@@ -306,6 +306,7 @@ void EDVFindWinListResetColumns(
 
 	/* Update clist column settings */
 	gtk_clist_column_titles_show(clist);
+	gtk_clist_column_titles_passive(clist); 
 
 	/* Iterate through columns */
 	for(i = 0; i < columns; i++)
@@ -373,7 +374,7 @@ void EDVFindWinListResetColumns(
 		    clist, i, TRUE
 		);
 		gtk_clist_set_column_auto_resize(
-		    clist, i, FALSE
+		    clist, i, TRUE
 		);
 		gtk_clist_set_column_title(
 		    clist, i, title[i]
@@ -393,17 +394,12 @@ void EDVFindWinListResetColumns(
 
 	gtk_clist_thaw(clist);
 
-	/* Autosize columns due to new titles being set */
-	gtk_clist_columns_autosize(clist);
-
 	/* Set RC style */
 	if(lists_rcstyle != NULL)
 	    gtk_widget_modify_style_recursive(
 		GTK_WIDGET(clist), lists_rcstyle
 	    );
 
-
-	/* Delete column property values */
 	g_free(title);
 	g_free(justify);
 }
@@ -470,7 +466,7 @@ void EDVFindWinListAppend(
 		    obj = EDVObjectNew();
 		    EDVObjectSetPath(obj, path);
 		    EDVObjectSetStat(obj, lstat_buf);
-		    EDVObjectValidateLink(obj);
+		    EDVObjectUpdateLinkFlags(obj);
 		    break;
 
 		  case EDV_FINDWIN_ROLE_RECYCLED_OBJECT:
@@ -526,7 +522,8 @@ void EDVFindWinListAppend(
 			core_ptr->mimetype, core_ptr->total_mimetypes,
 			obj->type,
 			obj->full_path,
-			obj->link_valid, obj->permissions,
+			EDV_OBJECT_IS_LINK_VALID(obj),
+			obj->permissions,
 			0,			/* Small icons */
 			&pixmap, &mask,
 			NULL, NULL,
@@ -596,7 +593,8 @@ void EDVFindWinListAppend(
 				    core_ptr->device, core_ptr->total_devices,
 				    core_ptr->mimetype, core_ptr->total_mimetypes,
 				    loc_obj->type, loc_obj->full_path,
-				    loc_obj->link_valid, loc_obj->permissions,
+				    EDV_OBJECT_IS_LINK_VALID(loc_obj),
+				    loc_obj->permissions,
 				    0,		/* Small icons */
 				    &pixmap, &mask,
 				    NULL, NULL,
@@ -684,7 +682,8 @@ void EDVFindWinListAppend(
 				    core_ptr->device, core_ptr->total_devices,
 				    core_ptr->mimetype, core_ptr->total_mimetypes,
 				    loc_obj->type, loc_obj->full_path,
-				    loc_obj->link_valid, loc_obj->permissions,
+				    EDV_OBJECT_IS_LINK_VALID(loc_obj),
+				    loc_obj->permissions,
 				    0,          /* Small icons */
 				    &pixmap, &mask,
 				    NULL, NULL,
@@ -721,7 +720,7 @@ void EDVFindWinListAppend(
 		    /* Set row data as the object */
 		    gtk_clist_set_row_data_full(
 			clist, row,
-			obj, (GtkDestroyNotify)EDVFindWinListItemDestroyCB
+			obj, EDVFindWinListItemDestroyCB
 		    );
 		    obj = NULL;
 		}
@@ -731,10 +730,6 @@ void EDVFindWinListAppend(
 
 	    /* Delete row cell values */
 	    g_free(strv);
-
-	    /* Autosize columns due to new row being appended */
-	    if(row > -1)
-		gtk_clist_columns_autosize(clist);
 	}
 
 }
@@ -842,7 +837,6 @@ edv_findwin_struct *EDVFindWinNew(gpointer core_ptr)
 {
 	const gint	border_major = 5,
 			border_minor = 2;
-	gint i;
 	gint	toplevel_x = 0,
 		toplevel_y = 0,
 		toplevel_width = EDV_DEF_FINDWIN_WIDTH,
@@ -853,7 +847,7 @@ edv_findwin_struct *EDVFindWinNew(gpointer core_ptr)
 	gboolean case_sensitive = FALSE, recursive = FALSE;
 	const cfg_item_struct *cfg_list = (core_ptr != NULL) ?
 	    EDV_CORE(core_ptr)->cfg_list : NULL;
-	edv_status_bar_struct *status_bar;
+	edv_statusbar_struct *status_bar;
 	GList *glist;
 	GtkRcStyle *standard_rcstyle = NULL, *lists_rcstyle = NULL;
 	GtkWidget *w, *parent, *parent2, *parent3, *parent4;
@@ -1319,9 +1313,7 @@ edv_findwin_struct *EDVFindWinNew(gpointer core_ptr)
 	gtk_container_add(GTK_CONTAINER(parent4), w);
 	gtk_widget_realize(w);
 	gtk_clist_set_selection_mode(clist, GTK_SELECTION_EXTENDED);
-	for(i = 0; i < clist->columns; i++)
-	    gtk_clist_set_column_width(clist, i, 10);
-	gtk_clist_column_titles_passive(clist);
+	gtk_clist_column_titles_hide(clist);
 	gtk_clist_set_row_height(clist, EDV_LIST_ROW_SPACING);
 	gtk_clist_set_shadow_type(clist, GTK_SHADOW_IN);
 	gtk_signal_connect(
@@ -2005,10 +1997,9 @@ void EDVFindWinUpdateMenus(edv_findwin_struct *fw)
 { if(w != NULL) { gtk_widget_show(w); } }
 #define DO_HIDE			\
 { if(w != NULL) { gtk_widget_hide(w); } }
-#define DO_SET_CHECK_STATE	{			\
- if((w != NULL) ? GTK_IS_CHECK_MENU_ITEM(w) : FALSE)	\
-  GTK_CHECK_MENU_ITEM(w)->active = state;		\
-}
+#define DO_SET_CHECK_STATE	\
+{ GUIMenuItemSetCheck(w, state, FALSE); }
+
 	/* Get global write protect state */
 	write_protect = EDV_GET_B(EDV_CFG_PARM_WRITE_PROTECT);
 	if(fw->last_write_protect_state < 0)
