@@ -2,6 +2,7 @@
 #include <string.h>
 #include <gtk/gtk.h>
 
+#include "../include/string.h"
 #include "../include/disk.h"
 
 #include "guiutils.h"
@@ -10,7 +11,7 @@
 #include "cfg.h"
 #include "edvtypes.h"
 #include "edvobj.h"
-#include "edvstatusbar.h"
+#include "statusbar.h"
 #include "archiver.h"
 #include "archivercontents.h"
 #include "browser.h"
@@ -705,7 +706,6 @@ void EDVFindWinSearchCB(GtkWidget *widget, gpointer data)
 			*search_string;
 	gint		total_matches = 0;
 	edv_findwin_operation operation;
-	GtkWidget *w;
 	const cfg_item_struct *cfg_list;
 	edv_core_struct *core_ptr;
 	edv_findwin_struct *fw = EDV_FINDWIN(data);
@@ -759,9 +759,8 @@ void EDVFindWinSearchCB(GtkWidget *widget, gpointer data)
 	  case EDV_FINDWIN_ROLE_DISK_OBJECT:
 	  case EDV_FINDWIN_ROLE_ARCHIVE_OBJECT:
 	    /* Get current location as the starting location */
-	    location = EDVCopyEvaluateInputPath(
-		NULL,
-		EDVFindWinCurrentLocation(fw)
+	    location = EDVEvaluatePath(
+		NULL, EDVFindWinCurrentLocation(fw)
 	    );
 	    /* Record starting location history */
 	    EDVFindWinSetLocation(fw, location, TRUE);
@@ -769,9 +768,8 @@ void EDVFindWinSearchCB(GtkWidget *widget, gpointer data)
 
 	  case EDV_FINDWIN_ROLE_RECYCLED_OBJECT:
 	    /* Get recycled objects index file as the starting location */
-	    location = EDVCopyEvaluateInputPath(
-		NULL,
-		EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLED_INDEX)
+	    location = EDVEvaluatePath(
+		NULL, EDV_GET_S(EDV_CFG_PARM_FILE_RECYCLED_INDEX)
 	    );
 	    /* Record starting location history */
 	    parent_path = g_dirname(location);
@@ -785,14 +783,14 @@ void EDVFindWinSearchCB(GtkWidget *widget, gpointer data)
 	}
 
 	/* Case sensitive */
-	w = fw->case_sensitive_check;
-	if(w != NULL)
-	    case_sensitive = GTK_TOGGLE_BUTTON(w)->active;
+	case_sensitive = GTK_TOGGLE_BUTTON_GET_ACTIVE(
+	    fw->case_sensitive_check
+	);
 
 	/* Recursive */
-	w = fw->recursive_check;
-	if(w != NULL)
-	    recursive = GTK_TOGGLE_BUTTON(w)->active;
+	recursive = GTK_TOGGLE_BUTTON_GET_ACTIVE(
+	    fw->recursive_check
+	);
 
 
 	/* Begin search */
@@ -812,7 +810,9 @@ void EDVFindWinSearchCB(GtkWidget *widget, gpointer data)
 	      case EDV_FINDWIN_ROLE_DISK_OBJECT:
 		total_matches = EDVFindObjectByName(
 		    location, search_string,
-		    recursive, case_sensitive,
+		    recursive,		/* Recursive */
+		    FALSE,		/* Do not follow links */
+		    case_sensitive,	/* Case sensitive */
 		    fw,
 		    EDVFindWinFindProgressCB,
 		    EDVFindWinFindMatchedCB
@@ -823,7 +823,7 @@ void EDVFindWinSearchCB(GtkWidget *widget, gpointer data)
 		total_matches = EDVFindRecycledObjectByName(
 		    location,		/* Recycled objects index file */
 		    search_string,
-		    case_sensitive,
+		    case_sensitive,	/* Case sensitive */
 		    fw,
 		    EDVFindWinFindProgressCB,
 		    EDVFindWinFindMatchedCB
@@ -833,9 +833,9 @@ void EDVFindWinSearchCB(GtkWidget *widget, gpointer data)
 	      case EDV_FINDBAR_ROLE_ARCHIVE_OBJECT:
 		total_matches = EDVFindArchiveObjectByName(
 		    core_ptr,
-		    location,           /* Archive */
+		    location,		/* Archive */
 		    search_string,
-		    case_sensitive,
+		    case_sensitive,	/* Case sensitive */
 		    fw,
 		    EDVFindWinFindProgressCB,
 		    EDVFindWinFindMatchedCB
@@ -850,7 +850,9 @@ void EDVFindWinSearchCB(GtkWidget *widget, gpointer data)
 	      case EDV_FINDWIN_ROLE_DISK_OBJECT:
 		total_matches = EDVFindObjectByContent(
 		    location, search_string,
-		    recursive, case_sensitive,
+		    recursive,		/* Recursive */
+		    FALSE,		/* Do not follow links */
+		    case_sensitive,	/* Case sensitive */
 		    fw,
 		    EDVFindWinFindProgressCB,
 		    EDVFindWinFindMatchedExcerptCB
@@ -861,7 +863,7 @@ void EDVFindWinSearchCB(GtkWidget *widget, gpointer data)
 		total_matches = EDVFindRecycledObjectByContent(
 		    location,		/* Recycled objects index file */
 		    search_string,
-		    case_sensitive,
+		    case_sensitive,	/* Case sensitive */
 		    fw,
 		    EDVFindWinFindProgressCB,
 		    EDVFindWinFindMatchedExcerptCB
@@ -869,7 +871,7 @@ void EDVFindWinSearchCB(GtkWidget *widget, gpointer data)
 		break;
 
 	      case EDV_FINDBAR_ROLE_ARCHIVE_OBJECT:
-		/* Finding archive object by content is not supported yet */
+		/* Finding archive object by content is not supported */
 		total_matches = 0;
 		break;
 	    }
@@ -1052,16 +1054,28 @@ can be opened.\n",
 	    {
 		gchar	*stdout_path_rtn = NULL,
 			*stderr_path_rtn = NULL;
+		GList *paths_list = NULL;
+
+		paths_list = g_list_append(
+		    paths_list,
+		    STRDUP(full_path)
+		);
 
 		EDVFindWinSetBusy(fw, TRUE);
-		EDVOpenObjectPath(
-		    EDV_CORE(fw->core_ptr), full_path,
-		    NULL,		/* Command name */
-		    toplevel, TRUE,
-		    &stdout_path_rtn, &stderr_path_rtn
+		EDVOpen(
+		    core_ptr,
+		    paths_list,			/* Paths List */
+		    NULL,			/* Command Name */
+		    toplevel,			/* Toplevel */
+		    TRUE,			/* Verbose */
+		    &stdout_path_rtn,
+		    &stderr_path_rtn
 		);
 		EDVFindWinSetBusy(fw, FALSE);
 
+		g_list_foreach(paths_list, (GFunc)g_free, NULL);
+		g_list_free(paths_list);
+
 		g_free(stdout_path_rtn);
 		g_free(stderr_path_rtn);
 	    }
@@ -1143,14 +1157,26 @@ can be opened.\n",
 	{
 	    gchar       *stdout_path_rtn = NULL,
 			*stderr_path_rtn = NULL;
+	    GList *paths_list = NULL;
 
-	    EDVOpenWithObjectPath(
-		EDV_CORE(fw->core_ptr), obj->full_path,
-		NULL,                   /* Command name */
-		toplevel, TRUE,
-		&stdout_path_rtn, &stderr_path_rtn
+	    paths_list = g_list_append(
+		paths_list,
+		STRDUP(obj->full_path)
 	    );
 
+	    EDVOpenWith(
+		core_ptr,
+		paths_list,		/* Paths List */
+		NULL,			/* Command Name */
+		toplevel,		/* Toplevel */
+		TRUE,			/* Verbose */
+		&stdout_path_rtn,
+		&stderr_path_rtn
+	    );
+
+	    g_list_foreach(paths_list, (GFunc)g_free, NULL);
+	    g_list_free(paths_list);
+
 	    g_free(stdout_path_rtn);
 	    g_free(stderr_path_rtn);
 	}
@@ -1174,12 +1200,9 @@ void EDVFindWinGotoCB(GtkWidget *widget, gpointer data)
 	if(fw->processing)
 	    return;
 
-	core_ptr = EDV_CORE(fw->core_ptr);
-	if(core_ptr == NULL)
-	    return;
-
 	clist = (GtkCList *)fw->results_clist;
-	if(clist == NULL)
+	core_ptr = EDV_CORE(fw->core_ptr);
+	if((clist == NULL) || (core_ptr == NULL))
 	    return;
 
 	/* Unsupported role for going to object? */
@@ -1194,7 +1217,7 @@ void EDVFindWinGotoCB(GtkWidget *widget, gpointer data)
 	    return;
 
 	/* Get copy of full path and parent directory */
-	full_path = STRDUP(obj->full_path);
+	full_path = EDVEvaluatePath(NULL, obj->full_path);
 	parent_dir = g_dirname(full_path);
 
 
@@ -1204,7 +1227,7 @@ void EDVFindWinGotoCB(GtkWidget *widget, gpointer data)
 	/* File browser? */
 	if(fw->browser_num > -1)
 	{
-	    gint browser_num = fw->browser_num;
+	    const gint browser_num = fw->browser_num;
 	    edv_browser_struct *browser;
 
 	    if((browser_num >= 0) && (browser_num < core_ptr->total_browsers))
@@ -1214,15 +1237,22 @@ void EDVFindWinGotoCB(GtkWidget *widget, gpointer data)
 
 	    if(browser != NULL)
 	    {
-		gint row;
 		const gchar *cur_path = EDVBrowserCurrentLocation(browser);
+		GtkWidget *toplevel = browser->toplevel;
 		GtkCList *clist = (GtkCList *)browser->contents_clist;
 
+		EDVBrowserSetBusy(browser, TRUE);
+		GUIBlockInput(toplevel, TRUE);
+
+		/* Change directory tree origin as needed */
+		if(!EDVBrowserIsPathFromDirTreeOrigin(browser, parent_dir))
+		    EDVBrowserDirTreeSetOriginPath(browser, parent_dir);
+
 		/* Select the parent directory only if its different
 		 * than the current directory
 	 	 */
 		if((cur_path != NULL) ? strcmp(cur_path, parent_dir) : TRUE)
-		    EDVBrowserDirTreeDoSelectPath(browser, parent_dir);
+		    EDVBrowserDirTreeSelectPath(browser, parent_dir);
 
 		/* The contents listing on the browser should be updated
 		 * if the parent directory was selected successfully
@@ -1232,22 +1262,26 @@ void EDVFindWinGotoCB(GtkWidget *widget, gpointer data)
 		 */
 		if(clist != NULL)
 		{
-		    row = EDVBrowserContentsFindRowByPath(browser, full_path);
+		    const gint row = EDVBrowserContentsFindRowByPath(
+			browser, full_path
+		    );
 		    if((row >= 0) && (row < clist->rows))
 		    {
 			gtk_clist_freeze(clist);
 			gtk_clist_unselect_all(clist);
-			gtk_clist_thaw(clist);
-
 			gtk_clist_select_row(clist, row, 0);
+			gtk_clist_thaw(clist);
 		    }
 		}
+
+		GUIBlockInput(toplevel, FALSE);
+                EDVBrowserSetBusy(browser, FALSE);
 	    }
 	}
 	/* Image browser? */
 	else if(fw->imbr_num > -1)
 	{
-	    gint imbr_num = fw->imbr_num;
+	    const gint imbr_num = fw->imbr_num;
 	    edv_imbr_struct *imbr;
 
 	    if((imbr_num >= 0) && (imbr_num < core_ptr->total_imbrs))
@@ -1257,7 +1291,6 @@ void EDVFindWinGotoCB(GtkWidget *widget, gpointer data)
 
 	    if(imbr != NULL)
 	    {
-		gint thumb_num;
 		const gchar *cur_path = EDVImbrCurrentLocation(imbr);
 		tlist_struct *tlist = imbr->tlist;
 
@@ -1275,14 +1308,14 @@ void EDVFindWinGotoCB(GtkWidget *widget, gpointer data)
 		 */
 		if(tlist != NULL)
 		{
-		    thumb_num = EDVImbrTListFindThumbByPath(imbr, full_path);
+		    const gint thumb_num = EDVImbrTListFindThumbByPath(
+			imbr, full_path
+		    );
 		    TListFreeze(tlist);
 		    TListUnselectAll(tlist);
 		    TListSelectThumb(tlist, thumb_num);
 		    TListThaw(tlist);
 		}
-
-		EDVImbrUpdateMenus(imbr);
 	    }
 	}
 	/* Recycle bin */
@@ -1291,29 +1324,29 @@ void EDVFindWinGotoCB(GtkWidget *widget, gpointer data)
 	    edv_recbin_struct *recbin = core_ptr->recbin;
 	    if((recbin != NULL) && (obj->name != NULL))
 	    {
-		gint row;
 		GtkCList *clist = (GtkCList *)recbin->contents_clist;
-
-		/* The disk object's name is a string specifying the
-		 * recycled object index number.
-		 */
-		row = EDVRecBinContentsFindRowByIndex(
-		    recbin, (guint)ATOI(obj->name)
-		);
-		if((row >= 0) && (row < clist->rows))
+		if(clist != NULL)
 		{
-		    gtk_clist_freeze(clist);
-		    gtk_clist_unselect_all(clist);
-		    gtk_clist_thaw(clist);
-
-		    gtk_clist_select_row(clist, row, 0);
+		    /* The object's name is a string specifying the
+		     * recycled object index number
+		     */
+		    const gint row = EDVRecBinContentsFindRowByIndex(
+			recbin, (guint)ATOI(obj->name)
+		    );
+		    if((row >= 0) && (row < clist->rows))
+		    {
+			gtk_clist_freeze(clist);
+			gtk_clist_unselect_all(clist);
+			gtk_clist_select_row(clist, row, 0);
+			gtk_clist_thaw(clist);
+		    }
 		}
 	    }
 	}
 	/* Archiver */
 	else if(fw->archiver_num > -1)
 	{
-	    gint archiver_num = fw->archiver_num;
+	    const gint archiver_num = fw->archiver_num;
 	    edv_archiver_struct *archiver;
 
 	    if((archiver_num >= 0) && (archiver_num < core_ptr->total_archivers))
@@ -1323,21 +1356,18 @@ void EDVFindWinGotoCB(GtkWidget *widget, gpointer data)
 
 	    if(archiver != NULL)
 	    {
-		gint row;
 		GtkCList *clist = (GtkCList *)archiver->contents_clist;
-
 		if(clist != NULL)
 		{
-		    row = EDVArchiverContentsFindRowByPath(
+		    const gint row = EDVArchiverContentsFindRowByPath(
 			archiver, full_path
 		    );
 		    if((row >= 0) && (row < clist->rows))
 		    {
 			gtk_clist_freeze(clist);
 			gtk_clist_unselect_all(clist);
-			gtk_clist_thaw(clist);
-
 			gtk_clist_select_row(clist, row, 0);
+			gtk_clist_thaw(clist);
 		    }
 		}
 	    }
