@@ -247,8 +247,10 @@ gint FormatManagerDiskIconExposeCB(
 }
 
 /*
+ *	Format timeout callback.
+ *
  *	Called while a format or mkfs process is running, the process is
- *	monitored and appropriate action is taken.
+ *	monitored and the appropriate action is taken.
  */
 gint FormatManagerFormatTOCB(gpointer data)
 {
@@ -486,40 +488,40 @@ static void FormatManagerDoStart(
 	format_manager_struct *fm, gint dev_num
 )
 {
-	const gchar *s, *prog_pfx, *capacity_str;
+	const gchar *s, *capacity_str;
 	gint capacity = 1440;
 	gboolean	quick_format = FALSE,
 			verbose = FALSE;
 	const gchar	*fs_type = EDV_FS_TYPE_MSDOS_NAME,
 			*volume_label = NULL;
-	GtkWidget *w;
+	GtkWidget *toplevel;
 	GtkEntry *entry;
 	GtkCombo *combo;
 	pid_t p;
 	guint toid;
-	gchar *cmd, *prog, *startup_message;
-	edv_device_struct *dev_ptr;
-
+	gchar *cmd, *prog, *prog_name, *startup_message;
+	edv_device_struct *dev;
 
 	if(fm == NULL)
 	    return;
 
+	toplevel = fm->toplevel;
 
 	/* Get format parameters */
-	w = fm->quick_format_check;
-	if(w != NULL)
-	    quick_format = GTK_TOGGLE_BUTTON(w)->active;
+	quick_format = GTK_TOGGLE_BUTTON_GET_ACTIVE(
+	   fm->quick_format_check
+	);
 
 	combo = (GtkCombo *)fm->capacity_combo;
 	if(combo != NULL)
 	{
-	    capacity_str = gtk_entry_get_text(GTK_ENTRY(combo->entry));
-	    if(capacity_str != NULL)
+	    s = gtk_entry_get_text(GTK_ENTRY(combo->entry));
+	    if(s != NULL)
 	    {
 		/* All capacity strings start with a number and
-		 * are in units of kb.
+		 * are in units of kb
 		 */
-		capacity = atoi(capacity_str);
+		capacity = atoi(s);
 	    }
 	}
 
@@ -534,20 +536,21 @@ static void FormatManagerDoStart(
 	if(entry != NULL)
 	    volume_label = gtk_entry_get_text(entry);
 
-	w = fm->verbose_check;
-	if(w != NULL)
-	    verbose = GTK_TOGGLE_BUTTON(w)->active;
+	verbose = GTK_TOGGLE_BUTTON_GET_ACTIVE(
+	    fm->verbose_check
+	);
 
 
 	/* Get pointer to device */
-	if((dev_num < 0) || (dev_num >= fm->total_devices))
-	    return;
-	dev_ptr = fm->device[dev_num];
-	if(dev_ptr == NULL)
+	dev = ((dev_num >= 0) && (dev_num < fm->total_devices)) ?
+	    fm->device[dev_num] : NULL;
+	if(dev == NULL)
 	    return;
 
 
-	/* Skip past format stage? */
+	/* Skip the format stage if quick format is selected and we are
+	 * currently at the format stage
+	 */
 	if(quick_format && (fm->format_stage == FORMAT_STAGE_FORMAT))
 	    fm->format_stage++;
 
@@ -555,7 +558,7 @@ static void FormatManagerDoStart(
 	/* Check if this device is already mounted, in which case we
 	 * cannot use format on it
 	 */
-	if(dev_ptr->is_mounted)
+	if(EDV_DEVICE_IS_MOUNTED(dev))
 	{
 	    gchar *buf = g_strdup_printf(
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -573,12 +576,26 @@ Usted debe unmount el artefacto primero antes de format.",
 \n\
 Vous devez unmount l'appareil premirement avant de format.",
 #endif
-		dev_ptr->device_path
+		dev->device_path
 	    );
 	    EDVPlaySoundWarning(fm->ctx);
-	    CDialogSetTransientFor(fm->toplevel);
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
-#ifdef PROG_LANGUAGE_ENGLISH
+#if defined(PROG_LANGUAGE_SPANISH)
+		"El Format Fall",
+		buf,
+"El artefacto se debe unmounted antes se puede format,\n\
+esto deber prevenir los errores debido a lectura/escritura\n\
+que pueden occure durante el proceso que format. Use la\n\
+Endeavour otra aplicacin al unmount el artefacto primero.",
+#elif defined(PROG_LANGUAGE_FRENCH)
+		"Le Format A Echou",
+		buf,
+"L'appareil doit tre unmounted avant d'il peut tre\n\
+format, ceci sera oblig  empcher des erreurs grce aux\n\
+lecture/criture qui peut occure pendant le procd qui\n\
+format. Utilise Endeavour ou un autre a la premierement.",
+#else
 		"Format Failed",
 		buf,
 "The device must be unmounted before the media can be\n\
@@ -586,22 +603,6 @@ formatted, this is to prevent errors due to read/writes\n\
 that may occure during the formatting process.\n\
 Use Endeavour or another application to unmount\n\
 the device first.",
-#endif
-#ifdef PROG_LANGUAGE_SPANISH
-		"El Format Fall",
-		buf,
-"El artefacto se debe unmounted antes se puede format,\n\
-esto deber prevenir los errores debido a lectura/escritura\n\
-que pueden occure durante el proceso que format. Use la\n\
-Endeavour otra aplicacin al unmount el artefacto primero.",
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-		"Le Format A Echou",
-		buf,
-"L'appareil doit tre unmounted avant d'il peut tre\n\
-format, ceci sera oblig  empcher des erreurs grce aux\n\
-lecture/criture qui peut occure pendant le procd qui\n\
-format. Utilise Endeavour ou un autre a la premierement.",
 #endif
 		CDIALOG_ICON_WARNING,
 		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
@@ -623,7 +624,7 @@ format. Utilise Endeavour ou un autre a la premierement.",
 	    if(ExecProcessExists(p))
 	    {
 		EDVPlaySoundError(fm->ctx);
-		CDialogSetTransientFor(fm->toplevel);
+		CDialogSetTransientFor(toplevel);
 		CDialogGetResponse(
 		    "Internal Error",
 "Starting format while a format process is\n\
@@ -634,6 +635,7 @@ already running.",
 		    CDIALOG_BTNFLAG_OK
 		);
 		CDialogSetTransientFor(NULL);
+		return;
 	    }
 	}
 
@@ -643,12 +645,11 @@ already running.",
 	 */
 	cmd = NULL;
 	prog = NULL;
-	prog_pfx = NULL;
 	startup_message = NULL;
 	switch(fm->format_stage)
 	{
 	  case FORMAT_STAGE_FORMAT:
-	    /* Generate capacity string as capacity_str */
+	    /* Get capacity string */
 	    switch(capacity)
 	    {
 	      case 1440:
@@ -669,43 +670,109 @@ already running.",
 	    }
 	    /* Format the command
 	     *
-	     * First check if the program superformat is installed, if
-	     * it is not then use fdformat
+	     * First check if the superformat program is installed, if
+	     * it is not then use the fdformat program
 	     */
-	    prog = g_strdup("/usr/bin/superformat");
-	    if(!access(prog, X_OK))
+	    prog = EDVWhich(SUPERFORMAT_PROG);
+	    if(prog != NULL)
 	    {
 		cmd = g_strdup_printf(
 		    "%s %s%s",
-		    prog, dev_ptr->device_path, capacity_str
+		    prog, dev->device_path, capacity_str
 		);
 	    }
 	    else
 	    {
-		g_free(prog);
-		prog = g_strdup("/usr/bin/fdformat");
-		cmd = g_strdup_printf(
-		    "%s %s%s",
-		    prog, dev_ptr->device_path, capacity_str
+		/* Could not find superformat, try fdformat */
+		prog = EDVWhich(FDFORMAT_PROG);
+		if(prog != NULL)
+		    cmd = g_strdup_printf(
+			"%s %s%s",
+			prog, dev->device_path, capacity_str
+		    );
+	    }
+	    /* No format programs installed? */
+	    if((prog == NULL) || (cmd == NULL))
+	    {
+		gchar *buf = g_strdup_printf(
+"Unable to find the Format programs:\n\
+\n\
+    %s\n\
+    %s\n\
+\n\
+Please verify that at least one of the programs is\n\
+installed in a location specified by the %s\n\
+environment and that it is executable by this program.",
+		    SUPERFORMAT_PROG,
+		    FDFORMAT_PROG,
+		    ENV_VAR_NAME_PATH
 		);
+		EDVPlaySoundWarning(fm->ctx);
+		CDialogSetTransientFor(toplevel);
+		CDialogGetResponse(
+		    "Unable To Find Format Program",
+		    buf,
+		    NULL,
+		    CDIALOG_ICON_WARNING,
+		    CDIALOG_BTNFLAG_OK,
+		    CDIALOG_BTNFLAG_OK
+		);
+		CDialogSetTransientFor(NULL);
+		g_free(buf);
+		g_free(prog);
+		g_free(cmd);
+		return;
 	    }
 	    startup_message = g_strdup_printf(
 "-------------------------------------------------\n\
 Formatting media in device %s...\n",
-		dev_ptr->device_path
+		dev->device_path
 	    );
 	    break;
 
 	  case FORMAT_STAGE_MKFS:
-	    prog_pfx = "/sbin/mkfs";
-	    prog = g_strdup_printf(
-		"%s.%s",
-		prog_pfx, fs_type
-	    );
+	    /* Get the mkfs program appropriate for the selected
+	     * filesystem
+	     */
+	    prog_name = g_strconcat(MKFS_PROG, ".", fs_type, NULL);
+	    prog = EDVWhich(prog_name);
+	    if(prog == NULL)
+	    {
+		gchar *buf = g_strdup_printf(
+"Unable to find the MKFS program:\n\
+\n\
+    %s\n\
+\n\
+Please verify that the program is installed at a location\n\
+specified by the %s environment and that it is\n\
+executable by this program.",
+		    prog_name,
+		    ENV_VAR_NAME_PATH
+		);
+		EDVPlaySoundWarning(fm->ctx);
+		CDialogSetTransientFor(toplevel);
+		CDialogGetResponse(
+		    "Unable To Find MKFS Program",
+		    buf,
+		    NULL,
+		    CDIALOG_ICON_WARNING,
+		    CDIALOG_BTNFLAG_OK,
+		    CDIALOG_BTNFLAG_OK
+		);
+		CDialogSetTransientFor(NULL);
+		g_free(buf);
+		g_free(prog);
+		g_free(prog_name);
+		return;
+	    }
+
+	    g_free(prog_name);
+	    prog_name = NULL;
+
 	    /* Add option to specify volume label (only for
 	     * mkfs.msdos)?
 	     */
-	    if(((volume_label != NULL) ? (*volume_label != '\0') : FALSE) &&
+	    if(!STRISEMPTY(volume_label) &&
 	       !strcmp(fs_type, EDV_FS_TYPE_MSDOS_NAME)
 	    )
 	    {
@@ -715,7 +782,7 @@ Formatting media in device %s...\n",
 		    dvolume_label[11] = '\0';
  		cmd = g_strdup_printf(
 		    "%s %s %s -n \"%s\"",
-		    prog, dev_ptr->device_path,
+		    prog, dev->device_path,
 		    verbose ? "-v" : "",
 		    dvolume_label
 		);
@@ -724,7 +791,7 @@ Formatting media in device %s...\n",
 	    else
 		cmd = g_strdup_printf(
 		    "%s %s %s",
-		    prog, dev_ptr->device_path,
+		    prog, dev->device_path,
 		    verbose ? "-v" : ""
 		);
 	    startup_message = g_strdup_printf(
@@ -739,7 +806,7 @@ Creating %s file system...\n",
 	if(cmd == NULL)
 	{
 	    EDVPlaySoundError(fm->ctx);
-	    CDialogSetTransientFor(fm->toplevel);
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 		"Internal Error",
 "Invalid format stage specified as the starting\n\
@@ -813,7 +880,7 @@ format stage.",
 		cmd
 	    );
 	    EDVPlaySoundWarning(fm->ctx);
-	    CDialogSetTransientFor(fm->toplevel);
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 #ifdef PROG_LANGUAGE_ENGLISH
 		"Format Failed",
@@ -882,11 +949,13 @@ void FormatManagerStartCB(GtkWidget *widget, gpointer data)
 {
 	gint status, dev_num;
 	GList *glist;
+	GtkWidget *toplevel;
 	GtkCList *clist;
 	format_manager_struct *fm = FORMAT_MANAGER(data);
 	if(fm == NULL)
 	    return;
 
+	toplevel = fm->toplevel;
 	clist = (GtkCList *)fm->devices_clist;
 	if(clist == NULL)
 	    return;
@@ -899,7 +968,7 @@ void FormatManagerStartCB(GtkWidget *widget, gpointer data)
 	 * media and loosing any existing data in the media
 	 */
 	EDVPlaySoundQuestion(fm->ctx);
-	CDialogSetTransientFor(fm->toplevel);
+	CDialogSetTransientFor(toplevel);
 	status = CDialogGetResponse(
 #ifdef PROG_LANGUAGE_ENGLISH
 	    "Confirm Format",
