@@ -2,10 +2,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <signal.h>
-#include <unistd.h>
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
+#include <unistd.h>
 
 #include "../../include/fio.h"
 #include "../../include/disk.h"
@@ -95,7 +94,7 @@ void FormatManagerSetDevices(
 	GdkPixmap *pixmap;
 	const gchar *cell_text;
 	GtkCList *clist;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	gchar *strv[4];
 
 #define DO_DEALLOCATE_INPUT_LIST	{	\
@@ -134,12 +133,12 @@ void FormatManagerSetDevices(
 	    strv[i] = "";
 	for(i = 0; i < fm->total_devices; i++)
 	{
-	    dev_ptr = fm->device[i];
-	    if(dev_ptr == NULL)
+	    dev = fm->device[i];
+	    if(dev == NULL)
 		continue;
 
 	    /* Hide this device from general listing? */
-	    if(dev_ptr->unlisted)
+	    if(EDV_DEVICE_IS_UNLISTED(dev))
 		continue;
 
 	    /* Append a new clist row */
@@ -148,19 +147,19 @@ void FormatManagerSetDevices(
 	    /* Load icon */
 	    pixmap = GDK_PIXMAP_NEW_FROM_XPM_FILE(
 		&mask,
-		dev_ptr->small_icon_file[EDV_DEVICE_ICON_STATE_STANDARD]
+		dev->small_icon_file[EDV_DEVICE_ICON_STATE_STANDARD]
 	    );
 
 	    /* Set name cell */
 	    column = 0;
-	    cell_text = dev_ptr->name;
-	    if((cell_text == NULL) && (dev_ptr->device_path != NULL))
+	    cell_text = dev->name;
+	    if((cell_text == NULL) && (dev->device_path != NULL))
 	    {
-		cell_text = strrchr(dev_ptr->device_path, DIR_DELIMINATOR);
+		cell_text = strrchr(dev->device_path, DIR_DELIMINATOR);
 		if(cell_text != NULL)
 		    cell_text++;
 		else
-		    cell_text = dev_ptr->device_path;
+		    cell_text = dev->device_path;
 	    }
 	    if(cell_text == NULL)
 		cell_text = "(null)";
@@ -178,7 +177,7 @@ void FormatManagerSetDevices(
 
 	    /* Set device path cell */
 	    column = 1;
-	    cell_text = dev_ptr->device_path;
+	    cell_text = dev->device_path;
 	    if(cell_text == NULL)
 		cell_text = "(null)";
 
@@ -189,7 +188,7 @@ void FormatManagerSetDevices(
 
 	    /* Set mount path cell */
 	    column = 2;
-	    cell_text = dev_ptr->mount_path;
+	    cell_text = dev->mount_path;
 	    if(cell_text == NULL)
 		cell_text = "(null)";
 
@@ -202,13 +201,13 @@ void FormatManagerSetDevices(
 	    column = 3;
 	    gtk_clist_set_text(
 		clist, row, column,
-		EDVDeviceGetFSStringFromNumber(dev_ptr->fs_type)
+		EDVDeviceGetFSNameFromType(dev->fs_type)
 	    );
 
 
 	    /* Set row data of this new row to be a gint indicating
 	     * the device listing index of the device that this row
-	     * is displaying.
+	     * is displaying
 	     */
 	    gtk_clist_set_row_data(clist, row, (gpointer)i);
 	}
@@ -235,7 +234,6 @@ void FormatManagerAppendMessage(
 	GtkEditable *editable;
 	GtkText *text_w;
 
-
 	if((fm == NULL) || (text == NULL))
 	    return;
 
@@ -299,7 +297,6 @@ format_manager_struct *FormatManagerNew(edv_context_struct *ctx)
 	if(fm == NULL)
 	    return(NULL);
 
-
 	/* Reset values */
 	fm->map_state = FALSE;
 	fm->ctx = ctx;
@@ -1476,4 +1473,3 @@ void FormatManagerDelete(format_manager_struct *fm)
 
 	g_free(fm);
 }
-
