@@ -11,6 +11,16 @@
 #include "../lib/endeavour2.h"
 
 
+/*
+ *	Format Stages:
+ */
+typedef enum {
+	FORMAT_STAGE_FORMAT,
+	FORMAT_STAGE_MKFS
+} fm_format_stage;
+#define FORMAT_STAGE_HIGHEST		FORMAT_STAGE_MKFS
+
+
 /*
  *	Format Manager Window:
  */
@@ -62,10 +72,7 @@ typedef struct {
 	 */
 	GList		*queued_device_to_format;
 
-#define FORMAT_STAGE_FORMAT	0
-#define FORMAT_STAGE_MKFS	1
-#define FORMAT_STAGE_HIGHEST	FORMAT_STAGE_MKFS
-	gint		format_stage;	/* One of FORMAT_STAGE_*. */
+	fm_format_stage	format_stage;
 	guint		format_toid;
 	pid_t		format_pid;
 	FILE		*stdout_fp, *stderr_fp;
