@@ -28,6 +28,9 @@
 #define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
+/*
+ *	UNIX signal callback.
+ */
 static void FormatManagerSignalCB(int s)
 {
 	switch(s)
@@ -40,6 +43,9 @@ static void FormatManagerSignalCB(int s)
 	}
 }
 
+/*
+ *	Main timeout callback.
+ */
 static gint FormatManagerMainTOCB(gpointer data)
 {
 	format_manager_struct *fm = FORMAT_MANAGER(data);
@@ -219,7 +225,7 @@ program again.",
 		if(clist != NULL)
 		{
 		    /* Search column 1, the device path column, for
-		     * a cell who's value matches startup_device.
+		     * a cell who's value matches startup_device
 		     */
 		    column = 1;
 		    for(row = 0; row < clist->rows; row++)
@@ -230,7 +236,6 @@ program again.",
 			  case GTK_CELL_TEXT:
 			    gtk_clist_get_text(clist, row, column, &cell_text);
 			    break;
-
 			  case GTK_CELL_PIXTEXT:
 			    gtk_clist_get_pixtext(
 				clist, row, column, &cell_text,
@@ -259,9 +264,8 @@ program again.",
 
 
 	    gtk_timeout_add(
-		1000,		/* ms */
-		(GtkFunction)FormatManagerMainTOCB,
-		fm
+		1000l,
+		FormatManagerMainTOCB, fm
 	    );
 	    gtk_main();
 
