@@ -1,7 +1,8 @@
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <signal.h>
 #include <sys/types.h>
+#include <signal.h>
 #include <gtk/gtk.h>
 #include <unistd.h>
 
@@ -422,7 +423,7 @@ gint FSCKManagerDeleteEventCB(
 
 /*
  *	Sets up the fsck manager window to start checking the given
- *	device.  The fsck program will be runned and timeout callback
+ *	device. The fsck program will be runned and timeout callback
  *	set.
  *
  *	Note that his function still needs work to be truely
@@ -432,64 +433,75 @@ static void FSCKManagerDoStart(
 	fsck_manager_struct *fm, gint dev_num
 )
 {
-	const gchar *fs_type_name, *fsck_prog_pfx;
-	gboolean bad_blocks = FALSE, verbose = FALSE;
-	GtkWidget *w;
 	pid_t p;
-	const gchar *tmp_dir;
-	gchar *cmd, *fsck_prog, *startup_message;
-	edv_device_struct *dev_ptr;
-
+	gboolean bad_blocks, verbose;
+	const gchar *fs_type_name, *tmp_dir;
+	gchar *cmd, *prog, *prog_name, *startup_message;
+	GtkWidget *toplevel;
+	edv_device_struct *dev;
 
 	if(fm == NULL)
 	    return;
 
-	/* Get fsck parameters */
-	w = fm->bad_blocks_check;
-	if(w != NULL)
-	    bad_blocks = GTK_TOGGLE_BUTTON(w)->active;
-	w = fm->verbose_check;
-	if(w != NULL)
-	    verbose = GTK_TOGGLE_BUTTON(w)->active;
+	toplevel = fm->toplevel;
 
-	/* Get pointer to device */
-	if((dev_num < 0) || (dev_num >= fm->total_devices))
-	    return;
-	dev_ptr = fm->device[dev_num];
-	if(dev_ptr == NULL)
+	/* Get the fsck parameters */
+	bad_blocks = GTK_TOGGLE_BUTTON_GET_ACTIVE(
+	    fm->bad_blocks_check
+	);
+	verbose = GTK_TOGGLE_BUTTON_GET_ACTIVE(
+	    fm->verbose_check
+	);
+
+	/* Get the device */
+	dev = ((dev_num >= 0) && (dev_num < fm->total_devices)) ?
+	    fm->device[dev_num] : NULL;
+	if(dev == NULL)
 	    return;
 
-	/* Get conical name of file system */
-	fs_type_name = EDVDeviceGetFSStringFromNumber(dev_ptr->fs_type);
+	/* Get the filesystem's conical name */
+	fs_type_name = EDVDeviceGetFSNameFromType(dev->fs_type);
 
 
 	/* Check if this device is already mounted, in which case we
-	 * cannot use fsck on it
+	 * cannot fsck it
 	 */
-	if(dev_ptr->is_mounted)
+	if(EDV_DEVICE_IS_MOUNTED(dev))
 	{
 	    gchar *buf = g_strdup_printf(
-#ifdef PROG_LANGUAGE_ENGLISH
-"Device `%s' is currently mounted.\n\
+#if defined(PROG_LANGUAGE_SPANISH)
+"El artefacto \"%s\" se monta actualmente.\n\
+\n\
+Usted debe unmount el artefacto primero antes de verificar.",
+#elif defined(PROG_LANGUAGE_FRENCH)
+"\"%s\" d'appareil est actuellement mont.\n\
+\n\
+Vous devez unmount l'appareil premirement avant de vrifiant.",
+#else
+"Device \"%s\" is currently mounted.\n\
 \n\
 You must unmount the device before checking.",
 #endif
-#ifdef PROG_LANGUAGE_SPANISH
-"El artefacto `%s' se monta actualmente.\n\
-\n\
-Usted debe unmount el artefacto primero antes de verificar.",
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-"`%s' d'appareil est actuellement mont.\n\
-\n\
-Vous devez unmount l'appareil premirement avant de vrifiant.",
-#endif
-		dev_ptr->device_path
+		dev->device_path
 	    );
 	    EDVPlaySoundWarning(fm->ctx);
-	    CDialogSetTransientFor(fm->toplevel);
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
-#ifdef PROG_LANGUAGE_ENGLISH
+#if defined(PROG_LANGUAGE_SPANISH)
+		"El Cheque Fall",
+		buf,
+"El artefacto se debe unmounted antes se puede verificar,\n\
+esto deber prevenir los errores debido a lectura/escritura\n\
+que pueden occure durante el proceso que verifica. Use la\n\
+Endeavour otra aplicacin al unmount el artefacto primero.",
+#elif defined(PROG_LANGUAGE_FRENCH)
+		"Le Chque A Echou",
+		buf,
+"L'appareil doit tre unmounted avant d'il peut tre\n\
+vrifi, ceci sera oblig  empcher des erreurs grce aux\n\
+lecture/criture qui peut occure pendant le procd qui\n\
+vrifiant. Utilise Endeavour ou un autre a la premierement.",
+#else
 		"Check Failed",
 		buf,
 "The device must be unmounted before it can be\n\
@@ -497,22 +509,6 @@ checked, this is to prevent errors due to read/writes\n\
 that may occure during the checking process.\n\
 Use Endeavour or another application to unmount\n\
 the device first.",
-#endif
-#ifdef PROG_LANGUAGE_SPANISH
-		"El Cheque Fall",
-		buf,
-"El artefacto se debe unmounted antes se puede verificar,\n\
-esto deber prevenir los errores debido a lectura/escritura\n\
-que pueden occure durante el proceso que verifica. Use la\n\
-Endeavour otra aplicacin al unmount el artefacto primero.",
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-		"Le Chque A Echou",
-		buf,
-"L'appareil doit tre unmounted avant d'il peut tre\n\
-vrifi, ceci sera oblig  empcher des erreurs grce aux\n\
-lecture/criture qui peut occure pendant le procd qui\n\
-vrifiant. Utilise Endeavour ou un autre a la premierement.",
 #endif
 		CDIALOG_ICON_WARNING,
 		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
@@ -526,7 +522,7 @@ vrifiant. Utilise Endeavour ou un autre a la premierement.",
 
 	/* Check if there is already an fsck process running, in which
 	 * case we will increment the stop count so the next call to
-	 * the timeout callback stops it.
+	 * the timeout callback stops it
 	 */
 	p = fm->fsck_pid;
 	if(p != 0)
@@ -548,120 +544,182 @@ vrifiant. Utilise Endeavour ou un autre a la premierement.",
 	    return;
 	}
 
-	cmd = NULL;
-	fsck_prog = NULL;
-	fsck_prog_pfx = "/sbin/fsck";
-
-	/* Format command string by handling of the fs type */
-	switch(dev_ptr->fs_type)
+	/* Get the FSCK program name based on the filesystem type */
+	prog_name = NULL;
+	switch(dev->fs_type)
 	{
 	  case EDV_FS_TYPE_MSDOS:
 	  case EDV_FS_TYPE_VFAT:
-	    fsck_prog = g_strdup_printf(
-		"%s.%s",
-		fsck_prog_pfx, "msdos"
-	    );
-	    cmd = g_strdup_printf(
-		"%s -a %s %s %s",
-		fsck_prog,
-		verbose ? "-v" : "",
-		bad_blocks ? "-t" : "",
-		dev_ptr->device_path
-	    );
+	    prog_name = g_strconcat(FSCK_PROG, ".", "msdos", NULL);
 	    break;
-
 	  case EDV_FS_TYPE_EXT2_OLD:
 	  case EDV_FS_TYPE_EXT2:
-	    fsck_prog = g_strdup_printf(
-		"%s.%s",
-		fsck_prog_pfx, "ext2"
-	    );
-	    cmd = g_strdup_printf(
-		"%s -p %s %s -f %s",
-		fsck_prog,
-		verbose ? "-v" : "",
-		bad_blocks ? "-c" : "",
-		dev_ptr->device_path
-	    );
+	    prog_name = g_strconcat(FSCK_PROG, ".", "ext2", NULL);
 	    break;
-
 	  case EDV_FS_TYPE_MINIX_ORIG:
 	  case EDV_FS_TYPE_MINIX:
-	    fsck_prog = g_strdup_printf(
-		"%s.%s",
-		fsck_prog_pfx, "minix"
+	    prog_name = g_strconcat(FSCK_PROG, ".", "minix", NULL);
+	    break;
+	}
+	/* Filesystem type not supported? */
+	if(prog_name == NULL)
+	{
+	    gchar *buf = g_strdup_printf(
+#if defined(PROG_LANGUAGE_SPANISH)
+"Este programa actualmente no sostiene el\n\
+filesystem:\n\
+\n\
+    %s",
+#elif defined(PROG_LANGUAGE_FRENCH)
+"Ce programme ne soutient pas actuellement\n\
+le filesystem:\n\
+\n\
+    %s",
+#else
+"This program currently does not support\n\
+the filesystem:\n\
+\n\
+    %s",
+#endif
+		fs_type_name
 	    );
+	    EDVPlaySoundWarning(fm->ctx);
+	    CDialogSetTransientFor(toplevel);
+	    CDialogGetResponse(
+#if defined(PROG_LANGUAGE_SPANISH)
+		"Filesystem No Sostuvo",
+#elif defined(PROG_LANGUAGE_FRENCH)
+		"Filesystem n'A Pas Soutenu",
+#else
+		"Filesystem Not Supported",
+#endif
+		buf,
+		NULL,
+		CDIALOG_ICON_WARNING,
+		CDIALOG_BTNFLAG_OK,
+		CDIALOG_BTNFLAG_OK
+	    );
+	    CDialogSetTransientFor(NULL);
+	    g_free(buf);
+	    return;
+	}
+	/* Check if the FSCK program exists */
+	prog = EDVWhich(prog_name);
+	if(prog == NULL)
+	{
+	    gchar *buf = g_strdup_printf(
+#if defined(PROG_LANGUAGE_SPANISH)
+"Incapaz de encontrar el programa de FSCK:\n\
+\n\
+    %s\n\
+\n\
+Verifique por favor ese programa es instalado en una\n\
+ubicacion especificada por el ambiente de %s y que es\n\
+ejecutable por este programa.",
+#elif defined(PROG_LANGUAGE_FRENCH)
+"Incapable de trouver de programme de FSCK:\n\
+\n\
+    %s\n\
+\n\
+S'il vous plait verifier ce programme est installe dans\n\
+un emplacement specifie par l'environnement de %s et\n\
+que c'est realisable par ce programme.",
+#else
+"Unable to find the FSCK program:\n\
+\n\
+    %s\n\
+\n\
+Please verify that the program is installed at a location\n\
+specified by the %s environment and that it is\n\
+executable by this program.",
+#endif
+		prog_name,
+		ENV_VAR_NAME_PATH
+	    );
+	    EDVPlaySoundWarning(fm->ctx);
+	    CDialogSetTransientFor(toplevel);
+	    CDialogGetResponse(
+#if defined(PROG_LANGUAGE_SPANISH)
+		"Incapaz De Encontrar El Programa De FSCK",
+#elif defined(PROG_LANGUAGE_FRENCH)
+		"Incapable De Trouver De Programme De FSCK",
+#else
+		"Unable To Find FSCK Program",
+#endif
+		buf,
+		NULL,
+		CDIALOG_ICON_WARNING,
+		CDIALOG_BTNFLAG_OK,
+		CDIALOG_BTNFLAG_OK
+	    );
+	    CDialogSetTransientFor(NULL);
+	    g_free(buf);
+	    g_free(prog_name);
+	    return;
+	}
+
+	/* Format the command based on the filesystem type */
+	cmd = NULL;
+	switch(dev->fs_type)
+	{
+	  case EDV_FS_TYPE_MSDOS:
+	  case EDV_FS_TYPE_VFAT:
 	    cmd = g_strdup_printf(
+		"%s -a %s %s %s",
+		prog,
+		verbose ? "-v" : "",
+		bad_blocks ? "-t" : "",
+		dev->device_path
+	    );
+	    break;
+	  case EDV_FS_TYPE_EXT2_OLD:
+	  case EDV_FS_TYPE_EXT2:
+	    cmd = g_strdup_printf(
+		"%s -p %s %s -f %s",
+		prog,
+		verbose ? "-v" : "",
+		bad_blocks ? "-c" : "",
+		dev->device_path
+	    );
+	    break;
+	  case EDV_FS_TYPE_MINIX_ORIG:
+	  case EDV_FS_TYPE_MINIX:
+	    cmd = g_strdup_printf(
 		"%s -a -v -f %s",
-		fsck_prog, dev_ptr->device_path
+		prog, dev->device_path
 	    );
 	    break;
-
 	}
 	/* Unable to generate command? */
 	if(cmd == NULL)
 	{
 	    gchar *buf = g_strdup_printf(
-#ifdef PROG_LANGUAGE_ENGLISH
-"This program does not currently support the\n\
-file system `%s'.",
-#endif
-#ifdef PROG_LANGUAGE_SPANISH
-"Este programa no sostiene actualmente el\n\
-sistema del archivo `%s'",
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-"Ce programme ne soutient pas actuellement le\n\
-`%s' de systme de fichier",
-#endif
+"Unable to generate command to check filesystem type:\n\
+\n\
+    %s",
 		fs_type_name
 	    );
-	    EDVPlaySoundWarning(fm->ctx);
-	    CDialogSetTransientFor(fm->toplevel);
+	    EDVPlaySoundError(fm->ctx);
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
-#ifdef PROG_LANGUAGE_ENGLISH
-		"Check Failed",
+		"Internal Error",
 		buf,
-"The device that you are trying to check has a\n\
-file system type that this program does not\n\
-currently recognize and is unable to issue the\n\
-appropriate fsck command to check that device.",
-#endif
-#ifdef PROG_LANGUAGE_SPANISH
-		"El Cheque Fall",
-		buf,
-"El artefacto que usted tratan de verificar tiene\n\
-un tipo de sistema de archivo que este programa no\n\
-reconoce actualmente y es incapaz de publicar la\n\
-orden apropiada de fsck para verificar ese\n\
-artefacto.",
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-		"Le Chque A Echou",
-		buf,
-"L'appareil que vous essayez vrifier a un type de\n\
-systme de fichier que ce programme ne reconnat\n\
-pas actuellement et est incapable pour distribuer\n\
-l'ordre de fsck correspondant pour vrifier cet\n\
-appareil.",
-#endif
-		CDIALOG_ICON_WARNING,
-		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
+		NULL,
+		CDIALOG_ICON_ERROR,
+		CDIALOG_BTNFLAG_OK,
 		CDIALOG_BTNFLAG_OK
 	    );
 	    CDialogSetTransientFor(NULL);
 	    g_free(buf);
-
-	    g_free(cmd);
-	    g_free(fsck_prog);
-
+	    g_free(prog);
+	    g_free(prog_name);
 	    return;
 	}
 
 startup_message = g_strdup_printf(
 "-------------------------------------------------\n\
 Checking device %s...\n",
- dev_ptr->device_path
+ dev->device_path
 );
 FSCKManagerAppendMessage(
  fm, fm->text_font, NULL, NULL,
@@ -695,52 +753,44 @@ startup_message = NULL;
 	    fm->stdout_path,
 	    fm->stderr_path
 	);
+	/* Unable to execute the command? */
 	if(p == 0)
 	{
 	    gchar *buf = g_strdup_printf(
-#ifdef PROG_LANGUAGE_ENGLISH
-"Unable to execute the fsck command:\n\
+#if defined(PROG_LANGUAGE_SPANISH)
+"Incapaz de ejecutar la orden:\n\
 \n\
     %s",
-#endif
-#ifdef PROG_LANGUAGE_SPANISH
-"Incapaz de ejecutar la orden de fsck:\n\
+#elif defined(PROG_LANGUAGE_FRENCH)
+"Incapable d'executer l'ordre:\n\
 \n\
     %s",
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-"Incapable pour excuter l'ordre de fsck:\n\
+#else
+"Unable to execute the command:\n\
 \n\
     %s",
 #endif
 		cmd
 	    );
 	    EDVPlaySoundError(fm->ctx);
-	    CDialogSetTransientFor(fm->toplevel);
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
-#ifdef PROG_LANGUAGE_ENGLISH
-		"Check Failed",
+#if defined(PROG_LANGUAGE_SPANISH)
+		"Incapaz De Ejecutar La Prden",
+#elif defined(PROG_LANGUAGE_FRENCH)
+		"Incapable D'Executer L'Ordre",
+#else
+		"Unable To Execute Command",
+#endif
 		buf,
 		NULL,
-#endif
-#ifdef PROG_LANGUAGE_SPANISH
-		"El Cheque Fall",
-		buf,
-		NULL
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-		"Le Chque A Echou",
-		buf,
-		NULL,
-#endif
 		CDIALOG_ICON_ERROR,
-		CDIALOG_BTNFLAG_OK | CDIALOG_BTNFLAG_HELP,
+		CDIALOG_BTNFLAG_OK,
 		CDIALOG_BTNFLAG_OK
 	    );
 	    CDialogSetTransientFor(NULL);
 	    g_free(buf);
 
-	    /* Execute failed */
 	    UNLINK(fm->stdout_path);
 	    g_free(fm->stdout_path);
 	    fm->stdout_path = NULL;
@@ -750,7 +800,8 @@ startup_message = NULL;
 	    fm->stderr_path = NULL;
 
 	    g_free(cmd);
-	    g_free(fsck_prog);
+	    g_free(prog);
+	    g_free(prog_name);
 
 	    return;
 	}
@@ -774,7 +825,8 @@ startup_message = NULL;
 	FSCKManagerUpdateMenus(fm);
 
 	g_free(cmd);
-	g_free(fsck_prog);
+	g_free(prog);
+	g_free(prog_name);
 }
 
 
