@@ -1,5 +1,5 @@
 /*
-                        FSCK Manager Window Callbacks
+			FSCK Manager Window Callbacks
  */
 
 #ifndef FSCKCB_H
@@ -11,7 +11,7 @@
 
 
 extern gint FSCKManagerButtonPressEventCB(
-        GtkWidget *widget, GdkEventButton *button, gpointer data
+	GtkWidget *widget, GdkEventButton *button, gpointer data
 );
 extern gint FSCKManagerDiskIconExposeCB(
 	GtkWidget *widget, GdkEventExpose *expose, gpointer data
@@ -19,10 +19,9 @@ extern gint FSCKManagerDiskIconExposeCB(
 
 extern gint FSCKManagerFSCKTOCB(gpointer data);
 
-extern gint FSCKManagerCloseCB(
-        GtkWidget *widget, GdkEvent *event, gpointer data
+extern gint FSCKManagerDeleteEventCB(
+	GtkWidget *widget, GdkEvent *event, gpointer data
 );
-extern void FSCKManagerDestroyCB(GtkObject *object, gpointer data);
 
 extern void FSCKManagerStartCB(GtkWidget *widget, gpointer data);
 extern void FSCKManagerStopCB(GtkWidget *widget, gpointer data);
@@ -30,12 +29,12 @@ extern void FSCKManagerClearCB(GtkWidget *widget, gpointer data);
 extern void FSCKManagerCloseBtnCB(GtkWidget *widget, gpointer data);
 
 extern void FSCKManagerSelectRowCB(
-        GtkCList *clist, gint row, gint column, GdkEvent *event,
-        gpointer data
+	GtkCList *clist, gint row, gint column, GdkEvent *event,
+	gpointer data
 );
 extern void FSCKManagerUnselectRowCB(
-        GtkCList *clist, gint row, gint column, GdkEvent *event,
-        gpointer data
+	GtkCList *clist, gint row, gint column, GdkEvent *event,
+	gpointer data
 );
 
 
