@@ -1,10 +1,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <signal.h>
-#include <unistd.h>
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
+#include <unistd.h>
 
 #include "../../include/fio.h"
 #include "../../include/disk.h"
@@ -93,7 +92,7 @@ void FSCKManagerSetDevices(
 	GdkBitmap *mask;
 	GdkPixmap *pixmap;
 	GtkCList *clist;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	gchar *strv[4];
 
 #define DO_DEALLOCATE_INPUT_LIST	{	\
@@ -132,12 +131,12 @@ void FSCKManagerSetDevices(
 	    strv[i] = "";
 	for(i = 0; i < fm->total_devices; i++)
 	{
-	    dev_ptr = fm->device[i];
-	    if(dev_ptr == NULL)
+	    dev = fm->device[i];
+	    if(dev == NULL)
 		continue;
 
 	    /* Hide this device from general listing? */
-	    if(dev_ptr->unlisted)
+	    if(EDV_DEVICE_IS_UNLISTED(dev))
 		continue;
 
 	    /* Append a new clist row */
@@ -146,19 +145,19 @@ void FSCKManagerSetDevices(
 	    /* Load icon */
 	    pixmap = GDK_PIXMAP_NEW_FROM_XPM_FILE(
 		&mask,
-		dev_ptr->small_icon_file[EDV_DEVICE_ICON_STATE_STANDARD]
+		dev->small_icon_file[EDV_DEVICE_ICON_STATE_STANDARD]
 	    );
 
 	    /* Set name cell */
 	    column = 0;
-	    cell_text = dev_ptr->name;
-	    if((cell_text == NULL) && (dev_ptr->device_path != NULL))
+	    cell_text = dev->name;
+	    if((cell_text == NULL) && (dev->device_path != NULL))
 	    {
-		cell_text = strrchr(dev_ptr->device_path, DIR_DELIMINATOR);
+		cell_text = strrchr(dev->device_path, DIR_DELIMINATOR);
 		if(cell_text != NULL)
 		    cell_text++;
 		else
-		    cell_text = dev_ptr->device_path;
+		    cell_text = dev->device_path;
 	    }
 	    if(cell_text == NULL)
 		cell_text = "(null)";
@@ -176,7 +175,7 @@ void FSCKManagerSetDevices(
 
 	    /* Set device path cell */
 	    column = 1;
-	    cell_text = dev_ptr->device_path;
+	    cell_text = dev->device_path;
 	    if(cell_text == NULL)
 		cell_text = "(null)";
 
@@ -187,7 +186,7 @@ void FSCKManagerSetDevices(
 
 	    /* Set mount path cell */
 	    column = 2;
-	    cell_text = dev_ptr->mount_path;
+	    cell_text = dev->mount_path;
 	    if(cell_text == NULL)
 		cell_text = "(null)";
 
@@ -200,7 +199,7 @@ void FSCKManagerSetDevices(
 	    column = 3;
 	    gtk_clist_set_text(
 		clist, row, column,
-		EDVDeviceGetFSStringFromNumber(dev_ptr->fs_type)
+		EDVDeviceGetFSNameFromType(dev->fs_type)
 	    );
 
 
