@@ -10,8 +10,9 @@
 #include <gtk/gtk.h>
 #include "../lib/endeavour2.h"
 
+
 /*
- *	FSCK Manager Window:
+ *	FSCK Manager:
  */
 typedef struct {
 
@@ -54,7 +55,7 @@ typedef struct {
 			*close_btn;
 
 	/* Queued this of rows in the devices_clist that we need
-	 * to check.
+	 * to check
 	 */
 	GList		*queued_device_to_check;
 
