@@ -1559,7 +1559,7 @@ void EDVHistoryListWinUpdateDisplay(
 	if(!STRISEMPTY(h_ptr->src_path))
 	{
 	    const gchar *path = h_ptr->src_path;
-	    gchar *name = EDVCopyShortenPath(
+	    gchar *name = EDVShortenPath(
 		EDVGetPathName(path), 25
 	    );
 	    GdkBitmap *mask = NULL;
@@ -1573,13 +1573,12 @@ void EDVHistoryListWinUpdateDisplay(
 		    edv_object_struct *o = EDVObjectNew();
 		    EDVObjectSetPath(o, path);
 		    EDVObjectSetStat(o, &lstat_buf);
-		    o->link_valid = TRUE;	/* Safe to assume */
 		    EDVMatchObjectIcon(
 			core_ptr->device, core_ptr->total_devices,
 			core_ptr->mimetype, core_ptr->total_mimetypes,
 			o->type,
 			o->full_path,
-			o->link_valid,
+			TRUE,		/* Assume link valid */
 			o->permissions,
 			1,		/* Medium icons */
 			&pixmap, &mask,
@@ -1665,7 +1664,7 @@ void EDVHistoryListWinUpdateDisplay(
 	if(!STRISEMPTY(h_ptr->tar_path))
 	{
 	    const gchar *path = h_ptr->tar_path;
-	    gchar *name = EDVCopyShortenPath(
+	    gchar *name = EDVShortenPath(
 		EDVGetPathName(path), 25
 	    );
 	    GdkBitmap *mask = NULL;
@@ -1679,13 +1678,12 @@ void EDVHistoryListWinUpdateDisplay(
 		    edv_object_struct *o = EDVObjectNew();
 		    EDVObjectSetPath(o, path);
 		    EDVObjectSetStat(o, &lstat_buf);
-		    o->link_valid = TRUE;	/* Safe to assume */
 		    EDVMatchObjectIcon(
 			core_ptr->device, core_ptr->total_devices,
 			core_ptr->mimetype, core_ptr->total_mimetypes,
 			o->type,
 			o->full_path,
-			o->link_valid,
+			TRUE,			/* Assume link valid */
 			o->permissions,
 			1,			/* Medium icons */
 			&pixmap, &mask,
@@ -1790,7 +1788,7 @@ void EDVHistoryListWinUpdateDisplay(
 	)
 	{
 	    gchar *path = g_dirname(h_ptr->src_path);
-	    gchar *text = EDVCopyShortenPath(path, 40);
+	    gchar *text = EDVShortenPath(path, 40);
 	    GdkBitmap *mask = NULL;
 	    GdkPixmap *pixmap = NULL;
 	    struct stat lstat_buf;
@@ -1800,15 +1798,14 @@ void EDVHistoryListWinUpdateDisplay(
 		edv_object_struct *o = EDVObjectNew();
 		EDVObjectSetPath(o, path);
 		EDVObjectSetStat(o, &lstat_buf);
-		o->link_valid = TRUE;	/* Safe to assume */
 		EDVMatchObjectIcon(
 		    core_ptr->device, core_ptr->total_devices,
 		    core_ptr->mimetype, core_ptr->total_mimetypes,
 		    o->type,
 		    o->full_path,
-		    o->link_valid,
+		    TRUE,		/* Assume link valid */
 		    o->permissions,
-		    0,		/* Small icons */
+		    0,			/* Small icons */
 		    &pixmap, &mask,
 		    NULL, NULL,
 		    NULL, NULL,
@@ -1869,7 +1866,7 @@ void EDVHistoryListWinUpdateDisplay(
 	)
 	{
 	    gchar *path = g_dirname(h_ptr->tar_path);
-	    gchar *text = EDVCopyShortenPath(path, 40);
+	    gchar *text = EDVShortenPath(path, 40);
 	    GdkBitmap *mask = NULL;
 	    GdkPixmap *pixmap = NULL;
 	    struct stat lstat_buf;
@@ -1879,15 +1876,14 @@ void EDVHistoryListWinUpdateDisplay(
 		edv_object_struct *o = EDVObjectNew();
 		EDVObjectSetPath(o, path);
 		EDVObjectSetStat(o, &lstat_buf);
-		o->link_valid = TRUE;   /* Safe to assume */
 		EDVMatchObjectIcon(
 		    core_ptr->device, core_ptr->total_devices,
 		    core_ptr->mimetype, core_ptr->total_mimetypes,
 		    o->type,
 		    o->full_path,
-		    o->link_valid,
+		    TRUE,		/* Assume link valid */
 		    o->permissions,
-		    0,          /* Small icons */
+		    0,			/* Small icons */
 		    &pixmap, &mask,
 		    NULL, NULL,
 		    NULL, NULL,
@@ -2242,15 +2238,14 @@ static void EDVHistoryListWinSetRow(
 			edv_object_struct *o = EDVObjectNew();
 			EDVObjectSetPath(o, path);
 			EDVObjectSetStat(o, &lstat_buf);
-			o->link_valid = TRUE;	/* Safe to assume */
 			EDVMatchObjectIcon(
 			    core_ptr->device, core_ptr->total_devices,
 			    core_ptr->mimetype, core_ptr->total_mimetypes,
 			    o->type,
 			    o->full_path,
-			    o->link_valid,
+			    TRUE,		/* Assume link valid */
 			    o->permissions,
-			    0,		/* Small icons */
+			    0,			/* Small icons */
 			    &pixmap, &mask,
 			    NULL, NULL,
 			    NULL, NULL,
@@ -2304,7 +2299,7 @@ static void EDVHistoryListWinSetRow(
 		if(STRISEMPTY(name))
 		    s = STRDUP("");
 		else
-		    s = EDVCopyShortenPath(name, 32);
+		    s = EDVShortenPath(name, 32);
 
 		/* Set cell */
 		if(pixmap != NULL)
@@ -2337,15 +2332,14 @@ static void EDVHistoryListWinSetRow(
 			edv_object_struct *o = EDVObjectNew();
 			EDVObjectSetPath(o, path);
 			EDVObjectSetStat(o, &lstat_buf);
-			o->link_valid = TRUE;   /* Safe to assume */
 			EDVMatchObjectIcon(
 			    core_ptr->device, core_ptr->total_devices,
 			    core_ptr->mimetype, core_ptr->total_mimetypes,
 			    o->type,
 			    o->full_path,
-			    o->link_valid,
+			    TRUE,		/* Assume link valid */
 			    o->permissions,
-			    0,          /* Small icons */
+			    0,			/* Small icons */
 			    &pixmap, &mask,
 			    NULL, NULL,
 			    NULL, NULL,
@@ -2394,7 +2388,7 @@ static void EDVHistoryListWinSetRow(
 		if(STRISEMPTY(name))
 		    s = STRDUP("");
 		else
-		    s = EDVCopyShortenPath(name, 32);
+		    s = EDVShortenPath(name, 32);
 
 		/* Set cell */
 		if(pixmap != NULL)
