@@ -1440,13 +1440,15 @@ void HViewUpdate(hview_struct *hv)
             gtk_widget_show(hv->edit_mode_hex_mi);
             gtk_widget_show(hv->edit_mode_ascii_mi);
 	}
-	gtk_check_menu_item_set_active(
-            GTK_CHECK_MENU_ITEM(hv->edit_mode_hex_mi),
-            (hv->edit_mode == HVIEW_EDIT_MODE_HEX) ? TRUE : FALSE
+	GUIMenuItemSetCheck(
+	    hv->edit_mode_hex_mi,
+            (hv->edit_mode == HVIEW_EDIT_MODE_HEX) ? TRUE : FALSE,
+	    TRUE
         );
-	gtk_check_menu_item_set_active(
-	    GTK_CHECK_MENU_ITEM(hv->edit_mode_ascii_mi),
-	    (hv->edit_mode == HVIEW_EDIT_MODE_ASCII) ? TRUE : FALSE
+	GUIMenuItemSetCheck(
+	    hv->edit_mode_ascii_mi,
+	    (hv->edit_mode == HVIEW_EDIT_MODE_ASCII) ? TRUE : FALSE,
+	    TRUE
 	);
 
         hv->freeze_count--;
