@@ -5,17 +5,20 @@
 #ifndef IMBR_H
 #define IMBR_H
 
-
 #include <gtk/gtk.h>
-
+#include "cfg.h"
 #include "edvtypes.h"
-#include "edvstatusbar.h"
 #include "toolbar.h"
 #include "mountbar.h"
 #include "findbar.h"
-#include "fopdlg.h"
 #include "tlist.h"
 #include "imgview.h"
+#include "statusbar.h"
+#include "fopdlg.h"
+
+
+typedef struct _edv_imbr_struct		edv_imbr_struct;
+typedef struct _edv_imbr_opid_struct	edv_imbr_opid_struct;
 
 
 /*
@@ -24,109 +27,107 @@
 typedef enum {
 
 	EDV_IMBR_OP_NONE			= 0,
-	EDV_IMBR_OP_SEPARATOR			= 10,
+	EDV_IMBR_OP_SEPARATOR			= 100,
 
-	EDV_IMBR_OP_CLOSE			= 20,
-	EDV_IMBR_OP_EXIT			= 21,
+	EDV_IMBR_OP_CLOSE			= 200,
+	EDV_IMBR_OP_EXIT			= 201,
 
-	EDV_IMBR_OP_SYNC_DISKS			= 30,
-	EDV_IMBR_OP_RUN				= 31,
-	EDV_IMBR_OP_RUN_TERMINAL		= 32,
-	EDV_IMBR_OP_WRITE_PROTECT		= 35,
+	EDV_IMBR_OP_SYNC_DISKS			= 300,
+        EDV_IMBR_OP_HISTORY			= 301,
+	EDV_IMBR_OP_RUN				= 302,
+	EDV_IMBR_OP_RUN_TERMINAL		= 303,
+	EDV_IMBR_OP_WRITE_PROTECT		= 304,
 
-	EDV_IMBR_OP_NEW				= 40,
-	EDV_IMBR_OP_NEW_FILE			= 41,
-	EDV_IMBR_OP_NEW_DIRECTORY		= 42,
-	EDV_IMBR_OP_NEW_LINK			= 43,
-	EDV_IMBR_OP_NEW_FIFO			= 44,
-	EDV_IMBR_OP_NEW_DEVICE_BLOCK		= 45,
-	EDV_IMBR_OP_NEW_DEVICE_CHARACTER	= 46,
-	EDV_IMBR_OP_NEW_SOCKET			= 47,
+	EDV_IMBR_OP_NEW				= 400,
+	EDV_IMBR_OP_NEW_FILE			= 401,
+	EDV_IMBR_OP_NEW_DIRECTORY		= 402,
+	EDV_IMBR_OP_NEW_LINK			= 403,
+	EDV_IMBR_OP_NEW_FIFO			= 404,
+	EDV_IMBR_OP_NEW_DEVICE_BLOCK		= 405,
+	EDV_IMBR_OP_NEW_DEVICE_CHARACTER	= 406,
+	EDV_IMBR_OP_NEW_SOCKET			= 407,
 
-	EDV_IMBR_OP_OPEN			= 50,
-	EDV_IMBR_OP_OPEN_WITH			= 51,
+	EDV_IMBR_OP_OPEN			= 500,
+	EDV_IMBR_OP_OPEN_WITH			= 501,
 
-	EDV_IMBR_OP_GOTO_PARENT			= 60,
-	EDV_IMBR_OP_GOTO_HOME			= 61,
-	EDV_IMBR_OP_MOUNT			= 62,	/* Mount/unmount */
-	EDV_IMBR_OP_EJECT			= 63,
+        EDV_IMBR_OP_COPY_PATH			= 600,
+        EDV_IMBR_OP_COPY_URL			= 601,
+        EDV_IMBR_OP_PASTE			= 610,
 
-	EDV_IMBR_OP_MOVE			= 65,
-	EDV_IMBR_OP_COPY			= 66,
-	EDV_IMBR_OP_LINK			= 67,
-	EDV_IMBR_OP_RENAME			= 68,
-	EDV_IMBR_OP_CHMOD			= 69,
-	EDV_IMBR_OP_CHOWN			= 70,
-	EDV_IMBR_OP_DELETE			= 71,
-	EDV_IMBR_OP_SELECT_ALL			= 72,
-	EDV_IMBR_OP_UNSELECT_ALL		= 73,
-	EDV_IMBR_OP_INVERT_SELECTION		= 74,
-	EDV_IMBR_OP_PROPERTIES			= 75,
+	EDV_IMBR_OP_MOVE			= 700,
+	EDV_IMBR_OP_COPY			= 701,
+	EDV_IMBR_OP_LINK			= 702,
+	EDV_IMBR_OP_RENAME			= 703,
+	EDV_IMBR_OP_CHMOD			= 704,
+	EDV_IMBR_OP_CHOWN			= 705,
+	EDV_IMBR_OP_DELETE			= 706,
+	EDV_IMBR_OP_PROPERTIES			= 707,
 
-	EDV_IMBR_OP_FIND			= 76,
+        EDV_IMBR_OP_SELECT_ALL			= 800,
+        EDV_IMBR_OP_UNSELECT_ALL		= 801,
+        EDV_IMBR_OP_INVERT_SELECTION		= 802,
+	EDV_IMBR_OP_FIND			= 850,
 
-	EDV_IMBR_OP_HISTORY			= 77,
-	EDV_IMBR_OP_COPY_PATH			= 78,
-	EDV_IMBR_OP_COPY_URL			= 79,
+        EDV_IMBR_OP_DOWNLOAD			= 900,
 
-	EDV_IMBR_OP_REFRESH			= 80,
-	EDV_IMBR_OP_REFRESH_ALL			= 81,
-	EDV_IMBR_OP_STOP			= 82,
-	EDV_IMBR_OP_CONTINUE			= 83,
+	EDV_IMBR_OP_REFRESH			= 1000,
+	EDV_IMBR_OP_REFRESH_ALL			= 1001,
+        EDV_IMBR_OP_GOTO_PARENT			= 1100,
+        EDV_IMBR_OP_GOTO_HOME			= 1101,
+	EDV_IMBR_OP_STOP			= 1200,
+	EDV_IMBR_OP_CONTINUE			= 1201,
+	EDV_IMBR_OP_PRESENTATION_MODE		= 1280,
 
-	EDV_IMBR_OP_DOWNLOAD			= 85,
+	EDV_IMBR_OP_SHOW_TOOL_BAR		= 1300,
+	EDV_IMBR_OP_SHOW_LOCATION_BAR		= 1301,
+	EDV_IMBR_OP_SHOW_MOUNT_BAR		= 1302,
+	EDV_IMBR_OP_SHOW_FIND_BAR		= 1303,
+	EDV_IMBR_OP_SHOW_STATUS_BAR		= 1304,
 
-	EDV_IMBR_OP_SHOW_TOOL_BAR		= 90,
-	EDV_IMBR_OP_SHOW_LOCATION_BAR		= 91,
-	EDV_IMBR_OP_SHOW_MOUNT_BAR		= 92,
-	EDV_IMBR_OP_SHOW_FIND_BAR		= 93,
-	EDV_IMBR_OP_SHOW_STATUS_BAR		= 94,
+	EDV_IMBR_OP_SHOW_HIDDEN_OBJECTS		= 1401,
+	EDV_IMBR_OP_SHOW_NOACCESS_OBJECTS	= 1402,
+	EDV_IMBR_OP_SHOW_NONIMAGE_OBJECTS	= 1403,
 
-	EDV_IMBR_OP_SHOW_HIDDEN_OBJECTS		= 95,
-	EDV_IMBR_OP_SHOW_NOACCESS_OBJECTS	= 96,
-	EDV_IMBR_OP_SHOW_NONIMAGE_OBJECTS	= 97,
+        EDV_IMBR_OP_MOUNT			= 1600,	/* Mount/unmount */
+        EDV_IMBR_OP_EJECT			= 1620,
+        EDV_IMBR_OP_DEVICE_CHECK		= 1650,
+        EDV_IMBR_OP_DEVICE_TOOLS		= 1651,
+        EDV_IMBR_OP_DEVICE_FORMAT		= 1652,
 
-	EDV_IMBR_OP_MIME_TYPES			= 100,
-	EDV_IMBR_OP_DEVICES			= 101,
+	EDV_IMBR_OP_MIME_TYPES			= 1700,
+	EDV_IMBR_OP_DEVICES			= 1701,
 
-	EDV_IMBR_OP_NEW_BROWSER			= 110,
-	EDV_IMBR_OP_NEW_IMBR			= 111,
-	EDV_IMBR_OP_NEW_ARCHIVER		= 112,
-	EDV_IMBR_OP_RECYCLE_BIN			= 113,
+	EDV_IMBR_OP_NEW_BROWSER			= 1800,
+	EDV_IMBR_OP_NEW_IMBR			= 1801,
+	EDV_IMBR_OP_NEW_ARCHIVER		= 1802,
+	EDV_IMBR_OP_RECYCLE_BIN			= 1900,
 
-	EDV_IMBR_OP_OPTIONS			= 150,
-	EDV_IMBR_OP_CUSTOMIZE			= 151,
+	EDV_IMBR_OP_OPTIONS			= 2000,
+	EDV_IMBR_OP_CUSTOMIZE			= 2001,
 
-	EDV_IMBR_OP_DEVICE_CHECK		= 180,
-	EDV_IMBR_OP_DEVICE_TOOLS		= 181,
-	EDV_IMBR_OP_DEVICE_FORMAT		= 182,
+	EDV_IMBR_OP_HELP_CONTENTS		= 3000,
+	EDV_IMBR_OP_HELP_FILE_BROWSER	 	= 3010,
+	EDV_IMBR_OP_HELP_IMAGE_BROWSER		= 3011,
+	EDV_IMBR_OP_HELP_ARCHIVER		= 3012,
+	EDV_IMBR_OP_HELP_RECYCLE_BIN		= 3030,
+	EDV_IMBR_OP_HELP_KEYS_LIST		= 3050,
+	EDV_IMBR_OP_HELP_MIME_TYPES		= 3051,
+	EDV_IMBR_OP_HELP_DEVICES		= 3052,
+	EDV_IMBR_OP_HELP_COMMON_OPERATIONS	= 3053,
+        EDV_IMBR_OP_HELP_ABOUT			= 3100
 
-	EDV_IMBR_OP_HELP_ABOUT			= 1000,
-	EDV_IMBR_OP_HELP_CONTENTS		= 1001,
-	EDV_IMBR_OP_HELP_FILE_BROWSER	 	= 1002,
-	EDV_IMBR_OP_HELP_IMAGE_BROWSER		= 1003,
-	EDV_IMBR_OP_HELP_ARCHIVER		= 1004,
-	EDV_IMBR_OP_HELP_RECYCLE_BIN		= 1005,
-	EDV_IMBR_OP_HELP_KEYS_LIST		= 1006,
-	EDV_IMBR_OP_HELP_MIME_TYPES		= 1007,
-	EDV_IMBR_OP_HELP_DEVICES		= 1008,
-	EDV_IMBR_OP_HELP_COMMON_OPERATIONS	= 1009
 } edv_imbr_op;
 
 
 /*
  *	Image Browser Operation ID:
  */
-typedef struct {
+struct _edv_imbr_opid_struct {
 
-	gpointer	imbr;
 	edv_imbr_op	op;
-	gboolean	allow_multiple;		/* Allow multiple instances
-						 * of this operation in
-						 * lists */
-
-	toolbar_item_type tb_item_type;		/* Type of item when placed
-						 * on the Tool Bar */
+	edv_opid_flags	flags;
+	toolbar_item_type	tb_item_type;
+	edv_imbr_struct	*imbr;
 
 	/* Operation callback */
 	void	(*func_cb)(
@@ -157,23 +158,22 @@ typedef struct {
 	guint8		**button_icon_data,	/* Shared */
 			**menu_icon_data;	/* Shared */
 
-} edv_imbr_opid_struct;
+};
 #define EDV_IMBR_OPID(p)	((edv_imbr_opid_struct *)(p))
 
 /*
  *	Image Browser:
  */
-typedef struct {
+struct _edv_imbr_struct {
 
 	GtkWidget	*toplevel;
-	GtkAccelGroup	*accelgrp;
 	gboolean	processing;
 	gint		busy_count,
+			passive_busy_count,
 			freeze_count;
 	gpointer	core_ptr;
 
-	edv_imbr_opid_struct	**opid;
-	gint			total_opids;
+	GList		*opid_list;
 
 	gint		stop_count;
 	guint		loading_tocb;
@@ -201,18 +201,9 @@ typedef struct {
 
 			*main_paned;		/* GtkHPaned */
 
-	/* General tool bar */
-	toolbar_struct	*toolbar;
-
-	/* Mount bar */
-	edv_mountbar_struct	*mountbar;
-
-	/* Find bar */
-	edv_findbar_struct	*findbar;
-
-	/* Important menu items */
+	/* Menu Bar Items */
 	GtkWidget	*open_mi,
-			*openwith_mi,
+			*open_with_mi,
 			*new_object_submi,
 			*new_object_submenu,
 			*new_file_mi,
@@ -236,6 +227,7 @@ typedef struct {
 			*delete_mi,
 			*copy_path_mi,
 			*copy_url_mi,
+			*paste_mi,
 			*select_all_mi,
 			*unselect_all_mi,
 			*invert_selection_mi,
@@ -251,6 +243,7 @@ typedef struct {
 
 			*stop_mi,
 			*continue_mi,
+			*presentation_mode_mi,
 			*refresh_mi,
 			*refresh_all_mi,
 			*show_tool_bar_micheck,
@@ -280,6 +273,15 @@ typedef struct {
 			*help_common_operations_mi,
 			*help_about_mi;
 
+        /* Tool Bar */
+        toolbar_struct	*toolbar;
+
+        /* Mount Bar */
+        edv_mountbar_struct	*mountbar;
+
+        /* Find Bar */
+        edv_findbar_struct	*findbar;
+
 	/* Thumbs list */
 	tlist_struct	*tlist;
 
@@ -290,7 +292,7 @@ typedef struct {
 	/* Right-click menu */
 	GtkWidget	*tlist_menu,
 			*tlist_open_mi,
-			*tlist_openwith_mi,
+			*tlist_open_with_mi,
 			*tlist_mount_mi,
 			*tlist_eject_mi,
 			*tlist_mount_misep,
@@ -303,11 +305,10 @@ typedef struct {
 			*tlist_delete_mi,
 			*tlist_copy_path_mi,
 			*tlist_copy_url_mi,
+			*tlist_paste_mi,
 			*tlist_properties_mi;
 
 	/* Icons used in the thumbs list */
-	GdkPixmap	*folder_home_pixmap;
-	GdkBitmap	*folder_home_mask;
 	GdkPixmap	*folder_parent_pixmap;
 	GdkBitmap	*folder_parent_mask;
 	GdkPixmap	*folder_noaccess_pixmap;
@@ -320,7 +321,7 @@ typedef struct {
 	 * Note that this does not reflect other selected rows since
 	 * multiple selections are allowed
 	 */
-	gint	tlist_selected_thumb;
+	gint		tlist_selected_thumb;
 
 	/* Selected device, reflects the device of the disk object of
 	 * the selected thumb
@@ -328,7 +329,7 @@ typedef struct {
 	 * The device number corresponds with a device on the core's
 	 * list of devices
 	 */
-	gint	selected_dev_num;
+	gint		selected_dev_num;
 
 
 	/* Last known items in recycle bin, this is used as a quick
@@ -337,26 +338,27 @@ typedef struct {
 	 *
 	 * Can be -1 to indicate undefined
 	 */
-	gint	last_recbin_items;
+	gint		last_recbin_items;
 
-	/* Last known write protect state (can be -1 to indicate
-	 * undefined)
-	 */
-	gint	last_write_protect_state;
+	/* Last known write protect state (can be -1 for unknown) */
+	gint		last_write_protect_state;
 
 
-
-	/* Status bar */
-	edv_status_bar_struct	*status_bar;
+	/* Status Bar */
+	edv_statusbar_struct	*status_bar;
 
 
-	/* File operation dialog */
+	/* File Operation Dialog */
 	edv_fopdlg_struct	*fopdlg;
 
-} edv_imbr_struct;
+};
 #define EDV_IMBR(p)	((edv_imbr_struct *)(p))
 
 
+extern edv_imbr_opid_struct *EDVImbrMatchOPID(
+	edv_imbr_struct *imbr, edv_imbr_op op
+);
+
 extern void EDVImbrSetTitle(edv_imbr_struct *imbr, const gchar *path);
 
 extern gchar *EDVImbrCurrentLocation(edv_imbr_struct *imbr);
@@ -368,6 +370,7 @@ extern void EDVImbrUpdateLocationIcon(
 	edv_imbr_struct *imbr, const gchar *path
 );
 
+extern void EDVImbrAccelkeysRegenerate(edv_imbr_struct *imbr);
 extern void EDVImbrToolbarRegenerate(edv_imbr_struct *imbr);
 extern void EDVImbrNewObjectMenuRegenerate(edv_imbr_struct *imbr);
 extern void EDVImbrTListMenuRegenerate(edv_imbr_struct *imbr);
@@ -380,18 +383,18 @@ extern void EDVImbrSelectPath(
 	edv_imbr_struct *imbr, const gchar *path
 );
 
-extern edv_imbr_opid_struct **EDVImbrOPIDListNew(
-	edv_imbr_struct *imbr,		/* Can be NULL */
-	gint *total
-);
-extern void EDVImbrOPIDListDelete(
-	edv_imbr_opid_struct **list, gint total
+extern GList *EDVImbrOPIDListNew(
+	edv_imbr_struct *imbr			/* Can be NULL */
 );
+extern void EDVImbrOPIDListDelete(GList *glist);
+
+extern cfg_accelkey_list_struct *EDVImbrAccelkeysListNewDefault(void);
 
 extern edv_imbr_struct *EDVImbrNew(gpointer core_ptr);
 extern void EDVImbrSyncData(edv_imbr_struct *imbr);
 extern void EDVImbrUpdateMenus(edv_imbr_struct *imbr);
 extern void EDVImbrSetBusy(edv_imbr_struct *imbr, gboolean is_busy);
+extern void EDVImbrSetPassiveBusy(edv_imbr_struct *imbr, gboolean is_busy);
 extern gboolean EDVImbrIsMapped(edv_imbr_struct *imbr);
 extern void EDVImbrMap(edv_imbr_struct *imbr);
 extern void EDVImbrUnmap(edv_imbr_struct *imbr);
