@@ -7,13 +7,12 @@
 #include "../include/string.h"
 
 #include "guiutils.h"
-#include "cdialog.h"
 
 #include "edvtypes.h"
 #include "cfg.h"
 #include "edvobj.h"
 #include "edvdevices.h"
-#include "edvstatusbar.h"
+#include "statusbar.h"
 #include "imbr.h"
 #include "imbrcb.h"
 #include "imbropcb.h"
@@ -50,10 +49,12 @@ void EDVImbrHandleChildDetachedCB(
 );
 
 void EDVImbrTListSelectCB(
-	gpointer tl, GdkEventButton *button, gint thumb_num, gpointer data
+	tlist_struct *tlist, GdkEventButton *button, gint thumb_num,
+	gpointer data
 );
 void EDVImbrTListUnselectCB(
-	gpointer tl, GdkEventButton *button, gint thumb_num, gpointer data
+	tlist_struct *tlist, GdkEventButton *button, gint thumb_num,
+	gpointer data
 );
 
 void EDVImbrComboActivateCB(GtkWidget *widget, gpointer data);
@@ -165,11 +166,13 @@ gint EDVImbrKeyEventCB(
 )
 {
 	gint status = FALSE;
+	gboolean is_press;
 	gint etype;
 	guint keyval, state;
-	gboolean press;
+	GtkWidget *w, *focus_widget;
+	const cfg_item_struct *cfg_list;
 	tlist_struct *tlist;
-	edv_core_struct *core_ptr;
+ 	edv_core_struct *core_ptr;
 	edv_imbr_struct *imbr = EDV_IMBR(data);
 	if((widget == NULL) || (key == NULL) || (imbr == NULL))
 	    return(status);
@@ -177,93 +180,82 @@ gint EDVImbrKeyEventCB(
 	if(imbr->processing)
 	    return(status);
 
+	tlist = imbr->tlist;
 	core_ptr = EDV_CORE(imbr->core_ptr);
-	if(core_ptr == NULL)
+	if((tlist == NULL) || (core_ptr == NULL))
 	    return(status);
 
-	/* Get event type */
+	w = imbr->toplevel;
+	focus_widget = (w != NULL) ? GTK_WINDOW(w)->focus_widget : NULL;
+	cfg_list = core_ptr->cfg_list;
 	etype = key->type;
-
-	/* Get other key event values */
-	press = (etype == GDK_KEY_PRESS) ? TRUE : FALSE;
+	is_press = (etype == GDK_KEY_PRESS) ? TRUE : FALSE;
 	keyval = key->keyval;
 	state = key->state;
 
-	tlist = imbr->tlist;
-	if(tlist == NULL)
-	    return(status);
-
 /* Stop emit of signal */
 #define DO_STOP_KEY_SIGNAL_EMIT	{		\
  gtk_signal_emit_stop_by_name(			\
   GTK_OBJECT(widget),				\
-  press ?					\
+  is_press ?					\
    "key_press_event" : "key_release_event"	\
  );						\
 }
 
-	/* Handle by key value */
-	switch(keyval)
+	/* If the focus_widget is not a GtkEditable then check if the
+	 * keyval is an accelerator key before all subsequence checks
+	 */
+	if((focus_widget != NULL) ?
+	    !GTK_IS_EDITABLE(focus_widget) : TRUE
+	)
 	{
-#if 0
-	  case GDK_Return:
-	  case GDK_KP_Enter:
-	  case GDK_ISO_Enter:
-	  case GDK_3270_Enter:
-	    /* Handle only if control key modifier is not held, so
-	     * that accelerator keys will get handled properly
-	     */
-	    if(!(state & GDK_CONTROL_MASK))
+	    edv_imbr_op op = (edv_imbr_op)EDVMatchAccelKeyOPID(
+		cfg_list, EDV_CFG_PARM_IMBR_ACCELERATOR_KEYS,
+		keyval, state
+	    );
+	    if(op > 0)
 	    {
-		if(press)
-		    EDVImbrTListDoOpenObject(
-			imbr, imbr->tlist_selected_thumb, state
+		if(is_press)
+		{
+		    edv_imbr_opid_struct *opid = EDVImbrMatchOPID(
+			imbr, op
 		    );
+		    if(opid != NULL)
+			EDVImbrOPCB(NULL, -1, opid);
+		}
 		DO_STOP_KEY_SIGNAL_EMIT
 		status = TRUE;
+		return(status);
 	    }
-	    break;
-#endif
-	  case GDK_Delete:
-	    if(press)
-		EDVImbrOPDelete(imbr);
-	    DO_STOP_KEY_SIGNAL_EMIT
-	    status = TRUE;
-	    break;
+	}
 
-	  case GDK_Insert:
-	    if(state & GDK_CONTROL_MASK)
+	/* Check which widget this signal is for */
+
+	/* Thumbs List */
+	if(widget == tlist->list_da)
+	{
+	    switch(keyval)
 	    {
-		if(press)
-		    EDVImbrOPCopyPath(imbr);
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
+	      default:
+		/* For all other alphanumeric character keys and while
+		 * no modifier keys are held, attempt to seek to the
+		 * item who's name starts with the letter of the key
+		 * that was pressed
+		 */
+		if(isalnum((char)keyval) && is_press &&
+		   ((state == 0x00000000) || (state == GDK_SHIFT_MASK))
+		)
+		{
+		    TListFreeze(tlist);
+		    EDVTListSeekCharacter(
+			tlist, 0, keyval
+		    );
+		    TListThaw(tlist);
+		    DO_STOP_KEY_SIGNAL_EMIT
+		    status = TRUE;
+		}
+		break;
 	    }
-	    break;
-
-	  default:
-	    /* For all other alphanumeric character keys and while
-	     * no modifier keys are held, attempt to seek to the
-	     * item who's name starts with the letter of the key
-	     * that was pressed
-	     */
-	    if(isalnum((char)keyval) && press &&
-	       ((state == 0x00000000) || (state == GDK_SHIFT_MASK))
-	    )
-	    {
-		TListFreeze(tlist);
-		EDVTListSeekCharacter(
-		    tlist, 0,
-		    (gchar)((state & GDK_SHIFT_MASK) ?
-			toupper((char)keyval) : keyval
-		    )
-		);
-		TListThaw(tlist);
-
-		DO_STOP_KEY_SIGNAL_EMIT
-		status = TRUE;
-	    }
-	    break;
 	}
 
 	return(status);
@@ -382,7 +374,11 @@ gint EDVImbrButtonPressEventCB(
 		{
 		    if(thumb_num > -1)
 		    {
-			EDVImbrTListDoOpenObject(imbr, thumb_num, state);
+			EDVImbrTListOpen(
+			    imbr,
+			    thumb_num,
+			    state		/* Modifier keys */
+			);
 			status = TRUE;
 		    }
 		}
@@ -421,7 +417,11 @@ gint EDVImbrButtonPressEventCB(
 		    gint thumb_num = imbr->tlist_selected_thumb;
 		    if(thumb_num > -1)
 		    {
-			EDVImbrTListDoOpenObject(imbr, thumb_num, state);
+			EDVImbrTListOpen(
+			    imbr,
+			    thumb_num,
+			    state		/* Modifier keys */
+			);
 			status = TRUE;
 		    }
 		}
@@ -469,28 +469,27 @@ void EDVImbrHandleChildDetachedCB(
  *	Image Browser thumbs list select thumb callback.
  */
 void EDVImbrTListSelectCB(
-	gpointer tl, GdkEventButton *button, gint thumb_num, gpointer data
+	tlist_struct *tlist, GdkEventButton *button, gint thumb_num,
+	gpointer data
 )
 {
 	tlist_thumb_struct *thumb;
-	tlist_struct *tlist;
 	edv_core_struct *core_ptr;
 	edv_imbr_struct *imbr = EDV_IMBR(data);
-	if((tl == NULL) || (imbr == NULL))
+	if((tlist == NULL) || (imbr == NULL))
 	    return;
 
 	if(imbr->processing)
 	    return;
 
-	tlist = imbr->tlist;
 	core_ptr = EDV_CORE(imbr->core_ptr);
-	if((tlist == NULL) || (core_ptr == NULL))
+	if(core_ptr == NULL)
 	    return;
 
 	thumb = ((thumb_num >= 0) && (thumb_num < tlist->total_thumbs)) ?
 	    tlist->thumb[thumb_num] : NULL;
 
-	if(tl == (gpointer)tlist)
+	if(tlist == imbr->tlist)
 	{
 	    /* Change in selection? */
 	    if(imbr->tlist_selected_thumb != thumb_num)
@@ -651,24 +650,23 @@ void EDVImbrTListSelectCB(
  *	Image Browser thumbs list unselect thumb callback.
  */
 void EDVImbrTListUnselectCB(
-	gpointer tl, GdkEventButton *button, gint thumb_num, gpointer data
+	tlist_struct *tlist, GdkEventButton *button, gint thumb_num,
+	gpointer data
 )
 {
 	edv_core_struct *core_ptr;
-	tlist_struct *tlist;
 	edv_imbr_struct *imbr = EDV_IMBR(data);
-	if((tl == NULL) || (imbr == NULL))
+	if((tlist == NULL) || (imbr == NULL))
 	    return;
 
 	if(imbr->processing)
 	    return;
 
-	tlist = imbr->tlist;
 	core_ptr = EDV_CORE(imbr->core_ptr);
-	if((tlist == NULL) || (core_ptr == NULL))
+	if(core_ptr == NULL)
 	    return;
 
-	if(tl == (gpointer)tlist)
+	if(tlist == imbr->tlist)
 	{
 	    /* Get last selected thumb (if any) */
 	    const gint total_selected = g_list_length(tlist->selection);
@@ -717,7 +715,7 @@ void EDVImbrTListUnselectCB(
  */
 void EDVImbrComboActivateCB(GtkWidget *widget, gpointer data)
 {
-	GtkCombo *combo = (GtkCombo *)widget;
+	GtkWidget *toplevel;
 	edv_imbr_struct *imbr = EDV_IMBR(data);
 	if((widget == NULL) || (imbr == NULL))
 	    return;
@@ -725,17 +723,20 @@ void EDVImbrComboActivateCB(GtkWidget *widget, gpointer data)
 	if(imbr->processing)
 	    return;
 
+	toplevel = imbr->toplevel;
+
 	/* Check which widget was activated */
 	if(widget == imbr->location_combo)
 	{
-	    gchar *new_path = EDVCopyEvaluateInputPath(
-		NULL,           /* No parent path, imply use toplevel */
-		gtk_entry_get_text(GTK_ENTRY(combo->entry))
+	    GtkCombo *combo = GTK_COMBO(widget);
+	    GtkEntry *entry = GTK_ENTRY(combo->entry);
+	    gchar *path = EDVEvaluatePath(
+		NULL, gtk_entry_get_text(entry)
 	    );
-	    if(new_path != NULL)
+	    if(path != NULL)
 	    {
 		EDVImbrSetBusy(imbr, TRUE);
-		GUIBlockInput(imbr->toplevel, TRUE);
+		GUIBlockInput(toplevel, TRUE);
 
 		/* Update location combo, this is really just to record
 		 * the new value as history. The combo will be updated
@@ -743,23 +744,21 @@ void EDVImbrComboActivateCB(GtkWidget *widget, gpointer data)
 		 * valid and selected in the callbacks triggered by
 		 * EDVImbrSelectPath() farther below
 		 */
-		EDVImbrSetLocation(imbr, new_path, TRUE);
+		EDVImbrSetLocation(imbr, path, TRUE);
 
 		/* Reset loading procedure values and get new directory
 		 * listing, then initialize loading procedure values for
 		 * the loading of images from the directory specified by
-		 * new_path
+		 * path
 		 */
-		EDVImbrSelectPath(imbr, new_path);
-
-		GUIBlockInput(imbr->toplevel, FALSE);
-		EDVImbrSetBusy(imbr, FALSE);
-
+		EDVImbrSelectPath(imbr, path);
 
 		EDVImbrUpdateMenus(imbr);
 
+		g_free(path);
 
-		g_free(new_path);
+		GUIBlockInput(toplevel, FALSE);
+		EDVImbrSetBusy(imbr, FALSE);
 	    }
 	}
 }
@@ -788,6 +787,8 @@ gint EDVImbrLoadingTOCB(gpointer data)
  /* Reset loading timeout id */		\
  imbr->loading_tocb = 0;		\
 					\
+ EDVImbrSetPassiveBusy(imbr, FALSE);	\
+					\
  return(FALSE);				\
 }
 
@@ -795,9 +796,8 @@ gint EDVImbrLoadingTOCB(gpointer data)
 					\
  /* Set new loading timeout callback */	\
  imbr->loading_tocb = gtk_timeout_add(	\
-  100,					\
-  (GtkFunction)EDVImbrLoadingTOCB,	\
-  imbr					\
+  100l,					\
+  EDVImbrLoadingTOCB, imbr		\
  );					\
 					\
  /* Return FALSE since we reschedualed	\
@@ -824,8 +824,8 @@ gint EDVImbrLoadingTOCB(gpointer data)
 		imbr->status_bar, "Loading interrupted", FALSE
 	    );
 	    EDVStatusBarProgress(imbr->status_bar, 0.0f, FALSE);
-
 	    EDVImbrUpdateMenus(imbr);
+	    EDVImbrSetPassiveBusy(imbr, FALSE);
 
 	    return(FALSE);
 	}
@@ -846,6 +846,7 @@ g_print(
 	  case 0:	/* All thumb loaded */
 	    imbr->loading_tocb = 0;
 	    EDVImbrUpdateMenus(imbr);
+	    EDVImbrSetPassiveBusy(imbr, FALSE);
 	    return(FALSE);
 	    break;
 
@@ -1104,7 +1105,7 @@ void EDVImbrReconfiguredNotifyCB(edv_imbr_struct *imbr)
 	GtkRcStyle *standard_rcstyle, *lists_rcstyle;
 	GtkWidget *w;
 	const cfg_item_struct *cfg_list;
-	edv_status_bar_struct *status_bar;
+	edv_statusbar_struct *status_bar;
 	edv_core_struct *core_ptr;
 	tlist_struct *tlist;
 	imgview_struct *iv;
@@ -1141,6 +1142,9 @@ void EDVImbrReconfiguredNotifyCB(edv_imbr_struct *imbr)
 	/* Update Title */
 	EDVImbrSetTitle(imbr, cur_path);
 
+	/* Recreate Accelkey Labels */
+	EDVImbrAccelkeysRegenerate(imbr);
+
 	/* Recreate Tool Bar */
 	EDVImbrToolbarRegenerate(imbr);
 
@@ -1230,8 +1234,8 @@ void EDVImbrReconfiguredNotifyCB(edv_imbr_struct *imbr)
 	    /* Update geometry of thumb size */
 	    TListResize(tlist, -1, -1);
 
-	    /* Update all thumbs */
-	    EDVImbrTListResetThumbs(imbr);
+	    /* Realize listing */
+	    EDVImbrTListRealizeListing(imbr);
 
 	    TListThaw(tlist);
 	}
@@ -1346,9 +1350,8 @@ void EDVImbrMimeTypeModifiedCB(
 )
 {
 	gchar *cur_path;
-	edv_core_struct *core_ptr;
 	tlist_struct *tlist;
-
+	edv_core_struct *core_ptr;
 
 	if(imbr == NULL)
 	    return;
@@ -1356,25 +1359,19 @@ void EDVImbrMimeTypeModifiedCB(
 	if(imbr->processing)
 	    return;
 
-	core_ptr = EDV_CORE(imbr->core_ptr);
-	if(core_ptr == NULL)
-	    return;
-
 	tlist = imbr->tlist;
-	if(tlist == NULL)
+	core_ptr = EDV_CORE(imbr->core_ptr);
+	if((tlist == NULL) || (core_ptr == NULL))
 	    return;
 
-
-	/* Get copy of current location path */
+	/* Get current location */
 	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
 
-
-	/* Reset displayed thumb values */
+	/* Realize listing */
 	TListFreeze(tlist);
-	EDVImbrTListResetThumbs(imbr);
+	EDVImbrTListRealizeListing(imbr);
 	TListThaw(tlist);
 
-	/* Delete copy of current location path */
 	g_free(cur_path);
 }
 
@@ -1387,9 +1384,8 @@ void EDVImbrMimeTypeRemovedCB(
 )
 {
 	gchar *cur_path;
-	edv_core_struct *core_ptr;
 	tlist_struct *tlist;
-
+	edv_core_struct *core_ptr;
 
 	if(imbr == NULL)
 	    return;
@@ -1397,26 +1393,19 @@ void EDVImbrMimeTypeRemovedCB(
 	if(imbr->processing)
 	    return;
 
-	core_ptr = EDV_CORE(imbr->core_ptr);
-	if(core_ptr == NULL)
-	    return;
-
 	tlist = imbr->tlist;
-	if(tlist == NULL)
+	core_ptr = EDV_CORE(imbr->core_ptr);
+	if((tlist == NULL) || (core_ptr == NULL))
 	    return;
 
-
-	/* Get copy of current location path */
+	/* Get current location */
 	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
 
-
-
-	/* Reset displayed thumb values */
+	/* Realize listing */
 	TListFreeze(tlist);
-	EDVImbrTListResetThumbs(imbr);
+	EDVImbrTListRealizeListing(imbr);
 	TListThaw(tlist);
 
-	/* Delete copy of current location path */
 	g_free(cur_path);
 }
 
@@ -1446,9 +1435,8 @@ void EDVImbrDeviceModifiedCB(
 )
 {
 	gchar *cur_path;
-	edv_core_struct *core_ptr;
 	tlist_struct *tlist;
-
+	edv_core_struct *core_ptr;
 
 	if(imbr == NULL)
 	    return;
@@ -1456,29 +1444,22 @@ void EDVImbrDeviceModifiedCB(
 	if(imbr->processing)
 	    return;
 
-	core_ptr = EDV_CORE(imbr->core_ptr);
-	if(core_ptr == NULL)
-	    return;
-
 	tlist = imbr->tlist;
-	if(tlist == NULL)
+	core_ptr = EDV_CORE(imbr->core_ptr);
+	if((tlist == NULL) || (core_ptr == NULL))
 	    return;
 
-
-	/* Get copy of current location path */
+	/* Get current location */
 	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
 
-
-
-	/* Reset displayed thumb values */
+	/* Realize listing */
 	TListFreeze(tlist);
-	EDVImbrTListResetThumbs(imbr);
+	EDVImbrTListRealizeListing(imbr);
 	TListThaw(tlist);
 
 	/* Update menus */
 	EDVImbrUpdateMenus(imbr);
 
-	/* Delete copy of current location path */
 	g_free(cur_path);
 }
 
@@ -1491,10 +1472,9 @@ void EDVImbrDeviceRemovedCB(
 )
 {
 	gchar *cur_path;
+	tlist_struct *tlist;
 	edv_mountbar_struct *mb;
 	edv_core_struct *core_ptr;
-	tlist_struct *tlist;
-
 
 	if(imbr == NULL)
 	    return;
@@ -1502,41 +1482,35 @@ void EDVImbrDeviceRemovedCB(
 	if(imbr->processing)
 	    return;
 
-	core_ptr = EDV_CORE(imbr->core_ptr);
-	if(core_ptr == NULL)
-	    return;
-
 	tlist = imbr->tlist;
-	if(tlist == NULL)
+	core_ptr = EDV_CORE(imbr->core_ptr);
+	if((tlist == NULL) || (core_ptr == NULL))
 	    return;
 
-
-	/* Get copy of current location path */
+	/* Get current location */
 	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
 
-
-	/* Check if mount bar is currently referencing this device, if it
-	 * is then its selected device needs to be set to -1.
+	/* Check if the Mount Bar is currently referencing this device,
+	 * if it is then its selected device needs to be set to -1
 	 */
 	mb = imbr->mountbar;
 	if(mb != NULL)
 	{
 	    if(mb->selected_dev_num == dev_num)
 		mb->selected_dev_num = -1;
-	    /* Mount bar will be updated further below when menus are
-	     * updated.
+
+	    /* Mount Bar will be updated further below when menus are
+	     * updated
 	     */
 	}
 
-
-	/* Reset displayed thumb values */
+	/* Realize listing */
 	TListFreeze(tlist);
-	EDVImbrTListResetThumbs(imbr);
+	EDVImbrTListRealizeListing(imbr);
 	TListThaw(tlist);
 
 	/* Update menus */
 	EDVImbrUpdateMenus(imbr);
 
-	/* Delete copy of current location path */
 	g_free(cur_path);
 }
