@@ -32,10 +32,12 @@ extern void EDVImbrHandleChildDetachedCB(
 );
 
 extern void EDVImbrTListSelectCB(
-	gpointer tl, GdkEventButton *button, gint thumb_num, gpointer data
+	tlist_struct *tlist, GdkEventButton *button, gint thumb_num,
+	gpointer data
 );
 extern void EDVImbrTListUnselectCB(
-	gpointer tl, GdkEventButton *button, gint thumb_num, gpointer data
+	tlist_struct *tlist, GdkEventButton *button, gint thumb_num,
+	gpointer data
 );
 
 extern void EDVImbrComboActivateCB(GtkWidget *widget, gpointer data);
