@@ -28,6 +28,7 @@
 #include "edvop.h"
 #include "edvcb.h"
 #include "edvutils.h"
+
 #include "edvutilsgtk.h"
 #include "config.h"
 
@@ -42,7 +43,7 @@ static void EDVImbrDNDUpdateStatusBar(
 static void EDVImbrDragDataReceivedNexus(
 	edv_core_struct *core_ptr, edv_imbr_struct *imbr,
 	GdkDragContext *dc, guint info, GtkSelectionData *selection_data,
-	edv_object_struct *object       /* Can be NULL */
+	edv_object_struct *obj			/* Can be NULL */
 );
 
 gint EDVImbrLocBarIconCrossingCB(
@@ -104,7 +105,7 @@ static void EDVImbrDNDUpdateStatusBar(
 )
 {
 	gchar *buf = NULL;
-	edv_status_bar_struct *sb = (imbr != NULL) ?
+	edv_statusbar_struct *sb = (imbr != NULL) ?
 	    imbr->status_bar : NULL;
 	if(sb == NULL)
 	    return;
@@ -269,7 +270,7 @@ static void EDVImbrDNDUpdateStatusBar(
 static void EDVImbrDragDataReceivedNexus(
 	edv_core_struct *core_ptr, edv_imbr_struct *imbr,
 	GdkDragContext *dc, guint info, GtkSelectionData *selection_data,
-	edv_object_struct *object		/* Can be NULL */
+	edv_object_struct *obj			/* Can be NULL */
 )
 {
 	gint initial_confirmation_result, nurls;
@@ -288,13 +289,12 @@ static void EDVImbrDragDataReceivedNexus(
  url_list = NULL;					\
 }
 
-	/* Get copy of parent_path as the disk object's full path if the
-	 * disk object is not NULL
+	/* Get copy of parent_path as the object's full path if the
+	 * object is not NULL
 	 */
-	parent_path = (object != NULL) ?
-	    STRDUP(object->full_path) : NULL;
+	parent_path = (obj != NULL) ? STRDUP(obj->full_path) : NULL;
 
-	/* If parent_path is not obtainable from the disk object then
+	/* If parent_path is not obtainable from the object then
 	 * use the image browser's current location as the parent_path
 	 */
 	if(parent_path == NULL)
@@ -773,7 +773,7 @@ gint EDVImbrLocBarIconCrossingCB(
 	GdkBitmap *mask;
 	GdkPixmap *pixmap;
 	GtkWidget *w;
-	edv_status_bar_struct *sb;
+	edv_statusbar_struct *sb;
 	edv_imbr_struct *imbr = EDV_IMBR(data);
 	if((crossing == NULL) || (imbr == NULL))
 	    return(status);
@@ -913,8 +913,8 @@ void EDVImbrTListDragDataGetCB(
 	edv_core_struct *core_ptr;
 	GList *glist, *url_list = NULL;
 	url_struct *url;
-	edv_object_struct *object;
 	tlist_struct *tlist;
+	edv_object_struct *obj;
 	edv_imbr_struct *imbr = EDV_IMBR(data);
 	if((dc == NULL) || (imbr == NULL))
 	    return;
@@ -936,12 +936,12 @@ void EDVImbrTListDragDataGetCB(
 	)
 	{
 	    thumb_num = (gint)glist->data;
-	    object = EDV_OBJECT(TListGetThumbData(tlist, thumb_num));
-	    if(object == NULL)
+	    obj = EDV_OBJECT(TListGetThumbData(tlist, thumb_num));
+	    if(obj == NULL)
 		continue;
 
 	    url = URLNew();
-	    url->path = STRDUP(object->full_path);
+	    url->path = STRDUP(obj->full_path);
 	    url_list = g_list_append(url_list, url);
 	}
 
@@ -995,9 +995,9 @@ void EDVImbrTListDragDataReceivedCB(
 )
 {
 	gint thumb_num = -1;
-	edv_object_struct *object;
-	edv_core_struct *core_ptr;
 	tlist_struct *tlist;
+	edv_object_struct *obj;
+	edv_core_struct *core_ptr;
 	edv_imbr_struct *imbr = EDV_IMBR(data);
 	if((dc == NULL) || (imbr == NULL))
 	    return;
@@ -1027,11 +1027,11 @@ void EDVImbrTListDragDataReceivedCB(
 	 */
 	if(!TListGetSelection(tlist, x, y, &thumb_num, NULL, NULL))
 	    thumb_num = -1;
-	object = EDV_OBJECT(TListGetThumbData(tlist, thumb_num));
+	obj = EDV_OBJECT(TListGetThumbData(tlist, thumb_num));
 
 	/* Handle received drag data */
 	EDVImbrDragDataReceivedNexus(
-	    core_ptr, imbr, dc, info, selection_data, object
+	    core_ptr, imbr, dc, info, selection_data, obj
 	);
 }
 
@@ -1045,11 +1045,11 @@ void EDVImbrTListDragDataDeleteCB(
 	const gchar *path;
 	gchar **strv;
 	gint i, thumb_num, strc;
-	edv_core_struct *core_ptr;
-	GList *glist;
-	edv_object_struct *object;
 	struct stat lstat_buf;
+	GList *glist;
 	tlist_struct *tlist;
+	edv_object_struct *obj;
+	edv_core_struct *core_ptr;
 	edv_imbr_struct *imbr = EDV_IMBR(data);
 	if((dc == NULL) || (imbr == NULL))
 	    return;
@@ -1068,8 +1068,8 @@ void EDVImbrTListDragDataDeleteCB(
 	)
 	{
 	    thumb_num = (gint)glist->data;
-	    object = EDV_OBJECT(TListGetThumbData(tlist, thumb_num));
-	    if((object != NULL) ? !STRISEMPTY(object->full_path) : FALSE)
+	    obj = EDV_OBJECT(TListGetThumbData(tlist, thumb_num));
+	    if((obj != NULL) ? !STRISEMPTY(obj->full_path) : FALSE)
 	    {
 		i = strc;
 		strc = i + 1;
@@ -1081,7 +1081,7 @@ void EDVImbrTListDragDataDeleteCB(
 		    strc = 0;
 		    break;
 		}
-		strv[i] = STRDUP(object->full_path);
+		strv[i] = STRDUP(obj->full_path);
 	    }
 	}
 
