@@ -8,9 +8,10 @@
 #include "guiutils.h"
 #include "cdialog.h"
 #include "progressdialog.h"
+#include "toolbar.h"
 
-#include "edvtypes.h"
 #include "cfg.h"
+#include "edvtypes.h"
 #include "edvobj.h"
 #include "edvconfirm.h"
 #include "edvrecbin.h"
@@ -18,13 +19,18 @@
 #include "edvrecbinfop.h"
 #include "edvdevices.h"
 #include "edvmount.h"
+#include "mountbar.h"
+#include "findbar.h"
+#include "statusbar.h"
 #include "fopdlg.h"
 #include "imbr.h"
 #include "imbrcb.h"
 #include "imbropcb.h"
 #include "imbrtlist.h"
+#include "presentationmode.h"
 #include "endeavour.h"
 #include "edvfcreate.h"
+#include "edvfop.h"
 #include "edvcb.h"
 #include "edvhelp.h"
 #include "edvop.h"
@@ -34,6 +40,10 @@
 #include "config.h"
 
 
+static void EDVImbrToolbarMenuPositionCB(
+	GtkMenu *menu, gint *x, gint *y, gpointer data
+);
+
 void EDVImbrMenuItemCB(GtkWidget *widget, gpointer data);
 gint EDVImbrMenuItemEnterCB(
 	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
@@ -53,22 +63,24 @@ void EDVImbrOPLeaveCB(
 );
 
 void EDVImbrMountBarMountCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 );
 void EDVImbrMountBarEjectCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 );
 void EDVImbrMountBarGoToCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 );
 
-gchar *EDVImbrFindBarLocationCB(gpointer fb, gpointer data);
-void EDVImbrFindBarStartCB(gpointer fb, gpointer data);
+const gchar *EDVImbrFindBarLocationCB(
+	edv_findbar_struct *fb, gpointer data
+);
+void EDVImbrFindBarStartCB(edv_findbar_struct *fb, gpointer data);
 void EDVImbrFindBarEndCB(
-	gpointer fb, gint total_matches, gpointer data
+	edv_findbar_struct *fb, gint total_matches, gpointer data
 );
 void EDVImbrFindBarMatchCB(
 	const gchar *path, const struct stat *lstat_buf,
@@ -76,12 +88,8 @@ void EDVImbrFindBarMatchCB(
 	gpointer data
 );
 
-void EDVImbrBarStatusMessageCB(
-	gpointer bar, const gchar *message, gpointer data
-);
-void EDVImbrBarStatusProgressCB(
-	gpointer bar, gfloat progress, gpointer data
-);
+void EDVImbrStatusMessageCB(const gchar *message, gpointer data);
+void EDVImbrStatusProgressCB(gfloat progress, gpointer data);
 
 void EDVImbrOPSyncDisks(edv_imbr_struct *imbr);
 void EDVImbrOPRun(edv_imbr_struct *imbr);
@@ -94,7 +102,9 @@ static void EDVImbrOPNewObjectNexus(
 	edv_imbr_struct *imbr,
 	edv_object_type type, GtkWidget *toplevel
 );
-void EDVImbrOPNewObject(edv_imbr_struct *imbr);
+void EDVImbrOPNewObject(
+	edv_imbr_struct *imbr, toolbar_item_struct *item
+);
 void EDVImbrOPNewFile(edv_imbr_struct *imbr);
 void EDVImbrOPNewDirectory(edv_imbr_struct *imbr);
 void EDVImbrOPNewLink(edv_imbr_struct *imbr);
@@ -120,6 +130,7 @@ void EDVImbrOPProperties(edv_imbr_struct *imbr);
 
 void EDVImbrOPCopyPath(edv_imbr_struct *imbr);
 void EDVImbrOPCopyURL(edv_imbr_struct *imbr);
+void EDVImbrOPPaste(edv_imbr_struct *imbr);
 
 void EDVImbrOPGoToParent(edv_imbr_struct *imbr);
 void EDVImbrOPGoToHome(edv_imbr_struct *imbr);
@@ -129,10 +140,11 @@ void EDVImbrOPSelectAll(edv_imbr_struct *imbr);
 void EDVImbrOPUnselectAll(edv_imbr_struct *imbr);
 void EDVImbrOPInvertSelection(edv_imbr_struct *imbr);
 
-void EDVImbrOpStop(edv_imbr_struct *imbr);
-void EDVImbrOpContinue(edv_imbr_struct *imbr);
 void EDVImbrOPRefresh(edv_imbr_struct *imbr);
 void EDVImbrOPRefreshAll(edv_imbr_struct *imbr);
+void EDVImbrOpStop(edv_imbr_struct *imbr);
+void EDVImbrOpContinue(edv_imbr_struct *imbr);
+void EDVImbrOpPresentationMode(edv_imbr_struct *imbr);
 
 void EDVImbrOPDownload(edv_imbr_struct *imbr);
 
@@ -150,7 +162,35 @@ void EDVImbrOPDownload(edv_imbr_struct *imbr);
 
 
 /*
- *	Menu item activate callback.
+ *	Tool Bar Item GtkMenu position callback.
+ */
+static void EDVImbrToolbarMenuPositionCB(
+	GtkMenu *menu, gint *x, gint *y, gpointer data
+)
+{
+	gint width, height;
+	GdkWindow *window;
+	GtkWidget *w;
+	toolbar_item_struct *item = TOOLBAR_ITEM(data);
+	if((menu == NULL) || (x == NULL) || (y == NULL) || (item == NULL))
+	    return;
+
+	w = item->w;
+	if(w == NULL)
+	    return;
+
+	window = w->window;
+	if(window == NULL)
+	    return;
+
+	gdk_window_get_root_position(window, x, y);
+	gdk_window_get_size(window, &width, &height);
+	*y = (*y) + height;
+}
+
+
+/*
+ *	Menu item "activate" signal callback.
  *
  *	The data must be a edv_imbr_opid_struct *.
  */
@@ -195,21 +235,23 @@ void EDVImbrOPCB(
 )
 {
 	gint dev_num;
+	GtkWidget *toplevel;
 	cfg_item_struct *cfg_list;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_imbr_struct *imbr;
 	edv_core_struct *core_ptr;
 	edv_imbr_opid_struct *opid = EDV_IMBR_OPID(data);
 	if(opid == NULL)
 	    return;
 
-	imbr = EDV_IMBR(opid->imbr);
+	imbr = opid->imbr;
 	if(imbr == NULL)
 	    return;
 
 	if(imbr->processing || (imbr->freeze_count > 0))
 	    return;
 
+	toplevel = imbr->toplevel;
 	core_ptr = EDV_CORE(imbr->core_ptr);
 	if(core_ptr == NULL)
 	    return;
@@ -219,9 +261,9 @@ void EDVImbrOPCB(
 	/* Get last selected device (if any) */
 	dev_num = imbr->selected_dev_num;
 	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
+	    dev = core_ptr->device[dev_num];
 	else
-	    dev_ptr = NULL;
+	    dev = NULL;
 
 	imbr->freeze_count++;
 
@@ -235,169 +277,131 @@ void EDVImbrOPCB(
 	  case EDV_IMBR_OP_CLOSE:
 	    EDVImbrOPClose(imbr);
 	    break;
-
 	  case EDV_IMBR_OP_EXIT:
 	    EDVImbrOPExit(imbr);
 	    break;
 
-
 	  case EDV_IMBR_OP_SYNC_DISKS:
 	    EDVImbrOPSyncDisks(imbr);
 	    break;
-
+	  case EDV_IMBR_OP_HISTORY:
+	    EDVMapHistoryListWin(core_ptr, toplevel);
+	    break;
 	  case EDV_IMBR_OP_RUN:
 	    EDVImbrOPRun(imbr);
 	    break;
-
+	  case EDV_IMBR_OP_RUN_TERMINAL:
+	    EDVRunTerminal(core_ptr, NULL, toplevel);
+	    break;
 	  case EDV_IMBR_OP_WRITE_PROTECT:
 	    EDVImbrOPWriteProtect(imbr);
 	    break;
 
-	  case EDV_IMBR_OP_RUN_TERMINAL:
-	    EDVRunTerminal(core_ptr, NULL, imbr->toplevel);
-	    break;
-
-
 	  case EDV_IMBR_OP_NEW:
-	    EDVImbrOPNewObject(imbr);
+	    EDVImbrOPNewObject(imbr, item);
 	    break;
-
 	  case EDV_IMBR_OP_NEW_FILE:
 	    EDVImbrOPNewFile(imbr);
 	    break;
-
 	  case EDV_IMBR_OP_NEW_DIRECTORY:
 	    EDVImbrOPNewDirectory(imbr);
 	    break;
-
 	  case EDV_IMBR_OP_NEW_LINK:
 	    EDVImbrOPNewLink(imbr);
 	    break;
-
 	  case EDV_IMBR_OP_NEW_FIFO:
 	    EDVImbrOPNewFifo(imbr);
 	    break;
-
 	  case EDV_IMBR_OP_NEW_DEVICE_BLOCK:
 	    EDVImbrOPNewDeviceBlock(imbr);
 	    break;
-
 	  case EDV_IMBR_OP_NEW_DEVICE_CHARACTER:
 	    EDVImbrOPNewDeviceCharacter(imbr);
 	    break;
-
 	  case EDV_IMBR_OP_NEW_SOCKET:
 	    EDVImbrOPNewSocket(imbr);
 	    break;
 
-
 	  case EDV_IMBR_OP_OPEN:
 	    EDVImbrOPOpen(imbr);
 	    break;
-
 	  case EDV_IMBR_OP_OPEN_WITH:
 	    EDVImbrOPOpenWith(imbr);
 	    break;
 
-
-	  case EDV_IMBR_OP_GOTO_PARENT:
-	    EDVImbrOPGoToParent(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_GOTO_HOME:
-	    EDVImbrOPGoToHome(imbr);
-	    break; 
-
-	  case EDV_IMBR_OP_MOUNT:
-	    EDVImbrOPMount(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_EJECT:
-	    EDVImbrOPEject(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_MOVE:
-	    EDVImbrOPMove(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_COPY:
-	    EDVImbrOPCopy(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_LINK:
-	    EDVImbrOPLink(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_RENAME:
-	    EDVImbrOPRename(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_CHMOD:
-	    EDVImbrOPChMod(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_CHOWN:
-	    EDVImbrOPChown(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_DELETE:
-	    EDVImbrOPDelete(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_SELECT_ALL:
-	    EDVImbrOPSelectAll(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_UNSELECT_ALL:
-	    EDVImbrOPUnselectAll(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_INVERT_SELECTION:
-	    EDVImbrOPInvertSelection(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_PROPERTIES:
-	    EDVImbrOPProperties(imbr);
-	    break;
-
-	  case EDV_IMBR_OP_FIND:
-	    EDVMapImbrFindWin(core_ptr, imbr);
-	    break;
-
-	  case EDV_IMBR_OP_HISTORY:
-	    EDVMapHistoryListWin(core_ptr, imbr->toplevel);
-	    break;
-
 	  case EDV_IMBR_OP_COPY_PATH:
 	    EDVImbrOPCopyPath(imbr);
 	    break;
-
 	  case EDV_IMBR_OP_COPY_URL:
 	    EDVImbrOPCopyURL(imbr);
 	    break;
-
-
-	  case EDV_IMBR_OP_STOP:
-	    EDVImbrOpStop(imbr);
+	  case EDV_IMBR_OP_PASTE:
+	    EDVImbrOPPaste(imbr);
 	    break;
 
-	  case EDV_IMBR_OP_CONTINUE:
-	    EDVImbrOpContinue(imbr);
+	  case EDV_IMBR_OP_MOVE:
+	    EDVImbrOPMove(imbr);
+	    break;
+	  case EDV_IMBR_OP_COPY:
+	    EDVImbrOPCopy(imbr);
+	    break;
+	  case EDV_IMBR_OP_LINK:
+	    EDVImbrOPLink(imbr);
+	    break;
+	  case EDV_IMBR_OP_RENAME:
+	    EDVImbrOPRename(imbr);
+	    break;
+	  case EDV_IMBR_OP_CHMOD:
+	    EDVImbrOPChMod(imbr);
+	    break;
+	  case EDV_IMBR_OP_CHOWN:
+	    EDVImbrOPChown(imbr);
+	    break;
+	  case EDV_IMBR_OP_DELETE:
+	    EDVImbrOPDelete(imbr);
+	    break;
+	  case EDV_IMBR_OP_PROPERTIES:
+	    EDVImbrOPProperties(imbr);
 	    break;
 
-	  case EDV_IMBR_OP_REFRESH:
-	    EDVImbrOPRefresh(imbr);
+	  case EDV_IMBR_OP_SELECT_ALL:
+	    EDVImbrOPSelectAll(imbr);
 	    break;
-
-	  case EDV_IMBR_OP_REFRESH_ALL:
-	    EDVImbrOPRefreshAll(imbr);
+	  case EDV_IMBR_OP_UNSELECT_ALL:
+	    EDVImbrOPUnselectAll(imbr);
+	    break;
+	  case EDV_IMBR_OP_INVERT_SELECTION:
+	    EDVImbrOPInvertSelection(imbr);
+	    break;
+	  case EDV_IMBR_OP_FIND:
+	    EDVMapImbrFindWin(core_ptr, imbr);
 	    break;
-
 
 	  case EDV_IMBR_OP_DOWNLOAD:
 	    EDVImbrOPDownload(imbr);
 	    break;
 
+	  case EDV_IMBR_OP_REFRESH:
+	    EDVImbrOPRefresh(imbr);
+	    break;
+	  case EDV_IMBR_OP_REFRESH_ALL:
+	    EDVImbrOPRefreshAll(imbr);
+	    break;
+	  case EDV_IMBR_OP_GOTO_PARENT:
+	    EDVImbrOPGoToParent(imbr);
+	    break;
+	  case EDV_IMBR_OP_GOTO_HOME:
+	    EDVImbrOPGoToHome(imbr);
+	    break;
+	  case EDV_IMBR_OP_STOP:
+	    EDVImbrOpStop(imbr);
+	    break;
+	  case EDV_IMBR_OP_CONTINUE:
+	    EDVImbrOpContinue(imbr);
+	    break;
+	  case EDV_IMBR_OP_PRESENTATION_MODE:
+	    EDVImbrOpPresentationMode(imbr);
+	    break;
 
 	  case EDV_IMBR_OP_SHOW_TOOL_BAR:
 	    if(core_ptr != NULL)
@@ -409,7 +413,6 @@ void EDVImbrOPCB(
 		EDVReconfiguredEmit(core_ptr);
 	    }
 	    break;
-
 	  case EDV_IMBR_OP_SHOW_LOCATION_BAR:
 	    if(core_ptr != NULL)
 	    {
@@ -420,7 +423,6 @@ void EDVImbrOPCB(
 		EDVReconfiguredEmit(core_ptr);
 	    }
 	    break;
-
 	  case EDV_IMBR_OP_SHOW_MOUNT_BAR:
 	    if(core_ptr != NULL)
 	    {
@@ -431,7 +433,6 @@ void EDVImbrOPCB(
 		EDVReconfiguredEmit(core_ptr);
 	    }
 	    break;
-
 	  case EDV_IMBR_OP_SHOW_FIND_BAR:
 	    if(core_ptr != NULL)
 	    {
@@ -442,7 +443,6 @@ void EDVImbrOPCB(
 		EDVReconfiguredEmit(core_ptr);
 	    }
 	    break;
-
 	  case EDV_IMBR_OP_SHOW_STATUS_BAR:
 	    if(core_ptr != NULL)
 	    {
@@ -453,7 +453,6 @@ void EDVImbrOPCB(
 		EDVReconfiguredEmit(core_ptr);
 	    }
 	    break;
-
 	  case EDV_IMBR_OP_SHOW_HIDDEN_OBJECTS:
 	    if(core_ptr != NULL)
 	    {
@@ -464,7 +463,6 @@ void EDVImbrOPCB(
 		EDVImbrOPRefresh(imbr);
 	    }
 	    break;
-
 	  case EDV_IMBR_OP_SHOW_NOACCESS_OBJECTS:
 	    if(core_ptr != NULL)               
 	    {                                 
@@ -475,7 +473,6 @@ void EDVImbrOPCB(
 		EDVImbrOPRefresh(imbr);
 	    }
 	    break;
-
 	  case EDV_IMBR_OP_SHOW_NONIMAGE_OBJECTS:
 	    if(core_ptr != NULL)               
 	    {                                 
@@ -487,82 +484,78 @@ void EDVImbrOPCB(
 	    }
 	    break;
 
+	  case EDV_IMBR_OP_MOUNT:
+	    EDVImbrOPMount(imbr);
+	    break;
+	  case EDV_IMBR_OP_EJECT:
+	    EDVImbrOPEject(imbr);
+	    break;
+	  case EDV_IMBR_OP_DEVICE_CHECK:
+	    EDVRunDeviceCheck(core_ptr, dev, toplevel);
+	    break;
+	  case EDV_IMBR_OP_DEVICE_TOOLS:
+	    EDVRunDeviceTools(core_ptr, dev, toplevel);
+	    break;
+	  case EDV_IMBR_OP_DEVICE_FORMAT:
+	    EDVRunDeviceFormat(core_ptr, dev, toplevel);
+	    break;
+
 	  case EDV_IMBR_OP_MIME_TYPES:
-	    EDVMapMIMETypesListWin(core_ptr, imbr->toplevel);
+	    EDVMapMIMETypesListWin(core_ptr, toplevel);
 	    break;
-
 	  case EDV_IMBR_OP_DEVICES:
-	    EDVMapDevicesListWin(core_ptr, imbr->toplevel);
+	    EDVMapDevicesListWin(core_ptr, toplevel);
 	    break;
 
-
 	  case EDV_IMBR_OP_NEW_BROWSER:
 	    EDVNewBrowser(core_ptr);
 	    break;
-
 	  case EDV_IMBR_OP_NEW_IMBR:
 	    EDVNewImbr(core_ptr);
 	    break;
-
 	  case EDV_IMBR_OP_NEW_ARCHIVER:
 	    EDVNewArchiver(core_ptr);
 	    break;
-
 	  case EDV_IMBR_OP_RECYCLE_BIN:
 	    EDVMapRecBin(core_ptr);
 	    break;
 
 	  case EDV_IMBR_OP_OPTIONS:
-	    EDVMapOptionsWin(core_ptr, imbr->toplevel);
+	    EDVMapOptionsWin(core_ptr, toplevel);
 	    break;
-
 	  case EDV_IMBR_OP_CUSTOMIZE:
-	    EDVMapCustomizeWin(core_ptr, imbr->toplevel);
+	    EDVMapCustomizeWin(core_ptr, toplevel);
 	    break;
 
-
-	  case EDV_IMBR_OP_DEVICE_CHECK:
-	    EDVRunDeviceCheck(core_ptr, dev_ptr, imbr->toplevel);
-	    break;
-
-	  case EDV_IMBR_OP_DEVICE_TOOLS:
-	    EDVRunDeviceTools(core_ptr, dev_ptr, imbr->toplevel);
-	    break;
-
-	  case EDV_IMBR_OP_DEVICE_FORMAT:
-	    EDVRunDeviceFormat(core_ptr, dev_ptr, imbr->toplevel);
-	    break;
-
-
-	  case EDV_IMBR_OP_HELP_ABOUT:
-	    EDVAbout(core_ptr, imbr->toplevel);
-	    break;
 	  case EDV_IMBR_OP_HELP_CONTENTS:
-	    EDVHelp(core_ptr, "Contents", imbr->toplevel);
+	    EDVHelp(core_ptr, "Contents", toplevel);
 	    break;
 	  case EDV_IMBR_OP_HELP_FILE_BROWSER:
-	    EDVHelp(core_ptr, "File Browser", imbr->toplevel);
+	    EDVHelp(core_ptr, "File Browser", toplevel);
 	    break;
 	  case EDV_IMBR_OP_HELP_IMAGE_BROWSER:
-	    EDVHelp(core_ptr, "Image Browser", imbr->toplevel);
+	    EDVHelp(core_ptr, "Image Browser", toplevel);
 	    break;
 	  case EDV_IMBR_OP_HELP_ARCHIVER:
-	    EDVHelp(core_ptr, "Archiver", imbr->toplevel);
+	    EDVHelp(core_ptr, "Archiver", toplevel);
 	    break;
 	  case EDV_IMBR_OP_HELP_RECYCLE_BIN:
-	    EDVHelp(core_ptr, "Recycle Bin", imbr->toplevel);
+	    EDVHelp(core_ptr, "Recycle Bin", toplevel);
 	    break;
 	  case EDV_IMBR_OP_HELP_KEYS_LIST:
-	    EDVHelp(core_ptr, "Keys List", imbr->toplevel);
+	    EDVHelp(core_ptr, "Keys List", toplevel);
 	    break;
 	  case EDV_IMBR_OP_HELP_MIME_TYPES:
-	    EDVHelp(core_ptr, "MIME Types", imbr->toplevel);
+	    EDVHelp(core_ptr, "MIME Types", toplevel);
 	    break;
 	  case EDV_IMBR_OP_HELP_DEVICES:
-	    EDVHelp(core_ptr, "Devices", imbr->toplevel);
+	    EDVHelp(core_ptr, "Devices", toplevel);
 	    break;
 	  case EDV_IMBR_OP_HELP_COMMON_OPERATIONS:
-	    EDVHelp(core_ptr, "Common Operations", imbr->toplevel);
+	    EDVHelp(core_ptr, "Common Operations", toplevel);
+	    break;
+	  case EDV_IMBR_OP_HELP_ABOUT:
+	    EDVAbout(core_ptr, toplevel);
 	    break;
 	}
 
@@ -580,9 +573,7 @@ void EDVImbrOPEnterCB(
 {
 	const gchar *tooltip;
 	edv_imbr_opid_struct *opid = EDV_IMBR_OPID(data);
-	edv_imbr_struct *imbr = EDV_IMBR(
-	    (opid != NULL) ? opid->imbr : NULL
-	);
+	edv_imbr_struct *imbr = (opid != NULL) ? opid->imbr : NULL;
 	if(imbr == NULL)
 	    return;
 
@@ -601,9 +592,7 @@ void EDVImbrOPLeaveCB(
 )
 {
 	edv_imbr_opid_struct *opid = EDV_IMBR_OPID(data);
-	edv_imbr_struct *imbr = EDV_IMBR( 
-	    (opid != NULL) ? opid->imbr : NULL 
-	);
+	edv_imbr_struct *imbr = (opid != NULL) ? opid->imbr : NULL;
 	if(imbr == NULL)
 	    return;
 
@@ -614,7 +603,9 @@ void EDVImbrOPLeaveCB(
 /*
  *	Find Bar get current location callback.
  */
-gchar *EDVImbrFindBarLocationCB(gpointer fb, gpointer data)
+const gchar *EDVImbrFindBarLocationCB(
+	edv_findbar_struct *fb, gpointer data
+)
 {
 	return(EDVImbrCurrentLocation(EDV_IMBR(data)));
 }
@@ -623,7 +614,7 @@ gchar *EDVImbrFindBarLocationCB(gpointer fb, gpointer data)
  *	Mount Bar mount callback.
  */
 void EDVImbrMountBarMountCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 )
 {
@@ -632,7 +623,7 @@ void EDVImbrMountBarMountCB(
 	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 	edv_imbr_struct *imbr = EDV_IMBR(data);
-	if((imbr == NULL) || (dev_ptr == NULL))
+	if((imbr == NULL) || (dev == NULL))
 	    return;
 
 	if(imbr->processing)
@@ -646,13 +637,13 @@ void EDVImbrMountBarMountCB(
 	EDVImbrSetBusy(imbr, TRUE);
 
 	/* Record original mount state */
-	original_mount_state = dev_ptr->is_mounted;
+	original_mount_state = EDV_DEVICE_IS_MOUNTED(dev);
 
 	/* Unmount or mount? */
-	if(dev_ptr->is_mounted)
-	    status = EDVMountDoUnmount(core_ptr, dev_ptr, toplevel);
+	if(EDV_DEVICE_IS_MOUNTED(dev))
+	    status = EDVMountDoUnmount(core_ptr, dev, toplevel);
 	else
-	    status = EDVMountDoMount(core_ptr, dev_ptr, toplevel);
+	    status = EDVMountDoMount(core_ptr, dev, toplevel);
 
 	/* Update all device mount states and stats */
 	EDVDevicesListUpdateMountStates(
@@ -683,7 +674,7 @@ void EDVImbrMountBarMountCB(
 	else
 	{
 	    /* Report mount signal to all of endeavour's resources */
-	    EDVObjectMountEmit(core_ptr, dev_num, dev_ptr, dev_ptr->is_mounted);
+	    EDVObjectMountEmit(core_ptr, dev_num, dev, EDV_DEVICE_IS_MOUNTED(dev));
 	}
 }
 
@@ -691,7 +682,7 @@ void EDVImbrMountBarMountCB(
  *	Mount Bar eject callback.
  */
 void EDVImbrMountBarEjectCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 )
 {
@@ -700,7 +691,7 @@ void EDVImbrMountBarEjectCB(
 	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 	edv_imbr_struct *imbr = EDV_IMBR(data);
-	if((imbr == NULL) || (dev_ptr == NULL))
+	if((imbr == NULL) || (dev == NULL))
 	    return;
 
 	if(imbr->processing)
@@ -714,13 +705,13 @@ void EDVImbrMountBarEjectCB(
 	EDVImbrSetBusy(imbr, TRUE);
 
 	/* Record original mount state */
-	original_mount_state = dev_ptr->is_mounted;
+	original_mount_state = EDV_DEVICE_IS_MOUNTED(dev);
 
 	/* Need to unmount first? */
-	if(dev_ptr->is_mounted)
-	    status = EDVMountDoUnmount(core_ptr, dev_ptr, toplevel);
+	if(EDV_DEVICE_IS_MOUNTED(dev))
+	    status = EDVMountDoUnmount(core_ptr, dev, toplevel);
 	/* So now eject */
-	status = EDVMountDoEject(core_ptr, dev_ptr, toplevel);
+	status = EDVMountDoEject(core_ptr, dev, toplevel);
 
 	/* Update all device mount states and stats */
 	EDVDevicesListUpdateMountStates(
@@ -752,7 +743,7 @@ void EDVImbrMountBarEjectCB(
 	    /* Report eject (unmount) signal to all of endeavour's
 	     * resources
 	     */
-	    EDVObjectMountEmit(core_ptr, dev_num, dev_ptr, dev_ptr->is_mounted);
+	    EDVObjectMountEmit(core_ptr, dev_num, dev, EDV_DEVICE_IS_MOUNTED(dev));
 	}
 }
 
@@ -760,36 +751,42 @@ void EDVImbrMountBarEjectCB(
  *	Mount Bar go to mount path callback.
  */
 extern void EDVImbrMountBarGoToCB(
-	gpointer mb, gint dev_num, edv_device_struct *dev_ptr,
+	edv_mountbar_struct *mb, gint dev_num, edv_device_struct *dev,
 	gpointer data
 )
 {
 	gchar *path;
+	GtkWidget *toplevel;
 	edv_imbr_struct *imbr = EDV_IMBR(data);
-	if((imbr == NULL) || (dev_ptr == NULL))
+	if((imbr == NULL) || (dev == NULL))
 	    return;
 
 	if(imbr->processing)
 	    return;
 
+	toplevel = imbr->toplevel;
+
 	/* Get copy of mount path */
-	path = STRDUP(dev_ptr->mount_path);
+	path = STRDUP(dev->mount_path);
 
 	EDVImbrSetBusy(imbr, TRUE);
+	GUIBlockInput(toplevel, TRUE);
 
+	/* Go to mount path */
 	EDVImbrSelectPath(imbr, path);
 	EDVImbrUpdateMenus(imbr);
 
-	EDVImbrSetBusy(imbr, FALSE);
-
 	g_free(path);
+
+	GUIBlockInput(toplevel, FALSE);
+	EDVImbrSetBusy(imbr, FALSE);
 }
 
 
 /*
  *	Find Bar start find callback.
  */
-void EDVImbrFindBarStartCB(gpointer fb, gpointer data)
+void EDVImbrFindBarStartCB(edv_findbar_struct *fb, gpointer data)
 {
 	tlist_struct *tlist;
 	edv_imbr_struct *imbr = EDV_IMBR(data);
@@ -813,7 +810,7 @@ void EDVImbrFindBarStartCB(gpointer fb, gpointer data)
  *	Find Bar end find callback.
  */
 void EDVImbrFindBarEndCB(
-	gpointer fb, gint total_matches, gpointer data
+	edv_findbar_struct *fb, gint total_matches, gpointer data
 )
 {
 	edv_imbr_struct *imbr = EDV_IMBR(data);
@@ -854,11 +851,9 @@ void EDVImbrFindBarMatchCB(
 
 
 /*
- *	Status Bar set message callback.
+ *	Status message callback.
  */
-void EDVImbrBarStatusMessageCB(
-	gpointer mb, const gchar *message, gpointer data
-)
+void EDVImbrStatusMessageCB(const gchar *message, gpointer data)
 {
 	edv_imbr_struct *imbr = EDV_IMBR(data);
 	if(imbr == NULL)
@@ -868,11 +863,9 @@ void EDVImbrBarStatusMessageCB(
 }
 
 /*
- *	Status Bar set progress callback.
+ *	Status progress callback.
  */
-void EDVImbrBarStatusProgressCB(
-	gpointer bar, gfloat progress, gpointer data
-)
+void EDVImbrStatusProgressCB(gfloat progress, gpointer data)
 {
 	edv_imbr_struct *imbr = EDV_IMBR(data);
 	if(imbr == NULL)
@@ -1211,7 +1204,9 @@ static void EDVImbrOPNewObjectNexus(
 /*
  *	New Object.
  */
-void EDVImbrOPNewObject(edv_imbr_struct *imbr)
+void EDVImbrOPNewObject(
+	edv_imbr_struct *imbr, toolbar_item_struct *item
+)
 {
 	GtkWidget *w;
 
@@ -1222,7 +1217,8 @@ void EDVImbrOPNewObject(edv_imbr_struct *imbr)
 	if(w != NULL)
 	    gtk_menu_popup(
 		GTK_MENU(w), NULL, NULL,
-		NULL, NULL,
+		(item != NULL) ? EDVImbrToolbarMenuPositionCB : NULL,
+		item,
 		1, GDK_CURRENT_TIME
 	    );
 }
@@ -1324,16 +1320,14 @@ void EDVImbrOPNewSocket(edv_imbr_struct *imbr)
  */
 void EDVImbrOPOpen(edv_imbr_struct *imbr)
 {
-	gint thumb_num;
-	GList *glist;
-	tlist_struct *tlist = (imbr != NULL) ? imbr->tlist : NULL;
-	if(tlist == NULL)
+	if(imbr == NULL)
 	    return;
 
-	glist = tlist->selection_end;
-	thumb_num = (glist != NULL) ? (gint)glist->data : -1;
-	if(thumb_num > -1)
-	    EDVImbrTListDoOpenObject(imbr, thumb_num, 0);
+	EDVImbrTListOpen(
+	    imbr,
+	    -1,				/* All selected object(s) */
+	    0				/* Modifier keys */
+	);
 }
 
 /*
@@ -1341,16 +1335,13 @@ void EDVImbrOPOpen(edv_imbr_struct *imbr)
  */
 void EDVImbrOPOpenWith(edv_imbr_struct *imbr)
 {
-	gint thumb_num;
-	GList *glist;
-	tlist_struct *tlist = (imbr != NULL) ? imbr->tlist : NULL;
-	if(tlist == NULL)
+	if(imbr == NULL)
 	    return;
 
-	glist = tlist->selection_end;
-	thumb_num = (glist != NULL) ? (gint)glist->data : -1;
-	if(thumb_num > -1)
-	    EDVImbrTListDoOpenWithObject(imbr, thumb_num);
+	EDVImbrTListOpenWith(
+	    imbr,
+	    -1				/* All selected object(s) */
+	);
 }
 
 
@@ -1361,11 +1352,13 @@ void EDVImbrOPGoToParent(edv_imbr_struct *imbr)
 {
 	gchar *parent_path;
 	const gchar *current_location;
+	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
 	core_ptr = EDV_CORE(imbr->core_ptr);
 	if(core_ptr == NULL)
 	    return;
@@ -1394,14 +1387,15 @@ void EDVImbrOPGoToParent(edv_imbr_struct *imbr)
 	}
 
 	EDVImbrSetBusy(imbr, TRUE);
+	GUIBlockInput(toplevel, TRUE);
 
 	/* Go to parent directory */
 	EDVImbrSelectPath(imbr, parent_path);
-
 	EDVImbrUpdateMenus(imbr);
 
 	g_free(parent_path);
 
+	GUIBlockInput(toplevel, FALSE);
 	EDVImbrSetBusy(imbr, FALSE);
 }
 
@@ -1411,11 +1405,13 @@ void EDVImbrOPGoToParent(edv_imbr_struct *imbr)
 void EDVImbrOPGoToHome(edv_imbr_struct *imbr)
 {
 	gchar *home_dir;
+	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
 
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
 	core_ptr = EDV_CORE(imbr->core_ptr);
 	if(core_ptr == NULL)
 	    return;
@@ -1467,22 +1463,23 @@ HOME setter.\n",
 environment variable HOME is set.\n",
 		NULL,
 #endif
-		imbr->toplevel
+		toplevel
 	    );
 	    g_free(home_dir);
 	    return;
 	}
 
 	EDVImbrSetBusy(imbr, TRUE);
+	GUIBlockInput(toplevel, TRUE);
 
 	/* Go to home directory */
 	EDVImbrSelectPath(imbr, home_dir);
-
-	EDVImbrSetBusy(imbr, FALSE);
-
 	EDVImbrUpdateMenus(imbr);
 
 	g_free(home_dir);
+
+	GUIBlockInput(toplevel, FALSE);
+	EDVImbrSetBusy(imbr, FALSE);
 }
 
 /*
@@ -1493,7 +1490,7 @@ void EDVImbrOPMount(edv_imbr_struct *imbr)
 	gboolean original_mount_state;
 	gint status, dev_num;
 	GtkWidget *toplevel;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_core_struct *core_ptr;
 
 
@@ -1508,22 +1505,22 @@ void EDVImbrOPMount(edv_imbr_struct *imbr)
 	/* Get number of last selected device index (if any) */
 	dev_num = imbr->selected_dev_num;
 	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
+	    dev = core_ptr->device[dev_num];
 	else
-	    dev_ptr = NULL;
-	if(dev_ptr == NULL)
+	    dev = NULL;
+	if(dev == NULL)
 	    return;
 
 	EDVImbrSetBusy(imbr, TRUE);
 
 	/* Record original mount state */
-	original_mount_state = dev_ptr->is_mounted;
+	original_mount_state = EDV_DEVICE_IS_MOUNTED(dev);
 
 	/* Unmount or mount? */
-	if(dev_ptr->is_mounted)
-	    status = EDVMountDoUnmount(core_ptr, dev_ptr, toplevel);
+	if(EDV_DEVICE_IS_MOUNTED(dev))
+	    status = EDVMountDoUnmount(core_ptr, dev, toplevel);
 	else
-	    status = EDVMountDoMount(core_ptr, dev_ptr, toplevel);
+	    status = EDVMountDoMount(core_ptr, dev, toplevel);
 
 	/* Update all device mount states and stats */
 	EDVDevicesListUpdateMountStates(
@@ -1554,7 +1551,7 @@ void EDVImbrOPMount(edv_imbr_struct *imbr)
 	else
 	{
 	    /* Report mount signal to all of endeavour's resources */
-	    EDVObjectMountEmit(core_ptr, dev_num, dev_ptr, dev_ptr->is_mounted);
+	    EDVObjectMountEmit(core_ptr, dev_num, dev, EDV_DEVICE_IS_MOUNTED(dev));
 	}
 }
 
@@ -1566,7 +1563,7 @@ void EDVImbrOPEject(edv_imbr_struct *imbr)
 	gboolean original_mount_state;
 	gint status, dev_num;
 	GtkWidget *toplevel;
-	edv_device_struct *dev_ptr;
+	edv_device_struct *dev;
 	edv_core_struct *core_ptr;
 
 	if(imbr == NULL)
@@ -1580,22 +1577,22 @@ void EDVImbrOPEject(edv_imbr_struct *imbr)
 	/* Get number of last selected device index (if any) */
 	dev_num = imbr->selected_dev_num;
 	if((dev_num >= 0) && (dev_num < core_ptr->total_devices))
-	    dev_ptr = core_ptr->device[dev_num];
+	    dev = core_ptr->device[dev_num];
 	else
-	    dev_ptr = NULL;
-	if(dev_ptr == NULL)
+	    dev = NULL;
+	if(dev == NULL)
 	    return;
 
 	EDVImbrSetBusy(imbr, TRUE);
 
 	/* Record original mount state */
-	original_mount_state = dev_ptr->is_mounted;
+	original_mount_state = EDV_DEVICE_IS_MOUNTED(dev);
 
 	/* Need to unmount first? */
-	if(dev_ptr->is_mounted)
-	    status = EDVMountDoUnmount(core_ptr, dev_ptr, toplevel);
+	if(EDV_DEVICE_IS_MOUNTED(dev))
+	    status = EDVMountDoUnmount(core_ptr, dev, toplevel);
 	/* So now eject */
-	status = EDVMountDoEject(core_ptr, dev_ptr, toplevel);
+	status = EDVMountDoEject(core_ptr, dev, toplevel);
 
 	/* Update all device mount states and stats */
 	EDVDevicesListUpdateMountStates(
@@ -1627,7 +1624,7 @@ void EDVImbrOPEject(edv_imbr_struct *imbr)
 	    /* Report eject (unmount) signal to all of endeavour's
 	     * resources
 	     */
-	    EDVObjectMountEmit(core_ptr, dev_num, dev_ptr, dev_ptr->is_mounted);
+	    EDVObjectMountEmit(core_ptr, dev_num, dev, EDV_DEVICE_IS_MOUNTED(dev));
 	}
 }
 
@@ -2460,49 +2457,174 @@ void EDVImbrOPCopyURL(edv_imbr_struct *imbr)
 	g_free(sel_object);
 }
 
-
 /*
- *	Stop.
+ *	Paste.
  */
-void EDVImbrOpStop(edv_imbr_struct *imbr)
+void EDVImbrOPPaste(edv_imbr_struct *imbr)
 {
+	gboolean yes_to_all = FALSE;
+	gint status = -1;
+	const gchar *protocol;
+	gchar *buf, *cur_location;
+	GList *glist, *url_list = NULL;
+	GtkWidget *toplevel;
+	url_struct *url;
+	edv_core_struct *core_ptr;
+
 	if(imbr == NULL)
 	    return;
 
-	imbr->stop_count++;
-}
-
-/*
- *	Continue.
- */
-void EDVImbrOpContinue(edv_imbr_struct *imbr)
-{
-	if(imbr == NULL)
+	toplevel = imbr->toplevel;
+	core_ptr = EDV_CORE(imbr->core_ptr);
+	if(core_ptr == NULL)
 	    return;
 
-	/* Reset loading process timeout callback and initialize
-	 * loading values
+	/* Check and warn if write protect is enabled */
+	if(EDVCheckWriteProtect(core_ptr, TRUE, toplevel))
+	    return;
+
+	EDVImbrSyncData(imbr);  
+
+	/* Get string from clipboard */
+	buf = GUIDDEGetString(
+	    toplevel,
+	    GDK_SELECTION_PRIMARY,
+	    GDK_CURRENT_TIME
+	);
+
+	/* Get current location */
+	cur_location = STRDUP(EDVImbrCurrentLocation(imbr));
+
+	if((buf == NULL) || (cur_location == NULL))
+	{
+	    g_free(cur_location);
+	    g_free(buf);
+	    return;
+	}
+
+	/* Decode URL list string into a list of URLs */
+	url_list = URLDecodeString(buf);
+	g_free(buf);
+	buf = NULL;
+
+	/* Make confirmation */
+	if(url_list != NULL)
+	{
+	    url = URL(url_list->data);
+	    if(EDVConfirmCopy(
+		core_ptr, toplevel,
+		(url != NULL) ? url->path : NULL, g_list_length(url_list),
+		cur_location
+	    ) != CDIALOG_RESPONSE_YES)
+	    {
+		g_list_foreach(url_list, (GFunc)URLDelete, NULL);
+		g_list_free(url_list);
+		g_free(cur_location);
+		return;
+	    }
+	}
+
+	/* Paste each URL */
+	for(glist = url_list; glist != NULL; glist = g_list_next(glist))
+	{
+	    url = URL(glist->data);
+	    if(url == NULL)
+		continue;
+
+	    protocol = url->protocol;
+	    if(STRISEMPTY(protocol))
+		protocol = "file";
+
+	    /* File? */
+	    if(!g_strcasecmp(protocol, "file"))
+	    {
+		const gchar *error_mesg;
+		gchar *new_path = NULL;
+		struct stat lstat_buf;
+		status = EDVFOPCopy(
+		    core_ptr,
+		    url->path, cur_location,
+		    &new_path, toplevel,
+		    TRUE, TRUE, &yes_to_all
+		);
+		error_mesg = EDVFOPGetError();
+		if(!STRISEMPTY(error_mesg) && (status != -4))
+		{
+		    EDVPlaySoundError(core_ptr);
+		    EDVMessageError(
+			"Operation Error",
+			error_mesg,
+			NULL,
+			toplevel
+		    );
+		}
+
+		/* Check if new_path is valid and that no error
+		 * occured
+		 *
+		 * This implies the operation was successful
+		 * and that we need to emit an object added signal
+		 */
+		if((!STRISEMPTY(new_path) && !status) ?
+		    !lstat(new_path, &lstat_buf) : FALSE
+		)
+		    EDVObjectAddedEmit(
+			core_ptr, new_path, &lstat_buf
+		    );
+
+		g_free(new_path);
+
+		/* Skip handling of the rest of the objects on error
+		 * (status != 0) and that the error was not a user
+		 * response of no (status != -5)
+		 */
+		if(status && (status != -5))
+		    break;
+	    }
+	    /* Download? */
+	    else if(!g_strcasecmp(protocol, "http") ||
+		    !g_strcasecmp(protocol, "ftp") ||
+		    !g_strcasecmp(protocol, "https")
+	    )
+	    {
+		EDVInternetDownloadObject(
+		    core_ptr, url, cur_location, toplevel
+		);
+	    }
+	}
+	 
+	/* Unmap progress dialog, it may have been mapped if any
+	 * operations occured in the above loop
 	 */
-	EDVImbrQueueLoadingProcess(imbr);
+	ProgressDialogBreakQuery(TRUE);
+	ProgressDialogSetTransientFor(NULL);
 
-	EDVImbrUpdateMenus(imbr);
+	/* Play completed sound on success */
+	if(status == 0)
+	    EDVPlaySoundCompleted(core_ptr);
+
+	g_list_foreach(url_list, (GFunc)URLDelete, NULL);
+	g_list_free(url_list);
+	g_free(cur_location);
 }
 
+
 /*
  *      Refresh.
  */
 void EDVImbrOPRefresh(edv_imbr_struct *imbr)
 {
 	gchar *cur_path;
-	GtkWidget *w;
+	GtkWidget *w, *toplevel;
 	tlist_struct *tlist;
 
-
 	if(imbr == NULL)
 	    return;
 
+	toplevel = imbr->toplevel;
+
 	EDVImbrSetBusy(imbr, TRUE);
-	GUIBlockInput(imbr->toplevel, TRUE);
+	GUIBlockInput(toplevel, TRUE);
 
 	cur_path = STRDUP(EDVImbrCurrentLocation(imbr));
 
@@ -2555,7 +2677,7 @@ void EDVImbrOPRefresh(edv_imbr_struct *imbr)
 	    imbr->status_bar, "Refreshed contents listing", FALSE
 	);
 
-	GUIBlockInput(imbr->toplevel, FALSE);
+	GUIBlockInput(toplevel, FALSE);
 	EDVImbrSetBusy(imbr, FALSE);
 
 	g_free(cur_path);
@@ -2587,6 +2709,54 @@ void EDVImbrOPRefreshAll(edv_imbr_struct *imbr)
 	EDVImbrOPRefresh(imbr);
 }
 
+/*
+ *      Stop.
+ */
+void EDVImbrOpStop(edv_imbr_struct *imbr)
+{
+	if(imbr == NULL)
+	    return;
+
+	imbr->stop_count++;
+}
+
+/*
+ *	Continue.
+ */
+void EDVImbrOpContinue(edv_imbr_struct *imbr)
+{
+	if(imbr == NULL)
+	    return;
+
+	/* Reset loading process timeout callback and initialize
+	 * loading values
+	 */
+	EDVImbrQueueLoadingProcess(imbr);
+
+	EDVImbrUpdateMenus(imbr);
+}
+
+/*
+ *	Presentation mode.
+ */
+void EDVImbrOpPresentationMode(edv_imbr_struct *imbr)
+{
+	if(imbr == NULL)
+	    return;
+
+	/* Need to notify the loading process to stop before we ente
+	 * presentation mode
+	 */
+	if(imbr->loading_tocb > 0)
+	    imbr->stop_count++;
+
+	/* Switch to presentation mode */
+	EDVPresentationModeEnterFromImbr(
+	    EDV_CORE(imbr->core_ptr),
+	    imbr
+	);
+}
+
 
 /*
  *	Download.
