@@ -31,12 +31,14 @@
 #include "edvcb.h"
 #include "edvutils.h"
 #include "edvutilsgtk.h"
+
 #include "edvcfglist.h"
 #include "config.h"
 
 
 static void EDVImbrTListFPromptCancelCB(gpointer data);
 
+/* Image Loading */
 static guint8 *EDVImbrTListConvertRGBToRGBA(
 	const guint8 *rgb, const guint8 *alpha,
 	gint width, gint height,
@@ -67,28 +69,40 @@ static gint EDVImbrTListAppendObject(
 	tlist_struct *tlist, edv_object_struct *obj
 );
 
+/* Finding */
 gint EDVImbrTListFindThumbByPath(
 	edv_imbr_struct *imbr, const gchar *path
 );
 
-void EDVImbrTListResetThumbs(edv_imbr_struct *imbr);
-void EDVImbrTListDoUpdate(
+/* Selection */
+GList *EDVImbrTListGetSelectedPaths(edv_imbr_struct *imbr);
+
+/* Realize Listing */
+void EDVImbrTListRealizeListing(edv_imbr_struct *imbr);
+
+/* Get Listing */
+void EDVImbrTListGetListing(
 	edv_imbr_struct *imbr, const gchar *path,
 	gboolean update_status_bar
 );
+void EDVImbrTlistClear(edv_imbr_struct *imbr);
 
+/* Thumb Image Load Iteration */
 gint EDVImbrTListLoadIterate(
 	edv_imbr_struct *imbr, gboolean update_status_bar,
 	gboolean no_enlarge
 );
 
-void EDVImbrTListDoOpenObject(
-	edv_imbr_struct *imbr, gint thumb_num, guint state
+/* Opening */
+void EDVImbrTListOpen(
+	edv_imbr_struct *imbr, gint thumb_num,
+	guint state				/* Key modifiers */
 );
-void EDVImbrTListDoOpenWithObject(
+void EDVImbrTListOpenWith(
 	edv_imbr_struct *imbr, gint thumb_num
 );
 
+/* Renaming */
 static void EDVImbrTListFPromptRenameApplyCB(
 	gpointer data, const gchar *value
 );
@@ -96,6 +110,7 @@ void EDVImbrTListDoFPromptRename(
 	edv_imbr_struct *imbr, gint thumb_num
 );
 
+/* Object Callbacks */
 void EDVImbrTListObjectAddedNotify(
 	edv_imbr_struct *imbr, const gchar *path,
 	const struct stat *lstat_buf
@@ -109,6 +124,7 @@ void EDVImbrTListObjectRemovedNotify(
 	edv_imbr_struct *imbr, const gchar *path
 );
 
+/* Mount Callbacks */
 void EDVImbrTListMountNotify(
 	edv_imbr_struct *imbr, edv_device_struct *dev_ptr,
 	gboolean is_mounted
@@ -251,11 +267,13 @@ static guint8 *EDVImbrTListLoadImageRGBATarga(
 }
 
 /* 
- *	Returns a dynamically allocated image buffer loaded from the image
- *	file specified by path, the calling function must deallocate this
- *	buffer.
+ *	Opens the image specified by path and returns the RGBA image
+ *	data and its geometry.
  *
- *	Can return NULL on error.
+ *	The specified Thumbs List can be NULL if resize_for_thumb is
+ *	FALSE.
+ *
+ *	Returns the RGBA image data or NULL on error.
  */
 guint8 *EDVImbrTListLoadImageRGBA(
 	tlist_struct *tlist, const gchar *path,
@@ -303,9 +321,7 @@ guint8 *EDVImbrTListLoadImageRGBA(
  */
 	/* Loaded image with native loaders? */
 	if(rgba != NULL)
-	{
 	    return(rgba);
-	}
 
 
 	/* Load Imlib image */
@@ -321,8 +337,8 @@ guint8 *EDVImbrTListLoadImageRGBA(
 	swidth = imlib_image->rgb_width;
 	sheight = imlib_image->rgb_height;
 
-	/* Need to resize for tlist thumb? */
-	if(resize_for_thumb)
+	/* Resize the image for a thumb on the Thumbs List? */
+	if(resize_for_thumb && (tlist != NULL))
 	{
 	    TListQueryThumbPixmapSize(
 		tlist, swidth, sheight, &twidth, &theight
@@ -343,9 +359,9 @@ guint8 *EDVImbrTListLoadImageRGBA(
 	    twidth = swidth;
 	    theight = sheight;
 	}
-	/* At this point swidth and sheight are the size of the
-	 * image and twidth and theight are the size of the
-	 * image needed to fit on the tlist thumb
+	/* At this point swidth and sheight are the size of the image
+	 * and twidth and theight are the size of the image needed to
+	 * fit on a thumb (if resize_for_thumb was TRUE)
 	 */
 
 	if((swidth <= 0) || (sheight <= 0) ||
@@ -385,7 +401,9 @@ guint8 *EDVImbrTListLoadImageRGBA(
 		    twidth, theight, -1
 		);
 
-	    /* Create RGBA data from resized thumb image data */
+	    /* Create RGBA image data from the resized thumb RGBA
+	     * image data
+	     */
 	    rgba = EDVImbrTListConvertRGBToRGBA(
 		t_rgb, t_alpha,
 		twidth, theight,
@@ -429,7 +447,7 @@ guint8 *EDVImbrTListLoadImageRGBA(
 
 
 /*
- *      Sets the text for the given thumb.
+ *      Sets the text for the specified Thumb.
  */
 static void EDVImbrTListSetThumbName(
 	edv_core_struct *core_ptr, edv_imbr_struct *imbr,
@@ -439,16 +457,19 @@ static void EDVImbrTListSetThumbName(
 {
 	edv_object_type type = obj->type;
 	const gchar *name = obj->name;
+	GdkColor *text_color_fg = NULL;
 
 	if(name == NULL)
 	    name = "(null)";
 
 	/* Check if this not an image file supported by Imlib */
-	if(!EDVCheckImlibImage(core_ptr, name))
+	if(!EDVCheckImlibImage(core_ptr, name) ||
+	   (EDV_OBJECT_IS_LINK(obj) && !EDV_OBJECT_IS_LINK_VALID(obj))
+	)
 	{
 	    /* Probably not an image, so set icon */
-	    GdkPixmap *pixmap, *pixmap_hid;
-	    GdkBitmap *mask, *mask_hid;
+	    GdkPixmap *pixmap, *pixmap_ext, *pixmap_hid;
+	    GdkBitmap *mask, *mask_ext, *mask_hid;
 
 	    /* Match icon with MIME Type */
 	    EDVMatchObjectIcon(
@@ -456,11 +477,12 @@ static void EDVImbrTListSetThumbName(
 		core_ptr->mimetype, core_ptr->total_mimetypes,
 		type,
 		obj->full_path,
-		obj->link_valid, obj->permissions,
+		EDV_OBJECT_IS_LINK_VALID(obj),
+		obj->permissions,
 		1,                  /* Medium icons */
 		&pixmap, &mask,
 		NULL, NULL,
-		NULL, NULL,
+		&pixmap_ext, &mask_ext,
 		&pixmap_hid, &mask_hid
 	    );
 	    /* Check if an alternate icon state should be used */
@@ -477,68 +499,134 @@ static void EDVImbrTListSetThumbName(
 		}
 		break;
 	      case EDV_OBJECT_TYPE_DIRECTORY:
-                /* Hidden */
-                if(EDVIsObjectHidden(obj) && (pixmap_hid != NULL))
-                {
-                    pixmap = pixmap_hid;
-                    mask = mask_hid;
-                }
+		/* Hidden */
+		if(EDVIsObjectHidden(obj) && (pixmap_hid != NULL))
+		{
+		    if(pixmap_hid != NULL)
+		    {
+			pixmap = pixmap_hid;
+			mask = mask_hid;
+		    }
+		}
 		/* Special directory notations? */
 		if(!strcmp(name, ".."))
 		{
-		    pixmap = imbr->folder_parent_pixmap;
-		    mask = imbr->folder_parent_mask;
+		    if(imbr->folder_parent_pixmap != NULL)
+		    {
+			pixmap = imbr->folder_parent_pixmap;
+			mask = imbr->folder_parent_mask;
+		    }
 		}
+#if 0
 		/* Home directory? */
 		if((!STRISEMPTY(obj->full_path) &&
 		    !STRISEMPTY(core_ptr->home_dir)) ?
 		    !strcmp(obj->full_path, core_ptr->home_dir) : FALSE
 		)
 		{
-		    pixmap = imbr->folder_home_pixmap;
-		    mask = imbr->folder_home_mask;
+		    if(imbr->folder_home_pixmap != NULL)
+		    {
+			pixmap = imbr->folder_home_pixmap;
+			mask = imbr->folder_home_mask;
+		    }
 		}
+#endif
 		/* Directory not accessable? */
 		if(!EDVIsObjectAccessable(core_ptr, obj))
 		{
 		    pixmap = imbr->folder_noaccess_pixmap;
 		    mask = imbr->folder_noaccess_mask;
+		    if(text_color_fg == NULL)
+		    {
+			const GdkColor cs = EDV_GDKCOLOR_NO_ACCESS_FG;
+			GdkColor *ct = (GdkColor *)g_malloc(
+			    sizeof(GdkColor)
+			);
+			if(ct != NULL)
+			    memcpy(ct, &cs, sizeof(GdkColor));
+			text_color_fg = ct;
+		    }
 		}
 		break;
 	      case EDV_OBJECT_TYPE_LINK:
+		/* Dangling? */
+		if(!EDV_OBJECT_IS_LINK_VALID(obj))
+		{
+		    if(pixmap_ext != NULL)
+		    {
+			pixmap = pixmap_ext;
+			mask = mask_ext;
+		    }
+		    if(text_color_fg == NULL)
+		    {
+			const GdkColor cs = EDV_GDKCOLOR_DANGLING_LINK_FG;
+			GdkColor *ct = (GdkColor *)g_malloc(
+			    sizeof(GdkColor)
+			);
+			if(ct != NULL)
+			    memcpy(ct, &cs, sizeof(GdkColor));
+			text_color_fg = ct;
+		    }
+		}
+		/* Infinately recursive? */
+		if(EDV_OBJECT_IS_LINK_TAR_GRAND_PARENT(obj))
+		{
+		    if(text_color_fg == NULL)
+		    {
+			const GdkColor cs = EDV_GDKCOLOR_RECURSIVE_LINK_FG;
+			GdkColor *ct = (GdkColor *)g_malloc(
+			    sizeof(GdkColor)
+			);
+			if(ct != NULL)
+			    memcpy(ct, &cs, sizeof(GdkColor));
+			text_color_fg = ct;
+		    }
+		}
 		break;
-              case EDV_OBJECT_TYPE_DEVICE_BLOCK:
-                /* Hidden */
-                if(EDVIsObjectHidden(obj) && (pixmap_hid != NULL))
-                {
-                    pixmap = pixmap_hid;
-                    mask = mask_hid;
-                }
+	      case EDV_OBJECT_TYPE_DEVICE_BLOCK:
+		/* Hidden */
+		if(EDVIsObjectHidden(obj) && (pixmap_hid != NULL))
+		{
+		    if(pixmap_hid != NULL)
+		    {
+			pixmap = pixmap_hid;
+			mask = mask_hid;
+		    }
+		}
+		break;
+	      case EDV_OBJECT_TYPE_DEVICE_CHARACTER:
+		/* Hidden */
+		if(EDVIsObjectHidden(obj) && (pixmap_hid != NULL))
+		{
+		    if(pixmap_hid != NULL)
+		    {
+		        pixmap = pixmap_hid;
+		        mask = mask_hid;
+		    }
+		}
+		break;
+	      case EDV_OBJECT_TYPE_FIFO:
+		/* Hidden */
+		if(EDVIsObjectHidden(obj) && (pixmap_hid != NULL))
+		{
+		    if(pixmap_hid != NULL)
+		    {
+		        pixmap = pixmap_hid;
+		        mask = mask_hid;
+		    }
+		}
+		break;
+	      case EDV_OBJECT_TYPE_SOCKET:
+		/* Hidden */
+		if(EDVIsObjectHidden(obj) && (pixmap_hid != NULL))
+		{
+		    if(pixmap_hid != NULL)
+		    {
+		        pixmap = pixmap_hid;
+		        mask = mask_hid;
+		    }
+		}
 		break;
-              case EDV_OBJECT_TYPE_DEVICE_CHARACTER:
-                /* Hidden */
-                if(EDVIsObjectHidden(obj) && (pixmap_hid != NULL))
-                {
-                    pixmap = pixmap_hid;
-                    mask = mask_hid;
-                }
-                break;
-              case EDV_OBJECT_TYPE_FIFO:
-                /* Hidden */
-                if(EDVIsObjectHidden(obj) && (pixmap_hid != NULL))
-                {
-                    pixmap = pixmap_hid;
-                    mask = mask_hid;
-                }
-                break;
-              case EDV_OBJECT_TYPE_SOCKET:
-                /* Hidden */
-                if(EDVIsObjectHidden(obj) && (pixmap_hid != NULL))
-                {
-                    pixmap = pixmap_hid;
-                    mask = mask_hid;
-                }
-                break;
  	    }
 
 	    /* Set thumb's pixmap */
@@ -558,6 +646,10 @@ static void EDVImbrTListSetThumbName(
 
 	/* Set thumb's text */
 	TListSetText(tlist, thumb_num, name);
+	if(text_color_fg != NULL)
+	    TListSetTextColor(tlist, thumb_num, text_color_fg, NULL);
+
+	g_free(text_color_fg);
 }
 
 /*
@@ -613,8 +705,7 @@ gint EDVImbrTListFindThumbByPath(
 {
 	gint i;
 	tlist_struct *tlist;
-	edv_object_struct *object;
-
+	edv_object_struct *obj;
 
 	if((imbr == NULL) || (path == NULL))
 	    return(-1);
@@ -626,34 +717,65 @@ gint EDVImbrTListFindThumbByPath(
 	/* Iterate through all thumbs */
 	for(i = 0; i < tlist->total_thumbs; i++)
 	{
-	    object = (edv_object_struct *)TListGetThumbData(tlist, i);
-	    if(object == NULL)
-		continue;
-
-	    /* Full path not specified on disk object structure? */
-	    if(object->full_path == NULL)
+	    obj = EDV_OBJECT(TListGetThumbData(tlist, i));
+	    if((obj != NULL) ? STRISEMPTY(obj->full_path) : TRUE)
 		continue;
 
 	    /* Full paths match? */
-	    if(!strcmp(object->full_path, path))
+	    if(!strcmp(obj->full_path, path))
 		return(i);
 	}
 
 	return(-1);
 }
 
+
 /*
- *      Updates all thumbs on the thumbs list by getting the thumb data
- *      and updating the thumb list's thumbs.
+ *	Returns a list of full paths describing the selected items.
  *
- *      This is designed to be called whenever the displayed values
- *      of each thumb need to be set again from internal data, usually
- *      when a MIME Type has been added/modified/removed. This function
- *      should not be used to `refresh' the list (get new values of
- *      disk object structures), use EDVImbrTListDoUpdate()
- *      instead.
+ *	The calling function must delete the list.
  */
-void EDVImbrTListResetThumbs(edv_imbr_struct *imbr)
+GList *EDVImbrTListGetSelectedPaths(edv_imbr_struct *imbr)
+{
+	GList *glist, *paths_list = NULL;
+	edv_object_struct *obj;
+	tlist_struct *tlist = (imbr != NULL) ? imbr->tlist : NULL;
+	if(tlist == NULL)
+	    return(paths_list);
+
+	for(glist = tlist->selection;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
+	{
+	    obj = EDV_OBJECT(TListGetThumbData(
+		tlist, (gint)glist->data
+	    ));
+	    if((obj != NULL) ? STRISEMPTY(obj->full_path) : TRUE)
+		continue;
+
+	    paths_list = g_list_append(
+		paths_list,
+		STRDUP(obj->full_path)
+	    );
+	}
+
+	return(paths_list);
+}
+
+
+/*
+ *	Updates all thumbs on the Thumbs List with each thumb's
+ *	associated object.
+ *
+ *	This should be called when MIME Types or Devices have been
+ *	added/modified/removed or after reconfiguration.
+ *
+ *	This function should not be used to refresh the list (get a
+ *	new listing of new objects), use EDVImbrTListGetListing()
+ *	instead.
+ */
+void EDVImbrTListRealizeListing(edv_imbr_struct *imbr)
 {
 	gint i;
 	tlist_thumb_struct *thumb;
@@ -683,13 +805,12 @@ void EDVImbrTListResetThumbs(edv_imbr_struct *imbr)
 	}
 }
 
-
 /*
- *	Deletes all Thumbs in the Image Browser's Thumbs List and loads
- *	the thumbs (but not each image) from the specified directory
- *	path.
+ *	Deletes all Thumbs in the Thumbs List and gets a new listing
+ *	of objects (does not load each Thumb's image) from the location
+ *	specified by path.
  */
-void EDVImbrTListDoUpdate(
+void EDVImbrTListGetListing(
 	edv_imbr_struct *imbr, const gchar *path,
 	gboolean update_status_bar
 )
@@ -781,9 +902,11 @@ void EDVImbrTListDoUpdate(
 		    /* Get this object's destination statistics */
 		    if(stat((char *)full_path, &stat_buf))
 			FREE_AND_CONTINUE
+#ifdef S_ISDIR
 		    /* Skip if destination is not a directory */
 		    if(!S_ISDIR(stat_buf.st_mode))
 			FREE_AND_CONTINUE
+#endif
 
 		    /* Object's destination is a directory, now get
 		     * the object's local stats
@@ -798,7 +921,7 @@ void EDVImbrTListDoUpdate(
 
 			EDVObjectSetPath(obj, full_path);
 			EDVObjectSetStat(obj, &lstat_buf);
-			obj->link_valid = TRUE;
+			EDVObjectUpdateLinkFlags(obj);
 
 			/* Begin filter checks */
 			if((hide_object_hidden ?
@@ -888,9 +1011,11 @@ void EDVImbrTListDoUpdate(
 		    stat_result = stat((char *)full_path, &stat_buf);
 		    if(!stat_result)
 		    {
+#ifdef S_ISDIR
 			/* Check if object destination is a directory */
 			if(S_ISDIR(stat_buf.st_mode))
 			    FREE_AND_CONTINUE
+#endif
 		    }
 
 		    /* Create new object */
@@ -901,7 +1026,7 @@ void EDVImbrTListDoUpdate(
 
 			EDVObjectSetPath(obj, full_path);
 			EDVObjectSetStat(obj, &lstat_buf);
-			obj->link_valid = stat_result ? FALSE : TRUE;
+			EDVObjectUpdateLinkFlags(obj);
 
 			/* Begin filter checks */
 			if((hide_object_hidden ?
@@ -971,6 +1096,26 @@ void EDVImbrTListDoUpdate(
 	TListThaw(tlist);
 }
 
+/*
+ *	Deletes all Thumbs in the Thumbs List.
+ */
+void EDVImbrTlistClear(edv_imbr_struct *imbr)
+{
+	tlist_struct *tlist;
+
+	if(imbr == NULL)
+	    return;
+
+	tlist = imbr->tlist;
+	if(tlist == NULL)
+	    return;
+
+	TListFreeze(tlist);
+	TListClear(tlist);
+	TListThaw(tlist);
+}
+
+
 /*
  *	Loads the Image Browser Thumbs List's next unloaded thumb.
  *
@@ -996,9 +1141,9 @@ gint EDVImbrTListLoadIterate(
 	gint starting_thumb_num, thumb_num, thumb_to_load_num = -1;
 	gint thumbs_already_loaded = 0;
 	GtkWidget *toplevel;
-	edv_object_struct *obj;
-	edv_status_bar_struct *sb = (imbr != NULL) ? imbr->status_bar : NULL;
 	tlist_thumb_struct *thumb, *thumb_to_load = NULL;
+	edv_object_struct *obj;
+	edv_statusbar_struct *sb = (imbr != NULL) ? imbr->status_bar : NULL;
 	edv_core_struct *core_ptr;
 	tlist_struct *tlist = (imbr != NULL) ? imbr->tlist : NULL;
 
@@ -1198,79 +1343,84 @@ gint EDVImbrTListLoadIterate(
 
 
 /*
- *	Procedure to open the object specified by thumb_num
+ *	Opens the object specified by thumb_num.
+ *
+ *	If thumb_num is -1 then the selected object(s) will be opened.
  */
-void EDVImbrTListDoOpenObject(
-	edv_imbr_struct *imbr, gint thumb_num, guint state
+void EDVImbrTListOpen(
+	edv_imbr_struct *imbr, gint thumb_num,
+	guint state				/* Key modifiers */
 )
 {
-	const gchar *name;
-	gchar *full_path;
-	struct stat stat_buf;
-	const edv_object_struct *obj;
+	GList *paths_list;
+	GtkWidget *toplevel;
 	edv_core_struct *core_ptr;
-	tlist_struct *tlist = (imbr != NULL) ? imbr->tlist : NULL;
-	if(tlist == NULL)
+
+	if(imbr == NULL)
 	    return;
 
-	obj = EDV_OBJECT(TListGetThumbData(tlist, thumb_num));
+	toplevel = imbr->toplevel;
 	core_ptr = EDV_CORE(imbr->core_ptr);
-	if((obj == NULL) || (core_ptr == NULL))
+	if(core_ptr == NULL)
 	    return;
 
-	/* Check name of object to check for special notations */
-	name = obj->name;
-	if(!STRISEMPTY(name))
+	/* Use selected objects? */
+	if(thumb_num < 0)
 	{
-	    if(!strcmp(name, "."))
-	    {
-		full_path = NULL;
-	    }
-	    else if(!strcmp(name, ".."))
-	    {
-		full_path = g_dirname(
-		    EDVImbrCurrentLocation(imbr)
-		);
-	    }
-	    else if(!STRISEMPTY(core_ptr->home_dir) ?
-		!strcmp(name, "~") : FALSE
-	    )
-	    {
-		full_path = STRDUP(core_ptr->home_dir);
-	    }      
-	    else
-	    {
-		full_path = STRDUP(obj->full_path);
-	    }
+	    paths_list = EDVImbrTListGetSelectedPaths(imbr);
 	}
 	else
 	{
-	    /* No name available, get copy of full path */
-	    full_path = STRDUP(obj->full_path);
-	}
-	if(full_path == NULL)
-	    return;
+	    tlist_struct *tlist = imbr->tlist;
+	    edv_object_struct *obj = EDV_OBJECT(
+		TListGetThumbData(tlist, thumb_num)
+	    );
+	    if(obj == NULL)
+		return;
 
-	/* Get stats of destination object, the object structure may
-	 * have that information already but we want to ensure we have
-	 * the most up to date information
-	 */
-	if(stat(full_path, &stat_buf))
-	{
-	    g_free(full_path);
-	    return;
+	    paths_list = g_list_append(
+		NULL,
+		STRDUP(obj->full_path)
+	    );
 	}
 
-	/* Is destination a directory? */
-	if(S_ISDIR(stat_buf.st_mode))
+	/* Check if there is only one path and it refers to a directory */
+	if(g_list_length(paths_list) == 1)
 	{
-	    /* Change directory */
-	    EDVImbrSetBusy(imbr, TRUE);
-	    EDVImbrSelectPath(imbr, full_path);
-	    EDVImbrUpdateMenus(imbr);
-	    EDVImbrSetBusy(imbr, FALSE);
+	    struct stat stat_buf;
+	    gchar *path = EDVEvaluatePath(
+		NULL, (gchar *)paths_list->data
+	    );
+	    if((path != NULL) ? stat(path, &stat_buf) : TRUE)
+	    {
+		g_list_foreach(paths_list, (GFunc)g_free, NULL);
+		g_list_free(paths_list);
+		g_free(path);
+		return;
+	    }
+#ifdef S_ISDIR
+	    if(S_ISDIR(stat_buf.st_mode))
+	    {
+		/* Change directory and return */                       
+		EDVImbrSetBusy(imbr, TRUE);
+		GUIBlockInput(toplevel, TRUE);
+
+		EDVImbrSelectPath(imbr, path);
+		EDVImbrUpdateMenus(imbr);
+
+		GUIBlockInput(toplevel, FALSE);
+		EDVImbrSetBusy(imbr, FALSE);
+
+		g_list_foreach(paths_list, (GFunc)g_free, NULL);
+		g_list_free(paths_list);
+		g_free(path);
+
+		return;
+	    }
+#endif	/* S_ISDIR */
 	}
-	else
+
+	if(paths_list != NULL)
 	{
 	    gchar	*stdout_path_rtn = NULL,
 			*stderr_path_rtn = NULL;
@@ -1282,11 +1432,14 @@ void EDVImbrTListDoOpenObject(
 		command_name = "edit";
 
 	    EDVImbrSetBusy(imbr, TRUE);
-	    EDVOpenObjectPath(
-		core_ptr, full_path,
-		command_name,		/* Command name */
-		imbr->toplevel, TRUE,
-		&stdout_path_rtn, &stderr_path_rtn
+	    EDVOpen(
+		core_ptr,
+		paths_list,		/* Paths List */
+		command_name,		/* Command Name */
+		toplevel,		/* Toplevel */
+		TRUE,			/* Verbose */
+		&stdout_path_rtn,
+		&stderr_path_rtn
 	    );
 	    EDVImbrSetBusy(imbr, FALSE);
 
@@ -1294,92 +1447,74 @@ void EDVImbrTListDoOpenObject(
 	    g_free(stderr_path_rtn);
 	}
 
-	/* Delete copy of full path */
-	g_free(full_path);
+	g_list_foreach(paths_list, (GFunc)g_free, NULL);
+	g_list_free(paths_list);
 }
 
 /*
- *      Procedure to `open with' the object specified by thumb_num
+ *	Prompts the user to open the object specified by thumb_num with
+ *	a specified method.
+ *
+ *	If thumb_num is -1 then the selected object(s) will be opened.
  */
-void EDVImbrTListDoOpenWithObject(
+void EDVImbrTListOpenWith(
 	edv_imbr_struct *imbr, gint thumb_num
 )
 {
-	tlist_struct *tlist;
-	edv_object_struct *object;
-	const gchar *name;
-	gchar *full_path;
-	struct stat stat_buf;
-
+	GList *paths_list;
+	GtkWidget *toplevel;
+	edv_core_struct *core_ptr;
 
 	if(imbr == NULL)
 	    return;
 
-	tlist = imbr->tlist;
-	if(tlist == NULL)
+	toplevel = imbr->toplevel;
+	core_ptr = EDV_CORE(imbr->core_ptr);
+	if(core_ptr == NULL)
 	    return;
 
-
-	/* Get object from row data */
-	object = (edv_object_struct *)TListGetThumbData(tlist, thumb_num);
-	if(object == NULL)
-	    return;
-
-	/* Check name of object for special notations */
-	name = object->name;
-	if(name != NULL)
+	/* Use selected objects? */
+	if(thumb_num < 0)
 	{
-	    if(!strcmp(name, "."))
-	    {
-		full_path = NULL;
-	    }
-	    else if(!strcmp(name, ".."))
-	    {
-		full_path = g_dirname(
-		    EDVImbrCurrentLocation(imbr)
-		);
-	    }
-	    else
-	    {
-		full_path = STRDUP(object->full_path);
-	    }
+	    /* Get list of selected object paths */
+	    paths_list = EDVImbrTListGetSelectedPaths(imbr);
 	}
 	else
 	{
-	    /* No name available, get copy of full path */
-	    full_path = STRDUP(object->full_path);
-	}
-	if(full_path == NULL)
-	    return;
+	    tlist_struct *tlist = imbr->tlist;
+	    edv_object_struct *obj = EDV_OBJECT(
+		TListGetThumbData(tlist, thumb_num)
+	    );
+	    if(obj == NULL)
+		return;
 
-	/* Get stats of destination object, the object structure may
-	 * have that information already but we want to ensure we have
-	 * the most up to date information
-	 */
-	if(stat(full_path, &stat_buf))
-	{
-	    g_free(full_path);
-	    return;
+	    paths_list = g_list_append(
+		NULL,
+		STRDUP(obj->full_path)
+	    );
 	}
 
-	if(TRUE)
+	if(paths_list != NULL)
 	{
 	    gchar       *stdout_path_rtn = NULL,
 			*stderr_path_rtn = NULL;
 
-	    EDVOpenWithObjectPath(
-		EDV_CORE(imbr->core_ptr), full_path,
-		NULL,                   /* Command name */
-		imbr->toplevel, TRUE,
-		&stdout_path_rtn, &stderr_path_rtn
+	    EDVOpenWith(
+		core_ptr,
+		paths_list,		/* Paths List */
+		NULL,			/* Command Name */
+		toplevel,		/* Toplevel */
+		TRUE,			/* Verbose */
+		&stdout_path_rtn,
+		&stderr_path_rtn
 	    );
 
 	    g_free(stdout_path_rtn);
 	    g_free(stderr_path_rtn);
 	}
 
-	/* Delete copy of full path */
-	g_free(full_path);
+	g_list_foreach(paths_list, (GFunc)g_free, NULL);
+	g_list_free(paths_list);
 }
 
 
@@ -1408,25 +1543,20 @@ static void EDVImbrTListFPromptRenameApplyCB(
 	)
 	{
 	    edv_core_struct *core_ptr = EDV_CORE(imbr->core_ptr);
-	    edv_object_struct *object = EDV_OBJECT(
+	    edv_object_struct *obj = EDV_OBJECT(
 		TListGetThumbData(tlist, thumb_num)
 	    );
 
-
-	    /* Check if the selected object's disk object structure is
-	     * valid
-	     */
-	    if((object != NULL) ? (object->full_path != NULL) : FALSE)
+	    /* Check if the selected object is valid */
+	    if((obj != NULL) ? !STRISEMPTY(obj->full_path) : FALSE)
 	    {
-		gchar *old_full_path = STRDUP(object->full_path);
+		gchar *old_full_path = STRDUP(obj->full_path);
 		gchar *new_obj = NULL;
 		const gchar *error_mesg;
 		gboolean yes_to_all = FALSE;
-		gint status;
-
 
 		/* Perform rename */
-		status = EDVFOPRename(
+		EDVFOPRename(
 		    core_ptr, old_full_path, value,
 		    &new_obj, imbr->toplevel,
 		    FALSE, TRUE,
@@ -1434,7 +1564,7 @@ static void EDVImbrTListFPromptRenameApplyCB(
 		);
 
 		/* Unmap progress dialog, it may have been mapped in the
-		 * above operation.
+		 * above operation
 		 */
 		ProgressDialogBreakQuery(FALSE);
 		ProgressDialogSetTransientFor(NULL);
@@ -1482,25 +1612,26 @@ static void EDVImbrTListFPromptRenameApplyCB(
 		}
 		else
 		{
-		    /* Did not get new object path new_obj, implying failed */
+		    /* Did not get new object path new_obj, this
+		     * implies failure
+		     */
 		    EDVStatusBarMessage(
 			imbr->status_bar, "Rename object failed", FALSE
 		    );
 		}
 
-		/* The disk object structure may now be invalid if the
-		 * object modified signal was emitted.
+		/* The object may now be invalid if the object modified
+		 * signal was emitted
 		 */
-		object = NULL;
+		obj = NULL;
 
-
-		/* Deallocate coppies of paths */
+		/* Delete coppies of paths */
 		g_free(new_obj);
 		g_free(old_full_path);
 	    }
 	}
 
-	/* Deallocate callback data, it is no longer needed */
+	/* Delete callback data, it is no longer needed */
 	g_free(cb_data);
 	cb_data = NULL;
 }
@@ -1516,9 +1647,9 @@ void EDVImbrTListDoFPromptRename(
 )
 {
 	gint cx, cy, px, py, pwidth, pheight;
-	edv_object_struct *object;
-	edv_core_struct *core_ptr;
 	tlist_struct *tlist;
+	edv_object_struct *obj;
+	edv_core_struct *core_ptr;
 
 	if((imbr == NULL) || (thumb_num < 0) || FPromptIsQuery())
 	    return;
@@ -1538,10 +1669,6 @@ void EDVImbrTListDoFPromptRename(
 	if((thumb_num < 0) || (thumb_num >= tlist->total_thumbs))
 	    return;
 
-	/* Get position of given thumb */
-	if(!TListGetPosition(tlist, thumb_num, &cx, &cy))
-	    return;
-
 	pwidth = tlist->thumb_width;
 	pheight = 20;
 
@@ -1552,20 +1679,24 @@ void EDVImbrTListDoFPromptRename(
 	    gdk_window_get_deskrelative_origin(
 		tlist->list_da->window, &px, &py
 	    );
-	px += cx;
-	py += cy + tlist->thumb_height - pheight - tlist->thumb_border - 4;
+	if(TListGetThumbPosition(tlist, thumb_num, &cx, &cy)) 
+	    px += cx;
+	if(TListGetThumbLabelGeometry(
+	    tlist, thumb_num, &cx, &cy, NULL, NULL
+	))
+	    py += cy - 4;
 
-	/* Get disk object structure thumb data */
-	object = (edv_object_struct *)TListGetThumbData(tlist, thumb_num);
-	if(object == NULL)
+	/* Get object from thumb data */
+	obj = EDV_OBJECT(TListGetThumbData(tlist, thumb_num));
+	if(obj == NULL)
 	    return;
 
-	/* Check if object name is a special notation that should not be
-	 * allowed to be renamed.
+	/* Check if object name is a special notation that should not
+	 * be allowed to be renamed
 	 */
-	if(object->name != NULL)
+	if(obj->name != NULL)
 	{
-	    const gchar *name = object->name;
+	    const gchar *name = obj->name;
 	    if(!strcmp(name, ".") || !strcmp(name, "..") ||
 	       !strcmp(name, "/")
 	    )
@@ -1577,7 +1708,7 @@ void EDVImbrTListDoFPromptRename(
 	    gpointer *cb_data = (gpointer *)g_malloc0(
 		3 * sizeof(gpointer)
 	    );
-	    gchar *value = STRDUP(object->name);
+	    gchar *value = STRDUP(obj->name);
 
 	    /* Set up callback data */
 	    if(cb_data != NULL)
@@ -1628,21 +1759,15 @@ void EDVImbrTListObjectAddedNotify(
 	gchar *cur_path, *parent_path;
 	gint thumb_num;
 	tlist_struct *tlist;
+	edv_object_struct *obj;
 	edv_core_struct *core_ptr;
-	edv_object_struct *object;
-	gint stat_result;
-	struct stat stat_buf;
-
 
 	if((imbr == NULL) || (path == NULL) || (lstat_buf == NULL))
 	    return;
 
-	core_ptr = EDV_CORE(imbr->core_ptr);
-	if(core_ptr == NULL)
-	    return;
-
 	tlist = imbr->tlist;
-	if(tlist == NULL)
+	core_ptr = EDV_CORE(imbr->core_ptr);
+	if((tlist == NULL) || (core_ptr == NULL))
 	    return;
 
 #define DO_FREE_LOCALS	{	\
@@ -1670,62 +1795,49 @@ void EDVImbrTListObjectAddedNotify(
 	}
 
 
-	/* Get destination stats */
-	stat_result = stat(path, &stat_buf);
-
-
-	/* Check if the new path of the object to add reffers to an object
-	 * that already exists in the list.
+	/* Check if the new path of the object to add refers to an object
+	 * that already exists in the list
 	 */
 	thumb_num = EDVImbrTListFindThumbByPath(imbr, path);
 	if((thumb_num >= 0) && (thumb_num < tlist->total_thumbs))
 	{
 	    /* The new object to add already exists in the list, so just
-	     * update the row.
+	     * update it
 	     */
-
-	    /* Get disk object structure from matched thumb */
-	    object = (edv_object_struct *)TListGetThumbData(tlist, thumb_num);
-	    if(object != NULL)
+	    obj = EDV_OBJECT(TListGetThumbData(tlist, thumb_num));
+	    if(obj != NULL)
 	    {
-		/* Update disk object structure */
-		EDVObjectSetPath(object, path);
-		EDVObjectSetStat(object, lstat_buf);
-		object->link_valid = stat_result ? FALSE : TRUE;
+		EDVObjectSetPath(obj, path);
+		EDVObjectSetStat(obj, lstat_buf);
+		EDVObjectUpdateLinkFlags(obj);
 
 		/* Update the thumb's displayed name */
 		EDVImbrTListSetThumbName(
-		    core_ptr, imbr, tlist, object, thumb_num
+		    core_ptr, imbr, tlist, obj, thumb_num
 		);
 	    }
 	}
 	else
 	{
-	    /* Create a new disk object structure */
-	    object = EDVObjectNew();
-	    if(object != NULL)
+	    /* Add a new object */
+	    obj = EDVObjectNew();
+	    if(obj != NULL)
 	    {
-		/* Set disk object structure */
-		EDVObjectSetPath(object, path);
-		EDVObjectSetStat(object, lstat_buf);
-		object->link_valid = stat_result ? FALSE : TRUE;
+		EDVObjectSetPath(obj, path);
+		EDVObjectSetStat(obj, lstat_buf);
+		EDVObjectUpdateLinkFlags(obj);
 
 		TListFreeze(tlist);
 
-		/* Append thumb using this disk object structure */
 		thumb_num = EDVImbrTListAppendObject(
-		    core_ptr, imbr, tlist, object
+		    core_ptr, imbr, tlist, obj
 		);
-		/* The object structure is now invalid after passing
-		 * it to EDVImbrTListAppendObject().
-		 */
-		object = NULL;
 
 		TListThaw(tlist);
 	    }
 
-	    /* Need to (re)queue loading process so that any newly added
-	     * thumb gets it's image loaded.
+	    /* Need to (re)queue loading process so that any newly
+	     * added thumb gets its image loaded
 	     */
 	    EDVImbrQueueLoadingProcess(imbr);
 	}
@@ -1752,11 +1864,8 @@ void EDVImbrTListObjectModifiedNotify(
 	gchar *cur_path, *parent_path;
 	gint thumb_num;
 	tlist_struct *tlist;
+	edv_object_struct *obj;
 	edv_core_struct *core_ptr;
-	edv_object_struct *object;
-	gint stat_result;
-	struct stat stat_buf;
-
 
 	if((imbr == NULL) || (path == NULL) || (lstat_buf == NULL))
 	    return;
@@ -1764,12 +1873,9 @@ void EDVImbrTListObjectModifiedNotify(
 	if(new_path == NULL)
 	    new_path = path;
 
-	core_ptr = EDV_CORE(imbr->core_ptr);
-	if(core_ptr == NULL)
-	    return;
-
 	tlist = imbr->tlist;
-	if(tlist == NULL)
+	core_ptr = EDV_CORE(imbr->core_ptr);
+	if((tlist == NULL) || (core_ptr == NULL))
 	    return;
 
 #define DO_FREE_LOCALS	{	\
@@ -1788,38 +1894,32 @@ void EDVImbrTListObjectModifiedNotify(
 	}
 
 
-	/* Get destination stats */
-	stat_result = stat(new_path, &stat_buf);
-
-
-	/* Is given path that has been modified the same as the current
-	 * location?
+	/* Is given path that has been modified the same as the
+	 * current location?
 	 */
 	if(!strcmp(new_path, cur_path))
 	{
 	    /* Reget listing */
-	    EDVImbrTListDoUpdate(imbr, new_path, TRUE);
+	    EDVImbrTListGetListing(imbr, new_path, TRUE);
 	}
 	else
 	{
-	    /* Look for a thumb who's disk object full path matches the
-	     * old path.
+	    /* Look for a thumb who's object's full path matches the
+	     * old path
 	     */
 	    thumb_num = EDVImbrTListFindThumbByPath(imbr, path);
 	    if((thumb_num >= 0) && (thumb_num < tlist->total_thumbs))
 	    {
-		/* Get disk object structure from matched thumb */
-		object = (edv_object_struct *)TListGetThumbData(tlist, thumb_num);
-		if(object != NULL)
+		obj = EDV_OBJECT(TListGetThumbData(tlist, thumb_num));
+		if(obj != NULL)
 		{
-		    /* Update disk object structure */
-		    EDVObjectSetPath(object, new_path);		/* Use new_path */
-		    EDVObjectSetStat(object, lstat_buf);
-		    object->link_valid = stat_result ? FALSE : TRUE;
+		    EDVObjectSetPath(obj, new_path);		/* Use new_path */
+		    EDVObjectSetStat(obj, lstat_buf);
+		    EDVObjectUpdateLinkFlags(obj);
 
 		    /* Update the thumb's displayed name */
 		    EDVImbrTListSetThumbName(
-			core_ptr, imbr, tlist, object, thumb_num
+			core_ptr, imbr, tlist, obj, thumb_num
 		    );
 		}
 	    }
@@ -1843,7 +1943,6 @@ void EDVImbrTListObjectRemovedNotify(
 	gint thumb_num;
 	tlist_struct *tlist;
 
-
 	if((imbr == NULL) || (path == NULL))
 	    return;
 
@@ -1906,7 +2005,6 @@ void EDVImbrTListMountNotify(
 	gchar *cur_path, *mount_path;
 	tlist_struct *tlist;
 
-
 	if((imbr == NULL) || (dev_ptr == NULL))
 	    return;
 
@@ -1933,14 +2031,13 @@ void EDVImbrTListMountNotify(
 	EDVSimplifyPath(cur_path);
 	EDVSimplifyPath(mount_path);
 
-
 	/* Check if mount path was the current location, if it was then
 	 * the contents clist needs to be updated
 	 */
 	if(!strcmp(cur_path, mount_path))
 	{
 	    /* Reget listing */
-	    EDVImbrTListDoUpdate(imbr, cur_path, TRUE);
+	    EDVImbrTListGetListing(imbr, cur_path, TRUE);
 	}
 
 	DO_FREE_LOCALS
