@@ -4,7 +4,6 @@
  *	program itself must be running or else nothing will happen.
  */
 
-#include <stdio.h>
 #include <glib.h>
 #include <endeavour2.h>
 
@@ -16,15 +15,19 @@ int main(int argc, char *argv[])
 	if(argc > 1)
 	{
 	    /* Instruct Endeavour to open the object by matching the
-	     * object's type with Endeavour's MIME Types list.  The
-	     * Endeavour program must be currently running or else
+	     * object's type with Endeavour's MIME Types list
+	     *
+	     * The Endeavour program must be currently running or else
 	     * this call will have no affect.
 	     */
 	    EDVOpen(ctx, argv[1], NULL);
 	}
 	else
 	{
-	    printf("Usage: %s <path>\n", argv[0]);
+	    g_print(
+"Usage: %s <path>\n",
+		argv[0]
+	    );
 	}
 
 	EDVContextSync(ctx);
