@@ -6,7 +6,6 @@
  *	bin so please use this with caution!
  */
 
-#include <stdio.h>
 #include <stdlib.h>
 #include <glib.h>
 #include <endeavour2.h>
@@ -33,13 +32,16 @@ int main(int argc, char *argv[])
 	    if(EDVPurge(
 		ctx, index, TRUE, NULL, NULL
 	    ))
-		printf("#%i: %s.\n", index, EDVRecycleGetError(ctx));
+		g_print("#%i: %s.\n", index, EDVRecycleGetError(ctx));
 	    else
-		printf("#%i: Purged.\n", index);
+		g_print("#%i: Purged.\n", index);
 	}
 	else
 	{
-	    printf("%s: <index>\n", argv[0]);
+	    g_print(
+"Usage: %s <index>\n",
+		argv[0]
+	    );
 	}
 
 	EDVContextSync(ctx);
