@@ -2,10 +2,9 @@
  *	Prints a list of all recycled objects found in the recycle bin.
  *
  *	Use "recover" to recover a recycled object or "purge" to
- *	permanently purge it.
+ *	permanently purge a recycled object.
  */
 
-#include <stdio.h>
 #include <sys/stat.h>
 #include <glib.h>
 #include <endeavour2.h>
@@ -24,14 +23,14 @@ int main(int argc, char *argv[])
 	 * recycled object's index, original full path, and statistics
 	 *
 	 * The returned path strings, statistics structures, and the
-	 * pointer arrays must be deallocated.
+	 * pointer arrays must be deleted.
 	 */
 	EDVRecycledObjectStatAll(
 	    ctx, &path, &index, &stat_buf, &total
 	);
 	for(i = 0; i < total; i++)
 	{
-	    printf(
+	    g_print(
 		"#%i\t%s\t%ld bytes\n",
 		index[i], path[i], stat_buf[i]->st_size
 	    );
@@ -43,7 +42,13 @@ int main(int argc, char *argv[])
 	g_free(index);
 	g_free(stat_buf);
 
-	printf("%i recycled objects found\n", i);
+#if 0
+	g_print(
+	    "%i recycled object%s found\n",
+	    i,
+	    (i == 1) ? "" : "s"
+	);
+#endif
 
 	EDVContextSync(ctx);
 	EDVContextDelete(ctx);
