@@ -16,6 +16,7 @@
 #define EDV_CFG_PARM_DIR_START_UP		"DirectoryStartUp"
 #define EDV_CFG_PARM_DIR_LOCAL			"DirectoryLocal"
 #define EDV_CFG_PARM_DIR_GLOBAL			"DirectoryGlobal"
+#define EDV_CFG_PARM_DIR_GLOBAL_CONFIG		"DirectoryGlobalConfig"
 #define EDV_CFG_PARM_DIR_TMP			"DirectoryTmp"
 
 #define EDV_CFG_PARM_FILE_RECYCLED_INDEX	"FileRecycledIndex"
@@ -148,6 +149,7 @@
 #define EDV_CFG_PARM_BROWSER_SHOW_OBJECT_HIDDEN	"BrowserShowObjectHidden"
 #define EDV_CFG_PARM_BROWSER_SHOW_OBJECT_NOACCESS	\
 						"BrowserShowObjectNoAccess"
+#define EDV_CFG_PARM_BROWSER_ACCELERATOR_KEYS	"BrowserAcceleratorKeys" 
 
 #define EDV_CFG_PARM_IMBR_X			"ImageBrowserX"
 #define EDV_CFG_PARM_IMBR_Y          		"ImageBrowserY"
@@ -177,6 +179,16 @@
 #define EDV_CFG_PARM_IMBR_SHOW_OBJECT_HIDDEN	"ImageBrowserShowObjectHidden"
 #define EDV_CFG_PARM_IMBR_SHOW_OBJECT_NOACCESS	"ImageBrowserShowObjectNoAccess"
 #define EDV_CFG_PARM_IMBR_SHOW_OBJECT_NONIMAGE	"ImageBrowserShowObjectNonImage"
+#define EDV_CFG_PARM_IMBR_ACCELERATOR_KEYS	"ImageBrowserAcceleratorKeys"
+
+#define EDV_CFG_PARM_PRESENTATION_SHOW_NAVIGATOR	"PresentationShowNavigator"
+#define EDV_CFG_PARM_PRESENTATION_FONT		"PresentationFont"
+#define EDV_CFG_PARM_PRESENTATION_COLOR_FG	"PresentationColorFG"
+#define EDV_CFG_PARM_PRESENTATION_COLOR_FG_INVERT	"PresentationColorFGInvert"
+#define EDV_CFG_PARM_PRESENTATION_COLOR_BG	"PresentationColorBG"
+#define EDV_CFG_PARM_PRESENTATION_HIDE_POINTER_DELAY	"PresentationHidePointerDelay"
+#define EDV_CFG_PARM_PRESENTATION_SLIDESHOW		"PresentationSlideshow"
+#define EDV_CFG_PARM_PRESENTATION_SLIDESHOW_DELAY	"PresentationSlideshowDelay"
 
 #define EDV_CFG_PARM_RECBIN_X			"RecBinX"
 #define EDV_CFG_PARM_RECBIN_Y			"RecBinY"
@@ -201,6 +213,7 @@
 #define EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN	"RecBinContentsColumn"
 #define EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN_WIDTH	\
 						"RecBinContentsColumnWidth"
+#define EDV_CFG_PARM_RECBIN_ACCELERATOR_KEYS	"RecBinAcceleratorKeys"
 
 #define EDV_CFG_PARM_ARCHIVER_X			"ArchiverX"
 #define EDV_CFG_PARM_ARCHIVER_Y			"ArchiverY"
@@ -227,6 +240,8 @@
 #define EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN	"ArchiverContentsColumn"
 #define EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN_WIDTH	\
 						"ArchiverContentsColumnWidth"
+#define EDV_CFG_PARM_ARCHIVER_ACCELERATOR_KEYS	"ArchiverAcceleratorKeys"
+
 
 #define EDV_CFG_PARM_FINDWIN_X			"FindWinX"
 #define EDV_CFG_PARM_FINDWIN_Y			"FindWinY"
@@ -244,6 +259,7 @@
 #define EDV_CFG_PARM_RUNDLG_LAST_WORKING_DIR	"RunDlgLastWorkingDir"
 
 
+#ifdef NEED_EDV_CFG_LIST_SOURCE
 /*
  *	Configuration list:
  *
@@ -261,8 +277,9 @@
 { CFG_ITEM_TYPE_INT32, EDV_CFG_PARM_VERSION_RELEASE, NULL },	\
 								\
 { CFG_ITEM_TYPE_STRING, EDV_CFG_PARM_DIR_START_UP, NULL },	\
-{ CFG_ITEM_TYPE_STRING, EDV_CFG_PARM_DIR_GLOBAL, NULL },	\
 { CFG_ITEM_TYPE_STRING, EDV_CFG_PARM_DIR_LOCAL, NULL },		\
+{ CFG_ITEM_TYPE_STRING, EDV_CFG_PARM_DIR_GLOBAL, NULL },	\
+{ CFG_ITEM_TYPE_STRING, EDV_CFG_PARM_DIR_GLOBAL_CONFIG, NULL },	\
 { CFG_ITEM_TYPE_STRING, EDV_CFG_PARM_DIR_TMP, NULL },		\
 								\
 { CFG_ITEM_TYPE_STRING, EDV_CFG_PARM_FILE_RECYCLED_INDEX, NULL }, \
@@ -381,6 +398,7 @@
 { CFG_ITEM_TYPE_INTLIST, EDV_CFG_PARM_BROWSER_CONTENTS_COLUMN_WIDTH, NULL }, \
 { CFG_ITEM_TYPE_UINT8, EDV_CFG_PARM_BROWSER_SHOW_OBJECT_HIDDEN, NULL }, \
 { CFG_ITEM_TYPE_UINT8, EDV_CFG_PARM_BROWSER_SHOW_OBJECT_NOACCESS, NULL }, \
+{ CFG_ITEM_TYPE_ACCELKEY_LIST, EDV_CFG_PARM_BROWSER_ACCELERATOR_KEYS, NULL }, \
 								\
 { CFG_ITEM_TYPE_INT32, EDV_CFG_PARM_IMBR_X, NULL },		\
 { CFG_ITEM_TYPE_INT32, EDV_CFG_PARM_IMBR_Y, NULL },		\
@@ -410,6 +428,16 @@
 { CFG_ITEM_TYPE_UINT8, EDV_CFG_PARM_IMBR_SHOW_OBJECT_HIDDEN, NULL }, \
 { CFG_ITEM_TYPE_UINT8, EDV_CFG_PARM_IMBR_SHOW_OBJECT_NOACCESS, NULL }, \
 { CFG_ITEM_TYPE_UINT8, EDV_CFG_PARM_IMBR_SHOW_OBJECT_NONIMAGE, NULL }, \
+{ CFG_ITEM_TYPE_ACCELKEY_LIST, EDV_CFG_PARM_IMBR_ACCELERATOR_KEYS, NULL }, \
+								\
+{ CFG_ITEM_TYPE_UINT8, EDV_CFG_PARM_PRESENTATION_SHOW_NAVIGATOR, NULL }, \
+{ CFG_ITEM_TYPE_STRING, EDV_CFG_PARM_PRESENTATION_FONT, NULL },	\
+{ CFG_ITEM_TYPE_COLOR, EDV_CFG_PARM_PRESENTATION_COLOR_FG, NULL }, \
+{ CFG_ITEM_TYPE_UINT8, EDV_CFG_PARM_PRESENTATION_COLOR_FG_INVERT, NULL }, \
+{ CFG_ITEM_TYPE_COLOR, EDV_CFG_PARM_PRESENTATION_COLOR_BG, NULL }, \
+{ CFG_ITEM_TYPE_INT32, EDV_CFG_PARM_PRESENTATION_HIDE_POINTER_DELAY, NULL }, \
+{ CFG_ITEM_TYPE_UINT8, EDV_CFG_PARM_PRESENTATION_SLIDESHOW, NULL }, \
+{ CFG_ITEM_TYPE_INT32, EDV_CFG_PARM_PRESENTATION_SLIDESHOW_DELAY, NULL }, \
 								\
 { CFG_ITEM_TYPE_INT32, EDV_CFG_PARM_RECBIN_X, NULL },		\
 { CFG_ITEM_TYPE_INT32, EDV_CFG_PARM_RECBIN_Y, NULL },		\
@@ -430,6 +458,7 @@
 { CFG_ITEM_TYPE_UINT8, EDV_CFG_PARM_RECBIN_CONTENTS_HIDE_LINK_PERMISSIONS, NULL }, \
 { CFG_ITEM_TYPE_INTLIST, EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN, NULL }, \
 { CFG_ITEM_TYPE_INTLIST, EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN_WIDTH, NULL }, \
+{ CFG_ITEM_TYPE_ACCELKEY_LIST, EDV_CFG_PARM_RECBIN_ACCELERATOR_KEYS, NULL }, \
 								\
 { CFG_ITEM_TYPE_INT32, EDV_CFG_PARM_ARCHIVER_X, NULL },		\
 { CFG_ITEM_TYPE_INT32, EDV_CFG_PARM_ARCHIVER_Y, NULL },		\
@@ -450,6 +479,7 @@
 { CFG_ITEM_TYPE_UINT8, EDV_CFG_PARM_ARCHIVER_CONTENTS_HIDE_LINK_PERMISSIONS, NULL }, \
 { CFG_ITEM_TYPE_INTLIST, EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN, NULL }, \
 { CFG_ITEM_TYPE_INTLIST, EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN_WIDTH, NULL }, \
+{ CFG_ITEM_TYPE_ACCELKEY_LIST, EDV_CFG_PARM_ARCHIVER_ACCELERATOR_KEYS, NULL }, \
 								\
 { CFG_ITEM_TYPE_INT32, EDV_CFG_PARM_FINDWIN_X, NULL },		\
 { CFG_ITEM_TYPE_INT32, EDV_CFG_PARM_FINDWIN_Y, NULL },		\
@@ -469,6 +499,7 @@
 /* Last item must be all 0's. */				\
 { CFG_ITEM_TYPE_NONE, NULL, NULL }				\
 }
+#endif
 
 
 /*
@@ -485,6 +516,7 @@
 #define EDV_GET_S(_parm_)	(CFGItemListGetValueS(cfg_list, (_parm_)))
 #define EDV_GET_COLOR(_parm_)	(CFGItemListGetValueColor(cfg_list, (_parm_)))
 #define EDV_GET_INTLIST(_parm_)	(CFGItemListGetValueIntList(cfg_list, (_parm_)))
+#define EDV_GET_ACCELKEY_LIST(_parm_) (CFGItemListGetValueAccelkeyList(cfg_list, (_parm_)))
 #define EDV_GET_STYLE(_parm_)	(CFGItemListGetValueStyle(cfg_list, (_parm_)))
 
 /*
@@ -517,6 +549,9 @@
 #define EDV_SET_INTLIST(_parm_,_v_)	(CFGItemListSetValueIntList( \
  cfg_list, (_parm_), (_v_), (FALSE) \
 ))
+#define EDV_SET_ACCELKEY_LIST(_parm_,_v_) (CFGItemListSetValueAccelkeyList( \
+ cfg_list, (_parm_), (_v_), (FALSE) \
+))
 #define EDV_SET_STYLE(_parm_,_v_)	(CFGItemListSetValueStyle( \
  cfg_list, (_parm_), (_v_), (FALSE) \
 ))
