@@ -1,7 +1,10 @@
 #include <string.h>
+#include <sys/stat.h>
 #include <glib.h>
+
 #include "../../include/string.h"
 #include "../../include/disk.h"
+
 #include "cfg.h"
 #include "../cfgfio.h"
 #include "../edvinterps.h"
@@ -11,6 +14,8 @@
 #include "edvmimetypesfio.h"
 #include "edvcontext.h"
 #include "edvnotify.h"
+
+#define NEED_EDV_CFG_LIST_SOURCE
 #include "edvcfglist.h"
 #include "config.h"
 
@@ -222,7 +227,7 @@ void EDVContextLoadConfigurationFile(
 	     *
 	     * $HOME/EDV_DEF_LOCAL_DATA_DIR/EDV_DEF_CONFIG_FILE
 	     */
-	    const gchar *home = g_getenv("HOME");
+	    const gchar *home = g_getenv(ENV_VAR_NAME_HOME);
 	    cfg_file = g_strdup_printf(
 		"%s%c%s%c%s",
 		(home != NULL) ? home : "/", G_DIR_SEPARATOR,
