@@ -1,6 +1,6 @@
 #include <limits.h>
-#include <unistd.h>
 #include <glib.h>
+#include <unistd.h>
 #include "edvcontext.h"
 #include "edvutils.h"
 #include "edvopen.h"
@@ -44,16 +44,15 @@ void EDVOpen(
 	const gchar *path, const gchar *command_name
 )
 {
-	gchar *cmd, *dpath;
-	gchar cwd[PATH_MAX];
+	gchar *cwd, *cmd, *dpath;
 
 	if((ctx == NULL) || STRISEMPTY(path))
 	    return;
 
-	/* Get copy of evaluated input path */
-	dpath = EDVCopyEvaluateInputPath(
-	    getcwd(cwd, sizeof(cwd)), path
-	);
+	cwd = EDVGetCWD();
+
+	/* Get evaluate the specified path */
+	dpath = EDVEvaluatePath(cwd, path);
 
 	/* Format command */
 	if(!STRISEMPTY(command_name))
@@ -70,4 +69,5 @@ void EDVOpen(
 
 	g_free(cmd);
 	g_free(dpath);
+	g_free(cwd);
 }
