@@ -1,10 +1,13 @@
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 #include <glib.h>
+#include <unistd.h>
+
 #include "../../include/disk.h"
 #include "../../include/prochandle.h"
+
 #include "../edvinterps.h"
+#include "edvutils.h"
 #include "edvcontext.h"
 #include "edvwindow.h"
 #include "config.h"
@@ -82,25 +85,17 @@ static gchar *EDVWindowCopyCompletePath(const gchar *path)
 	/* Home prefix? */
 	if(*path == '~')
 	{
-	    const gchar *home = getenv("HOME");
+	    const gchar *home = g_getenv(ENV_VAR_NAME_HOME);
 	    if(home == NULL)
 		home = "/";
-	    return(g_strdup_printf(
-		"%s%s",
-		home,
-		path + 1
-	    ));
+	    return(g_strconcat(home, path + 1, NULL));
 	}
 	else
 	{
-	    gchar cwd[PATH_MAX];
-	    if(getcwd(cwd, sizeof(cwd)) != NULL)
-		cwd[sizeof(cwd) - 1] = '\0';
-	    else
-		strncpy(cwd, "/", sizeof(cwd));
-	    return(STRDUP(
-		PrefixPaths(cwd, path)
-	    ));
+	    gchar	*cwd = EDVGetCWD(),
+			*dpath = STRDUP(PrefixPaths(cwd, path));
+	    g_free(cwd);
+	    return(dpath);
 	}
 }
 
