@@ -1,9 +1,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#include <unistd.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
+#include <unistd.h>
 
 #include "../include/string.h"
 
@@ -21,6 +21,7 @@
 #include "edvutils.h"
 #include "edvutilsgtk.h"
 #include "config.h"
+#include "edvcfglist.h"
 
 #include "images/icon_ok_20x20.xpm"
 #include "images/icon_select_20x20.xpm"
@@ -648,6 +649,44 @@ static void EDVMimeTypesEditWinECListRowAddedCB(
 	gpointer data
 )
 {
+	const gchar *name, *cmd;
+	const cfg_item_struct *cfg_list;
+	edv_core_struct *core_ptr;
+	edv_mimetype_editwin_struct *ew = EDV_MIMETYPE_EDITWIN(data);
+	if(ew == NULL)                                               
+	    return;
+
+	if(ew->freeze_count > 0)
+	    return;
+
+	core_ptr = EDV_CORE(ew->core_ptr);
+	if(core_ptr == NULL)
+	    return;
+
+	cfg_list = core_ptr->cfg_list;
+
+	ew->freeze_count++;
+
+	/* Set default values for the new row */
+	switch(row)
+	{
+	  case 0:
+	    name = "default";
+	    break;
+	  case 1:
+	    name = "edit";
+	    break;
+	  default:
+	    name = "other";
+	    break;
+	}
+	cmd = EDV_GET_S(EDV_CFG_PARM_PROG_DEF_VIEWER);
+
+	EditCListSetCellText(eclist, row, 0, name);
+	EditCListSetCellText(eclist, row, 1, cmd);
+
+	ew->freeze_count--;
+
 	EDVMimeTypesEditWinAnyChangedCB(
 	    EDITCLIST_CLIST(eclist), data
 	);
