@@ -2946,7 +2946,7 @@ edv_mimetype_listwin_struct *EDVMimeTypesListWinNew(
 	parent3 = w;
 
 	/* Vbox for add, edit, and remove set of buttons */
-	w = gtk_vbox_new(FALSE, 2 * border_minor);
+	w = gtk_vbox_new(FALSE, border_minor);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
@@ -3159,7 +3159,7 @@ edv_mimetype_listwin_struct *EDVMimeTypesListWinNew(
 	);
 
 	/* Vbox for Save, Import, and Export Buttons */
-	w = gtk_vbox_new(FALSE, 2 * border_minor);
+	w = gtk_vbox_new(FALSE, border_minor);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
