@@ -7,6 +7,7 @@
 #include "fsd.h"
 #include "styleedit.h"
 #include "stacklist.h"
+#include "keymaplist.h"
 
 #include "optwin.h"
 #include "optwinop.h"
@@ -42,6 +43,10 @@ static void OptWinStyleEditChangedCB(
 static void OptWinStackListChangedCB(
 	stack_list_struct *slist, gpointer data
 );
+static void OptWinKeymapListChangedCB(
+	keymap_list_struct *kmlist, gpointer data
+);
+
 
 /* Widget References */
 optwin_wref_struct *OptWinWRefNew(
@@ -60,6 +65,9 @@ void OptWinWRefSetStyleEdit(
 void OptWinWRefSetStackList(
 	optwin_wref_struct *wref, stack_list_struct *slist
 );
+void OptWinWRefSetKeymapList(
+	optwin_wref_struct *wref, keymap_list_struct *kmlist
+);
 optwin_wref_struct *OptWinWRefAppend(
 	optwin_struct *optwin,
 	GtkWidget *w,
@@ -283,6 +291,12 @@ static void OptWinStackListChangedCB(
 {
 	OptWinAnyChangedCB(NULL, data);
 }
+static void OptWinKeymapListChangedCB(
+	keymap_list_struct *kmlist, gpointer data
+)
+{
+	OptWinAnyChangedCB(NULL, data);
+}
 
 
 /*
@@ -310,6 +324,7 @@ optwin_wref_struct *OptWinWRefNew(
 
 	wref->radio_value = 0;
 	wref->slist = NULL;
+	wref->kmlist = NULL;
 
 	return(wref);
 }
@@ -331,6 +346,8 @@ void OptWinWRefDelete(optwin_wref_struct *wref)
 
 	StackListDelete(wref->slist);
 
+	KeymapListDelete(wref->kmlist);
+
 	g_free(wref->cfg_parm);
 
 	g_free(wref);
@@ -402,6 +419,29 @@ void OptWinWRefSetStackList(
 	}
 }
 
+/*
+ *	Sets the Widget Reference to the Keymap List.
+ */
+void OptWinWRefSetKeymapList(
+	optwin_wref_struct *wref, keymap_list_struct *kmlist
+)
+{
+	if(wref == NULL)
+	    return;
+
+	wref->kmlist = kmlist;
+
+	if(kmlist != NULL)
+	{
+	    KeymapListSetChangedCB(
+		kmlist,
+		OptWinKeymapListChangedCB,
+		wref
+	    );
+	}     
+}
+
+
 /*
  *	Appends a new Widget Reference to the Options Window.
  *	the new wref structure.
@@ -470,6 +510,7 @@ optwin_wref_struct *OptWinWRefAppend(
 			GTK_SIGNAL_FUNC(optwin_change_cb), data
 		    );
 		}
+#if 0
 		else if(GTK_IS_CHECK_MENU_ITEM(w))
 		{
 		    sig_id = gtk_signal_connect(
@@ -477,6 +518,7 @@ optwin_wref_struct *OptWinWRefAppend(
 			GTK_SIGNAL_FUNC(optwin_change_cb), data
 		    );
 		}
+#endif
 		else if(GTK_IS_MENU_ITEM(w))
 		{
 		    sig_id = gtk_signal_connect(
@@ -516,7 +558,6 @@ optwin_wref_struct *OptWinWRefAppend(
 #endif
 		}
 	    }
-#undef optwin_change_cb
 	}
 
 	return(wref);
