@@ -8,16 +8,21 @@
 #include <gtk/gtk.h>
 #include "styleedit.h"
 #include "stacklist.h"
+#include "keymaplist.h"
 #include "edvtypes.h"
 
 
+typedef struct _optwin_struct		optwin_struct;
+typedef struct _optwin_wref_struct	optwin_wref_struct;
+
+
 /*
- *	Widget Reference structure:
+ *	Widget Reference:
  *
  *	References a widget on the Options Window to a configuration
  *	parameter cfg_parm.
  */
-typedef struct {
+struct _optwin_wref_struct {
 
 	GtkWidget	*w;		/* Widget that holds the value */
 	GtkWidget	*browse;	/* Browse button */
@@ -41,13 +46,17 @@ typedef struct {
 	/* Stack List, used instead of w if not NULL */
 	stack_list_struct	*slist;
 
-} optwin_wref_struct;
+	/* Keymap List, used instead of w if not NULL */
+	keymap_list_struct	*kmlist;
+
+};
 #define OPTWIN_WREF(p)	((optwin_wref_struct *)(p))
 
+
 /*
  *	Options Window:
  */
-typedef struct {
+struct _optwin_struct {
 
 	GtkWidget       *toplevel;
 	GtkAccelGroup   *accelgrp;
@@ -74,7 +83,7 @@ typedef struct {
 	optwin_wref_struct	**wref;
 	gint			total_wrefs;
 
-} optwin_struct;
+};
 #define OPTWIN(p)	((optwin_struct *)(p))
 
 
@@ -95,6 +104,9 @@ extern void OptWinWRefSetStyleEdit(
 extern void OptWinWRefSetStackList(
 	optwin_wref_struct *wref, stack_list_struct *slist
 );
+extern void OptWinWRefSetKeymapList(
+	optwin_wref_struct *wref, keymap_list_struct *kmlist
+);
 extern optwin_wref_struct *OptWinWRefAppend(
 	optwin_struct *optwin,
 	GtkWidget *w,
