@@ -7,13 +7,16 @@
 #include "csd.h"
 #include "styleedit.h"
 #include "stacklist.h"
+#include "keymaplist.h"
 
 #include "cfg.h"
 #include "edvtypes.h"
 #include "optwin.h"
 #include "endeavour.h"
 #include "edvcb.h"
+
 #include "config.h"
+#include "edvcfglist.h"
 
 
 static void OptWinFetchWidgetValueFromCFG(
@@ -44,7 +47,7 @@ void OptWinDoApply(optwin_struct *optwin);
 
 /*
  *	Nexus for fetching a value from the configruation list to the
- *	given widget.
+ *	specified widget.
  */
 static void OptWinFetchWidgetValueFromCFG(
 	edv_core_struct *core_ptr, optwin_struct *optwin,
@@ -80,7 +83,7 @@ static void OptWinFetchWidgetValueFromCFG(
 	    w = wref->color_btn;
 	    if(cfg_type == CFG_ITEM_TYPE_COLOR)
 	    {
-		const cfg_color_struct *c = CFG_COLOR(cfg_item->value);
+		cfg_color_struct *c = CFG_COLOR(cfg_item->value);
 		if(c != NULL)
 		{
 		    csd_color_struct csd_color, *c2 = &csd_color;
@@ -101,7 +104,7 @@ static void OptWinFetchWidgetValueFromCFG(
 	    if(cfg_type == CFG_ITEM_TYPE_STYLE)
 	    {
 		style_edit_struct *se = wref->style_edit;
-		const cfg_style_struct *src_style = CFG_STYLE(
+		cfg_style_struct *src_style = CFG_STYLE(
 		    cfg_item->value
 		);
 		GtkRcStyle *tar_style = gtk_rc_style_new();
@@ -181,12 +184,14 @@ static void OptWinFetchWidgetValueFromCFG(
 	    FREEZE
 	    if(cfg_type == CFG_ITEM_TYPE_INTLIST)
 	    {
-		const cfg_intlist_struct *intlist = CFG_INTLIST(
+		cfg_intlist_struct *intlist = CFG_INTLIST(
 		    cfg_item->value
 		);
 		stack_list_struct *slist = wref->slist;
-		if((intlist != NULL) && (slist != NULL))
+		if(intlist != NULL)
 		{
+		    GList *glist;
+
 		    /* Update stack list's source list by deleting all
 		     * items in its source list and then adding all
 		     * items from its cache to its source list
@@ -198,9 +203,12 @@ static void OptWinFetchWidgetValueFromCFG(
 		     * specified in the intlist (except items that
 		     * allow multiple occurances)
 		     */
-		    for(i = 0; i < intlist->total; i++)
+		    for(glist = intlist->list;
+		        glist != NULL;
+		        glist = g_list_next(glist)
+		    )
 			StackListItemRemoveByIDSrc(
-			    slist, intlist->i[i],
+			    slist, (gint)glist->data,
 			    TRUE		/* Exclude allow_multiples */
 			);
 
@@ -209,15 +217,62 @@ static void OptWinFetchWidgetValueFromCFG(
 		     * the intlist
 		     */
 		    StackListItemClearTar(slist);
-		    for(i = 0; i < intlist->total; i++)
+		    for(glist = intlist->list;
+			glist != NULL;
+			glist = g_list_next(glist)
+		    )
 			StackListItemAppendTar(
-			    slist, intlist->i[i]
+			    slist, (gint)glist->data
 			);
 		}
 	    }
 	    THAW
 	    return;	/* Do not go on to regular widget handling */
 	}
+	/* Keymap List */
+	else if(wref->kmlist != NULL)
+	{
+	    FREEZE
+	    if(cfg_type == CFG_ITEM_TYPE_ACCELKEY_LIST)
+	    {
+		cfg_accelkey_struct *ak;
+		cfg_accelkey_list_struct *ak_list = CFG_ACCELKEY_LIST(
+		    cfg_item->value
+		);
+		keymap_list_struct *kmlist = wref->kmlist;
+		if(ak_list != NULL)
+		{
+		    gint row;
+		    GList *glist;
+		    keymap_key_struct *km;
+
+		    /* Iterate through Accelkey list and set them to
+		     * the Keymap List
+		     */
+		    for(glist = ak_list->list, row = 0;
+			glist != NULL;
+			glist = g_list_next(glist), row++
+		    )
+		    {
+			ak = CFG_ACCELKEY(glist->data);
+			if(ak == NULL)
+			    continue;
+
+			km = KeymapKeyNew(
+			    ak->key,			/* Keyval */
+			    ak->modifiers,		/* State */
+			    (gpointer)ak->opid		/* Data */
+			);
+			KeymapListSetKey(
+			    kmlist, row, km
+			);
+			KeymapKeyDelete(km);
+		    }
+		}
+	    }
+	    THAW
+	    return;	/* Do not go on to regular widget handling */
+	}
 
 
 	/* Standard widget handling, get widget that is to hold value */
@@ -234,23 +289,18 @@ static void OptWinFetchWidgetValueFromCFG(
 	    if(cfg_type == CFG_ITEM_TYPE_STRING)
 	    {
 		/* Select the GtkCList row who's cell text matches the
-		 * configuration value string
+		 * cfg value
 		 */
-		const gchar *s = CFGItemListGetValueS(
-		    cfg_list, cfg_parm
-		);
+		const gchar *s = EDV_GET_S(cfg_parm);
 		if(!STRISEMPTY(s) && (clist->columns > 0))
 		{
+		    const gint rows = clist->rows;
 		    gint row, column = 0;
 		    gchar *s2;
 		    guint8 spacing;
 		    GdkPixmap *pixmap;
 		    GdkBitmap *mask;
-
-		    /* Iterate through rows, searching for a cell who's
-		     * text matches the configuration value string
-		     */
-		    for(row = 0; row < clist->rows; row++)
+		    for(row = 0; row < rows; row++)
 		    {
 			switch(gtk_clist_get_cell_type(clist, row, column))
 			{
@@ -275,8 +325,7 @@ static void OptWinFetchWidgetValueFromCFG(
 			{
 			    if(!g_strcasecmp(s, s2))
 			    {
-				if(clist->selection != NULL)
-				    gtk_clist_unselect_all(clist);
+				gtk_clist_unselect_all(clist);
 				gtk_clist_select_row(clist, row, column);
 				break;
 			    }
@@ -284,17 +333,21 @@ static void OptWinFetchWidgetValueFromCFG(
 		    }
 		}
 	    }
-	    else
+	    else if((cfg_type == CFG_ITEM_TYPE_INT8) ||
+		    (cfg_type == CFG_ITEM_TYPE_UINT8) ||
+		    (cfg_type == CFG_ITEM_TYPE_INT16) ||
+		    (cfg_type == CFG_ITEM_TYPE_UINT16) ||
+		    (cfg_type == CFG_ITEM_TYPE_INT32) ||
+		    (cfg_type == CFG_ITEM_TYPE_UINT32)
+	    )
 	    {
-		/* Select the GtkCList row who's index is the 
-		 * configuration value
+		/* Select the GtkCList row who's index is the cfg
+		 * value
 		 */
-		gint valuei = CFGItemListGetValueI(
-		    cfg_list, cfg_parm
-		);
-		if(clist->selection != NULL)
-		    gtk_clist_unselect_all(clist);
-		if((valuei >= 0) && (valuei < clist->rows))
+		gint valuei = EDV_GET_I(cfg_parm);
+		const gint rows = clist->rows;
+		gtk_clist_unselect_all(clist);
+		if((valuei >= 0) && (valuei < rows))
 		    gtk_clist_select_row(clist, valuei, -1);
 	    }
 	    THAW
@@ -312,9 +365,7 @@ static void OptWinFetchWidgetValueFromCFG(
 	    }
 	    else
 	    {
-		gfloat valuef = CFGItemListGetValueF(
-		    cfg_list, cfg_parm
-		);
+		gfloat valuef = EDV_GET_F(cfg_parm);
 		gtk_spin_button_set_value(spin_button, valuef);
 	    }
 	    THAW
@@ -340,14 +391,11 @@ static void OptWinFetchWidgetValueFromCFG(
 		 * string value of the GtkCombo's list item index
 		 * specified by the configuration value
 		 */
-		gint i = CFGItemListGetValueI(
-		    cfg_list, cfg_parm
-		);
+		const gint i = EDV_GET_I(cfg_parm);
 		GList *glist = GUIComboGetList(w);
 		if(glist != NULL)
 		{
 		    const gchar *s;
-
 		    glist = g_list_nth(glist, i);
 		    s = (const gchar *)((glist != NULL) ?
 			glist->data : NULL
@@ -385,9 +433,7 @@ static void OptWinFetchWidgetValueFromCFG(
 		    g_snprintf(
 			num_str, sizeof(num_str),
 			"%i",
-			CFGItemListGetValueI(
-			    cfg_list, cfg_parm
-			)
+			EDV_GET_I(cfg_parm)
 		    );
 		    break;
 
@@ -396,9 +442,7 @@ static void OptWinFetchWidgetValueFromCFG(
 		    g_snprintf(
 			num_str, sizeof(num_str),
 			"%ld",
-			CFGItemListGetValueL(
-			    cfg_list, cfg_parm
-			)
+			EDV_GET_L(cfg_parm)
 		    );
 		    break;
 
@@ -406,9 +450,7 @@ static void OptWinFetchWidgetValueFromCFG(
 		    g_snprintf(
 			num_str, sizeof(num_str),
 			"%f",
-			CFGItemListGetValueF(
-			    cfg_list, cfg_parm
-			)
+			EDV_GET_F(cfg_parm)
 		    );
 		    break;
 
@@ -416,9 +458,7 @@ static void OptWinFetchWidgetValueFromCFG(
 		    g_snprintf(
 			num_str, sizeof(num_str),
 			"%f",
-			CFGItemListGetValueD(
-			    cfg_list, cfg_parm
-			)
+			EDV_GET_D(cfg_parm)
 		    );
 		    break;
 		}
@@ -426,16 +466,6 @@ static void OptWinFetchWidgetValueFromCFG(
 	    }
 	    THAW
 	}
-	else if(GTK_IS_CHECK_MENU_ITEM(w))
-	{
-	    gboolean valueb;
-	    GtkCheckMenuItem *check = GTK_CHECK_MENU_ITEM(w);
-
-	    FREEZE
-	    valueb = (gboolean)CFGItemListGetValueI(cfg_list, cfg_parm);
-	    check->active = (valueb) ? TRUE : FALSE;
-	    THAW
-	}
 	else if(GTK_IS_RADIO_BUTTON(w))
 	{
 	    /* Set this GtkRadioButton active if the Widget Reference's
@@ -445,7 +475,7 @@ static void OptWinFetchWidgetValueFromCFG(
 	    GtkToggleButton *toggle_button = GTK_TOGGLE_BUTTON(w);
 
 	    FREEZE
-	    valuei = CFGItemListGetValueI(cfg_list, cfg_parm);
+	    valuei = EDV_GET_I(cfg_parm);
 	    if(valuei == wref->radio_value)
 		toggle_button->active = TRUE;
 	    else
@@ -458,9 +488,7 @@ static void OptWinFetchWidgetValueFromCFG(
 	    GtkToggleButton *toggle_button = GTK_TOGGLE_BUTTON(w);
 
 	    FREEZE
-	    valueb = (gboolean)CFGItemListGetValueI(
-		cfg_list, cfg_parm
-	    );
+	    valueb = EDV_GET_B(cfg_parm);
 	    toggle_button->active = valueb ? TRUE : FALSE;
 	    THAW
 	}
@@ -471,7 +499,7 @@ static void OptWinFetchWidgetValueFromCFG(
 	    GtkAdjustment *adj = range->adjustment;
 
 	    FREEZE
-	    valuef = CFGItemListGetValueF(cfg_list, cfg_parm);
+	    valuef = EDV_GET_F(cfg_parm);
 	    if(adj != NULL)
 	    {
 		if(valuef > (adj->upper - adj->page_size))
@@ -550,10 +578,7 @@ static void OptWinSetWidgetValueToCFG(
 		    c_src->b,
 		    c_src->a
 		);
-		CFGItemListSetValueColor(
-		    cfg_list, cfg_parm,
-		    c_tar, FALSE
-		);
+		EDV_SET_COLOR(cfg_parm, c_tar);
 		CFGColorDelete(c_tar);
 	    }
 	    return;	/* Do not go on to regular widget handling */
@@ -631,10 +656,7 @@ static void OptWinSetWidgetValueToCFG(
 		    }
 
 		    /* Set target style to cfg item */
-		    CFGItemListSetValueStyle(
-			cfg_list, cfg_parm,
-			tar_style, FALSE
-		    );
+		    EDV_SET_STYLE(cfg_parm, tar_style);
 
 #undef STRDUP2
 		}
@@ -649,9 +671,9 @@ static void OptWinSetWidgetValueToCFG(
 	{
 	    if(cfg_type == CFG_ITEM_TYPE_INTLIST)
 	    {
-		cfg_intlist_struct *intlist = CFGIntListNew(NULL, 0);
+		cfg_intlist_struct *intlist = CFGIntListNew(NULL);
 		stack_list_struct *slist = wref->slist;
-		if((intlist != NULL) && (slist != NULL))
+		if(intlist != NULL)
 		{
 		    /* Get the target list's list of IDs and add each
 		     * ID to the intlist
@@ -660,43 +682,71 @@ static void OptWinSetWidgetValueToCFG(
 		    gint *id = StackListItemGetTar(slist, &nids);
 		    if(id != NULL)
 		    {
-			intlist->total = nids;
-			if(nids > 0)
-			{
-			    intlist->i = (gint *)g_malloc(
-				nids * sizeof(gint)
+			gint i;
+
+			/* Add ids to the new intlist */
+			for(i = 0; i < nids; i++)
+			    intlist->list = g_list_append(
+				intlist->list,
+				(gpointer)id[i]
 			    );
-			    if(intlist->i != NULL)
-				memcpy(
-				    intlist->i, id,
-				    nids * sizeof(gint)
-				);
-			    else
-				intlist->total = 0;
-			}
-			else
-			{
-			    intlist->i = NULL;
-			    intlist->total = 0;
-			}
 
 			/* Delete target list ids */
 			g_free(id);
 		    }
 
 		    /* Set/copy intlist to cfg item */
-		    CFGItemListSetValueIntList(
-			cfg_list, cfg_parm,
-			intlist, FALSE
-		    );
+		    EDV_SET_INTLIST(cfg_parm, intlist);
 		}
 
-		/* Delete the Cfg Intlist */
 		CFGIntListDelete(intlist);
 	    }
 	    return;	/* Do not go on to regular widget handling */
 	}
+	/* Accelkey Edit List */
+	else if(wref->kmlist != NULL)
+	{
+	    if(cfg_type == CFG_ITEM_TYPE_ACCELKEY_LIST)
+	    {
+		gint row;
+		GList *glist = NULL;
+		cfg_accelkey_list_struct *ak_list;
+		keymap_key_struct *km;
+		keymap_list_struct *kmlist = wref->kmlist;
 
+		/* Iterate through each row on the Keymap List and
+		 * append/copy each key to the glist
+		 */
+		for(row = 0; TRUE; row++)
+		{
+		    km = KeymapListGet(kmlist, row);
+		    if(km == NULL)
+			break;
+
+		    glist = g_list_append(
+			glist,
+			CFGAccelkeyNew(
+			    (gint)km->data,	/* OPID */
+			    km->keyval,		/* Key */
+			    km->state		/* Modifiers */
+			)
+		    );
+		}
+
+		/* Create a new Accelkey List and then delete the glist
+		 * containing the Accelkeys
+		 */
+		ak_list = CFGAccelkeyListNew(glist);
+		g_list_foreach(glist, (GFunc)CFGAccelkeyDelete, NULL);
+		g_list_free(glist);
+
+		/* Set/copy the Accelkey List to cfg item */
+		EDV_SET_ACCELKEY_LIST(cfg_parm, ak_list);
+
+		CFGAccelkeyListDelete(ak_list);
+	    }
+	    return;	/* Do not go on to regular widget handling */
+	}
 
 
 	/* Standard widget handling, get widget that is to hold value */
@@ -717,12 +767,12 @@ static void OptWinSetWidgetValueToCFG(
 		const GList *glist = clist->selection_end;
 		if((glist != NULL) && (clist->columns > 0))
 		{
+		    const gint	row = (gint)glist->data,
+				column = 0;
 		    gchar *s;
 		    guint8 spacing;
 		    GdkPixmap *pixmap;
 		    GdkBitmap *mask;
-		    gint	row = (gint)glist->data,
-				column = 0;
 
 		    switch(gtk_clist_get_cell_type(clist, row, column))
 		    {
@@ -744,23 +794,23 @@ static void OptWinSetWidgetValueToCFG(
 			break;
 		    }
 		    if(!STRISEMPTY(s))
-			CFGItemListSetValueS(
-			    cfg_list, cfg_parm,
-			    s, FALSE
-			);
+			EDV_SET_S(cfg_parm, s);
 		}
 	    }
-	    else
+	    else if((cfg_type == CFG_ITEM_TYPE_INT8) ||
+		    (cfg_type == CFG_ITEM_TYPE_UINT8) ||
+		    (cfg_type == CFG_ITEM_TYPE_INT16) ||
+		    (cfg_type == CFG_ITEM_TYPE_UINT16) ||
+		    (cfg_type == CFG_ITEM_TYPE_INT32) ||
+		    (cfg_type == CFG_ITEM_TYPE_UINT32)
+	    )
 	    {
 		/* Set configuration value as the selected row index */
 		const GList *glist = clist->selection_end;
 		if(glist != NULL)
 		{
-		    gint valuei = (gint)glist->data;
-		    CFGItemListSetValueI(
-			cfg_list, cfg_parm,
-			valuei, FALSE
-		    );
+		    const gint valuei = (gint)glist->data;
+		    EDV_SET_I(cfg_parm, valuei);
 		}
 	    }
 	}
@@ -772,10 +822,7 @@ static void OptWinSetWidgetValueToCFG(
 	    {
 		const gchar *values = gtk_entry_get_text(GTK_ENTRY(w));
 		if(values != NULL)
-		    CFGItemListSetValueS(
-			cfg_list, cfg_parm,
-			values, FALSE
-		    );
+		    EDV_SET_S(cfg_parm, values);
 	    }
 	    else
 	    {
@@ -784,20 +831,14 @@ static void OptWinSetWidgetValueToCFG(
 		    gfloat valuef = gtk_spin_button_get_value_as_float(
 			spin_button
 		    );
-		    CFGItemListSetValueF(
-			cfg_list, cfg_parm,
-			valuef, FALSE
-		    );
+		    EDV_SET_F(cfg_parm, valuef);
 		}
 		else
 		{
 		    gfloat valuei = gtk_spin_button_get_value_as_int(
 			spin_button
 		    );
-		    CFGItemListSetValueI(
-			cfg_list, cfg_parm,
-			valuei, FALSE
-		    );
+		    EDV_SET_I(cfg_parm, valuei);
 		}
 	    }
 	}
@@ -813,10 +854,7 @@ static void OptWinSetWidgetValueToCFG(
 		 */
 		const gchar *values = gtk_entry_get_text(entry);
 		if(values != NULL)
-		    CFGItemListSetValueS(
-			cfg_list, cfg_parm,
-			values, FALSE
-		    );
+		    EDV_SET_S(cfg_parm, values);
 	    }
 	    else
 	    {
@@ -842,10 +880,7 @@ static void OptWinSetWidgetValueToCFG(
 			glist = g_list_next(glist);
 		    }
 		    if(glist != NULL)
-			CFGItemListSetValueI(
-			    cfg_list, cfg_parm,
-			    valuei, FALSE
-			);
+			EDV_SET_I(cfg_parm, valuei);
 		}
 	    }
 	}
@@ -857,10 +892,7 @@ static void OptWinSetWidgetValueToCFG(
 	    {
 		const gchar *values = gtk_entry_get_text(entry);
 		if(values != NULL)
-		    CFGItemListSetValueS(
-			cfg_list, cfg_parm,
-			values, FALSE
-		    );
+		    EDV_SET_S(cfg_parm, values);
 	    }
 	    else
 	    {
@@ -869,42 +901,23 @@ static void OptWinSetWidgetValueToCFG(
 		{
 		    /* Decimal in the string? */
 		    if(strchr(values, '.'))
-			CFGItemListSetValueF(
-			    cfg_list, cfg_parm,
-			    ATOF(values), FALSE
-			);
+			EDV_SET_F(cfg_parm, ATOF(values));
 		    else
-			CFGItemListSetValueI(
-			    cfg_list, cfg_parm,
-			    ATOI(values), FALSE
-			);
+			EDV_SET_I(cfg_parm, ATOI(values));
 		}
 	    }
 	}
-	else if(GTK_IS_CHECK_MENU_ITEM(w))
-	{
-	    CFGItemListSetValueI(
-		cfg_list, cfg_parm,
-		GTK_CHECK_MENU_ITEM_GET_ACTIVE(w), FALSE
-	    );
-	}
 	else if(GTK_IS_RADIO_BUTTON(w))
 	{
 	    /* Set the configuration value to the Widget Reference's
 	     * specified radio_value if this GtkRadioButton is active
 	     */
 	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(w))
-		CFGItemListSetValueI(
-		    cfg_list, cfg_parm,
-		    wref->radio_value, FALSE
-		);
+		EDV_SET_I(cfg_parm, wref->radio_value);
 	}
 	else if(GTK_IS_TOGGLE_BUTTON(w))
 	{
-	    CFGItemListSetValueI(
-		cfg_list, cfg_parm,
-		GTK_TOGGLE_BUTTON_GET_ACTIVE(w), FALSE
-	    );
+	    EDV_SET_I(cfg_parm, GTK_TOGGLE_BUTTON_GET_ACTIVE(w));
 	}
 	else if(GTK_IS_RANGE(w))
 	{
@@ -914,16 +927,10 @@ static void OptWinSetWidgetValueToCFG(
 	    {
 	      case CFG_ITEM_TYPE_FLOAT:
 	      case CFG_ITEM_TYPE_DOUBLE:
-		CFGItemListSetValueF(
-		    cfg_list, cfg_parm,
-		    adj->value, FALSE
-		);
+		EDV_SET_F(cfg_parm, adj->value);
 		break;
 	      default:
-		CFGItemListSetValueI(
-		    cfg_list, cfg_parm,
-		    (gint)adj->value, FALSE
-		);
+		EDV_SET_I(cfg_parm, (gint)adj->value);
 		break;
 	    }
 	}
