@@ -9,7 +9,7 @@
 #include "cfg.h"
 #include "edvtypes.h"
 #include "edvlistcb.h"
-#include "edvstatusbar.h"
+#include "statusbar.h"
 #include "recbin.h"
 #include "recbincb.h"
 #include "recbinopcb.h"
@@ -58,7 +58,7 @@
 
 
 /* Utilities */
-static edv_recbin_opid_struct *EDVRecBinMatchOPID(
+edv_recbin_opid_struct *EDVRecBinMatchOPID(
 	edv_recbin_struct *recbin, edv_recbin_op op
 );
 
@@ -66,22 +66,21 @@ static edv_recbin_opid_struct *EDVRecBinMatchOPID(
 void EDVRecBinSetTitle(edv_recbin_struct *recbin);
 
 /* Regenerate Style, Menus, and Tool Bar */
-void EDVRecBinToolbarRegenerate(edv_recbin_struct *recbin);
+void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin);
+void EDVRecBinToolBarRegenerate(edv_recbin_struct *recbin);
 void EDVRecBinContentsMenuRegenerate(edv_recbin_struct *recbin);
 
 /* Sync Configuration */
 void EDVRecBinSyncConfiguration(edv_recbin_struct *recbin);
 
 /* Operation IDs */
-edv_recbin_opid_struct **EDVRecBinOPIDListNew(
-	edv_recbin_struct *recbin,      /* Can be NULL */
-	gint *total
-);
-void EDVRecBinOPIDListDelete(
-	edv_recbin_opid_struct **list, gint total
-);
+GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin);
+void EDVRecBinOPIDListDelete(GList *glist);
 
-/* Basics */
+/* Accel Keys */
+cfg_accelkey_list_struct *EDVRecBinAccelkeysListNewDefault(void);
+
+/* Recycle Bin */
 static void EDVRecBinCreateMenuBar(
 	edv_recbin_struct *recbin, GtkWidget *parent
 );
@@ -115,20 +114,26 @@ void EDVRecBinDelete(edv_recbin_struct *recbin);
  *	Returns the Recycle Bin Operation ID that matches the given
  *	operation.
  */
-static edv_recbin_opid_struct *EDVRecBinMatchOPID(
+edv_recbin_opid_struct *EDVRecBinMatchOPID(
 	edv_recbin_struct *recbin, edv_recbin_op op
 )
 {
-	gint i;
+	GList *glist;
 	edv_recbin_opid_struct *opid;
 
 	if(recbin == NULL)
 	    return(NULL);
 
-	for(i = 0; i < recbin->total_opids; i++)
+	for(glist = recbin->opid_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
-	    opid = recbin->opid[i];
-	    if((opid != NULL) ? (opid->op == op) : FALSE)
+	    opid = EDV_RECBIN_OPID(glist->data);
+	    if(opid == NULL)
+		continue;
+
+	    if(opid->op == op)
 		return(opid);
 	}
 
@@ -183,12 +188,210 @@ void EDVRecBinSetTitle(edv_recbin_struct *recbin)
 }
 
 
+/*
+ *	Resets the Recycle Bin's accelkeys displayed on the widgets.
+ */
+void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin)
+{
+	GtkAccelGroup *accelgrp = NULL; 
+	cfg_accelkey_list_struct *ak_list;
+	const cfg_item_struct *cfg_list;
+	edv_core_struct *core_ptr;
+
+	if(recbin == NULL)
+	    return;
+		   
+	core_ptr = EDV_CORE(recbin->core_ptr);
+	if(core_ptr == NULL)
+	    return;
+
+	cfg_list = core_ptr->cfg_list;
+
+	ak_list = EDV_GET_ACCELKEY_LIST(EDV_CFG_PARM_RECBIN_ACCELERATOR_KEYS);
+	if(ak_list == NULL)                                                    
+	    return;
+
+#define UPDATE_ACCELKEY(_w_,_opid_)	{	\
+ if(((_w_) != NULL) && ((_opid_) > 0)) {	\
+  GList *glist;					\
+  cfg_accelkey_struct *ak;			\
+						\
+  for(glist = ak_list->list;			\
+      glist != NULL;				\
+      glist = g_list_next(glist)		\
+  ) {						\
+   ak = CFG_ACCELKEY(glist->data);		\
+   if(ak == NULL)				\
+    continue;					\
+						\
+   if(ak->opid == (gint)(_opid_)) {		\
+    GUIMenuItemSetAccelKey(			\
+     (_w_), accelgrp, ak->key, ak->modifiers	\
+    );						\
+    break;                                      \
+   }                                            \
+  }                                             \
+ }                                              \
+}
+
+	UPDATE_ACCELKEY(
+	    recbin->recover_mi,
+	    EDV_RECBIN_OP_RECOVER
+	);
+	UPDATE_ACCELKEY(
+	    recbin->purge_mi,
+	    EDV_RECBIN_OP_PURGE
+	);
+	UPDATE_ACCELKEY(
+	    recbin->purge_all_mi,
+	    EDV_RECBIN_OP_PURGE_ALL
+	);
+	UPDATE_ACCELKEY(
+	    recbin->sync_recycle_bin_mi,
+	    EDV_RECBIN_OP_SYNC_RECYCLE_BIN
+	);
+	UPDATE_ACCELKEY(
+	    recbin->sync_disks_mi,
+	    EDV_RECBIN_OP_SYNC_DISKS
+	);
+	UPDATE_ACCELKEY(
+	    recbin->history_mi,
+	    EDV_RECBIN_OP_HISTORY
+	);
+	UPDATE_ACCELKEY(
+	    recbin->run_mi,
+	    EDV_RECBIN_OP_RUN
+	);
+	UPDATE_ACCELKEY(
+	    recbin->close_mi,
+	    EDV_RECBIN_OP_CLOSE
+	);
+
+	UPDATE_ACCELKEY(
+	    recbin->edit_recover_mi,
+	    EDV_RECBIN_OP_RECOVER
+	);
+	UPDATE_ACCELKEY(
+	    recbin->edit_purge_mi,
+	    EDV_RECBIN_OP_PURGE
+	);
+	UPDATE_ACCELKEY(
+	    recbin->edit_purge_all_mi,
+	    EDV_RECBIN_OP_PURGE_ALL
+	);
+	UPDATE_ACCELKEY(
+	    recbin->select_all_mi,
+	    EDV_RECBIN_OP_SELECT_ALL
+	);
+	UPDATE_ACCELKEY(
+	    recbin->unselect_all_mi,
+	    EDV_RECBIN_OP_UNSELECT_ALL
+	);
+	UPDATE_ACCELKEY(
+	    recbin->invert_selection_mi,   
+	    EDV_RECBIN_OP_INVERT_SELECTION
+	);
+	UPDATE_ACCELKEY(
+	    recbin->find_mi,
+	    EDV_RECBIN_OP_FIND
+	);
+
+	UPDATE_ACCELKEY(
+	    recbin->refresh_mi,
+	    EDV_RECBIN_OP_REFRESH
+	);
+	UPDATE_ACCELKEY(
+	    recbin->refresh_all_mi,
+	    EDV_RECBIN_OP_REFRESH_ALL
+	);
+	UPDATE_ACCELKEY(
+	    recbin->show_tool_bar_micheck,
+	    EDV_RECBIN_OP_SHOW_TOOL_BAR
+	);
+	UPDATE_ACCELKEY(
+	    recbin->show_find_bar_micheck,
+	    EDV_RECBIN_OP_SHOW_FIND_BAR
+	);
+	UPDATE_ACCELKEY(
+	    recbin->show_status_bar_micheck,
+	    EDV_RECBIN_OP_SHOW_STATUS_BAR
+	);
+	UPDATE_ACCELKEY(
+	    recbin->mime_types_mi,
+	    EDV_RECBIN_OP_MIME_TYPES
+	);
+
+	UPDATE_ACCELKEY(
+	    recbin->write_protect_mi,
+	    EDV_RECBIN_OP_WRITE_PROTECT
+	);
+	UPDATE_ACCELKEY(
+	    recbin->options_mi,
+	    EDV_RECBIN_OP_OPTIONS
+	);
+	UPDATE_ACCELKEY(
+	    recbin->customize_mi,
+	    EDV_RECBIN_OP_CUSTOMIZE
+	);
+
+	UPDATE_ACCELKEY(
+	    recbin->window_new_browser_mi,
+	    EDV_RECBIN_OP_NEW_BROWSER
+	);
+	UPDATE_ACCELKEY(
+	    recbin->window_new_imbr_mi,
+	    EDV_RECBIN_OP_NEW_IMBR
+	);
+	UPDATE_ACCELKEY(
+	    recbin->window_new_archiver_mi,
+	    EDV_RECBIN_OP_NEW_ARCHIVER
+	);
+
+	UPDATE_ACCELKEY(
+	    recbin->help_contents_mi,
+	    EDV_RECBIN_OP_HELP_CONTENTS
+	);
+	UPDATE_ACCELKEY(
+	    recbin->help_recycle_bin_mi,
+	    EDV_RECBIN_OP_HELP_RECYCLE_BIN
+	);
+	UPDATE_ACCELKEY(
+	    recbin->help_keys_list_mi,
+	    EDV_RECBIN_OP_HELP_KEYS_LIST
+	);
+	UPDATE_ACCELKEY(
+	    recbin->help_common_operations_mi,
+	    EDV_RECBIN_OP_HELP_COMMON_OPERATIONS
+	);
+	UPDATE_ACCELKEY(
+	    recbin->help_about_mi,
+	    EDV_RECBIN_OP_HELP_ABOUT
+	);
+
+
+	UPDATE_ACCELKEY(
+	    recbin->contents_clist_recover_mi,
+	    EDV_RECBIN_OP_RECOVER
+	);
+	UPDATE_ACCELKEY(
+	    recbin->contents_clist_purge_mi,
+	    EDV_RECBIN_OP_PURGE
+	);
+	UPDATE_ACCELKEY(
+	    recbin->contents_clist_purge_all_mi,
+	    EDV_RECBIN_OP_PURGE_ALL
+	);
+
+#undef UPDATE_ACCELKEY
+}
+
 /*
  *	Recreates the Recycle Bin's Tool Bar.
  */
-void EDVRecBinToolbarRegenerate(edv_recbin_struct *recbin)
+void EDVRecBinToolBarRegenerate(edv_recbin_struct *recbin)
 {
 	gint i, total_items;
+	GList *glist;
 	toolbar_display tb_display;
 	toolbar_relief tb_relief;
 	GtkWidget *w, *parent;
@@ -225,7 +428,8 @@ void EDVRecBinToolbarRegenerate(edv_recbin_struct *recbin)
 	recbin->toolbar = NULL;
 
 	/* Create Tool Bar items list */
-	total_items = intlist->total;
+	glist = intlist->list;
+	total_items = g_list_length(glist);
 	if(total_items > 0)
 	{
 	    item = (toolbar_item_struct **)g_malloc0(
@@ -241,7 +445,13 @@ void EDVRecBinToolbarRegenerate(edv_recbin_struct *recbin)
 	for(i = 0; i < total_items; i++)
 	{
 	    /* Get Operation ID */
-	    opid = EDVRecBinMatchOPID(recbin, intlist->i[i]);
+	    opid = EDVRecBinMatchOPID(
+	 	recbin,
+		(edv_recbin_op)((glist != NULL) ?
+		    glist->data : NULL
+		)
+	    );
+	    glist = g_list_next(glist);    
 	    if(opid == NULL)
 		continue;
 
@@ -398,56 +608,38 @@ void EDVRecBinSyncConfiguration(edv_recbin_struct *recbin)
 /*
  *	Creates a new Recycle Bin Operation IDs list.
  */
-edv_recbin_opid_struct **EDVRecBinOPIDListNew(
-	edv_recbin_struct *recbin,      /* Can be NULL */
-	gint *total
-)
+GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 {
-	edv_recbin_op op;
-	gboolean allow_multiple;
-	toolbar_item_type tb_item_type;
 	const gchar *button_name, *menu_name, *tooltip;
 	guint accel_key, accel_mods;
 	guint8 **button_icon_data, **menu_icon_data;
-	edv_recbin_opid_struct **list, *opid;
+	GList *opid_list = NULL;
+	toolbar_item_type tb_item_type;
+	edv_opid_flags flags;
+	edv_recbin_op op;    
+	edv_recbin_opid_struct *opid;
 	void (*func_cb)(toolbar_item_struct *, gint, gpointer);
 	void (*enter_func_cb)(toolbar_item_struct *, gint, gpointer);
 
-	if(total == NULL)
-	    return(NULL);
-
-	*total = 0;
-	list = NULL;
-
 #define DO_APPEND_OPID	{			\
- const gint i = MAX(*total, 0);			\
- *total = i + 1;				\
- list = (edv_recbin_opid_struct **)g_realloc(	\
-  list,						\
-  (*total) * sizeof(edv_recbin_opid_struct *)	\
+ opid = EDV_RECBIN_OPID(			\
+  g_malloc0(sizeof(edv_recbin_opid_struct))	\
  );						\
- if(list == NULL) {				\
-  *total = 0;					\
-  return(list);					\
- } else {					\
-  list[i] = opid = EDV_RECBIN_OPID(		\
-   g_malloc0(sizeof(edv_recbin_opid_struct))	\
-  );						\
-  if(opid != NULL) {				\
-   opid->recbin = recbin;			\
-   opid->op = op;				\
-   opid->allow_multiple = allow_multiple;	\
-   opid->tb_item_type = tb_item_type;		\
-   opid->func_cb = func_cb;			\
-   opid->enter_func_cb = enter_func_cb;		\
-   opid->button_name = STRDUP(button_name);	\
-   opid->menu_name = STRDUP(menu_name);		\
-   opid->tooltip = STRDUP(tooltip);		\
-   opid->accel_key = accel_key;			\
-   opid->accel_mods = accel_mods;		\
-   opid->button_icon_data = button_icon_data;	\
-   opid->menu_icon_data = menu_icon_data;	\
-  }						\
+ if(opid != NULL) {				\
+  opid->op = op;				\
+  opid->flags = flags;				\
+  opid->tb_item_type = tb_item_type;		\
+  opid->func_cb = func_cb;			\
+  opid->enter_func_cb = enter_func_cb;		\
+  opid->button_name = STRDUP(button_name);	\
+  opid->menu_name = STRDUP(menu_name);		\
+  opid->tooltip = STRDUP(tooltip);		\
+  opid->accel_key = accel_key;			\
+  opid->accel_mods = accel_mods;		\
+  opid->button_icon_data = button_icon_data;	\
+  opid->menu_icon_data = menu_icon_data;	\
+  opid->recbin = recbin;			\
+  opid_list = g_list_append(opid_list, opid);	\
  }						\
 }
 
@@ -456,8 +648,8 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 
 	op = EDV_RECBIN_OP_SEPARATOR;
+	flags = EDV_OPID_ALLOW_MULTIPLE | EDV_OPID_NO_OP;
 	tb_item_type = TOOLBAR_ITEM_SEPARATOR;
-	allow_multiple = TRUE;
 	button_icon_data = (guint8 **)icon_hsep_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -499,8 +691,8 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 
 	op = EDV_RECBIN_OP_CLOSE;
+	flags = 0;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
 	button_icon_data = (guint8 **)icon_close_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -524,7 +716,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_EXIT;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_exit_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -547,33 +739,9 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 	DO_APPEND_OPID
 
 
-	op = EDV_RECBIN_OP_WRITE_PROTECT;
-	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
-	button_icon_data = (guint8 **)icon_secure_20x20_xpm;
-	menu_icon_data = button_icon_data;
-#ifdef PROG_LANGUAGE_ENGLISH
-	button_name = "Protect";
-	menu_name = "Write Protect";
-	tooltip = "Enable/disable write protect";
-#endif
-#ifdef PROG_LANGUAGE_SPANISH
-	button_name = "Proteja";
-	menu_name = "Escriba Proteja";
-	tooltip = "Habilite/incapacita escribe protege";
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-	button_name = "Protge";
-	menu_name = "Protge En criture";
-	tooltip = "Rend capable/rend infirme protge en criture";
-#endif
-	accel_key = GDK_y;
-	accel_mods = GDK_CONTROL_MASK;
-	DO_APPEND_OPID
-
 	op = EDV_RECBIN_OP_SYNC_DISKS;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_save_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -595,9 +763,33 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 	accel_mods = 0;
 	DO_APPEND_OPID
 
+	op = EDV_RECBIN_OP_HISTORY;
+	tb_item_type = TOOLBAR_ITEM_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_trace_20x20_xpm;
+	menu_icon_data = button_icon_data;
+#ifdef PROG_LANGUAGE_ENGLISH
+	button_name = "History";
+	menu_name = "History...";
+	tooltip = "History of commands processed by this application";
+#endif
+#ifdef PROG_LANGUAGE_SPANISH
+	button_name = "Historia";
+	menu_name = "La Historia...";
+	tooltip = "La Historia de rdenes procesadas por esta aplicacin";
+#endif
+#ifdef PROG_LANGUAGE_FRENCH
+	button_name = "L'Histoire";
+	menu_name = "L'Histoire...";
+	tooltip = "L'Histoire d'ordres traits par cette application";
+#endif
+	accel_key = 0;
+	accel_mods = 0;
+	DO_APPEND_OPID
+
 	op = EDV_RECBIN_OP_RUN;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_run_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -621,7 +813,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_RUN_TERMINAL;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_terminal_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -643,9 +835,33 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 	accel_mods = 0;
 	DO_APPEND_OPID
 
+	op = EDV_RECBIN_OP_WRITE_PROTECT;
+	tb_item_type = TOOLBAR_ITEM_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_secure_20x20_xpm;
+	menu_icon_data = button_icon_data;
+#ifdef PROG_LANGUAGE_ENGLISH
+	button_name = "Protect";
+	menu_name = "Write Protect";
+	tooltip = "Enable/disable write protect";
+#endif
+#ifdef PROG_LANGUAGE_SPANISH
+	button_name = "Proteja";
+	menu_name = "Escriba Proteja";
+	tooltip = "Habilite/incapacita escribe protege";
+#endif
+#ifdef PROG_LANGUAGE_FRENCH
+	button_name = "Protge";
+	menu_name = "Protge En criture";
+	tooltip = "Rend capable/rend infirme protge en criture";
+#endif
+	accel_key = GDK_y;
+	accel_mods = GDK_CONTROL_MASK;
+	DO_APPEND_OPID
+
 	op = EDV_RECBIN_OP_SYNC_RECYCLE_BIN;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_trash_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -685,9 +901,10 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 	accel_mods = 0;
 	DO_APPEND_OPID
 
+
 	op = EDV_RECBIN_OP_RECOVER;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_recover_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -711,7 +928,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_PURGE;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_purge_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -735,7 +952,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_PURGE_ALL;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_purge_all_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -757,9 +974,10 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 	accel_mods = GDK_SHIFT_MASK;
 	DO_APPEND_OPID
 
+
 	op = EDV_RECBIN_OP_SELECT_ALL;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_select_all_20x20_xpm;
 	menu_icon_data = NULL;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -783,7 +1001,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_UNSELECT_ALL;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_unselect_all_20x20_xpm;
 	menu_icon_data = NULL;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -807,7 +1025,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_INVERT_SELECTION;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_invert_selection_20x20_xpm;
 	menu_icon_data = NULL;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -834,7 +1052,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_FIND;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_search_20x20_xpm;;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -856,33 +1074,10 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 	accel_mods = GDK_CONTROL_MASK;
 	DO_APPEND_OPID
 
-	op = EDV_RECBIN_OP_HISTORY;
-	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
-	button_icon_data = (guint8 **)icon_trace_20x20_xpm;
-	menu_icon_data = button_icon_data;
-#ifdef PROG_LANGUAGE_ENGLISH
-	button_name = "History";
-	menu_name = "History...";
-	tooltip = "History of commands processed by this application";
-#endif
-#ifdef PROG_LANGUAGE_SPANISH
-	button_name = "Historia";
-	menu_name = "La Historia...";
-	tooltip = "La Historia de rdenes procesadas por esta aplicacin";
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-	button_name = "L'Histoire";
-	menu_name = "L'Histoire...";
-	tooltip = "L'Histoire d'ordres traits par cette application";
-#endif
-	accel_key = 0;
-	accel_mods = 0;
-	DO_APPEND_OPID
 
 	op = EDV_RECBIN_OP_REFRESH;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_reload_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -906,7 +1101,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_REFRESH_ALL;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_reload_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -930,7 +1125,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_SHOW_TOOL_BAR;
 	tb_item_type = TOOLBAR_ITEM_TOGGLE_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_tool_bar_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -954,7 +1149,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_SHOW_FIND_BAR;
 	tb_item_type = TOOLBAR_ITEM_TOGGLE_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_tool_bar_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -978,7 +1173,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_SHOW_STATUS_BAR;
 	tb_item_type = TOOLBAR_ITEM_TOGGLE_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_status_bar_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -1003,7 +1198,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_MIME_TYPES;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_mimetypes_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -1028,7 +1223,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_NEW_BROWSER;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)endeavour_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -1052,7 +1247,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_NEW_IMBR;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)image_browser_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -1076,7 +1271,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_NEW_ARCHIVER;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)archiver_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -1101,7 +1296,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_OPTIONS;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_options2_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -1125,7 +1320,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_CUSTOMIZE;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_customize_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -1150,7 +1345,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_HELP_CONTENTS;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_help_20x20_xpm;
 	menu_icon_data = NULL;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -1174,7 +1369,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_HELP_FILE_BROWSER;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_help_20x20_xpm;
 	menu_icon_data = NULL;
 	button_name = "Help";
@@ -1186,7 +1381,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_HELP_IMAGE_BROWSER;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_help_20x20_xpm;
 	menu_icon_data = NULL;
 	button_name = "Help";
@@ -1198,7 +1393,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_HELP_ARCHIVER;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_help_20x20_xpm;
 	menu_icon_data = NULL;
 	button_name = "Help";
@@ -1210,7 +1405,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_HELP_RECYCLE_BIN;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_help_20x20_xpm;
 	menu_icon_data = NULL;
 	button_name = "Help";
@@ -1222,7 +1417,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_HELP_KEYS_LIST;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_help_20x20_xpm;
 	menu_icon_data = NULL;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -1246,7 +1441,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_HELP_COMMON_OPERATIONS;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_help_20x20_xpm;
 	menu_icon_data = NULL;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -1270,7 +1465,7 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 
 	op = EDV_RECBIN_OP_HELP_ABOUT;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
-	allow_multiple = FALSE;
+	flags = 0;
 	button_icon_data = (guint8 **)icon_about_20x20_xpm;
 	menu_icon_data = (guint8 **)icon_about_20x20_xpm;
 #ifdef PROG_LANGUAGE_ENGLISH
@@ -1293,27 +1488,21 @@ edv_recbin_opid_struct **EDVRecBinOPIDListNew(
 	DO_APPEND_OPID
 
 
+	return(opid_list);
 #undef DO_APPEND_OPID
-
-	return(list);
 }
 
 /*
  *	Deletes the Recycle Bin Operation IDs list.
  */
-void EDVRecBinOPIDListDelete(
-	edv_recbin_opid_struct **list, gint total
-)
+void EDVRecBinOPIDListDelete(GList *glist)
 {
-	gint i;
+	GList *opid_list = glist;
 	edv_recbin_opid_struct *opid;
 
-	if(list == NULL)
-	    return;
-
-	for(i = 0; i < total; i++)
+	for(; glist != NULL; glist = g_list_next(glist))
 	{
-	    opid = list[i];
+	    opid = EDV_RECBIN_OPID(glist->data);
 	    if(opid == NULL)
 		continue;
 
@@ -1323,7 +1512,46 @@ void EDVRecBinOPIDListDelete(
 
 	    g_free(opid);
 	}
-	g_free(list);
+	g_list_free(opid_list);
+}
+
+
+/*
+ *	Creates a new Accel Key List with default values.
+ */
+cfg_accelkey_list_struct *EDVRecBinAccelkeysListNewDefault(void)
+{
+	GList *glist, *opid_list, *ak_glist = NULL;
+	cfg_accelkey_list_struct *ak_list;
+	edv_recbin_opid_struct *opid;
+
+	opid_list = EDVRecBinOPIDListNew(NULL);
+	for(glist = opid_list; glist != NULL; glist = g_list_next(glist))
+	{
+	    opid = EDV_RECBIN_OPID(glist->data);
+	    if(opid == NULL)
+		continue;
+
+	    if(opid->flags & EDV_OPID_NO_OP)
+		continue;
+
+	    ak_glist = g_list_append(
+		ak_glist,
+		CFGAccelkeyNew(
+		    (gint)opid->op,
+		    opid->accel_key,
+		    opid->accel_mods
+		)
+	    );
+	}
+	EDVRecBinOPIDListDelete(opid_list);
+
+	ak_list = CFGAccelkeyListNew(ak_glist);
+
+	g_list_foreach(ak_glist, (GFunc)CFGAccelkeyDelete, NULL);
+	g_list_free(ak_glist);
+
+	return(ak_list);
 }
 
 
@@ -1338,7 +1566,7 @@ static void EDVRecBinCreateMenuBar(
 {
 	guint8 **icon_data = NULL;
 	edv_recbin_op op;
-	GtkAccelGroup *accelgrp = recbin->accelgrp;
+	GtkAccelGroup *accelgrp = NULL;
 	GtkWidget *w, *menu, *menu_bar;
 
 	/* Create Menu Bar */
@@ -1727,13 +1955,12 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 			find_bar_map_state = TRUE,
 			status_bar_map_state = TRUE;
 	gint i;
-	edv_status_bar_struct *status_bar;
+	edv_statusbar_struct *status_bar;
 	const gchar	*wm_name = NULL,
 			*wm_class = NULL;
 	const cfg_item_struct *cfg_list = (core_ptr != NULL) ?
 	    EDV_CORE(core_ptr)->cfg_list : NULL;
 	GdkWindow *window;
-	GtkAccelGroup *accelgrp;
 	GtkRcStyle	*standard_rcstyle = NULL,
 			*lists_rcstyle = NULL;
 	GtkStyle *style;
@@ -1786,15 +2013,12 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 	    status_bar_map_state = EDV_GET_B(EDV_CFG_PARM_RECBIN_SHOW_STATUS_BAR);
 	}
 
-	recbin->accelgrp = accelgrp = gtk_accel_group_new();
 	recbin->processing = FALSE;
 	recbin->busy_count = 0;
 	recbin->freeze_count = 0;
 	recbin->core_ptr = core_ptr;
 
-	recbin->opid = EDVRecBinOPIDListNew(
-	    recbin, &recbin->total_opids
-	);
+	recbin->opid_list = EDVRecBinOPIDListNew(recbin);
 
 	recbin->tool_bar_map_state = tool_bar_map_state;
 	recbin->find_bar_map_state = find_bar_map_state;
@@ -1845,11 +2069,22 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 		GDK_HINT_RESIZE_INC
 	    );
 	}
+	gtk_widget_add_events(
+	    w,
+	    GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK
+	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "delete_event",
 	    GTK_SIGNAL_FUNC(EDVRecBinDeleteEventCB), recbin
 	);
-	gtk_window_add_accel_group(GTK_WINDOW(w), accelgrp);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "key_press_event",
+	    GTK_SIGNAL_FUNC(EDVRecBinKeyEventCB), recbin
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "key_release_event",
+	    GTK_SIGNAL_FUNC(EDVRecBinKeyEventCB), recbin
+	);
 	style = gtk_widget_get_style(w);
 	parent = w;
 
@@ -1901,8 +2136,7 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 	recbin->toolbar = NULL;
 
 
-
-	/* Find bar handle box */
+	/* GtkHandleBox for the Find Bar */
 	recbin->find_bar_handle = w = gtk_handle_box_new();
 	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "child_attached",
@@ -1917,16 +2151,16 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 	    gtk_widget_show(w);
 	parent2 = w;
 
-	/* Create find bar */
+	/* Create the Find Bar */
 	recbin->findbar = EDVFindBarNew(
 	    core_ptr, parent2,
 	    EDV_FINDBAR_ROLE_RECYCLED_OBJECT,
-	    EDVRecBinBarStatusMessageCB,
-	    EDVRecBinBarStatusProgressCB,
 	    NULL,
 	    EDVRecBinFindBarStartCB,
 	    EDVRecBinFindBarEndCB,
 	    EDVRecBinFindBarMatchCB,
+	    EDVRecBinStatusMessageCB,
+	    EDVRecBinStatusProgressCB,
 	    recbin
 	);
 	EDVFindBarMap(recbin->findbar);
@@ -2041,14 +2275,14 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 
 
 
-	/* Create tool bar */
-	EDVRecBinToolbarRegenerate(recbin);
+	/* Create the Tool Bar */
+	EDVRecBinToolBarRegenerate(recbin);
 
-	/* Create contents clist menu */
+	/* Create the Contents List Menu */
 	EDVRecBinContentsMenuRegenerate(recbin);
 
 
-	/* Create status bar */
+	/* Create the Status Bar */
 	recbin->status_bar = status_bar = EDVStatusBarNew(
 	    core_ptr, recbin->main_vbox
 	);
@@ -2078,6 +2312,7 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 
 	/* Reset values */
 	EDVRecBinSetTitle(recbin);
+	EDVRecBinAccelkeysRegenerate(recbin);
 	EDVRecBinUpdateMenus(recbin);
 
 	return(recbin);
@@ -2132,10 +2367,8 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 { if(w != NULL) gtk_widget_show(w); }
 #define DO_HIDE			\
 { if(w != NULL) gtk_widget_hide(w); }
-#define DO_SET_CHECK_STATE	{	\
- if((w != NULL) ? GTK_IS_CHECK_MENU_ITEM(w) : FALSE) \
-  GTK_CHECK_MENU_ITEM(w)->active = state; \
-}
+#define DO_SET_CHECK_STATE	\
+{ GUIMenuItemSetCheck(w, state, FALSE); }
 
 	/* Get global write protect state */
 	write_protect = EDV_GET_B(EDV_CFG_PARM_WRITE_PROTECT);
@@ -2476,14 +2709,9 @@ void EDVRecBinDelete(edv_recbin_struct *recbin)
 	GTK_WIDGET_DESTROY(recbin->toplevel)
 	recbin->toplevel = NULL;
 
-	GTK_ACCEL_GROUP_UNREF(recbin->accelgrp)
-	recbin->accelgrp = NULL;
-
 
 	/* Delete all Operation IDs */
-	EDVRecBinOPIDListDelete(
-	    recbin->opid, recbin->total_opids
-	);
+	EDVRecBinOPIDListDelete(recbin->opid_list);
 
 	g_free(recbin);
 }
