@@ -6,10 +6,15 @@
 #define RECBIN_H
 
 #include <gtk/gtk.h>
+#include "cfg.h"
 #include "edvtypes.h"
-#include "edvstatusbar.h"
 #include "toolbar.h"
 #include "findbar.h"
+#include "statusbar.h"
+
+
+typedef struct _edv_recbin_struct		edv_recbin_struct;
+typedef struct _edv_recbin_opid_struct		edv_recbin_opid_struct;
 
 
 /*
@@ -94,15 +99,12 @@ typedef enum {
 /*
  *	Recycle Bin Operation ID:
  */
-typedef struct {
+struct _edv_recbin_opid_struct {
 
-	gpointer	recbin;
 	edv_recbin_op	op;
-	gboolean	allow_multiple;		/* Allow multiple instances
-						 * of this operation in
-						 * lists */
-	toolbar_item_type tb_item_type;		/* Type of item when placed
-						 * on the tool bar */
+	edv_opid_flags	flags;
+	toolbar_item_type	tb_item_type;
+	edv_recbin_struct	*recbin;
 
 	/* Operation callback */
 	void	(*func_cb)(
@@ -133,23 +135,21 @@ typedef struct {
 	guint8		**button_icon_data,	/* Shared */
 			**menu_icon_data;	/* Shared */
 
-} edv_recbin_opid_struct;
+};
 #define EDV_RECBIN_OPID(p)	((edv_recbin_opid_struct *)(p))
 
 /*
  *	Recycle Bin:
  */
-typedef struct {
+struct _edv_recbin_struct {
 
 	GtkWidget	*toplevel;
-	GtkAccelGroup	*accelgrp;
 	gboolean	processing;
 	gint		busy_count,
 			freeze_count;
 	gpointer	core_ptr;
 
-	edv_recbin_opid_struct	**opid;
-	gint			total_opids;
+	GList		*opid_list;
 
 	gboolean	tool_bar_map_state,
 			find_bar_map_state,
@@ -237,29 +237,31 @@ typedef struct {
 	gint		last_write_protect_state;
 
 
+	/* Status Bar */
+	edv_statusbar_struct	*status_bar;
 
-
-	/* Status bar */
-	edv_status_bar_struct	*status_bar;
-
-} edv_recbin_struct;
+};
 #define EDV_RECBIN(p)	((edv_recbin_struct *)(p))
 
 
+extern edv_recbin_opid_struct *EDVRecBinMatchOPID(
+	edv_recbin_struct *recbin, edv_recbin_op op
+);
+
 extern void EDVRecBinSetTitle(edv_recbin_struct *recbin);
 
-extern void EDVRecBinToolbarRegenerate(edv_recbin_struct *recbin);
+extern void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin);
+extern void EDVRecBinToolBarRegenerate(edv_recbin_struct *recbin);
 extern void EDVRecBinContentsMenuRegenerate(edv_recbin_struct *recbin);
 
 extern void EDVRecBinSyncConfiguration(edv_recbin_struct *recbin);
 
-extern edv_recbin_opid_struct **EDVRecBinOPIDListNew(
-	edv_recbin_struct *recbin,	/* Can be NULL */
-	gint *total
-);
-extern void EDVRecBinOPIDListDelete(
-	edv_recbin_opid_struct **list, gint total
+extern GList *EDVRecBinOPIDListNew(
+	edv_recbin_struct *recbin	/* Can be NULL */
 );
+extern void EDVRecBinOPIDListDelete(GList *glist);
+
+extern cfg_accelkey_list_struct *EDVRecBinAccelkeysListNewDefault(void);
 
 extern edv_recbin_struct *EDVRecBinNew(gpointer core_ptr);
 extern void EDVRecBinSyncData(edv_recbin_struct *recbin);
