@@ -14,7 +14,7 @@
 #include "cfg.h"
 #include "edvobj.h"
 #include "edvrecbin.h"
-#include "edvstatusbar.h"
+#include "statusbar.h"
 #include "recbin.h"
 #include "recbincb.h"
 #include "recbinopcb.h"
@@ -249,16 +249,19 @@ gint EDVRecBinDeleteEventCB(
 }
 
 /*
- *	Recycle Bin "key_press_event" or "key_release_event" signal callback.
+ *	Recycle Bin "key_press_event" or "key_release_event" signal
+ *	callback.
  */
 gint EDVRecBinKeyEventCB(
 	 GtkWidget *widget, GdkEventKey *key, gpointer data
 )
 {
 	gint status = FALSE;
+	gboolean is_press;
 	gint etype;
 	guint keyval, state;
-	gboolean press;
+	GtkWidget *w, *focus_widget;
+	const cfg_item_struct *cfg_list;
 	edv_core_struct *core_ptr;
 	edv_recbin_struct *recbin = EDV_RECBIN(data);
 	if((widget == NULL) || (key == NULL) || (recbin == NULL))
@@ -271,11 +274,11 @@ gint EDVRecBinKeyEventCB(
 	if(core_ptr == NULL)
 	    return(status);
 
-	/* Get event type */
+	w = recbin->toplevel;
+	focus_widget = (w != NULL) ? GTK_WINDOW(w)->focus_widget : NULL;
+	cfg_list = core_ptr->cfg_list;
 	etype = key->type;
-
-	/* Get other key event values */
-	press = (etype == GDK_KEY_PRESS) ? TRUE : FALSE;
+	is_press = (etype == GDK_KEY_PRESS) ? TRUE : FALSE;
 	keyval = key->keyval;
 	state = key->state;
 
@@ -283,67 +286,57 @@ gint EDVRecBinKeyEventCB(
 #define DO_STOP_KEY_SIGNAL_EMIT	{		\
  gtk_signal_emit_stop_by_name(			\
   GTK_OBJECT(widget),				\
-  press ?					\
+  is_press ?					\
    "key_press_event" : "key_release_event"	\
  );						\
 }
 
-	/* Check which ctree this signal is for */
-
-	/* Contents clist */
-	if(widget == recbin->contents_clist)
+	/* If the focus_widget is not a GtkEditable then check if the
+	 * keyval is an accelerator key before all subsequence checks
+	 */
+	if((focus_widget != NULL) ?
+	    !GTK_IS_EDITABLE(focus_widget) : TRUE
+	)
 	{
-	    gint row;
-	    GList *glist;
-	    GtkCList *clist = GTK_CLIST(widget);
-
-
-	    /* Get last selected row */
-	    row = EDVCListGetSelectedLast(clist, NULL);
-
-	    /* Handle by key value */
-	    switch(keyval)
+	    edv_recbin_op op = (edv_recbin_op)EDVMatchAccelKeyOPID(
+		cfg_list, EDV_CFG_PARM_RECBIN_ACCELERATOR_KEYS,
+		keyval, state
+	    );
+	    if(op > 0)
 	    {
-	      case GDK_Return:
-	      case GDK_KP_Enter:
-	      case GDK_ISO_Enter:
-	      case GDK_3270_Enter:
-#if 0
-		/* Handle only if control key modifier is not held, so
-		 * that accelerator keys will get handled properly.
-		 */
-		if(!(state & GDK_CONTROL_MASK))
+		if(is_press)
 		{
-		    if(press)
-			EDVRecBinOPRecover(recbin);
-
-		    DO_STOP_KEY_SIGNAL_EMIT
-		    status = TRUE;
-		}
-#endif
-		break;
-
-	      case GDK_Delete:
-		if(press)
-		{
-		    if(state & GDK_SHIFT_MASK)
-			EDVRecBinOPPurgeAll(recbin);
-		    else
-			EDVRecBinOPPurge(recbin);
+		    edv_recbin_opid_struct *opid = EDVRecBinMatchOPID(
+			recbin, op
+		    );
+		    if(opid != NULL)
+			EDVRecBinOPCB(NULL, -1, opid);
 		}
 		DO_STOP_KEY_SIGNAL_EMIT
 		status = TRUE;
-		break;
+		return(status);
+	    }
+	}
 
+	/* Check which widget this signal is for */
+
+	/* Contents List */
+	if(widget == recbin->contents_clist)
+	{
+	    GtkCList *clist = GTK_CLIST(widget);
+	    gint row = EDVCListGetSelectedLast(clist, NULL);
+
+	    switch(keyval)
+	    {
 	      case GDK_space:
 	      case GDK_KP_Space:
 		row = clist->focus_row;
-		if((row >= 0) && (row < clist->rows) && press)
+		if((row >= 0) && (row < clist->rows) && is_press)
 		{
 		    gboolean already_selected = FALSE;
 
 		    /* Check if this row is already selected */
-		    glist = clist->selection;
+		    GList *glist = clist->selection;
 		    while(glist != NULL)
 		    {
 			if(row == (gint)glist->data)
@@ -371,39 +364,40 @@ gint EDVRecBinKeyEventCB(
 		 * item who's name starts with the letter of the key
 		 * that was pressed
 		 */
-		if(isalnum((char)keyval) && press &&
+		if(isalnum((char)keyval) && is_press &&
 		   ((state == 0x00000000) || (state == GDK_SHIFT_MASK))
 		)
 		{
 		    /* Get the column that is displaying the object
 		     * name as column_type_name
 		     */
-		    gint i, column_type_name = -1;
-		    const cfg_intlist_struct *column_type_intlist =
-			CFGItemListGetValueIntList(
-			    core_ptr->cfg_list,
-			    EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN
-			);
-		    if(column_type_intlist != NULL)
+		    gint column_type_name = -1;
+		    const cfg_item_struct *cfg_list = core_ptr->cfg_list;
+		    const cfg_intlist_struct *intlist = EDV_GET_INTLIST(
+			EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN
+		    );
+		    if(intlist != NULL)
 		    {
 			/* Iterate through column type intlist */
-			for(i = 0; i < column_type_intlist->total; i++)
+			gint i = 0;
+			GList *glist = intlist->list;
+			while(glist != NULL)
 			{
-			    /* Is column i displaying the name? */
-			    if(column_type_intlist->i[i] == EDV_RECBIN_COLUMN_TYPE_NAME)
+			    if((edv_recbin_column_type)glist->data ==
+				EDV_RECBIN_COLUMN_TYPE_NAME
+			    )
 			    {
 				column_type_name = i;
 				break;
 			    }
+			    i++;
+			    glist = g_list_next(glist);
 			}
 		    }
 
 		    gtk_clist_freeze(clist);
 		    EDVCListSeekCharacter(
-			clist, column_type_name, 0,
-			(gchar)((state & GDK_SHIFT_MASK) ?
-			    toupper((char)keyval) : keyval
-			)
+			clist, column_type_name, 0, keyval
 		    );
 		    gtk_clist_thaw(clist);
 
@@ -411,7 +405,6 @@ gint EDVRecBinKeyEventCB(
 		    status = TRUE;
 		}
 		break;
-
 	    }
 	}
 
@@ -597,18 +590,18 @@ void EDVRecBinResizeColumnCB(
 	/* Check which clist this signal is for */
 	if(GTK_WIDGET(clist) == recbin->contents_clist)
 	{
-	    gint column_type = -1;
+	    edv_recbin_column_type column_type = EDV_RECBIN_COLUMN_TYPE_NAME;
 	    cfg_intlist_struct *column_types_intlist, *column_width_intlist;
 
-
 	    /* Get column_type from the given column index */
 	    column_types_intlist = CFGItemListGetValueIntList(
 		core_ptr->cfg_list, EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN
 	    );
 	    if(column_types_intlist != NULL)
 	    {
-		if((column >= 0) && (column < column_types_intlist->total))
-		    column_type = column_types_intlist->i[column];
+		column_type = (edv_recbin_column_type)g_list_nth_data(
+		    column_types_intlist->list, column
+		);
 	    }
 
 	    /* Get column widths intlist */
@@ -617,37 +610,17 @@ void EDVRecBinResizeColumnCB(
 	    );
 	    if(column_width_intlist != NULL)
 	    {
-		/* Need to increase column_width_intlist allocation? */
-		if((column_type >= column_width_intlist->total) &&
-		   (column_type >= 0)
-		)
-		{
-		    gint n;
-		    gint prev_total = column_width_intlist->total;
-
-		    /* Increase array allocation */
-		    column_width_intlist->total = column_type + 1;
-		    column_width_intlist->i = (gint *)g_realloc(
-			column_width_intlist->i,
-			column_width_intlist->total * sizeof(gint)
+		GList *glist = g_list_nth(
+		    column_width_intlist->list, (guint)column_type
+		);
+		if(glist != NULL)
+		    glist->data = (gpointer)width;
+		else
+		    g_printerr(
+"EDVRecBinResizeColumnCB(): Warning:\
+ Specified column type %i not in list of column widths.\n",
+			column_type
 		    );
-		    /* Reset newly allocated indexes */
-		    for(n = prev_total; n < column_width_intlist->total; n++)
-			column_width_intlist->i[n] = 0;
-		}
-
-		/* Got column type in bounds as index on column width
-		 * intlist?
-		 */
-		if((column_type >= 0) &&
-		   (column_type < column_width_intlist->total)
-		)
-		{
-		    /* Record new width of column on the column width
-		     * intlist.
-		     */
-		    column_width_intlist->i[column_type] = width;
-		}
 	    }
 	}
 }
@@ -693,51 +666,51 @@ void EDVRecBinClickColumnCB(
 	    );
 	    if(column_types_intlist != NULL)
 	    {
-		if((column >= 0) && (column < column_types_intlist->total))
+		edv_recbin_column_type column_type = (edv_recbin_column_type)g_list_nth_data(
+		    column_types_intlist->list,
+		    column
+		);
+		switch(column_type)
 		{
-		    gint column_type = column_types_intlist->i[column];
-		    switch(column_type)
-		    {
-		      case EDV_RECBIN_COLUMN_TYPE_NAME:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_RECBIN_COLUMN_TYPE_SIZE:
-			cmp_func = cmp_func_num;
-			break;
-		      case EDV_RECBIN_COLUMN_TYPE_TYPE:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_RECBIN_COLUMN_TYPE_PERMISSIONS:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_RECBIN_COLUMN_TYPE_OWNER:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_RECBIN_COLUMN_TYPE_GROUP:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_RECBIN_COLUMN_TYPE_DATE_ACCESS:
-			cmp_func = EDVRecBinCListColumnSortDateAccessCB;
-			break;
-		      case EDV_RECBIN_COLUMN_TYPE_DATE_MODIFIED:
-			cmp_func = EDVRecBinCListColumnSortDateModifyCB;
-			break;
-		      case EDV_RECBIN_COLUMN_TYPE_DATE_CHANGED:
-			cmp_func = EDVRecBinCListColumnSortDateChangeCB;
-			break;
-		      case EDV_RECBIN_COLUMN_TYPE_DATE_DELETED:
-			cmp_func = EDVRecBinCListColumnSortDateDeleteCB;
-			break;
-		      case EDV_RECBIN_COLUMN_TYPE_LINKED_TO:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_RECBIN_COLUMN_TYPE_ORIGINAL_LOCATION:
-			cmp_func = cmp_func_str;
-			break;
-		      case EDV_RECBIN_COLUMN_TYPE_INDEX:
-			cmp_func = cmp_func_num;
-			break;
-		    }
+		  case EDV_RECBIN_COLUMN_TYPE_NAME:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_RECBIN_COLUMN_TYPE_SIZE:
+		    cmp_func = cmp_func_num;
+		    break;
+		  case EDV_RECBIN_COLUMN_TYPE_TYPE:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_RECBIN_COLUMN_TYPE_PERMISSIONS:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_RECBIN_COLUMN_TYPE_OWNER:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_RECBIN_COLUMN_TYPE_GROUP:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_RECBIN_COLUMN_TYPE_DATE_ACCESS:
+		    cmp_func = EDVRecBinCListColumnSortDateAccessCB;
+		    break;
+		  case EDV_RECBIN_COLUMN_TYPE_DATE_MODIFIED:
+		    cmp_func = EDVRecBinCListColumnSortDateModifyCB;
+		    break;
+		  case EDV_RECBIN_COLUMN_TYPE_DATE_CHANGED:
+		    cmp_func = EDVRecBinCListColumnSortDateChangeCB;
+		    break;
+		  case EDV_RECBIN_COLUMN_TYPE_DATE_DELETED:
+		    cmp_func = EDVRecBinCListColumnSortDateDeleteCB;
+		    break;
+		  case EDV_RECBIN_COLUMN_TYPE_LINKED_TO:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_RECBIN_COLUMN_TYPE_ORIGINAL_LOCATION:
+		    cmp_func = cmp_func_str;
+		    break;
+		  case EDV_RECBIN_COLUMN_TYPE_INDEX:
+		    cmp_func = cmp_func_num;
+		    break;
 		}
 	    }
 
@@ -1054,7 +1027,7 @@ void EDVRecBinReconfiguredNotifyCB(edv_recbin_struct *recbin)
 	GtkWidget *w;
 	GtkCList *clist;
 	const cfg_item_struct *cfg_list;
-	edv_status_bar_struct *status_bar;
+	edv_statusbar_struct *status_bar;
 	edv_core_struct *core_ptr;
 
 
@@ -1083,8 +1056,11 @@ void EDVRecBinReconfiguredNotifyCB(edv_recbin_struct *recbin)
 	/* Update title */
 	EDVRecBinSetTitle(recbin);
 
-	/* Regenerate tool bar */
-	EDVRecBinToolbarRegenerate(recbin);
+	/* Update Accelkey Labels */
+	EDVRecBinAccelkeysRegenerate(recbin);
+
+	/* Regenerate Tool Bar */
+	EDVRecBinToolBarRegenerate(recbin);
 
 	/* Show tool bar? */
 	w = recbin->tool_bar_handle;
