@@ -25,6 +25,7 @@
 #include "edvcb.h"
 #include "edvutils.h"
 #include "edvutilsgtk.h"
+
 #include "edvcfglist.h"
 #include "config.h"
 
@@ -159,14 +160,15 @@ static void EDVRecBinContentsResetColumns(
 	GtkCList *clist
 )
 {
-	gint i, m, width, justify = GTK_JUSTIFY_LEFT;
+	gint i, width;
 	const gchar *title = NULL;
-	edv_recbin_column_type column_type;
+	GList *glist;             
+	GtkJustification justify = GTK_JUSTIFY_LEFT;
 	GtkRcStyle *lists_rcstyle;
-	const cfg_intlist_struct	*column_types_intlist,
-					*column_width_intlist;
+	cfg_intlist_struct	*column_types_intlist,
+				*column_width_intlist;
 	const cfg_item_struct *cfg_list;
-
+	edv_recbin_column_type column_type;
 
 	if((core_ptr == NULL) || (recbin == NULL) || (clist == NULL))
 	    return;
@@ -195,7 +197,6 @@ static void EDVRecBinContentsResetColumns(
 	gtk_clist_set_auto_sort(clist, FALSE);
 	gtk_clist_set_sort_type(clist, GTK_SORT_DESCENDING);
 
-
 #if 0
 /* Already set */
 	/* Change clist selection mode to GTK_SELECTION_EXTENDED
@@ -206,25 +207,23 @@ static void EDVRecBinContentsResetColumns(
 	gtk_clist_set_selection_mode(clist, GTK_SELECTION_EXTENDED);
 #endif
 
-	/* Get number of columns defined */
-	m = MIN(
-	    MIN(clist->columns, column_types_intlist->total),
-	    column_width_intlist->total
-	);
-
-	/* Iterate through defined columns */
-	for(i = 0; i < m; i++)
+	/* Iterate through each column */
+	for(i = 0, glist = column_types_intlist->list;
+	    glist != NULL;
+	    i++, glist = g_list_next(glist)
+	)
 	{
-	    /* Get column type */
-	    column_type = (edv_recbin_column_type)column_types_intlist->i[i];
+	    column_type = (edv_recbin_column_type)glist->data;
 
-	    /* Get width of the column displaying this type */
-	    if((column_type >= 0) && (column_type < column_width_intlist->total))
-		width = column_width_intlist->i[column_type];
-	    else
-		width = 0;
+	    /* Get the width for this column type */
+	    width = (gint)g_list_nth_data(
+		column_width_intlist->list,
+		(guint)column_type
+	    );
 
-	    /* Get column title and attributes based on column type */
+	    /* Get column title and justification  based on the
+	     * column type
+	     */
 	    switch(column_type)
 	    {
 	      case EDV_RECBIN_COLUMN_TYPE_NAME:
@@ -289,7 +288,7 @@ static void EDVRecBinContentsResetColumns(
 	    gtk_clist_set_column_width(clist, i, width);
 	    gtk_clist_set_column_justification(clist, i, justify);
 	}
-	/* Hide the rest of the columns on the clist */
+	/* Reset the rest of the columns */
 	for(; i < clist->columns; i++)
 	    gtk_clist_set_column_visibility(clist, i, FALSE);
 
@@ -377,8 +376,8 @@ static void EDVRecBinContentsSetCellSize(
 	gboolean hide_dir_size, gboolean hide_link_size
 )
 {
-	gint	border_minor = 2,
-		type = obj->type;
+	const gint border_minor = 2;
+	const edv_object_type type = obj->type;
 	const gchar *s;
 
 	/* Get size string */
@@ -437,7 +436,7 @@ static void EDVRecBinContentsSetCellPermissions(
 	gint row, gint column, gboolean hide_link_permissions
 )
 {
-	edv_permission_flags permissions = obj->permissions;
+	const edv_permission_flags permissions = obj->permissions;
 	gchar s[80];
 
 	/* Get permissions string */
@@ -663,9 +662,9 @@ static void EDVRecBinContentsSetCellLinkedTo(
 )
 {
 	/* Get link destination */
-	const gchar *link_dest = ((obj->linked_to != NULL) &&
+	const gchar *link_dest = ((obj->link_value != NULL) &&
 	    (obj->type == EDV_OBJECT_TYPE_LINK)) ?
-	    obj->linked_to : "";
+	    obj->link_value : "";
 
 	/* Set cell */
 	gtk_clist_set_text(
@@ -696,13 +695,13 @@ static void EDVRecBinContentsSetCellOriginalLocation(
 	if(!lstat(location, &lstat_buf))
 	{
 	    EDVObjectSetStat(loc_obj, &lstat_buf);
-	    loc_obj->link_valid = TRUE;
+	    EDVObjectUpdateLinkFlags(loc_obj);
 	    EDVMatchObjectIcon(
 		core_ptr->device, core_ptr->total_devices,
 		core_ptr->mimetype, core_ptr->total_mimetypes,
 		loc_obj->type,
 		loc_obj->full_path,
-		loc_obj->link_valid,
+		EDV_OBJECT_IS_LINK_VALID(loc_obj),
 		loc_obj->permissions,
 		0,			/* Small icons */
 		&pixmap, &mask,
@@ -754,7 +753,7 @@ static void EDVRecBinContentsSetCellIndex(
 	gint row, gint column
 )
 {
-	gint border_minor = 2;
+	const gint border_minor = 2;
  	gchar num_str[80];
 
 	/* Get index string */
@@ -786,14 +785,14 @@ static void EDVRecBinContentsSetRow(
 	gint row
 )
 {
+	gint i;
 	gboolean hide_dir_size, hide_link_size, hide_link_permissions;
-	gint i, columns;
-	edv_date_relativity date_relativity;
 	const gchar *date_format;
+	GList *glist;
+	edv_date_relativity date_relativity;
 	edv_recbin_column_type column_type;
-	const cfg_item_struct *cfg_list;
 	cfg_intlist_struct *column_types_intlist;
-
+	const cfg_item_struct *cfg_list;   
 
 	if((core_ptr == NULL) || (recbin == NULL) ||
 	   (clist == NULL) || (obj == NULL)
@@ -818,17 +817,13 @@ static void EDVRecBinContentsSetRow(
 	hide_link_size = EDV_GET_B(EDV_CFG_PARM_RECBIN_CONTENTS_HIDE_LINK_SIZE);
 	hide_link_permissions = EDV_GET_B(EDV_CFG_PARM_RECBIN_CONTENTS_HIDE_LINK_PERMISSIONS);
 
-
-	/* Get number of columns defined */
-	columns = MIN(clist->columns, column_types_intlist->total);
-
-	/* Iterate through defined columns */
-	for(i = 0; i < columns; i++)
+	/* Iterate through each column */
+	for(i = 0, glist = column_types_intlist->list;
+	    glist != NULL;
+	    i++, glist = g_list_next(glist)
+	)
 	{
-	    /* Check column references on configuration list, see which
-	     * one this column should show
-	     */
-	    column_type = (edv_recbin_column_type)column_types_intlist->i[i];
+	    column_type = (edv_recbin_column_type)glist->data;
 	    switch(column_type)
 	    {
 	      case EDV_RECBIN_COLUMN_TYPE_NAME:
