@@ -1,5 +1,5 @@
 /*
-                 Endeavour Recycle Bin Contents List
+		 Endeavour Recycle Bin Contents List
  */
 
 #ifndef RECBINCONTENTS_H
@@ -10,22 +10,22 @@
 
 
 extern gint EDVRecBinContentsFindRowByIndex(
-        edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, guint index
 );
 
 extern void EDVRecBinContentsResetRows(edv_recbin_struct *recbin);
 extern void EDVRecBinContentsDoUpdate(
-        edv_recbin_struct *recbin, gbool update_status_bar
+	edv_recbin_struct *recbin, gboolean update_status_bar
 );
 
 extern void EDVRecBinContentsObjectAddedNotify(
 	edv_recbin_struct *recbin, guint index
 );
 extern void EDVRecBinContentsObjectModifiedNotify(
-        edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, guint index
 );
 extern void EDVRecBinContentsObjectRemovedNotify(
-        edv_recbin_struct *recbin, guint index
+	edv_recbin_struct *recbin, guint index
 );
 
 
