@@ -1,5 +1,5 @@
 /*
-                       Recycle Bin Desktop Icon
+		       Recycle Bin Desktop Icon
  */
 
 #ifndef RECBINDESKICON_H
@@ -14,17 +14,20 @@
  */
 typedef struct {
 
-	gpointer core_ptr;
+	gpointer	core_ptr;
 
-	deskicon_struct *deskicon;
+	deskicon_struct	*deskicon;
 
-        /* Last known items in recycle bin, this is used as a quick access
-         * value to check if the recycle bin has contents or not. Can be
-         * -1 to indicate undefined.
-         */
-        gint last_recbin_items;
+	/* Last known items in recycle bin, this is used as a quick
+	 * access value to check if the recycle bin has contents or
+	 * not
+	 *
+	 * Can be -1 to indicate undefined
+	 */
+	gint		last_recbin_items;
 
 } edv_recbin_deskicon_struct;
+#define EDV_RECBIN_DESKICON(p)	((edv_recbin_deskicon_struct *)(p))
 
 
 extern edv_recbin_deskicon_struct *EDVRecBinDeskIconNew(
