@@ -5,12 +5,15 @@
 #include "guiutils.h"
 #include "cdialog.h"
 #include "progressdialog.h"
+#include "toolbar.h"
 
 #include "cfg.h"
 #include "edvtypes.h"
 #include "edvobj.h"
 #include "edvrecbin.h"
 #include "edvrecbinfio.h"
+#include "findbar.h"
+#include "statusbar.h"
 #include "edvconfirm.h"
 #include "edvutils.h"
 #include "endeavour.h"
@@ -47,9 +50,9 @@ void EDVRecBinOPLeaveCB(
 	toolbar_item_struct *item, gint id, gpointer data
 );
 
-void EDVRecBinFindBarStartCB(gpointer fb, gpointer data);
+void EDVRecBinFindBarStartCB(edv_findbar_struct *fb, gpointer data);
 void EDVRecBinFindBarEndCB(
-	gpointer fb, gint total_matches, gpointer data
+	edv_findbar_struct *fb, gint total_matches, gpointer data
 );
 void EDVRecBinFindBarMatchCB(
 	const gchar *path, const struct stat *lstat_buf,
@@ -57,12 +60,8 @@ void EDVRecBinFindBarMatchCB(
 	gpointer data
 );
 
-void EDVRecBinBarStatusMessageCB(
-	gpointer bar, const gchar *message, gpointer data
-);
-void EDVRecBinBarStatusProgressCB(
-	gpointer bar, gfloat progress, gpointer data
-);
+void EDVRecBinStatusMessageCB(const gchar *message, gpointer data);
+void EDVRecBinStatusProgressCB(gfloat progress, gpointer data);
 
 void EDVRecBinOPSyncRecycleBin(edv_recbin_struct *recbin);
 
@@ -146,7 +145,7 @@ void EDVRecBinOPCB(
 	if(opid == NULL)
 	    return;
 
-	recbin = EDV_RECBIN(opid->recbin);
+	recbin = opid->recbin;
 	if(recbin == NULL)
 	    return;
 
@@ -351,9 +350,7 @@ void EDVRecBinOPEnterCB(
 {
 	const gchar *tooltip;
 	edv_recbin_opid_struct *opid = EDV_RECBIN_OPID(data);
-	edv_recbin_struct *recbin = EDV_RECBIN(
-	    (opid != NULL) ? opid->recbin : NULL
-	);
+	edv_recbin_struct *recbin = (opid != NULL) ? opid->recbin : NULL;
 	if(recbin == NULL)
 	    return;
 
@@ -370,9 +367,7 @@ void EDVRecBinOPLeaveCB(
 )
 {
 	edv_recbin_opid_struct *opid = EDV_RECBIN_OPID(data);
-	edv_recbin_struct *recbin = EDV_RECBIN(
-	    (opid != NULL) ? opid->recbin : NULL
-	);
+	edv_recbin_struct *recbin = (opid != NULL) ? opid->recbin : NULL;
 	if(recbin == NULL)
 	    return;
 
@@ -383,7 +378,7 @@ void EDVRecBinOPLeaveCB(
 /*
  *      Find bar start find callback.
  */
-void EDVRecBinFindBarStartCB(gpointer fb, gpointer data)
+void EDVRecBinFindBarStartCB(edv_findbar_struct *fb, gpointer data)
 {
 	GtkCList *clist;
 	edv_recbin_struct *recbin = EDV_RECBIN(data);
@@ -408,7 +403,7 @@ void EDVRecBinFindBarStartCB(gpointer fb, gpointer data)
  *      Find bar end find callback.
  */
 void EDVRecBinFindBarEndCB(
-	gpointer fb, gint total_matches, gpointer data
+	edv_findbar_struct *fb, gint total_matches, gpointer data
 )
 {
 	edv_recbin_struct *recbin = EDV_RECBIN(data);
@@ -446,12 +441,9 @@ void EDVRecBinFindBarMatchCB(
 
 
 /*
- *      Opaque status bar message update callback, the first argument
- *      bar is completely ignored.
+ *	Status message callback.
  */
-void EDVRecBinBarStatusMessageCB(
-	gpointer bar, const gchar *message, gpointer data
-)
+void EDVRecBinStatusMessageCB(const gchar *message, gpointer data)
 {
 	edv_recbin_struct *recbin = EDV_RECBIN(data);
 	if(recbin == NULL)
@@ -461,12 +453,9 @@ void EDVRecBinBarStatusMessageCB(
 }
 
 /*
- *      Opaque status bar progress update callback, the first argument
- *      bar is completely ignored.
+ *	Status progress callback.
  */
-void EDVRecBinBarStatusProgressCB(
-	gpointer bar, gfloat progress, gpointer data
-)
+void EDVRecBinStatusProgressCB(gfloat progress, gpointer data)
 {
 	edv_recbin_struct *recbin = EDV_RECBIN(data);
 	if(recbin == NULL)
@@ -477,7 +466,9 @@ void EDVRecBinBarStatusProgressCB(
 
 
 /*
- *	Compact recycled objects and fix any errors.
+ *	Sync Recycle Bin.
+ *
+ *	Compacts recycled objects and fix any errors.
  */
 void EDVRecBinOPSyncRecycleBin(edv_recbin_struct *recbin)
 {
@@ -505,8 +496,8 @@ void EDVRecBinOPSyncRecycleBin(edv_recbin_struct *recbin)
 	    recbin->toplevel,
 	    TRUE, TRUE,
 	    &yes_to_all,
-	    EDVRecBinBarStatusMessageCB,
-	    EDVRecBinBarStatusProgressCB,
+	    EDVRecBinStatusMessageCB,
+	    EDVRecBinStatusProgressCB,
 	    recbin
 	);
 
