@@ -5,8 +5,9 @@
 #ifndef RECBINOPCB_H
 #define RECBINOPCB_H
 
-
 #include <gtk/gtk.h>
+#include "toolbar.h"
+#include "findbar.h"
 #include "recbin.h"
 
 
@@ -28,9 +29,9 @@ extern void EDVRecBinOPLeaveCB(
 	toolbar_item_struct *item, gint id, gpointer data
 );
 
-extern void EDVRecBinFindBarStartCB(gpointer fb, gpointer data);
+extern void EDVRecBinFindBarStartCB(edv_findbar_struct *fb, gpointer data);
 extern void EDVRecBinFindBarEndCB(
-	gpointer fb, gint total_matches, gpointer data
+	edv_findbar_struct *fb, gint total_matches, gpointer data
 );
 extern void EDVRecBinFindBarMatchCB(
 	const gchar *path, const struct stat *lstat_buf,
@@ -38,12 +39,8 @@ extern void EDVRecBinFindBarMatchCB(
 	gpointer data
 );
 
-extern void EDVRecBinBarStatusMessageCB(
-	gpointer bar, const gchar *message, gpointer data
-);
-extern void EDVRecBinBarStatusProgressCB(
-	gpointer bar, gfloat progress, gpointer data
-);
+extern void EDVRecBinStatusMessageCB(const gchar *message, gpointer data);
+extern void EDVRecBinStatusProgressCB(gfloat progress, gpointer data);
 
 extern void EDVRecBinOPSyncDisks(edv_recbin_struct *recbin);
 extern void EDVRecBinOPWriteProtect(edv_recbin_struct *recbin);
