@@ -765,25 +765,16 @@ static void EDVRunDlgCompleteCommand(edv_run_dlg_struct *d)
 	    s = g_path_is_absolute(prog) ? NULL : EDVWhich(prog);
 	    if(s != NULL)
 	    {
+		GtkCombo *combo = GTK_COMBO(d->run_combo);
+
 		/* Set new program with completed path */
 		g_free(prog);
 		prog = s;
 
 		/* Format and set new command */
-		if(args != NULL)
-		    s = g_strdup_printf(
-			"%s %s",
-			prog, args
-		    );
-		else
-		    s = g_strdup_printf(
-			"%s",
-			prog 
-		    );
-		gtk_entry_set_text(
-		    GTK_ENTRY(GTK_COMBO(d->run_combo)->entry),
-		    s
-		);
+		s = (args != NULL) ?
+		    g_strconcat(prog, " ", args, NULL) : g_strdup(prog);
+		gtk_entry_set_text(GTK_ENTRY(combo->entry), s);
 		g_free(s);
 	    }
 
