@@ -607,7 +607,7 @@ static void StyleEditPreviewDraw(style_edit_struct *se)
 	    gc = style->text_gc[state];
 	    gdk_draw_string(
 		drawable, font, gc,
-		x + lbearing,
+		x - lbearing,
 		y + font->ascent,
 		s
 	    );
@@ -639,7 +639,7 @@ static void StyleEditPreviewDraw(style_edit_struct *se)
 	    gc = style->text_gc[state];
 	    gdk_draw_string(
 		drawable, font, gc,
-		x + lbearing,
+		x - lbearing,
 		y + font->ascent,
 		s
 	    );
