@@ -310,11 +310,13 @@ void ZipToolMountCB(GtkWidget *widget, gpointer data)
 	gboolean got_error = FALSE;
 	const gchar *cmd, *tmp_dir;
 	gchar *stderr_path;
+	GtkWidget *toplevel;
 	edv_device_struct *dev_ptr;
 	zip_tool_struct *zt = ZIP_TOOL(data);
 	if(zt == NULL)
 	    return;
 
+	toplevel = zt->toplevel;
 	dev_ptr = zt->device;
 	if(dev_ptr == NULL)
 	    return;
@@ -323,7 +325,7 @@ void ZipToolMountCB(GtkWidget *widget, gpointer data)
 	if(STRISEMPTY(cmd))
 	{
 	    EDVPlaySoundWarning(zt->ctx);
-	    CDialogSetTransientFor(zt->toplevel);
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 		"Mount Failed",
 "There is no mount command defined for this device",
@@ -359,10 +361,10 @@ program again.",
 
 	    if(!stat(stderr_path, &stat_buf))
 	    {
-		if(stat_buf.st_size > 0)
+		if(stat_buf.st_size > 0l)
 		{
 		    EDVPlaySoundWarning(zt->ctx);
-		    CDialogSetTransientFor(zt->toplevel);
+		    CDialogSetTransientFor(toplevel);
 		    CDialogGetResponseFile(
 			"Mount Warning",
 			stderr_path,
@@ -384,7 +386,7 @@ program again.",
 		cmd
 	    );
 	    EDVPlaySoundError(zt->ctx);
-	    CDialogSetTransientFor(zt->toplevel);
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 		"Mount Failed",
 		cmd,
@@ -412,11 +414,13 @@ program again.",
 #else   /* ZIP_TOOL_USE_ENDEAVOUR_MOUNT */
 	gboolean got_error = FALSE;
 	gint status;
+	GtkWidget *toplevel;
 	edv_device_struct *dev_ptr;
 	zip_tool_struct *zt = ZIP_TOOL(data);
 	if(zt == NULL)
 	    return;
 
+	toplevel = zt->toplevel;
 	dev_ptr = zt->device;
 	if(dev_ptr == NULL)
 	    return;
@@ -433,7 +437,7 @@ program again.",
 	    if(!STRISEMPTY(buf))
 	    {
 		EDVPlaySoundError(zt->ctx);
-		CDialogSetTransientFor(zt->toplevel);
+		CDialogSetTransientFor(toplevel);
 		CDialogGetResponse(
 "Error Mounting Device",
 buf,
@@ -480,11 +484,13 @@ void ZipToolUnmountCB(GtkWidget *widget, gpointer data)
 	gboolean got_error = FALSE;
 	const gchar *cmd, *tmp_dir;
 	gchar *stderr_path;
+	GtkWidget *toplevel;
 	edv_device_struct *dev_ptr;
 	zip_tool_struct *zt = ZIP_TOOL(data);
 	if(zt == NULL)
 	    return;
 
+	toplevel = zt->toplevel;
 	dev_ptr = zt->device;
 	if(dev_ptr == NULL)
 	    return;
@@ -493,7 +499,7 @@ void ZipToolUnmountCB(GtkWidget *widget, gpointer data)
 	if(STRISEMPTY(cmd))
 	{
 	    EDVPlaySoundWarning(zt->ctx);
-	    CDialogSetTransientFor(zt->toplevel);
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 		"Unmount Failed",
 "There is no unmount command defined for this device",
@@ -536,7 +542,7 @@ program again.",
 		if(stat_buf.st_size > 0)
 		{
 		    EDVPlaySoundWarning(zt->ctx);
-		    CDialogSetTransientFor(zt->toplevel);
+		    CDialogSetTransientFor(toplevel);
 		    CDialogGetResponseFile(
 			"Unmount Warning",
 			stderr_path,
@@ -558,7 +564,7 @@ program again.",
 		cmd
 	    );
 	    EDVPlaySoundError(zt->ctx);
-	    CDialogSetTransientFor(zt->toplevel);
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 		"Unmount Error",
 		cmd,
@@ -586,11 +592,13 @@ program again.",
 #else	/* ZIP_TOOL_USE_ENDEAVOUR_MOUNT */
 	gboolean got_error = FALSE;
 	gint status;
+	GtkWidget *toplevel;
 	edv_device_struct *dev_ptr;
 	zip_tool_struct *zt = ZIP_TOOL(data);
 	if(zt == NULL)
 	    return;
 
+	toplevel = zt->toplevel;
 	dev_ptr = zt->device;
 	if(dev_ptr == NULL)
 	    return;
@@ -607,7 +615,7 @@ program again.",
 	    if(!STRISEMPTY(buf))
 	    {
 		EDVPlaySoundError(zt->ctx);
-		CDialogSetTransientFor(zt->toplevel);
+		CDialogSetTransientFor(toplevel);
 		CDialogGetResponse(
 "Error Unmounting Device",
 buf,
@@ -652,11 +660,13 @@ void ZipToolSpinDownCB(GtkWidget *widget, gpointer data)
 {
 	gboolean got_error = FALSE;
 	gint status;
+	GtkWidget *toplevel;
 	edv_device_struct *dev_ptr;
 	zip_tool_struct *zt = ZIP_TOOL(data);
 	if(zt == NULL)
 	    return;
 
+	toplevel = zt->toplevel;
 	dev_ptr = zt->device;
 	if(dev_ptr == NULL)
 	    return;
@@ -673,7 +683,7 @@ void ZipToolSpinDownCB(GtkWidget *widget, gpointer data)
 	    if(!STRISEMPTY(buf))
 	    {
 		EDVPlaySoundError(zt->ctx);
-		CDialogSetTransientFor(zt->toplevel);
+		CDialogSetTransientFor(toplevel);
 		CDialogGetResponse(
 "Error Spinning Down Device",
 buf,
@@ -719,11 +729,13 @@ void ZipToolEjectCB(GtkWidget *widget, gpointer data)
 {
 	gboolean got_error = FALSE;
 	gint status;
+	GtkWidget *toplevel;
 	edv_device_struct *dev_ptr;
 	zip_tool_struct *zt = ZIP_TOOL(data);
 	if(zt == NULL)
 	    return;
 
+	toplevel = zt->toplevel;
 	dev_ptr = zt->device;
 	if(dev_ptr == NULL)
 	    return;
@@ -740,7 +752,7 @@ void ZipToolEjectCB(GtkWidget *widget, gpointer data)
 	    if(!STRISEMPTY(buf))
 	    {
 		EDVPlaySoundError(zt->ctx);
-		CDialogSetTransientFor(zt->toplevel);
+		CDialogSetTransientFor(toplevel);
 		CDialogGetResponse(
 "Error Ejecting Media",
 buf,
@@ -785,24 +797,28 @@ void ZipToolPasswordCB(GtkWidget *widget, gpointer data)
 	gint status;
 	gchar **strv;
 	gint strc;
+	GtkWidget *toplevel;
+	edv_device_struct *dev;
 	zip_tool_lock_state lock_state;
 	zip_tool_struct *zt = ZIP_TOOL(data);
 	if((zt == NULL) || CDialogIsQuery() || PDialogIsQuery())
 	    return;
 
-	if(zt->device == NULL)
+	toplevel = zt->toplevel;
+	dev = zt->device;
+	if(dev == NULL)
 	    return;
 
-	if(zt->device->is_mounted)
+	if(EDV_DEVICE_IS_MOUNTED(dev))
 	{
-	    EDVPlaySoundError(zt->ctx);
-	    CDialogSetTransientFor(zt->toplevel);
+	    EDVPlaySoundWarning(zt->ctx);
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
-"Error Locking/Unlocking Media",
+"Unable To Lock/Unlock Media",
 "The device must be unmounted first, before\n\
 locking or unlocking the media.",
 		NULL,
-		CDIALOG_ICON_ERROR,
+		CDIALOG_ICON_WARNING,
 		CDIALOG_BTNFLAG_OK,
 		CDIALOG_BTNFLAG_OK
 	    );
@@ -828,7 +844,7 @@ locking or unlocking the media.",
 		NULL, "Password:", NULL
 	    );
 	    PDialogSetSize(300, -1);
-	    PDialogSetTransientFor(zt->toplevel);
+	    PDialogSetTransientFor(toplevel);
 	    strv = PDialogGetResponse(
 		"Unlock Media",
 "A password is required to unlock this media,\n\
@@ -867,7 +883,7 @@ please enter the password below.",
 			break;
 		    }
 		    EDVPlaySoundError(zt->ctx);
-		    CDialogSetTransientFor(zt->toplevel);
+		    CDialogSetTransientFor(toplevel);
 		    CDialogGetResponse(
 			"Error Unlocking Media",
 			buf,
@@ -933,7 +949,7 @@ program again.",
 		    break;
 		}
 		EDVPlaySoundError(zt->ctx);
-		CDialogSetTransientFor(zt->toplevel);
+		CDialogSetTransientFor(toplevel);
 		CDialogGetResponse(
 		    "Error Unlocking Media",
 		    buf,
@@ -977,7 +993,7 @@ program again.",
 		NULL, "Confirm:", NULL
 	    );
 	    PDialogSetSize(300, -1);
-	    PDialogSetTransientFor(zt->toplevel);
+	    PDialogSetTransientFor(toplevel);
 	    strv = PDialogGetResponse(
 		"Lock Media",
 "Enter a new password that will be used to\n\
@@ -993,8 +1009,8 @@ media as read only",
 	    PDialogSetTransientFor(NULL);
 	    if((strv != NULL) && (strc >= 2))
 	    {
-		const gchar *password = strv[0];
-		const gchar *confirm = strv[1];
+		const gchar	*password = strv[0],
+				*confirm = strv[1];
 		if(!STRISEMPTY(password))
 		{
 		    /* Password given, now make sure password matches
@@ -1039,7 +1055,7 @@ media as read only",
 			break;
 		    }
 		    EDVPlaySoundError(zt->ctx);
-		    CDialogSetTransientFor(zt->toplevel);
+		    CDialogSetTransientFor(toplevel);
 		    CDialogGetResponse(
 			"Error Locking Media",
 			buf,
@@ -1129,10 +1145,13 @@ void ZipToolRefreshCB(GtkWidget *widget, gpointer data)
 void ZipToolFSCKCB(GtkWidget *widget, gpointer data)
 {
 	const gchar *cmd;
+	GtkWidget *toplevel;
 	zip_tool_struct *zt = ZIP_TOOL(data);
 	if(zt == NULL)
 	    return;
 
+	toplevel = zt->toplevel;
+
 	ZipToolSetBusy(zt, TRUE);
 
 	cmd = (zt->device != NULL) ? zt->device->command_check : NULL;
@@ -1143,7 +1162,7 @@ void ZipToolFSCKCB(GtkWidget *widget, gpointer data)
 	else
 	{
 	    EDVPlaySoundWarning(zt->ctx);
-	    CDialogSetTransientFor(zt->toplevel);
+	    CDialogSetTransientFor(toplevel);
 	    CDialogGetResponse(
 		"FSCK Program Undefined",
 "There is no defined command to run the FSCK program\n\
